/*
 *  Simple performance test of GdkPixbuf compositing
 *
 *  Author: Dan Amelang (dan@amelang.net)
 *
 *  I release this code into the public domain.
 *
 *  To compile:
 *
 *       gcc composite_pixbuf.c -o composite_pixbuf \
 *          `pkg-config --cflags gdk-2.0` `pkg-config --libs gdk-2.0`
 *
 *  Timing results:
 *
 *       N800 standard X server
 *       FPS: 4.64
 *
 *       N800 modified X server
 *       FPS: 15.92
 */

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <sys/time.h>
#include <gdk/gdk.h>

#define WINDOW_WIDTH  (800)
#define WINDOW_HEIGHT (480)
#define SCROLL_STEP     (1)

static const guint8 cairo_logo_no_text_pixbuf[];

static void
scroll_logo (GdkWindow *window, GdkPixbuf *logo)
{
    int x, frames, logo_width;
    double duration;
    struct timeval timer_start, timer_finish;
    GdkDisplay *display = gdk_display_get_default ();
    GdkRectangle window_extents = { 0, 0, WINDOW_WIDTH, WINDOW_HEIGHT };

    frames = 0;
    gettimeofday (&timer_start, NULL);
    logo_width = gdk_pixbuf_get_width (logo);

    for (x = WINDOW_WIDTH - logo_width; x > 0; x -= SCROLL_STEP) {
        gdk_window_begin_paint_rect (window, &window_extents);
        gdk_draw_pixbuf (GDK_DRAWABLE (window), NULL, logo, 0, 0,
                         x, 0, -1, -1, GDK_RGB_DITHER_NONE, 0, 0);
        gdk_window_end_paint (window);
        frames++;
    }

    gdk_display_sync (display);
    gettimeofday (&timer_finish, NULL);
    duration  = (timer_finish.tv_sec + timer_finish.tv_usec / 1000000.0);
    duration -= (timer_start.tv_sec  + timer_start.tv_usec  / 1000000.0);
    printf ("FPS: %.2f\n", frames / duration);
}

int
main (int argc, char **argv)
{
    GdkPixbuf *logo;
    GdkWindow *window;
    GdkWindowAttr attr;

    gdk_init (&argc, &argv);

    attr.width = WINDOW_WIDTH;
    attr.height = WINDOW_HEIGHT;
    attr.event_mask = 0;
    attr.wclass = GDK_INPUT_OUTPUT;
    attr.window_type = GDK_WINDOW_TOPLEVEL;
    attr.wmclass_name = NULL;
    attr.override_redirect = TRUE;
    window = gdk_window_new (NULL, &attr, GDK_WA_NOREDIR);

    logo = gdk_pixbuf_new_from_inline (-1, cairo_logo_no_text_pixbuf,
                                       FALSE, NULL);

    gdk_window_show (window);
    scroll_logo (window, logo);

    return 0;
}

/* GdkPixbuf RGBA C-Source image dump */

#ifdef __SUNPRO_C
#pragma align 4 (cairo_logo_no_text_pixbuf)
#endif
#ifdef __GNUC__
static const guint8 cairo_logo_no_text_pixbuf[] __attribute__ ((__aligned__ (4))) = 
#else
static const guint8 cairo_logo_no_text_pixbuf[] = 
#endif
{ ""
  /* Pixbuf magic (0x47646b50) */
  "GdkP"
  /* length: header (24) + pixel_data (1232640) */
  "\0\22\317\30"
  /* pixdata_type (0x1010002) */
  "\1\1\0\2"
  /* rowstride (2568) */
  "\0\0\12\10"
  /* width (642) */
  "\0\0\2\202"
  /* height (480) */
  "\0\0\1\340"
  /* pixel_data: */
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\16;\200\256/;\200"
  "\256E;\200\256[;\200\256r;\200\256\210;\200\256\236;\200\256\265;\200"
  "\256\313;\200\256\341;\200\256\364;\200\256\357;\200\256\347;\200\256"
  "\337;\200\256\327;\200\256\317;\200\256\307;\200\256\277;\200\256\267"
  ";\200\256\257;\200\256\241;\200\256w;\200\256J;\200\256\34\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\25;\200\256W;\200"
  "\256\223;\200\256\320;\200\256\375;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\356"
  ";\200\256\301;\200\256\224;\200\256f;\200\2569;\200\256\14\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256=;\200\256\247;\200\256\371;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256\321;\200"
  "\256w;\200\256\35\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256Z;\200\256\323;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\376;\200\256\277;\200\256c;\200\256\17\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256&;\200\256"
  "\274;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\367;\200\256\252;\200\256N;\200\256\5\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256\27;\200\256&;\200"
  "\2563;\200\256#;\200\256\11\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\7"
  ";\200\256\200;\200\256\370;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\354;\200\256\224;\200\256$\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\3;\200\256H;\200\256\202;\200\256\267;\200\256\353;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\357;\200\256\326;\200\256\274;\200\256\242;\200\256\210;\200\256o;\200"
  "\256E;\200\256\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256C"
  ";\200\256\332;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200"
  "\256\250;\200\256/\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\27;\200\256"
  "{;\200\256\343;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\372;\200\256\306;\200\256\206;\200"
  "\256F;\200\256\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\27;\200\256\244"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\266;\200\256<\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256e;\200\256\365;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\373;\200\256\307;\200\256\207;\200\256"
  "G;\200\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256K;\200\256\356;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\303;\200\256J\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\21;\200\256\256;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\364;\200\256\246;\200\256N;\200\256\6\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256z;\200\256\375;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\320;\200\256W;\200\256\3"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\6;\200\256\305;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357;\200"
  "\256\235;\200\256E;\200\256\3\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\13;\200\256\254;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\333;\200"
  "\256e;\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\237;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\351;\200\256\225;\200\256<;\200\256\1\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256\323"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\344;\200\256i;\200\256\6\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256c;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\343;\200\256\216;\200\256"
  "8;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256F;\200\256\356;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\340;\200\256d;\200\256\4\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\3;\200\256\335;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\340;\200"
  "\256\213;\200\2565\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256u;\200\256\374"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\334;\200\256^;\200\256\3\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256W;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\336;\200\256\210;\200\2562\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\7"
  ";\200\256\244;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\341;\200\256\260;\200\256\203;\200\256p;\200\256p;\200"
  "\256p;\200\256p;\200\256p;\200\256r;\200\256\210;\200\256\243;\200\256"
  "\276;\200\256\331;\200\256\364;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\331;\200"
  "\256Y;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\311;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\370;\200\256\360;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\333"
  ";\200\256\205;\200\256.\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\26;\200\256\305;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\257;\200\256A\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\17;\200\256*;\200\256E;\200\256_;\200\256z;\200\256"
  "\227;\200\256\266;\200\256\326;\200\256\365;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\324;\200\256T;\200"
  "\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\20;\200\256\376;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\342;\200\256b;\200\256-;\200\256\4\377\377"
  "\377\0;\200\256\31;\200\256C;\200\256p;\200\256\311;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\330;\200\256\202;\200"
  "\256+\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  ",;\200\256\337;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\207\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\25;\200\256C;\200\256\205;\200\256\310;\200\256\374;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\320;\200\256O\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256F;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\242;\200\256\17\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256,;\200\256\217;\200\256\353;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\325;\200"
  "\256\177;\200\256(\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256J;\200\256\362;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\207\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\16;\200\256P;\200\256\266"
  ";\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\313;\200\256<\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256~;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\\\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256U;\200\256\270"
  ";\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\326;\200\256\215;\200\256C;\200\256\6\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256o;\200\256\374"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\224\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256(;\200\256\226"
  ";\200\256\365;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\244;\200\256\31\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\263;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\255\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\35;\200\256~;\200\256\351;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\363;\200\256\260;\200\256g;\200\256"
  "\35\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\4;\200\256\230;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\327;\200\256\10\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\21"
  ";\200\256w;\200\256\342;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\362;\200\256s;\200\256\5\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\310;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\371;\200\256\"\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\13;\200\256v;\200\256\353;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\324;\200"
  "\256\212;\200\256A;\200\256\5\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\27;\200\256\277;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\374;\200\256"
  "6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\4"
  ";\200\256W;\200\256\307;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\326;\200\256C\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\321;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\332\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\14;\200\256y;\200\256\355;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\362;\200\256\255;\200\256d;\200\256\33\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\77;\200\256\347;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\205\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256A;\200\256\316;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\253;\200\256\35\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\333;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\321\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\15;\200\256|;\200\256\356;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\321;\200\256\207;\200"
  "\256>;\200\256\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\1;\200\256x;\200\256\374;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\322"
  ";\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\2;\200\256`;\200\256\345;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\365;\200\256z;\200\256\7\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\345;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\322\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\16;\200\256~;\200\256\357;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\360;\200"
  "\256\252;\200\256_;\200\256\26\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\22;\200\256\264"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\375;\200\2567\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\12;\200\256\200;\200\256\365;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\333;\200\256J\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\353;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256\34"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\20;\200\256\201;\200\256\361;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\375;\200\256\310;\200\256};\200\2561\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\2565;\200\256\340;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\222\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\32;\200\256\237;\200\256\375;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\262;\200\256"
  "\34\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\326;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256p\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\21;\200\256\204;\200\256\362"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\345;\200\256"
  "\232;\200\256O;\200\256\13\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256l"
  ";\200\256\371;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\343;\200\256\15"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\2561;\200\256\277;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\356;\200\256W\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\273;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\326;\200\256\6\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\23;\200\256\207;\200"
  "\256\351;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\370;\200\256\270;\200\256m;\200\256!\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\15;\200\256\250;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256N\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256O;\200\256\332;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\243;\200\256\17"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\241;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\202\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256@;\200"
  "\256\224;\200\256\346;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\326;\200\256\212;\200\256\77;\200"
  "\256\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256-;\200\256\330;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\232\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\5;\200\256o;\200\256\355;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\340;\200\256>\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\206;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\372;\200"
  "\256/\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256"
  "<;\200\256\220;\200\256\342;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\357;\200\256\250;\200\256X;\200"
  "\256\11\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256_;\200\256\365"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\314"
  ";\200\256\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\21;\200\256\217;\200\256\372;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\375;\200\256\206;\200\256\2\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256k;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\316;\200\256\4\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\2567;\200"
  "\256\213;\200\256\333;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\362;\200\256\237;\200\256C;\200\256"
  "\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256\234"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\355;\200\256\40\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256%;\200\256"
  "\257;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\265;\200"
  "\256\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "I;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256z\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\36;\200"
  "\256a;\200\256\243;\200\256\345;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\344;\200\256\212;\200\256-\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256%"
  ";\200\256\320;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\356;\200\256@\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\77;\200\256\314;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\326;\200\256#\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\24;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\370;\200\256-\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256(;\200\256j;\200\256\254;\200\256\355;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\320;\200\256t;\200\256\32\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256T;\200\256\361;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\321;\200\256\"\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256L;\200\256\307;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\355;\200\256B\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\335;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\334;\200\256\21\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\2;\200\2561;\200\256v;\200\256\274;\200\256"
  "\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\375;\200\256\273;\200\256^;\200\256"
  "\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\5;\200\256\220;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\246;\200"
  "\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256D;\200\256\277;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373;\200"
  "\256i\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\247;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\267;\200\256"
  "\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256G;\200\256\215;\200"
  "\256\323;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\365;\200\256\245;\200\256I;\200"
  "\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\32;\200\256\307;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\353;\200\256j\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256;;\200\256\267;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\215;\200\256"
  "\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256q;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\206\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\31;\200"
  "\256^;\200\256\244;\200\256\355;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\350;\200\256\217;\200"
  "\2563\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "5;\200\256\345;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\361;\200\256\177;\200\256\15\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\2564;\200\256\257;\200\256\376;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\253;\200\256\10\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256:;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256S\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\7;\200\256U;\200\256\267;\200\256\374;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\306;\200"
  "\256J\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256Y;\200\256\367;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\340;\200\256\207;\200\256\23\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256,;\200\256\247;\200\256\375;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\305;\200\256\23\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\11;\200\256\372;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\353"
  ";\200\256\20\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\33;\200\256y;\200\256\332;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\315;\200\256R;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256\204;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\325;\200\256\203;\200\2562\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256&;\200\256\237;\200\256\373;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\331;\200\256#\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\274;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\215\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256<;\200\256\235;\200\256\363;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\324;\200\256Z;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\13;\200\256\256;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\376;\200\256\310;\200\256w;\200\256&\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\40;\200\256\227;\200\256\370;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\352;\200\2567\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256i;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\372;\200\256%\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\13;\200\256^;\200\256\261;\200"
  "\256\367;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\333;\200\256a;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\36;\200\256\320;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\367;\200\256\265;\200\256h;\200\256\33\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\32;\200\256\217;\200\256\365;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\366"
  ";\200\256L\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\30;\200\256\375;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\262\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\14;\200\256U;\200"
  "\256\246;\200\256\361;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\302;\200\256!\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256:"
  ";\200\256\351;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\372;\200\256\250;\200\256O;\200\256\13"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\25;\200\256\206;\200\256\362"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\371"
  ";\200\256L\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\303;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\2569\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\6;\200\256J;\200\256\234;\200\256\333;\200\256\376;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\363;\200\256d\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\\;\200\256\371;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\343;\200"
  "\256|;\200\256\27\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\31;\200\256\246"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\371"
  ";\200\256K\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256p;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\205\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\15;\200\256"
  "<;\200\256l;\200\256\235;\200\256\315;\200\256\371;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\264;\200\256\30\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256^;\200\256\375;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\355;\200\256c;\200\256\3\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256A;\200\256\326;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\370;\200\256J\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\34;\200\256\373;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\310\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256/;\200\256"
  "o;\200\256\262;\200\256\362;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\354;\200\256T\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256["
  ";\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\246;\200\256\26\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\5;\200\256w;\200\256\364;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\370;\200\256H\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\244;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\374;\200\256"
  "\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\4;\200\256:;\200\256};\200\256\301;\200\256"
  "\371;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\244;\200\256\12\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256X;\200\256\374;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\347;\200\256H\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\35;\200\256\254;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\370;\200\2566\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256-;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256L\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\13;\200\256V;\200\256\310;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\303;\200\256"
  "\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256U;\200\256\373;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\346;\200\256'\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256G;\200\256\333;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\324;\200\256\6\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\264;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256l\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256;;\200\256\260;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\312;\200\256\21\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256Q;\200\256\373;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\345;\200\256&\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\7;\200\256\231;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\201\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256<;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\203\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256M;\200\256\347;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\320;\200\256\20\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256N;\200\256\372;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\344;\200\256%\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256m;\200\256\374;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\372;\200\256-\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\243"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\233\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\23;\200\256\250"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\264;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256K;\200\256\371;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\365;\200\256(\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256D;\200\256\356;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\312;\200\256\3\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\17;\200\256\341;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\262\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256a;\200\256\367;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\177\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256H;\200\256\370;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256n\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256%;\200\256\327;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "s\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\77;\200\256\375"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\311"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2561"
  ";\200\256\336;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200"
  "\256I\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256\361;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\300;\200\256\1\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\17;\200\256\267;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\366;\200\256\26\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\212;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\341\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\22;\200\256\266;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\345;\200\256\12\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\313;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\363;\200\256!\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\216;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256z\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\6;\200\256\320;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\370\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256\200"
  ";\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256}\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\214;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256i\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256b;\200\256\371;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\341"
  ";\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256,;\200\256"
  "\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\17\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256J;\200\256\356;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\363;\200"
  "\256\30\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256I;\200\256\376"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\274;\200"
  "\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256B;\200\256\371;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256N\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256q;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "'\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\36;\200\256\245"
  ";\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\226\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\31"
  ";\200\256\352;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\362;\200\256\36\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256a;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\270\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256\256;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256I\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\2562;\200\256\273;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\363;\200\256\12\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\255;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256e\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\212;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\376;\200\256#\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\14;\200\256\323;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\275\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256G;\200\256\320;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256Y\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256A;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\270\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\2;\200\256\311;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\213\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256"
  "\355;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256C\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2"
  ";\200\256L;\200\256\214;\200\256\310;\200\256\372;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\264\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\322;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\371;\200\256!\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256.;\200\256\373;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\355"
  ";\200\256\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256D;\200\256\374;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\311\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\11;\200\256\77;\200\256{;\200\256\263;\200\256\302;\200\256"
  "\305;\200\256\310;\200\256\312;\200\256\315;\200\256\320;\200\256\323"
  ";\200\256\321;\200\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256j;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\222\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\210;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256_\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "q;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256P\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\21;\200\256\354;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\362;\200\256\25\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\12;\200\256\352;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\312\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\241"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\322;\200\256\1\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\222;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256~\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256w;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256@\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\10;\200\256\313;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256T\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256"
  "\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350"
  ";\200\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\14;\200\256\354"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\267\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256$;\200\256\365;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\323;\200"
  "\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\244;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256k\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256|;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256/\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256j;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256V\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "+;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\334;\200\256\5\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\16;\200\256\357;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\246\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\1;\200\256\272;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\324;\200\256\2\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\256;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256W\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\200;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\374;\200\256!\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\34"
  ";\200\256\360;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256W\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\2565;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\314;\200\256\1\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\21;\200\256"
  "\361;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\210\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256q"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\325;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\271"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256D\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256};\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\323\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256\336;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256X\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256>;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\274\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\13;\200\256\346;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\35\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256Y;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\326;\200\256\2\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\304;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256:\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256f;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256e\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\1;\200\256\314;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256Z\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256I;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\271\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\3;\200\256\327;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\256\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256B;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\327;\200\256\2\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\1;\200\256\315;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\2568\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256O;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\362;\200\256\5\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\25;\200\2562;\200\256N;\200\256k;\200\256\207;\200\256"
  "\244;\200\256\300;\200\256\335;\200\256\370;\200\256\377;\200\256\377"
  ";\200\256[\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256T;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\267"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\303"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256A\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\1;\200\256\26;\200\2563;\200\2564\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\3;\200\256\326;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\2566\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\2569;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\376;\200\256\340;\200\256\267"
  ";\200\256\217;\200\256g;\200\256\40\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256_;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\265\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\214;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373;\200\256"
  "\214;\200\256Y;\200\2560;\200\256\12\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\22;\200\256+;\200\256=\377\377\377"
  "\0;\200\256\33;\200\256w;\200\256\205;\200\256\223;\200\256\241;\200"
  "\256\256;\200\256\274;\200\256\312;\200\256\330;\200\256\346;\200\256"
  "\304;\200\256:\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256$;\200\256\233;\200\256\327;\200\256\304;\200\256\260;\200"
  "\256\234;\200\256\210;\200\256u;\200\256a;\200\256M;\200\2569;\200\256"
  "%;\200\256\21;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\15;\200\256\346;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\2564\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\4"
  ";\200\256\304;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\360;\200\256"
  "D\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\21;\200\256+;\200"
  "\256E;\200\256^;\200\256x;\200\256\222;\200\256\253;\200\256\305;\200"
  "\256\336;\200\256\370;\200\256\377;\200\256\377;\200\256\350\377\377"
  "\377\0;\200\256/;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\361;\200\256#\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\35"
  ";\200\256\346;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\374;\200\256\351;\200\256\325"
  ";\200\256\302;\200\256\256;\200\256\232;\200\256\206;\200\256r;\200\256"
  "^;\200\256J;\200\2566;\200\256\26\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\213;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\262\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\33;\200\256\352;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\335;\200\256)\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\3;\200\256$;\200\256J;\200\256q;\200\256\230;\200\256\277"
  ";\200\256\336;\200\256\367;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256.;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\311;\200\256\1\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\7;\200\256\320"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357;\200\256"
  "\310;\200\256\242;\200\256{;\200\256T;\200\256-;\200\256\10\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256("
  ";\200\256\372;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\2562\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256:;\200\256\361;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\305;\200\256\25\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\24;\200"
  "\256;;\200\256b;\200\256\211;\200\256\257;\200\256\326;\200\256\371;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377\0;\200"
  "\256.;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256S\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256s;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256\340;\200"
  "\256\271;\200\256\222;\200\256k;\200\256D;\200\256\36;\200\256\1\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\273;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\260\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\2564;\200\256\355;\200\256\377;\200\256\377;\200\256\245"
  ";\200\256\7\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\23;\200"
  "\256\231;\200\256\307;\200\256\355;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\350\377\377\377\0;\200\256-;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\316\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\22;\200\256\356;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\365;\200\256\320;\200\256\251;\200\256\202;\200\256\\;\200\2565"
  ";\200\256\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256S;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\374;\200\256+\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256.;\200\256\350;\200\256\200\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256';\200\256\333;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\350\377\377\377\0;\200\256,;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256I\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\216;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\333;\200\256\240;\200\256e;\200\256*;\200\256\1\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\14;\200\256\341;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\230\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\15\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256C;\200\256\357;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\350\377\377\377\0;\200\256,;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\305\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\""
  ";\200\256\371;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\356;\200"
  "\256\265;\200\256z;\200\256\77;\200\256\12\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\246"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\362;\200\256\27\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "e;\200\256\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\350\377\377\377\0;\200\256+;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256@\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\250;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\372;\200\256\312;\200\256\217;\200\256T;\200"
  "\256\32\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256i;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256z\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\2;\200\256\215;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256*;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\272"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\2566;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\337"
  ";\200\256\244;\200\256i;\200\256.;\200\256\2\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2563;\200\256\370;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\341;\200\256\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\254;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\350\377\377\377\0;\200\256*;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\2564\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\276;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\361;\200\256\271;\200\256~;\200\256<;\200\256\2\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\14;\200\256*;\200\256H;\200\256e;\200\256{;\200\256q;\200\256e;\200"
  "\256X;\200\256L;\200\256\77;\200\2562;\200\256&;\200\256\26\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\20;\200\256\336;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256[\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\7;\200\256\262;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\350\377\377\377\0;\200\256);\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\256\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256G;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\352;\200\256\236"
  ";\200\256O;\200\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256N;\200\256"
  "\223;\200\256\263;\200\256\321;\200\256\356;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\352;\200\256\267;\200\256\204;\200\256P;\200\256\35\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\1;\200\256\261;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\312;\200\256\1\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\11;\200\256\270;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\350\377\377\377\0;\200\256(;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\376;\200\256)\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\1;\200\256\317;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\366;\200\256\261;\200\256b;\200\256\26\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\21"
  ";\200\256];\200\256\255;\200\256\365;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\351"
  ";\200\256\266;\200\256\202;\200\2567\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200"
  "\256\242;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256<\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\13;\200\256\275"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\350\377\377\377\0;\200\256(;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\241\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256Y"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256\304"
  ";\200\256u;\200\256&\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\33;\200\256k;\200\256\274;\200\256\373;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\334;\200\256\202;\200\256(\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\14;\200\256\270;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\255\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\15;\200\256\303;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377"
  "\377\377\0;\200\256';\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\373;\200\256\40\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\335;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\327;\200\256\210;\200\2569;\200\256\2\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\16;\200\256b;\200\256\275;\200\256\375"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\316;\200"
  "\256s;\200\256\33\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\26"
  ";\200\256\313;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\371;\200\256#\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\12;\200\256\307"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\350\377\377\377\0;\200\256&;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\255\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  ";\200\256\206;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\350;\200\256\233;\200\256L;\200\256\10"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\5;\200\256N;\200\256\252;\200\256\367;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256\276"
  ";\200\256I\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256#;\200\256\333;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\207\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256\256;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\350\377\377\377\0;\200\256&;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256]\377"
  "\377\377\0\377\377\377\0;\200\256M;\200\256\376;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\364;\200\256\256;\200\256];\200\256"
  "\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256;;\200\256\226;\200\256\354;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\306;\200\256C\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\20;\200\256~;\200\256\357;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\341;\200\256\12\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\212;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\350\377\377\377\0;\200\256%;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\372;\200\256\216;\200\256\234;\200\256\372;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\361;\200\256\226;\200\2560\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256"
  "G;\200\256\226;\200\256\344;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\300;\200\256=\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\23"
  ";\200\256\204;\200\256\361;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256Q\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256e;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\350\377\377\377\0;\200\256%;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\313;\200\256e;\200\256\14\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\17;\200\256X;\200\256\250;\200\256\361;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\271;\200\2567\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\3;\200\256\1\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\10;\200\256/;\200\256\212;\200\256\363"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\267\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256D;\200\256\373;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\350\377\377\377\0;\200\256$;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\363;\200\256\232;\200\2565\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\24;\200\256j;\200"
  "\256\272;\200\256\372;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\250;\200\256\22\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\20;\200\256w;\200\256\263"
  ";\200\256\335;\200\256\375;\200\256\377;\200\256\372;\200\256\364;\200"
  "\256\355;\200\256\346;\200\256\340;\200\256\335;\200\256\332;\200\256"
  "\340;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\370;\200\256"
  "$\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256);\200\256\360;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\350\377\377\377\0;\200\256#;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\317;\200\256"
  "j;\200\256\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256<;\200\256\244;\200\256\370;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\344;\200\256D\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\5;\200\256\205;\200\256\361;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\177\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\25;\200\256\336;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\350\377\377\377\0;\200\256#;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\365;\200\256\237;\200\2569\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\16;\200\256k;\200\256\323;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\376;\200\256\216;\200\256\7\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256\246;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\317;\200\256\5\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\10"
  ";\200\256\306;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256\";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\323;\200\256n;\200\256\21\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\2562;\200\256\232;\200\256\364"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256\315;\200"
  "\256\257;\200\256\224;\200\256y;\200\256_;\200\256_;\200\256\203;\200"
  "\256\246;\200\256\327;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\322;\200"
  "\256-\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\225;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\371;\200\256-\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256\250;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\350\377\377\377\0;\200\256!;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\367;\200\256\243;\200\256=\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\2;\200\256[;\200\256\311;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200"
  "\256\314;\200\256\241;\200\256v;\200\256L;\200\256!;\200\256\1\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256N;\200\256\314"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\370;\200\256p;\200\256\1\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\2561;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256y\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\203;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\350\377\377\377\0;\200\256!;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\314;\200"
  "\256O;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256D;\200\256\317;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\365"
  ";\200\256\314;\200\256\242;\200\256w;\200\256L;\200\256!;\200\256\1\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256O;\200\256\350;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\241;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\231;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\310;\200"
  "\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256^;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256\40;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\320;\200\256S;\200\256\1"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256,;\200\256\266;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\365;\200\256\315;\200\256\242;\200\256w;\200\256L;\200"
  "\256\";\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\27;\200\256\273;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\251;\200\256\5\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\15;\200\256\363;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\325;\200\256\32\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256>;\200\256"
  "\371;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\354\377\377\377\0;\200\256\37;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\324;\200\256X;\200\256\2\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\15;\200\256\227;\200\256\374;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256\314;\200"
  "\256\206;\200\256M;\200\256\";\200\256\2\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2"
  ";\200\256z;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\261;\200\256\7\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\36;\200\256m;\200\256r;\200\256\202;\200\256\264"
  ";\200\256\351;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\312;\200\256\23\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\26;\200\256\353;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\361\377\377\377"
  "\0;\200\256\37;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\330;\200\256];\200\256\3\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256@;\200\256\337;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\341;\200\256\234;\200\256V;\200"
  "\256\23\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256>;\200\256\356"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\271;\200\256\11\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256/"
  ";\200\256\210;\200\256\340;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\277;\200"
  "\256\15\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\254;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\366\377\377\377\0;\200\256\36;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\333;\200\256a;\200\256\4\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11;\200"
  "\256\221;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\362;\200\256\261;\200\256l;\200\256&\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256*;\200\256\341;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\300;\200\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\1;\200\256;;\200\256\224;\200\256\350;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\341;\200\256v;\200\256\10\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256V;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\372"
  "\377\377\377\0;\200\256\35;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\337;\200\256f;\200\256\6\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\2567;\200\256\331;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\352;\200\256\212;\200\256<;\200\256\4\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\33;\200\256\322;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\306;\200"
  "\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\1;\200\2566;\200\256\201;\200\256\314;\200\256\376;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\300;\200\256R;\200\256\3\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\25;\200\256\352;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377\377\377\377\0;\200\256"
  "\35;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\342;\200\256k;\200\256\7\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\33;\200"
  "\256\242;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\276;\200\256W;\200\256"
  "\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\17;\200\256\277;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\236\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\31;\200\256"
  "];\200\256z;\200\256\216;\200\256\230;\200\256{;\200\256[;\200\256*\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\251;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\4;\200\256\34;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\345;\200\256o;\200\256\11\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "6;\200\256\306;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\364;\200\256"
  "\216;\200\256&\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\7;\200\256\251;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256[\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256S;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\11;\200\256\33;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350;\200"
  "\256o;\200\256\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256Z;\200\256\342;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\370;\200\256\221;\200\256\27\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256\250;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\363;\200\256"
  "&\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\24;\200\256\351;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\15;\200\256\33;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\324;\200\256A\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\12;\200\256\177;\200\256\365"
  ";\200\256\373;\200\256\234;\200\256\36\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200"
  "\256\274;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\317;\200\256\7\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\247;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\22;\200\256\32;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\250;\200\256"
  "\33\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\34;\200\256%\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\15;\200\256\316;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\225\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256Q;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\27"
  ";\200\256\31;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\364;\200\256w;\200\256\6\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\27;\200\256\334;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256S\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\22;\200\256\350;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\34;\200\256\31;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\331;\200\256F\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256#;\200\256\351;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\357;\200\256\40\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\245;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\40;\200\256\30;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\256;\200\256\37\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\2567;\200\256\373;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\311;\200\256\4\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256N;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256%;\200\256\27;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\366;\200\256};\200\256\7"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256{;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256q\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\21;\200\256\346;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256*;\200\256\21;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\335;\200\256L\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200"
  "\256\303;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\360"
  ";\200\256\25\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\234;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256/;\200\256\12"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\264;\200\256#\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\37;\200\256\361;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\231\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256&;\200\256\374;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2563;\200\256\3"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\370;\200"
  "\256\203;\200\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256[;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\375;\200\2560\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\245;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2568\377\377\377"
  "\0;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\336;\200\256:\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\246;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\301\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256*;\200\256\375;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256=\377"
  "\377\377\0;\200\256\365;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\374;\200\256\177;\200\256\3\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\17;\200\256\341;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256U\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\251;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256B\377\377"
  "\377\0;\200\256\356;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\304;\200"
  "\256\37\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256>;\200\256\375"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\340;\200\256\11\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256."
  ";\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256F\377\377\377\0;"
  "\200\256\347;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\360;\200\256X\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\207"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256}\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\256"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256K\377\377\377\0;"
  "\200\256\340;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\240;\200\256\14\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\5"
  ";\200\256\314;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256"
  "\34\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2562;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256P\377\377\377\0;"
  "\200\256\331;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\334;\200\2566\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256';\200\256\365;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\241\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\263;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256U\377\377\377\0;\200"
  "\256\322;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\373;\200\256y;\200\256"
  "\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256h;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\374;\200\256"
  "$\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\2566;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256Z\377\377\377\0;\200\256\313;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\277;\200"
  "\256\34\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\1;\200\256\305;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\235\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\270;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256^\377\377\377\0;\200\256\304;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\355"
  ";\200\256R\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\2560;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\372;\200\256\40\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256;;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256c\377\377\377\0;\200\256\275;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\232;\200\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\222;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\230\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\275;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256h\377\377\377\0;\200\256\266;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\330;\200\2561\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\17"
  ";\200\256\350;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\371;\200\256\33\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256@;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256m\377\377"
  "\377\0;\200\256\257;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\366;\200\256R\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256];\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\222\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\302;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256q\377\377\377\0;\200\256\250"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\375;\200\256s\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\301;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\367;\200\256\30\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\2567;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256v\377\377\377\0;\200\256\241;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\225;\200\256\3\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256,;\200\256\373;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\214\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\231;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256{\377\377\377\0;\200\256\232;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\265;\200\256\14\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\215;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\364;\200\256\24\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\11;\200\256\361;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\200\377\377\377\0;\200\256\223;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\317;\200\256\32\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\15;\200\256\345;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\206\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\\;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\204\377\377"
  "\377\0;\200\256\214;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\343;\200\256.\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256X;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\362;\200\256"
  "\21\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\275;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\211\377\377\377\0;\200\256\205;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\362;\200\256G\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\275;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\200\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256!;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\216\377\377\377\0;\200\256~;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\373;\200\256f\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256)"
  ";\200\256\372;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\357;\200\256\16\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\201;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\223"
  "\377\377\377\0;\200\256w;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\211;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\200;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256z\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\1;\200\256\340;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\227\377\377\377\0;\200\256"
  "p;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\252"
  ";\200\256\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256\323;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\354;\200\256\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "D;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\234\377\377\377\0;\200\256i;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\306;\200\256\24"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\2566;\200\256\374;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256u\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\245;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\241\377"
  "\377\377\0;\200\256b;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\334;\200\256\"\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\214;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\350;\200\256\11\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\20;\200\256\367;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\246\377\377\377\0;\200\256[;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\340;\200\256\35\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11;\200"
  "\256\334;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256o\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256h;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\252\377\377\377\0;\200\256T;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\332;\200\256\30\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256@;\200\256\376;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\344"
  ";\200\256\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\312;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\257\377\377\377"
  "\0;\200\256M;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\324;\200\256\24\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\230;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256n\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256,;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\264\377\377\377\0;\200\256F;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\316;\200\256"
  "\20\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\16"
  ";\200\256\343;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\346;\200\256\11\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\215;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\271\377"
  "\377\377\0;\200\256\77;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\307;\200\256\14\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256K;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256r\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\351;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\275\377\377\377\0;\200\2568;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\277;\200\256\11\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\244;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\351;\200\256\13\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\20\212\212\212\"\212\212\212/\212\212\212<\212\212\212"
  "I\212\212\212V\212\212\212c\212\212\212o\212\212\212|\212\212\212\211"
  "\212\212\212\224\212\212\212\214\212\212\212\177\212\212\212s\212\212"
  "\212f\212\212\212Y\212\212\212L\212\212\212\77\212\212\2122\212\212\212"
  "&\212\212\212\26\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256A;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\302\377\377\377\0;\200\2561;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\267;\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\23;\200\256\352;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256w\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212\3\212\212\212#\212\212\212K\212\212\212s\212\212"
  "\212\232\212\212\212\302\212\212\212\352\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\363\212\212\212\314"
  "\212\212\212\244\212\212\212}\212\212\212U\212\212\212-\212\212\212\10"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\204;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\307\377\377\377\0;\200\256*;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\256;\200\256\4\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256V;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\354;\200\256\15\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\3\212\212\2127\212\212\212"
  "y\212\212\212\255\212\212\212\324\212\212\212\371\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\375\212\212\212\336\212"
  "\212\212\266\212\212\212\210\212\212\212G\212\212\212\13\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\307;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\321\377\377\377\0;\200\256#;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\245;\200\256\2\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\242;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256{\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\212\1\212\212\212/\212\212"
  "\212q\212\212\212\263\212\212\212\361\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\215\215\215"
  "\377\222\222\222\377\230\230\230\377\236\236\236\377\244\244\244\377"
  "\251\251\251\377\257\257\257\377\264\264\264\377\261\261\261\377\253"
  "\253\253\377\245\245\245\377\237\237\237\377\232\232\232\377\224\224"
  "\224\377\216\216\216\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\372\212\212"
  "\212\303\212\212\212\201\212\212\212\77\212\212\212\7\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\16;\200\256\373;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\335\377\377\377\0;\200\256\34;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\234"
  ";\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\15;\200\256\335;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\356;\200\256"
  "\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\"\212\212\212i\212\212\212\253\212\212\212\353\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\221\221\221\377\243\243\243\377\265\265\265\377\307"
  "\307\307\377\331\331\331\377\353\353\353\377\367\367\367\377\374\374"
  "\374\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\370\370"
  "\370\377\357\357\357\377\335\335\335\377\314\314\314\377\272\272\272"
  "\377\247\247\247\377\225\225\225\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\366\212\212\212\274\212\212\212z\212\212\2126\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256L;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377\0;\200"
  "\256\25;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\222\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\2568;\200\256\373;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\200\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\22\212\212\212h\212\212\212\306\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\236\236\236\377\274\274\274"
  "\377\320\320\320\377\342\342\342\377\364\364\364\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\371\371\371\377\347\347\347\377\325\325\325\377\302\302\302\377"
  "\246\246\246\377\214\214\214\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\335\212\212\212\200\212\212\212"
  "#\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\217;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\364\377\377\377\0;\200\256\16;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\210\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256};\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\361;\200\256\21\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\5\212\212\212P\212\212\212\255\212\212\212\371\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\232\232\232\377\270\270\270\377\327\327"
  "\327\377\365\365\365\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\372\372\372\377\336\336\336\377\300\300\300\377\242\242\242\377\213"
  "\213\213\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\305\212\212\212g\212\212\212\21\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\322;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\376;\200\256\1;\200\256\7;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256p\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\3"
  ";\200\256\302;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\205\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\2127\212\212\212\224\212\212\212\354"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\225\225\225\377\265\265\265\377\323\323"
  "\323\377\361\361\361\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\376\376\376\377\376\376\376\377"
  "\376\376\376\377\376\376\376\377\376\376\376\377\376\376\376\377\376"
  "\376\376\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\367\367"
  "\367\377\332\332\332\377\274\274\274\377\235\235\235\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\370\212\212\212\254\212\212\212N\212\212"
  "\212\5\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\26;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\12;\200\256\1;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\373;\200\256>\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\36;\200\256\357;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\363;\200\256\24\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\2\212\212"
  "\212X\212\212\212\322\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\217\217\217\377\265"
  "\265\265\377\340\340\340\377\376\376\376\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\376\376\376\377\375\375\375\377\375\375\375\377\375\375"
  "\375\377\374\374\374\377\374\374\374\377\374\374\374\377\374\374\374"
  "\377\374\374\374\377\373\373\373\377\373\373\373\377\373\373\373\377"
  "\373\373\373\377\373\373\373\377\373\373\373\377\373\373\373\377\373"
  "\373\373\377\374\374\374\377\374\374\374\377\374\374\374\377\374\374"
  "\374\377\374\374\374\377\375\375\375\377\375\375\375\377\375\375\375"
  "\377\376\376\376\377\376\376\376\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\353\353\353"
  "\377\300\300\300\377\226\226\226\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\350\212\212\212w\212\212\212\15\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256X;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\26\377\377\377\0;\200\256\371"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350;\200\256\32"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256W;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\211\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\212\5\212\212\212a\212\212"
  "\212\332\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\213\213\213\377\252\252\252\377\325\325\325\377"
  "\372\372\372\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\376\376\376\377\375\375\375\377\375\375\375\377\374\374\374\377"
  "\374\374\374\377\373\373\373\377\373\373\373\377\372\372\372\377\372"
  "\372\372\377\372\372\372\377\371\371\371\377\371\371\371\377\371\371"
  "\371\377\371\371\371\377\371\371\371\377\371\371\371\377\370\370\370"
  "\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377"
  "\370\370\370\377\371\371\371\377\371\371\371\377\371\371\371\377\371"
  "\371\371\377\371\371\371\377\371\371\371\377\372\372\372\377\372\372"
  "\372\377\372\372\372\377\373\373\373\377\373\373\373\377\374\374\374"
  "\377\374\374\374\377\375\375\375\377\375\375\375\377\376\376\376\377"
  "\376\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\340\340\340"
  "\377\265\265\265\377\217\217\217\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\356\212"
  "\212\212\200\212\212\212\21\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\32;\200\256v;\200\256\240;\200\256\300;\200"
  "\256\340;\200\256\331;\200\256\260;\200\256\177;\200\256\21\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\232;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256!\377\377\377"
  "\0;\200\256\362;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\305;\200\256\5\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\240"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256\26\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\7\212\212\212i\212\212\212\340\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\237\237\237\377\312\312\312\377\363\363\363\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\375\375\375\377\374\374"
  "\374\377\374\374\374\377\373\373\373\377\372\372\372\377\372\372\372"
  "\377\371\371\371\377\371\371\371\377\370\370\370\377\370\370\370\377"
  "\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\366"
  "\366\366\377\366\366\366\377\366\366\366\377\366\366\366\377\366\366"
  "\366\377\366\366\366\377\365\365\365\377\365\365\365\377\365\365\365"
  "\377\365\365\365\377\366\366\366\377\366\366\366\377\366\366\366\377"
  "\366\366\366\377\366\366\366\377\366\366\366\377\367\367\367\377\367"
  "\367\367\377\367\367\367\377\367\367\367\377\370\370\370\377\370\370"
  "\370\377\371\371\371\377\371\371\371\377\372\372\372\377\372\372\372"
  "\377\373\373\373\377\374\374\374\377\374\374\374\377\375\375\375\377"
  "\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\372\372\372\377\325\325\325"
  "\377\252\252\252\377\213\213\213\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\362\212\212\212\210\212"
  "\212\212\26\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256C;\200\256\255;\200\256\373;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\352;\200\256^\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\335;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256,\377\377\377\0;\200\256\353;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\222\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\15;\200\256\334;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\216\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\13\212\212\212r\212\212\212\346\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\253\253\253\377\344\344\344\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376"
  "\376\377\375\375\375\377\374\374\374\377\374\374\374\377\373\373\373"
  "\377\372\372\372\377\371\371\371\377\371\371\371\377\370\370\370\377"
  "\367\367\367\377\367\367\367\377\366\366\366\377\366\366\366\377\366"
  "\366\366\377\365\365\365\377\365\365\365\377\365\365\365\377\364\364"
  "\364\377\364\364\364\377\363\363\363\377\363\363\363\377\363\363\363"
  "\377\363\363\363\377\363\363\363\377\363\363\363\377\363\363\363\377"
  "\363\363\363\377\363\363\363\377\363\363\363\377\363\363\363\377\363"
  "\363\363\377\363\363\363\377\363\363\363\377\363\363\363\377\363\363"
  "\363\377\364\364\364\377\364\364\364\377\364\364\364\377\365\365\365"
  "\377\365\365\365\377\366\366\366\377\366\366\366\377\366\366\366\377"
  "\367\367\367\377\367\367\367\377\370\370\370\377\371\371\371\377\371"
  "\371\371\377\372\372\372\377\373\373\373\377\374\374\374\377\374\374"
  "\374\377\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\360\360\360\377\271"
  "\271\271\377\215\215\215\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\366\212\212\212\221\212\212\212"
  "\33\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\26;\200\256\256;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "s\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\40"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\2568\377\377\377\0;\200\256\344;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256[\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2567;\200\256"
  "\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\366;\200\256\31\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\2\212\212\212f\212\212\212\353\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\257\257\257\377\347\347\347\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\375\375\375"
  "\377\374\374\374\377\373\373\373\377\372\372\372\377\372\372\372\377"
  "\371\371\371\377\370\370\370\377\367\367\367\377\367\367\367\377\366"
  "\366\366\377\365\365\365\377\365\365\365\377\364\364\364\377\364\364"
  "\364\377\363\363\363\377\363\363\363\377\362\362\362\377\362\362\362"
  "\377\362\362\362\377\361\361\361\377\361\361\361\377\361\361\361\377"
  "\360\360\360\377\360\360\360\377\360\360\360\377\360\360\360\377\360"
  "\360\360\377\360\360\360\377\360\360\360\377\360\360\360\377\360\360"
  "\360\377\360\360\360\377\360\360\360\377\360\360\360\377\360\360\360"
  "\377\360\360\360\377\360\360\360\377\361\361\361\377\361\361\361\377"
  "\362\362\362\377\362\362\362\377\362\362\362\377\363\363\363\377\363"
  "\363\363\377\364\364\364\377\364\364\364\377\365\365\365\377\365\365"
  "\365\377\366\366\366\377\366\366\366\377\367\367\367\377\370\370\370"
  "\377\371\371\371\377\371\371\371\377\372\372\372\377\373\373\373\377"
  "\374\374\374\377\375\375\375\377\376\376\376\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\363\363\363\377\275\275\275"
  "\377\216\216\216\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\371\212\212\212\215\212\212\212\15\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256V;\200\256\353;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\376;\200\256T\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256c;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256C\377"
  "\377\377\0;\200\256\335;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256-\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256{;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\222\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\2122\212\212\212\311\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\262"
  "\262\262\377\352\352\352\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\375\375\375\377\374\374\374\377"
  "\373\373\373\377\372\372\372\377\371\371\371\377\371\371\371\377\370"
  "\370\370\377\367\367\367\377\366\366\366\377\365\365\365\377\365\365"
  "\365\377\364\364\364\377\363\363\363\377\363\363\363\377\362\362\362"
  "\377\361\361\361\377\361\361\361\377\360\360\360\377\360\360\360\377"
  "\357\357\357\377\357\357\357\377\357\357\357\377\356\356\356\377\356"
  "\356\356\377\356\356\356\377\356\356\356\377\355\355\355\377\355\355"
  "\355\377\355\355\355\377\355\355\355\377\355\355\355\377\355\355\355"
  "\377\355\355\355\377\355\355\355\377\355\355\355\377\355\355\355\377"
  "\355\355\355\377\355\355\355\377\356\356\356\377\356\356\356\377\356"
  "\356\356\377\356\356\356\377\357\357\357\377\357\357\357\377\357\357"
  "\357\377\360\360\360\377\360\360\360\377\361\361\361\377\361\361\361"
  "\377\362\362\362\377\362\362\362\377\363\363\363\377\364\364\364\377"
  "\365\365\365\377\365\365\365\377\366\366\366\377\367\367\367\377\367"
  "\367\367\377\370\370\370\377\371\371\371\377\372\372\372\377\373\373"
  "\373\377\374\374\374\377\375\375\375\377\376\376\376\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\364\364\364\377\300\300\300\377\217"
  "\217\217\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\345\212\212\212V\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\212;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\363;\200\256\25\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\246;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256O\377\377\377\0;\200\256\325;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\333;\200\256\17\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200"
  "\256\301;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\370;\200\256\34\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\20\212\212\212\224\212\212"
  "\212\375\212\212\212\377\212\212\212\377\212\212\212\377\213\213\213"
  "\377\266\266\266\377\355\355\355\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\375\375\375\377\374\374"
  "\374\377\372\372\372\377\371\371\371\377\371\371\371\377\367\367\367"
  "\377\367\367\367\377\366\366\366\377\365\365\365\377\364\364\364\377"
  "\363\363\363\377\363\363\363\377\362\362\362\377\361\361\361\377\360"
  "\360\360\377\360\360\360\377\357\357\357\377\357\357\357\377\356\356"
  "\356\377\356\356\356\377\355\355\355\377\355\355\355\377\354\354\354"
  "\377\354\354\354\377\353\353\353\377\353\353\353\377\353\353\353\377"
  "\353\353\353\377\353\353\353\377\352\352\352\377\352\352\352\377\352"
  "\352\352\377\352\352\352\377\352\352\352\377\352\352\352\377\352\352"
  "\352\377\352\352\352\377\352\352\352\377\352\352\352\377\352\352\352"
  "\377\353\353\353\377\353\353\353\377\353\353\353\377\353\353\353\377"
  "\354\354\354\377\354\354\354\377\354\354\354\377\355\355\355\377\356"
  "\356\356\377\356\356\356\377\356\356\356\377\357\357\357\377\360\360"
  "\360\377\360\360\360\377\361\361\361\377\362\362\362\377\362\362\362"
  "\377\363\363\363\377\364\364\364\377\365\365\365\377\366\366\366\377"
  "\366\366\366\377\367\367\367\377\370\370\370\377\371\371\371\377\372"
  "\372\372\377\373\373\373\377\374\374\374\377\375\375\375\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\367\367\367\377\304\304\304\377"
  "\221\221\221\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\273\212\212\212&\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256\222;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\213\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\350;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256Z\377\377\377\0;\200\256\307;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\262;\200\256\1\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\36;\200\256"
  "\357;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\227\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212]\212\212\212\351\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\251\251\251\377\355\355\355\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\374"
  "\374\374\377\373\373\373\377\372\372\372\377\371\371\371\377\370\370"
  "\370\377\367\367\367\377\366\366\366\377\365\365\365\377\364\364\364"
  "\377\363\363\363\377\362\362\362\377\361\361\361\377\360\360\360\377"
  "\360\360\360\377\357\357\357\377\356\356\356\377\356\356\356\377\355"
  "\355\355\377\354\354\354\377\354\354\354\377\353\353\353\377\353\353"
  "\353\377\352\352\352\377\352\352\352\377\351\351\351\377\351\351\351"
  "\377\351\351\351\377\350\350\350\377\350\350\350\377\350\350\350\377"
  "\350\350\350\377\347\347\347\377\347\347\347\377\347\347\347\377\347"
  "\347\347\377\347\347\347\377\347\347\347\377\347\347\347\377\347\347"
  "\347\377\347\347\347\377\347\347\347\377\350\350\350\377\350\350\350"
  "\377\350\350\350\377\350\350\350\377\351\351\351\377\351\351\351\377"
  "\351\351\351\377\352\352\352\377\352\352\352\377\353\353\353\377\353"
  "\353\353\377\354\354\354\377\354\354\354\377\355\355\355\377\356\356"
  "\356\377\356\356\356\377\357\357\357\377\360\360\360\377\360\360\360"
  "\377\361\361\361\377\362\362\362\377\363\363\363\377\364\364\364\377"
  "\365\365\365\377\366\366\366\377\366\366\366\377\367\367\367\377\371"
  "\371\371\377\372\372\372\377\373\373\373\377\374\374\374\377\375\375"
  "\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\367\367\367\377"
  "\273\273\273\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\371\212\212\212\204\212\212\212\11\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256\231"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\366;\200\256\30\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256+;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256e\377\377\377"
  "\0;\200\256\271;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256{\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256V;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\372;\200\256\37\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212+\212\212\212\301\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\226\226\226\377\327\327\327"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\375"
  "\375\375\377\374\374\374\377\373\373\373\377\371\371\371\377\370\370"
  "\370\377\367\367\367\377\366\366\366\377\365\365\365\377\364\364\364"
  "\377\363\363\363\377\362\362\362\377\361\361\361\377\360\360\360\377"
  "\357\357\357\377\357\357\357\377\356\356\356\377\355\355\355\377\354"
  "\354\354\377\354\354\354\377\353\353\353\377\352\352\352\377\351\351"
  "\351\377\351\351\351\377\350\350\350\377\350\350\350\377\347\347\347"
  "\377\347\347\347\377\347\347\347\377\346\346\346\377\346\346\346\377"
  "\345\345\345\377\345\345\345\377\345\345\345\377\345\345\345\377\345"
  "\345\345\377\344\344\344\377\344\344\344\377\344\344\344\377\344\344"
  "\344\377\344\344\344\377\344\344\344\377\344\344\344\377\344\344\344"
  "\377\345\345\345\377\345\345\345\377\345\345\345\377\345\345\345\377"
  "\345\345\345\377\346\346\346\377\346\346\346\377\347\347\347\377\347"
  "\347\347\377\347\347\347\377\350\350\350\377\350\350\350\377\351\351"
  "\351\377\351\351\351\377\352\352\352\377\353\353\353\377\353\353\353"
  "\377\354\354\354\377\355\355\355\377\356\356\356\377\356\356\356\377"
  "\357\357\357\377\360\360\360\377\361\361\361\377\362\362\362\377\363"
  "\363\363\377\364\364\364\377\365\365\365\377\366\366\366\377\367\367"
  "\367\377\370\370\370\377\371\371\371\377\372\372\372\377\374\374\374"
  "\377\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\350"
  "\350\350\377\242\242\242\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\337\212\212\212M\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\210;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256u\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256n;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256q\377\377\377\0;\200\256\252;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200"
  "\256F\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\237;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\234\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\1\212\212\212"
  "v\212\212\212\373\212\212\212\377\212\212\212\377\212\212\212\377\213"
  "\213\213\377\276\276\276\377\371\371\371\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\376\376\376\377\375\375\375\377\374\374\374\377\372\372\372\377"
  "\371\371\371\377\370\370\370\377\367\367\367\377\366\366\366\377\365"
  "\365\365\377\363\363\363\377\362\362\362\377\361\361\361\377\360\360"
  "\360\377\357\357\357\377\356\356\356\377\356\356\356\377\355\355\355"
  "\377\354\354\354\377\353\353\353\377\352\352\352\377\351\351\351\377"
  "\351\351\351\377\350\350\350\377\347\347\347\377\347\347\347\377\346"
  "\346\346\377\346\346\346\377\345\345\345\377\345\345\345\377\344\344"
  "\344\377\344\344\344\377\343\343\343\377\343\343\343\377\343\343\343"
  "\377\342\342\342\377\342\342\342\377\342\342\342\377\342\342\342\377"
  "\341\341\341\377\341\341\341\377\341\341\341\377\341\341\341\377\341"
  "\341\341\377\341\341\341\377\341\341\341\377\341\341\341\377\342\342"
  "\342\377\342\342\342\377\342\342\342\377\342\342\342\377\342\342\342"
  "\377\343\343\343\377\343\343\343\377\344\344\344\377\344\344\344\377"
  "\344\344\344\377\345\345\345\377\345\345\345\377\346\346\346\377\347"
  "\347\347\377\347\347\347\377\350\350\350\377\351\351\351\377\351\351"
  "\351\377\352\352\352\377\353\353\353\377\354\354\354\377\354\354\354"
  "\377\355\355\355\377\356\356\356\377\357\357\357\377\360\360\360\377"
  "\361\361\361\377\362\362\362\377\363\363\363\377\364\364\364\377\365"
  "\365\365\377\366\366\366\377\370\370\370\377\371\371\371\377\372\372"
  "\372\377\373\373\373\377\375\375\375\377\376\376\376\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\376\376\376\377\320\320\320\377\222\222\222\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\245\212\212"
  "\212\15\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256T;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\270\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\243;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256|\377\377\377\0;\200\256\234;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\354;\200\256\37\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\14;\200\256\333;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\373;\200\256\"\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\24\212\212\212\265\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\245\245\245\377\352"
  "\352\352\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375"
  "\377\374\374\374\377\372\372\372\377\371\371\371\377\370\370\370\377"
  "\367\367\367\377\365\365\365\377\364\364\364\377\363\363\363\377\362"
  "\362\362\377\361\361\361\377\360\360\360\377\357\357\357\377\356\356"
  "\356\377\355\355\355\377\354\354\354\377\353\353\353\377\352\352\352"
  "\377\351\351\351\377\350\350\350\377\347\347\347\377\347\347\347\377"
  "\346\346\346\377\345\345\345\377\345\345\345\377\344\344\344\377\343"
  "\343\343\377\343\343\343\377\342\342\342\377\342\342\342\377\341\341"
  "\341\377\341\341\341\377\340\340\340\377\340\340\340\377\340\340\340"
  "\377\340\340\340\377\337\337\337\377\337\337\337\377\337\337\337\377"
  "\337\337\337\377\336\336\336\377\336\336\336\377\336\336\336\377\336"
  "\336\336\377\336\336\336\377\336\336\336\377\337\337\337\377\337\337"
  "\337\377\337\337\337\377\337\337\337\377\340\340\340\377\340\340\340"
  "\377\340\340\340\377\340\340\340\377\341\341\341\377\341\341\341\377"
  "\342\342\342\377\342\342\342\377\343\343\343\377\343\343\343\377\344"
  "\344\344\377\344\344\344\377\345\345\345\377\346\346\346\377\347\347"
  "\347\377\347\347\347\377\350\350\350\377\351\351\351\377\352\352\352"
  "\377\353\353\353\377\354\354\354\377\354\354\354\377\356\356\356\377"
  "\356\356\356\377\357\357\357\377\360\360\360\377\362\362\362\377\363"
  "\363\363\377\364\364\364\377\365\365\365\377\366\366\366\377\367\367"
  "\367\377\371\371\371\377\372\372\372\377\373\373\373\377\375\375\375"
  "\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\365\365\365\377\267\267\267\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\332\212\212\212/\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "*;\200\256\363;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\365;\200\256\6\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\313;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\210\377\377\377\0;\200\256\216;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\314;\200\256\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\2566;\200\256\373;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\240\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212<\212\212\212\343\212\212\212\377\212\212\212\377\212\212"
  "\212\377\222\222\222\377\323\323\323\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\375\375\375\377\374\374\374\377\372\372\372\377\371"
  "\371\371\377\370\370\370\377\366\366\366\377\365\365\365\377\364\364"
  "\364\377\363\363\363\377\362\362\362\377\360\360\360\377\357\357\357"
  "\377\356\356\356\377\355\355\355\377\354\354\354\377\353\353\353\377"
  "\352\352\352\377\351\351\351\377\350\350\350\377\347\347\347\377\346"
  "\346\346\377\345\345\345\377\345\345\345\377\344\344\344\377\343\343"
  "\343\377\342\342\342\377\342\342\342\377\341\341\341\377\341\341\341"
  "\377\340\340\340\377\340\340\340\377\337\337\337\377\336\336\336\377"
  "\336\336\336\377\336\336\336\377\335\335\335\377\335\335\335\377\335"
  "\335\335\377\334\334\334\377\334\334\334\377\334\334\334\377\334\334"
  "\334\377\334\334\334\377\333\333\333\377\333\333\333\377\333\333\333"
  "\377\333\333\333\377\334\334\334\377\334\334\334\377\334\334\334\377"
  "\334\334\334\377\334\334\334\377\335\335\335\377\335\335\335\377\335"
  "\335\335\377\336\336\336\377\336\336\336\377\336\336\336\377\337\337"
  "\337\377\337\337\337\377\340\340\340\377\340\340\340\377\341\341\341"
  "\377\342\342\342\377\342\342\342\377\343\343\343\377\344\344\344\377"
  "\344\344\344\377\345\345\345\377\346\346\346\377\347\347\347\377\350"
  "\350\350\377\351\351\351\377\352\352\352\377\353\353\353\377\354\354"
  "\354\377\355\355\355\377\356\356\356\377\357\357\357\377\360\360\360"
  "\377\361\361\361\377\362\362\362\377\364\364\364\377\365\365\365\377"
  "\366\366\366\377\367\367\367\377\371\371\371\377\372\372\372\377\374"
  "\374\374\377\375\375\375\377\376\376\376\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\344\344\344"
  "\377\236\236\236\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\367\212\212\212h\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\16;\200\256\331"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\77\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\362;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\223\377\377\377\0;\200\256\177;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\232\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256z"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\374;\200\256&\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\1\212"
  "\212\212y\212\212\212\374\212\212\212\377\212\212\212\377\212\212\212"
  "\377\245\245\245\377\362\362\362\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\374\374\374\377\373\373\373\377\371\371\371\377\370\370"
  "\370\377\367\367\367\377\365\365\365\377\364\364\364\377\363\363\363"
  "\377\361\361\361\377\360\360\360\377\357\357\357\377\356\356\356\377"
  "\355\355\355\377\353\353\353\377\352\352\352\377\351\351\351\377\350"
  "\350\350\377\347\347\347\377\346\346\346\377\345\345\345\377\344\344"
  "\344\377\344\344\344\377\343\343\343\377\342\342\342\377\341\341\341"
  "\377\340\340\340\377\340\340\340\377\337\337\337\377\336\336\336\377"
  "\336\336\336\377\335\335\335\377\335\335\335\377\334\334\334\377\333"
  "\333\333\377\333\333\333\377\333\333\333\377\332\332\332\377\332\332"
  "\332\377\332\332\332\377\332\332\332\377\331\331\331\377\331\331\331"
  "\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377"
  "\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331"
  "\331\331\377\331\331\331\377\331\331\331\377\332\332\332\377\332\332"
  "\332\377\332\332\332\377\333\333\333\377\333\333\333\377\333\333\333"
  "\377\334\334\334\377\335\335\335\377\335\335\335\377\336\336\336\377"
  "\336\336\336\377\337\337\337\377\340\340\340\377\340\340\340\377\341"
  "\341\341\377\342\342\342\377\342\342\342\377\343\343\343\377\344\344"
  "\344\377\345\345\345\377\346\346\346\377\347\347\347\377\350\350\350"
  "\377\351\351\351\377\352\352\352\377\353\353\353\377\354\354\354\377"
  "\356\356\356\377\357\357\357\377\360\360\360\377\361\361\361\377\362"
  "\362\362\377\364\364\364\377\365\365\365\377\366\366\366\377\367\367"
  "\367\377\371\371\371\377\372\372\372\377\374\374\374\377\375\375\375"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\373\373\373\377\271\271\271\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\251\212\212"
  "\212\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\226;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\203\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\33;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\236\377\377\377\0;\200"
  "\256q;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256D\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\2;\200\256\302;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\231\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\25\212\212\212"
  "\270\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\301\301\301\377\375\375\375\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\375\375"
  "\375\377\373\373\373\377\372\372\372\377\370\370\370\377\367\367\367"
  "\377\365\365\365\377\364\364\364\377\363\363\363\377\361\361\361\377"
  "\360\360\360\377\357\357\357\377\356\356\356\377\354\354\354\377\353"
  "\353\353\377\352\352\352\377\351\351\351\377\350\350\350\377\347\347"
  "\347\377\346\346\346\377\345\345\345\377\344\344\344\377\343\343\343"
  "\377\342\342\342\377\341\341\341\377\340\340\340\377\337\337\337\377"
  "\336\336\336\377\336\336\336\377\335\335\335\377\334\334\334\377\333"
  "\333\333\377\333\333\333\377\332\332\332\377\332\332\332\377\331\331"
  "\331\377\331\331\331\377\330\330\330\377\330\330\330\377\327\327\327"
  "\377\327\327\327\377\327\327\327\377\327\327\327\377\326\326\326\377"
  "\326\326\326\377\326\326\326\377\326\326\326\377\326\326\326\377\326"
  "\326\326\377\326\326\326\377\326\326\326\377\326\326\326\377\326\326"
  "\326\377\326\326\326\377\326\326\326\377\327\327\327\377\327\327\327"
  "\377\327\327\327\377\327\327\327\377\330\330\330\377\330\330\330\377"
  "\330\330\330\377\331\331\331\377\332\332\332\377\332\332\332\377\333"
  "\333\333\377\333\333\333\377\334\334\334\377\335\335\335\377\335\335"
  "\335\377\336\336\336\377\337\337\337\377\340\340\340\377\341\341\341"
  "\377\341\341\341\377\342\342\342\377\343\343\343\377\344\344\344\377"
  "\345\345\345\377\347\347\347\377\347\347\347\377\351\351\351\377\352"
  "\352\352\377\353\353\353\377\354\354\354\377\355\355\355\377\357\357"
  "\357\377\360\360\360\377\361\361\361\377\362\362\362\377\364\364\364"
  "\377\365\365\365\377\366\366\366\377\370\370\370\377\371\371\371\377"
  "\373\373\373\377\374\374\374\377\376\376\376\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\327\327"
  "\327\377\220\220\220\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\333\212\212\2122\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "8;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\306\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256B;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\252\377\377\377"
  "\0;\200\256c;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\333;\200\256"
  "\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256#;\200\256\365;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256\21\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212<\212\212\212\345\212"
  "\212\212\377\212\212\212\377\212\212\212\377\223\223\223\377\336\336"
  "\336\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\375\375\375\377\374\374\374\377"
  "\372\372\372\377\371\371\371\377\367\367\367\377\366\366\366\377\364"
  "\364\364\377\363\363\363\377\362\362\362\377\360\360\360\377\357\357"
  "\357\377\356\356\356\377\354\354\354\377\353\353\353\377\352\352\352"
  "\377\350\350\350\377\347\347\347\377\346\346\346\377\345\345\345\377"
  "\344\344\344\377\343\343\343\377\342\342\342\377\341\341\341\377\340"
  "\340\340\377\337\337\337\377\336\336\336\377\335\335\335\377\334\334"
  "\334\377\333\333\333\377\333\333\333\377\332\332\332\377\331\331\331"
  "\377\331\331\331\377\330\330\330\377\327\327\327\377\327\327\327\377"
  "\326\326\326\377\326\326\326\377\326\326\326\377\325\325\325\377\325"
  "\325\325\377\324\324\324\377\324\324\324\377\324\324\324\377\324\324"
  "\324\377\323\323\323\377\323\323\323\377\323\323\323\377\323\323\323"
  "\377\323\323\323\377\323\323\323\377\323\323\323\377\323\323\323\377"
  "\323\323\323\377\323\323\323\377\323\323\323\377\324\324\324\377\324"
  "\324\324\377\324\324\324\377\324\324\324\377\325\325\325\377\325\325"
  "\325\377\326\326\326\377\326\326\326\377\327\327\327\377\327\327\327"
  "\377\330\330\330\377\330\330\330\377\331\331\331\377\332\332\332\377"
  "\333\333\333\377\333\333\333\377\334\334\334\377\335\335\335\377\336"
  "\336\336\377\337\337\337\377\340\340\340\377\341\341\341\377\342\342"
  "\342\377\343\343\343\377\344\344\344\377\345\345\345\377\346\346\346"
  "\377\347\347\347\377\350\350\350\377\351\351\351\377\353\353\353\377"
  "\354\354\354\377\355\355\355\377\357\357\357\377\360\360\360\377\361"
  "\361\361\377\363\363\363\377\364\364\364\377\365\365\365\377\367\367"
  "\367\377\370\370\370\377\372\372\372\377\373\373\373\377\375\375\375"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\356\356\356\377\240\240\240\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\370\212\212\212i\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\4"
  ";\200\256\322;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\373;\200\256\16\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256j"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\265"
  "\377\377\377\0;\200\256U;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\203\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256p;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256s\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212S\212\212\212\370\212"
  "\212\212\377\212\212\212\377\212\212\212\377\246\246\246\377\363\363"
  "\363\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\375\375\375\377\373\373\373\377"
  "\371\371\371\377\370\370\370\377\366\366\366\377\365\365\365\377\363"
  "\363\363\377\362\362\362\377\360\360\360\377\357\357\357\377\356\356"
  "\356\377\354\354\354\377\353\353\353\377\352\352\352\377\350\350\350"
  "\377\347\347\347\377\346\346\346\377\345\345\345\377\344\344\344\377"
  "\342\342\342\377\341\341\341\377\340\340\340\377\337\337\337\377\336"
  "\336\336\377\335\335\335\377\334\334\334\377\333\333\333\377\332\332"
  "\332\377\332\332\332\377\331\331\331\377\330\330\330\377\327\327\327"
  "\377\327\327\327\377\326\326\326\377\325\325\325\377\325\325\325\377"
  "\324\324\324\377\324\324\324\377\323\323\323\377\323\323\323\377\322"
  "\322\322\377\322\322\322\377\321\321\321\377\321\321\321\377\321\321"
  "\321\377\321\321\321\377\320\320\320\377\320\320\320\377\320\320\320"
  "\377\320\320\320\377\320\320\320\377\320\320\320\377\320\320\320\377"
  "\320\320\320\377\320\320\320\377\320\320\320\377\321\321\321\377\321"
  "\321\321\377\321\321\321\377\321\321\321\377\322\322\322\377\322\322"
  "\322\377\323\323\323\377\323\323\323\377\323\323\323\377\324\324\324"
  "\377\324\324\324\377\325\325\325\377\326\326\326\377\326\326\326\377"
  "\327\327\327\377\330\330\330\377\330\330\330\377\331\331\331\377\332"
  "\332\332\377\333\333\333\377\334\334\334\377\335\335\335\377\336\336"
  "\336\377\337\337\337\377\340\340\340\377\341\341\341\377\342\342\342"
  "\377\343\343\343\377\344\344\344\377\346\346\346\377\347\347\347\377"
  "\350\350\350\377\351\351\351\377\353\353\353\377\354\354\354\377\355"
  "\355\355\377\357\357\357\377\360\360\360\377\362\362\362\377\363\363"
  "\363\377\365\365\365\377\366\366\366\377\367\367\367\377\371\371\371"
  "\377\372\372\372\377\374\374\374\377\376\376\376\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\373\373\373\377\273"
  "\273\273\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\212\212\212\212\1\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256w;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256M\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\222;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\300\377\377\377\0;\200\256F;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\371;\200\256)\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2"
  ";\200\256\305;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\336;\200\256\2\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212g\212\212\212\375\212"
  "\212\212\377\212\212\212\377\212\212\212\377\303\303\303\377\375\375"
  "\375\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\375\375\375\377\374\374\374\377\372\372\372\377"
  "\371\371\371\377\367\367\367\377\365\365\365\377\364\364\364\377\362"
  "\362\362\377\361\361\361\377\357\357\357\377\356\356\356\377\354\354"
  "\354\377\353\353\353\377\352\352\352\377\350\350\350\377\347\347\347"
  "\377\346\346\346\377\345\345\345\377\343\343\343\377\342\342\342\377"
  "\341\341\341\377\340\340\340\377\337\337\337\377\336\336\336\377\335"
  "\335\335\377\333\333\333\377\332\332\332\377\332\332\332\377\330\330"
  "\330\377\330\330\330\377\327\327\327\377\326\326\326\377\325\325\325"
  "\377\324\324\324\377\324\324\324\377\323\323\323\377\323\323\323\377"
  "\322\322\322\377\321\321\321\377\321\321\321\377\320\320\320\377\320"
  "\320\320\377\317\317\317\377\317\317\317\377\317\317\317\377\316\316"
  "\316\377\316\316\316\377\316\316\316\377\315\315\315\377\315\315\315"
  "\377\315\315\315\377\315\315\315\377\315\315\315\377\315\315\315\377"
  "\315\315\315\377\315\315\315\377\315\315\315\377\315\315\315\377\316"
  "\316\316\377\316\316\316\377\316\316\316\377\317\317\317\377\317\317"
  "\317\377\317\317\317\377\320\320\320\377\320\320\320\377\321\321\321"
  "\377\321\321\321\377\322\322\322\377\322\322\322\377\323\323\323\377"
  "\324\324\324\377\324\324\324\377\325\325\325\377\326\326\326\377\327"
  "\327\327\377\327\327\327\377\330\330\330\377\331\331\331\377\332\332"
  "\332\377\333\333\333\377\334\334\334\377\335\335\335\377\336\336\336"
  "\377\340\340\340\377\341\341\341\377\342\342\342\377\343\343\343\377"
  "\344\344\344\377\345\345\345\377\347\347\347\377\350\350\350\377\351"
  "\351\351\377\353\353\353\377\354\354\354\377\356\356\356\377\357\357"
  "\357\377\360\360\360\377\362\362\362\377\363\363\363\377\365\365\365"
  "\377\367\367\367\377\370\370\370\377\372\372\372\377\373\373\373\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\330\330\330\377\220\220\220\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\240\212\212\212"
  "\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\26;\200\256\365;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\205\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\272;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\314\377\377\377\0;\200\256"
  "8;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\301;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256';\200\256\367;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256M\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212~\212\212"
  "\212\377\212\212\212\377\212\212\212\377\216\216\216\377\334\334\334"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\375\375\375\377\373\373\373\377\371"
  "\371\371\377\370\370\370\377\366\366\366\377\365\365\365\377\363\363"
  "\363\377\361\361\361\377\360\360\360\377\356\356\356\377\355\355\355"
  "\377\353\353\353\377\352\352\352\377\351\351\351\377\347\347\347\377"
  "\346\346\346\377\345\345\345\377\343\343\343\377\342\342\342\377\341"
  "\341\341\377\340\340\340\377\336\336\336\377\335\335\335\377\334\334"
  "\334\377\333\333\333\377\332\332\332\377\331\331\331\377\330\330\330"
  "\377\327\327\327\377\326\326\326\377\325\325\325\377\324\324\324\377"
  "\323\323\323\377\323\323\323\377\322\322\322\377\321\321\321\377\320"
  "\320\320\377\320\320\320\377\317\317\317\377\317\317\317\377\316\316"
  "\316\377\315\315\315\377\315\315\315\377\314\314\314\377\314\314\314"
  "\377\314\314\314\377\314\314\314\377\313\313\313\377\313\313\313\377"
  "\313\313\313\377\312\312\312\377\312\312\312\377\312\312\312\377\312"
  "\312\312\377\312\312\312\377\312\312\312\377\312\312\312\377\312\312"
  "\312\377\313\313\313\377\313\313\313\377\313\313\313\377\313\313\313"
  "\377\314\314\314\377\314\314\314\377\314\314\314\377\315\315\315\377"
  "\315\315\315\377\316\316\316\377\316\316\316\377\317\317\317\377\320"
  "\320\320\377\320\320\320\377\321\321\321\377\321\321\321\377\322\322"
  "\322\377\323\323\323\377\324\324\324\377\325\325\325\377\326\326\326"
  "\377\327\327\327\377\330\330\330\377\330\330\330\377\332\332\332\377"
  "\333\333\333\377\334\334\334\377\335\335\335\377\336\336\336\377\337"
  "\337\337\377\340\340\340\377\342\342\342\377\343\343\343\377\344\344"
  "\344\377\345\345\345\377\347\347\347\377\350\350\350\377\352\352\352"
  "\377\353\353\353\377\354\354\354\377\356\356\356\377\357\357\357\377"
  "\361\361\361\377\363\363\363\377\364\364\364\377\366\366\366\377\367"
  "\367\367\377\371\371\371\377\373\373\373\377\374\374\374\377\376\376"
  "\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\356\356\356\377\232\232\232\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\264\212\212\212\12\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\203;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\242\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\341;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\327\377\377\377\0;\200\256*;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256a\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256u;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\272\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\2\212\212\212\225\212\212\212\377\212\212\212\377\212\212\212\377\222"
  "\222\222\377\345\345\345\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374\374\374"
  "\377\372\372\372\377\371\371\371\377\367\367\367\377\365\365\365\377"
  "\364\364\364\377\362\362\362\377\360\360\360\377\357\357\357\377\356"
  "\356\356\377\354\354\354\377\353\353\353\377\351\351\351\377\350\350"
  "\350\377\346\346\346\377\345\345\345\377\343\343\343\377\342\342\342"
  "\377\341\341\341\377\337\337\337\377\336\336\336\377\335\335\335\377"
  "\334\334\334\377\332\332\332\377\331\331\331\377\330\330\330\377\327"
  "\327\327\377\326\326\326\377\325\325\325\377\324\324\324\377\323\323"
  "\323\377\322\322\322\377\321\321\321\377\320\320\320\377\320\320\320"
  "\377\317\317\317\377\316\316\316\377\315\315\315\377\315\315\315\377"
  "\314\314\314\377\314\314\314\377\313\313\313\377\312\312\312\377\312"
  "\312\312\377\312\312\312\377\311\311\311\377\311\311\311\377\311\311"
  "\311\377\310\310\310\377\310\310\310\377\310\310\310\377\310\310\310"
  "\377\310\310\310\377\310\310\310\377\310\310\310\377\310\310\310\377"
  "\310\310\310\377\310\310\310\377\310\310\310\377\310\310\310\377\310"
  "\310\310\377\310\310\310\377\311\311\311\377\311\311\311\377\311\311"
  "\311\377\312\312\312\377\312\312\312\377\312\312\312\377\313\313\313"
  "\377\314\314\314\377\314\314\314\377\315\315\315\377\315\315\315\377"
  "\316\316\316\377\317\317\317\377\320\320\320\377\320\320\320\377\321"
  "\321\321\377\322\322\322\377\323\323\323\377\324\324\324\377\325\325"
  "\325\377\326\326\326\377\327\327\327\377\330\330\330\377\331\331\331"
  "\377\332\332\332\377\333\333\333\377\335\335\335\377\336\336\336\377"
  "\337\337\337\377\340\340\340\377\342\342\342\377\343\343\343\377\344"
  "\344\344\377\346\346\346\377\347\347\347\377\351\351\351\377\352\352"
  "\352\377\354\354\354\377\355\355\355\377\357\357\357\377\360\360\360"
  "\377\362\362\362\377\363\363\363\377\365\365\365\377\367\367\367\377"
  "\370\370\370\377\372\372\372\377\374\374\374\377\375\375\375\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\364\364"
  "\364\377\240\240\240\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\305\212\212\212\21\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\13;\200\256\355;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\275\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\13;\200\256\376;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\343\377\377\377\0;\200\256\33"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\354;\200\256\24\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\311"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256(\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212\6\212\212\212\252\212\212\212\377\212\212\212"
  "\377\212\212\212\377\227\227\227\377\354\354\354\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\374\374\374\377\372\372\372\377\370\370\370\377\366\366"
  "\366\377\365\365\365\377\363\363\363\377\361\361\361\377\360\360\360"
  "\377\356\356\356\377\355\355\355\377\353\353\353\377\351\351\351\377"
  "\350\350\350\377\347\347\347\377\345\345\345\377\344\344\344\377\342"
  "\342\342\377\341\341\341\377\340\340\340\377\336\336\336\377\335\335"
  "\335\377\333\333\333\377\332\332\332\377\331\331\331\377\330\330\330"
  "\377\327\327\327\377\326\326\326\377\324\324\324\377\323\323\323\377"
  "\322\322\322\377\321\321\321\377\320\320\320\377\320\320\320\377\317"
  "\317\317\377\316\316\316\377\315\315\315\377\314\314\314\377\314\314"
  "\314\377\313\313\313\377\312\312\312\377\311\311\311\377\311\311\311"
  "\377\310\310\310\377\310\310\310\377\307\307\307\377\307\307\307\377"
  "\306\306\306\377\306\306\306\377\306\306\306\377\305\305\305\377\305"
  "\305\305\377\305\305\305\377\305\305\305\377\305\305\305\377\305\305"
  "\305\377\305\305\305\377\305\305\305\377\305\305\305\377\305\305\305"
  "\377\305\305\305\377\305\305\305\377\305\305\305\377\305\305\305\377"
  "\306\306\306\377\306\306\306\377\306\306\306\377\307\307\307\377\307"
  "\307\307\377\310\310\310\377\310\310\310\377\311\311\311\377\311\311"
  "\311\377\312\312\312\377\312\312\312\377\313\313\313\377\314\314\314"
  "\377\315\315\315\377\315\315\315\377\317\317\317\377\317\317\317\377"
  "\320\320\320\377\321\321\321\377\322\322\322\377\323\323\323\377\324"
  "\324\324\377\325\325\325\377\326\326\326\377\330\330\330\377\331\331"
  "\331\377\332\332\332\377\333\333\333\377\335\335\335\377\336\336\336"
  "\377\337\337\337\377\340\340\340\377\342\342\342\377\343\343\343\377"
  "\345\345\345\377\346\346\346\377\350\350\350\377\351\351\351\377\353"
  "\353\353\377\354\354\354\377\356\356\356\377\357\357\357\377\361\361"
  "\361\377\363\363\363\377\364\364\364\377\366\366\366\377\370\370\370"
  "\377\371\371\371\377\373\373\373\377\375\375\375\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\371\371\371\377\250"
  "\250\250\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\325\212\212\212\34\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256n;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\330\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "1;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\363\377\377\377\0;\200\256\15;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\240"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256*;\200\256\370;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\224\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212\15\212\212\212\275"
  "\212\212\212\377\212\212\212\377\212\212\212\377\235\235\235\377\362"
  "\362\362\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\375\375\375\377\373\373\373\377\371\371\371"
  "\377\370\370\370\377\366\366\366\377\364\364\364\377\362\362\362\377"
  "\361\361\361\377\357\357\357\377\356\356\356\377\354\354\354\377\352"
  "\352\352\377\351\351\351\377\347\347\347\377\345\345\345\377\344\344"
  "\344\377\342\342\342\377\341\341\341\377\340\340\340\377\336\336\336"
  "\377\335\335\335\377\333\333\333\377\332\332\332\377\331\331\331\377"
  "\330\330\330\377\326\326\326\377\325\325\325\377\324\324\324\377\323"
  "\323\323\377\322\322\322\377\321\321\321\377\320\320\320\377\317\317"
  "\317\377\316\316\316\377\315\315\315\377\314\314\314\377\313\313\313"
  "\377\312\312\312\377\311\311\311\377\311\311\311\377\310\310\310\377"
  "\307\307\307\377\307\307\307\377\306\306\306\377\305\305\305\377\305"
  "\305\305\377\304\304\304\377\304\304\304\377\303\303\303\377\303\303"
  "\303\377\303\303\303\377\303\303\303\377\302\302\302\377\302\302\302"
  "\377\302\302\302\377\302\302\302\377\302\302\302\377\302\302\302\377"
  "\302\302\302\377\302\302\302\377\302\302\302\377\302\302\302\377\302"
  "\302\302\377\302\302\302\377\302\302\302\377\303\303\303\377\303\303"
  "\303\377\303\303\303\377\304\304\304\377\304\304\304\377\305\305\305"
  "\377\305\305\305\377\306\306\306\377\306\306\306\377\307\307\307\377"
  "\310\310\310\377\311\311\311\377\311\311\311\377\312\312\312\377\313"
  "\313\313\377\314\314\314\377\315\315\315\377\315\315\315\377\317\317"
  "\317\377\317\317\317\377\320\320\320\377\321\321\321\377\323\323\323"
  "\377\324\324\324\377\325\325\325\377\326\326\326\377\327\327\327\377"
  "\330\330\330\377\332\332\332\377\333\333\333\377\335\335\335\377\336"
  "\336\336\377\337\337\337\377\341\341\341\377\342\342\342\377\344\344"
  "\344\377\345\345\345\377\347\347\347\377\350\350\350\377\352\352\352"
  "\377\353\353\353\377\355\355\355\377\357\357\357\377\360\360\360\377"
  "\362\362\362\377\364\364\364\377\365\365\365\377\367\367\367\377\371"
  "\371\371\377\373\373\373\377\375\375\375\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\374\374\374\377\261\261\261"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\341"
  "\212\212\212(\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\4;\200\256\340;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\363\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0;\200\256Y;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\10;\200\256\1;\200\256\375;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256@\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256z;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\363;\200\256\16\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\11\212\212\212\303\212\212\212\377\212\212\212\377\212\212\212"
  "\377\244\244\244\377\367\367\367\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\373"
  "\373\373\377\371\371\371\377\367\367\367\377\365\365\365\377\364\364"
  "\364\377\362\362\362\377\360\360\360\377\356\356\356\377\355\355\355"
  "\377\353\353\353\377\351\351\351\377\350\350\350\377\346\346\346\377"
  "\345\345\345\377\343\343\343\377\342\342\342\377\340\340\340\377\337"
  "\337\337\377\335\335\335\377\334\334\334\377\332\332\332\377\331\331"
  "\331\377\330\330\330\377\326\326\326\377\325\325\325\377\324\324\324"
  "\377\323\323\323\377\321\321\321\377\320\320\320\377\317\317\317\377"
  "\316\316\316\377\315\315\315\377\314\314\314\377\313\313\313\377\312"
  "\312\312\377\311\311\311\377\310\310\310\377\310\310\310\377\307\307"
  "\307\377\306\306\306\377\305\305\305\377\305\305\305\377\304\304\304"
  "\377\303\303\303\377\303\303\303\377\302\302\302\377\302\302\302\377"
  "\301\301\301\377\301\301\301\377\300\300\300\377\300\300\300\377\300"
  "\300\300\377\277\277\277\377\277\277\277\377\277\277\277\377\277\277"
  "\277\377\277\277\277\377\277\277\277\377\277\277\277\377\277\277\277"
  "\377\277\277\277\377\277\277\277\377\277\277\277\377\277\277\277\377"
  "\300\300\300\377\300\300\300\377\300\300\300\377\301\301\301\377\301"
  "\301\301\377\302\302\302\377\302\302\302\377\302\302\302\377\303\303"
  "\303\377\304\304\304\377\304\304\304\377\305\305\305\377\306\306\306"
  "\377\306\306\306\377\307\307\307\377\310\310\310\377\311\311\311\377"
  "\312\312\312\377\313\313\313\377\314\314\314\377\315\315\315\377\316"
  "\316\316\377\317\317\317\377\320\320\320\377\321\321\321\377\322\322"
  "\322\377\324\324\324\377\325\325\325\377\326\326\326\377\327\327\327"
  "\377\331\331\331\377\332\332\332\377\333\333\333\377\335\335\335\377"
  "\336\336\336\377\340\340\340\377\341\341\341\377\343\343\343\377\344"
  "\344\344\377\346\346\346\377\347\347\347\377\351\351\351\377\353\353"
  "\353\377\354\354\354\377\356\356\356\377\360\360\360\377\362\362\362"
  "\377\363\363\363\377\365\365\365\377\367\367\367\377\371\371\371\377"
  "\372\372\372\377\374\374\374\377\376\376\376\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\273\273\273\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\351\212\212\212"
  "$\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256Y"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0;\200\256\201;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\35\377\377\377\0;\200"
  "\256\360;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\330;\200\256\6\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\4;\200\256\315;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256n\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\3\212\212\212\262\212\212"
  "\212\377\212\212\212\377\212\212\212\377\255\255\255\377\372\372\372"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\376\376\376\377\374\374\374\377\372\372\372\377\371\371\371\377\367"
  "\367\367\377\365\365\365\377\363\363\363\377\361\361\361\377\360\360"
  "\360\377\356\356\356\377\354\354\354\377\352\352\352\377\351\351\351"
  "\377\347\347\347\377\345\345\345\377\344\344\344\377\342\342\342\377"
  "\341\341\341\377\337\337\337\377\336\336\336\377\334\334\334\377\333"
  "\333\333\377\331\331\331\377\330\330\330\377\326\326\326\377\325\325"
  "\325\377\324\324\324\377\323\323\323\377\321\321\321\377\320\320\320"
  "\377\317\317\317\377\316\316\316\377\315\315\315\377\313\313\313\377"
  "\312\312\312\377\311\311\311\377\310\310\310\377\307\307\307\377\306"
  "\306\306\377\306\306\306\377\305\305\305\377\304\304\304\377\303\303"
  "\303\377\302\302\302\377\302\302\302\377\301\301\301\377\301\301\301"
  "\377\300\300\300\377\277\277\277\377\277\277\277\377\276\276\276\377"
  "\276\276\276\377\276\276\276\377\275\275\275\377\275\275\275\377\274"
  "\274\274\377\274\274\274\377\274\274\274\377\274\274\274\377\274\274"
  "\274\377\274\274\274\377\274\274\274\377\274\274\274\377\274\274\274"
  "\377\274\274\274\377\274\274\274\377\274\274\274\377\275\275\275\377"
  "\275\275\275\377\275\275\275\377\276\276\276\377\276\276\276\377\277"
  "\277\277\377\277\277\277\377\300\300\300\377\300\300\300\377\301\301"
  "\301\377\302\302\302\377\302\302\302\377\303\303\303\377\304\304\304"
  "\377\305\305\305\377\305\305\305\377\306\306\306\377\307\307\307\377"
  "\310\310\310\377\311\311\311\377\312\312\312\377\313\313\313\377\314"
  "\314\314\377\315\315\315\377\317\317\317\377\320\320\320\377\321\321"
  "\321\377\322\322\322\377\323\323\323\377\325\325\325\377\326\326\326"
  "\377\327\327\327\377\331\331\331\377\332\332\332\377\334\334\334\377"
  "\335\335\335\377\337\337\337\377\340\340\340\377\342\342\342\377\344"
  "\344\344\377\345\345\345\377\347\347\347\377\350\350\350\377\352\352"
  "\352\377\354\354\354\377\356\356\356\377\357\357\357\377\361\361\361"
  "\377\363\363\363\377\365\365\365\377\366\366\366\377\370\370\370\377"
  "\372\372\372\377\374\374\374\377\376\376\376\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\306\306\306\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\335\212\212\212"
  "\30\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\317;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256*\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\250;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\2561\377\377\377\0;\200\256\342;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256~\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256/"
  ";\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\332"
  ";\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212\236\212\212\212\377\212\212\212\377\212\212\212"
  "\377\260\260\260\377\375\375\375\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\376\376\376\377\374\374\374\377\372"
  "\372\372\377\370\370\370\377\366\366\366\377\365\365\365\377\363\363"
  "\363\377\361\361\361\377\357\357\357\377\355\355\355\377\354\354\354"
  "\377\352\352\352\377\350\350\350\377\347\347\347\377\345\345\345\377"
  "\343\343\343\377\341\341\341\377\340\340\340\377\336\336\336\377\335"
  "\335\335\377\333\333\333\377\332\332\332\377\330\330\330\377\327\327"
  "\327\377\325\325\325\377\324\324\324\377\323\323\323\377\321\321\321"
  "\377\320\320\320\377\317\317\317\377\315\315\315\377\314\314\314\377"
  "\313\313\313\377\312\312\312\377\311\311\311\377\310\310\310\377\307"
  "\307\307\377\306\306\306\377\305\305\305\377\304\304\304\377\303\303"
  "\303\377\302\302\302\377\301\301\301\377\300\300\300\377\300\300\300"
  "\377\277\277\277\377\276\276\276\377\276\276\276\377\275\275\275\377"
  "\274\274\274\377\274\274\274\377\273\273\273\377\273\273\273\377\273"
  "\273\273\377\272\272\272\377\272\272\272\377\272\272\272\377\272\272"
  "\272\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\272\272\272\377\272\272\272\377\272\272\272\377\272\272\272\377\273"
  "\273\273\377\273\273\273\377\273\273\273\377\274\274\274\377\274\274"
  "\274\377\275\275\275\377\276\276\276\377\276\276\276\377\277\277\277"
  "\377\277\277\277\377\300\300\300\377\301\301\301\377\302\302\302\377"
  "\303\303\303\377\303\303\303\377\304\304\304\377\305\305\305\377\306"
  "\306\306\377\310\310\310\377\311\311\311\377\312\312\312\377\313\313"
  "\313\377\314\314\314\377\315\315\315\377\316\316\316\377\320\320\320"
  "\377\321\321\321\377\322\322\322\377\324\324\324\377\325\325\325\377"
  "\326\326\326\377\330\330\330\377\331\331\331\377\333\333\333\377\334"
  "\334\334\377\336\336\336\377\340\340\340\377\341\341\341\377\343\343"
  "\343\377\344\344\344\377\346\346\346\377\350\350\350\377\351\351\351"
  "\377\353\353\353\377\355\355\355\377\357\357\357\377\360\360\360\377"
  "\362\362\362\377\364\364\364\377\366\366\366\377\370\370\370\377\372"
  "\372\372\377\374\374\374\377\376\376\376\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\314\314\314\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\320\212\212\212\16\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256E;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256E\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\320;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256F\377\377\377\0;\200\256\324;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\370;\200\256&\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\223;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256H\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\207\212"
  "\212\212\377\212\212\212\377\212\212\212\377\250\250\250\377\373\373"
  "\373\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\376\376\376\377\374\374\374\377\372\372\372\377\370\370\370\377"
  "\366\366\366\377\364\364\364\377\362\362\362\377\360\360\360\377\357"
  "\357\357\377\355\355\355\377\353\353\353\377\351\351\351\377\350\350"
  "\350\377\346\346\346\377\344\344\344\377\342\342\342\377\341\341\341"
  "\377\337\337\337\377\335\335\335\377\334\334\334\377\332\332\332\377"
  "\331\331\331\377\327\327\327\377\326\326\326\377\324\324\324\377\323"
  "\323\323\377\321\321\321\377\320\320\320\377\317\317\317\377\315\315"
  "\315\377\314\314\314\377\313\313\313\377\312\312\312\377\310\310\310"
  "\377\307\307\307\377\306\306\306\377\305\305\305\377\304\304\304\377"
  "\303\303\303\377\302\302\302\377\301\301\301\377\300\300\300\377\277"
  "\277\277\377\276\276\276\377\276\276\276\377\275\275\275\377\274\274"
  "\274\377\273\273\273\377\273\273\273\377\272\272\272\377\272\272\272"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377\272"
  "\272\272\377\273\273\273\377\273\273\273\377\274\274\274\377\275\275"
  "\275\377\275\275\275\377\276\276\276\377\277\277\277\377\300\300\300"
  "\377\301\301\301\377\302\302\302\377\303\303\303\377\304\304\304\377"
  "\305\305\305\377\306\306\306\377\307\307\307\377\310\310\310\377\311"
  "\311\311\377\312\312\312\377\314\314\314\377\315\315\315\377\316\316"
  "\316\377\320\320\320\377\321\321\321\377\323\323\323\377\324\324\324"
  "\377\325\325\325\377\327\327\327\377\330\330\330\377\332\332\332\377"
  "\333\333\333\377\335\335\335\377\337\337\337\377\340\340\340\377\342"
  "\342\342\377\344\344\344\377\345\345\345\377\347\347\347\377\351\351"
  "\351\377\353\353\353\377\354\354\354\377\356\356\356\377\360\360\360"
  "\377\362\362\362\377\364\364\364\377\366\366\366\377\367\367\367\377"
  "\372\372\372\377\374\374\374\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\301\301\301\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\300\212\212\212"
  "\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\273;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256`\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0;\200\256\1;\200\256\366;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256[\377\377\377\0;\200\256\305;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\275\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\20;\200\256\352"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\263\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212p\212\212\212\377\212\212\212"
  "\377\212\212\212\377\240\240\240\377\370\370\370\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374"
  "\374\374\377\372\372\372\377\370\370\370\377\366\366\366\377\364\364"
  "\364\377\362\362\362\377\360\360\360\377\356\356\356\377\354\354\354"
  "\377\353\353\353\377\351\351\351\377\347\347\347\377\345\345\345\377"
  "\344\344\344\377\342\342\342\377\340\340\340\377\336\336\336\377\335"
  "\335\335\377\333\333\333\377\332\332\332\377\330\330\330\377\326\326"
  "\326\377\325\325\325\377\323\323\323\377\322\322\322\377\320\320\320"
  "\377\317\317\317\377\315\315\315\377\314\314\314\377\313\313\313\377"
  "\311\311\311\377\310\310\310\377\307\307\307\377\306\306\306\377\305"
  "\305\305\377\303\303\303\377\302\302\302\377\301\301\301\377\300\300"
  "\300\377\277\277\277\377\276\276\276\377\275\275\275\377\274\274\274"
  "\377\274\274\274\377\273\273\273\377\272\272\272\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\273\273\273\377\273\273\273\377\274\274\274\377\275\275\275\377\276"
  "\276\276\377\277\277\277\377\300\300\300\377\301\301\301\377\302\302"
  "\302\377\303\303\303\377\304\304\304\377\305\305\305\377\307\307\307"
  "\377\310\310\310\377\311\311\311\377\312\312\312\377\314\314\314\377"
  "\315\315\315\377\317\317\317\377\320\320\320\377\321\321\321\377\323"
  "\323\323\377\324\324\324\377\326\326\326\377\327\327\327\377\331\331"
  "\331\377\333\333\333\377\334\334\334\377\336\336\336\377\340\340\340"
  "\377\341\341\341\377\343\343\343\377\345\345\345\377\347\347\347\377"
  "\350\350\350\377\352\352\352\377\354\354\354\377\356\356\356\377\360"
  "\360\360\377\362\362\362\377\363\363\363\377\366\366\366\377\367\367"
  "\367\377\371\371\371\377\373\373\373\377\375\375\375\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\267\267\267\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\255\212"
  "\212\212\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2561;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256{\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0;\200\256\40;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256p\377\377"
  "\377\0;\200\256\267;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256]\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256d;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\372;\200\256\20\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212[\212\212\212\376\212\212\212\377\212\212\212\377\231\231"
  "\231\377\364\364\364\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\374\374\374\377\372\372\372\377"
  "\370\370\370\377\366\366\366\377\364\364\364\377\362\362\362\377\360"
  "\360\360\377\356\356\356\377\354\354\354\377\352\352\352\377\350\350"
  "\350\377\347\347\347\377\345\345\345\377\343\343\343\377\341\341\341"
  "\377\340\340\340\377\336\336\336\377\334\334\334\377\332\332\332\377"
  "\331\331\331\377\327\327\327\377\326\326\326\377\324\324\324\377\322"
  "\322\322\377\321\321\321\377\317\317\317\377\316\316\316\377\314\314"
  "\314\377\313\313\313\377\312\312\312\377\310\310\310\377\307\307\307"
  "\377\306\306\306\377\304\304\304\377\303\303\303\377\302\302\302\377"
  "\301\301\301\377\300\300\300\377\277\277\277\377\276\276\276\377\274"
  "\274\274\377\274\274\274\377\273\273\273\377\272\272\272\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\272\272\272\377\272\272\272\377\273\273\273\377"
  "\274\274\274\377\275\275\275\377\276\276\276\377\277\277\277\377\301"
  "\301\301\377\302\302\302\377\303\303\303\377\304\304\304\377\305\305"
  "\305\377\307\307\307\377\310\310\310\377\311\311\311\377\313\313\313"
  "\377\314\314\314\377\315\315\315\377\317\317\317\377\320\320\320\377"
  "\322\322\322\377\323\323\323\377\325\325\325\377\327\327\327\377\330"
  "\330\330\377\332\332\332\377\334\334\334\377\335\335\335\377\337\337"
  "\337\377\341\341\341\377\342\342\342\377\344\344\344\377\346\346\346"
  "\377\350\350\350\377\352\352\352\377\354\354\354\377\356\356\356\377"
  "\357\357\357\377\361\361\361\377\363\363\363\377\365\365\365\377\367"
  "\367\367\377\371\371\371\377\373\373\373\377\375\375\375\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\375\375\375\377\255\255\255"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\231"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\246;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\226\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0;\200\256G;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\204\377"
  "\377\377\0;\200\256\251;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\342;\200\256\5\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256"
  "\312;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256]\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "H\212\212\212\372\212\212\212\377\212\212\212\377\224\224\224\377\356"
  "\356\356\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\376\376\376\377\374\374\374\377\372\372\372\377\370\370\370"
  "\377\366\366\366\377\364\364\364\377\362\362\362\377\360\360\360\377"
  "\356\356\356\377\354\354\354\377\352\352\352\377\350\350\350\377\346"
  "\346\346\377\344\344\344\377\342\342\342\377\341\341\341\377\337\337"
  "\337\377\335\335\335\377\333\333\333\377\332\332\332\377\330\330\330"
  "\377\326\326\326\377\325\325\325\377\323\323\323\377\321\321\321\377"
  "\320\320\320\377\316\316\316\377\315\315\315\377\313\313\313\377\312"
  "\312\312\377\311\311\311\377\307\307\307\377\306\306\306\377\304\304"
  "\304\377\303\303\303\377\302\302\302\377\301\301\301\377\277\277\277"
  "\377\276\276\276\377\275\275\275\377\274\274\274\377\273\273\273\377"
  "\272\272\272\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\272\272\272\377\273\273\273\377\274\274\274\377\275\275\275\377"
  "\276\276\276\377\277\277\277\377\300\300\300\377\302\302\302\377\303"
  "\303\303\377\304\304\304\377\305\305\305\377\307\307\307\377\310\310"
  "\310\377\312\312\312\377\313\313\313\377\314\314\314\377\316\316\316"
  "\377\320\320\320\377\321\321\321\377\323\323\323\377\324\324\324\377"
  "\326\326\326\377\330\330\330\377\331\331\331\377\333\333\333\377\335"
  "\335\335\377\336\336\336\377\340\340\340\377\342\342\342\377\344\344"
  "\344\377\346\346\346\377\350\350\350\377\351\351\351\377\353\353\353"
  "\377\355\355\355\377\357\357\357\377\361\361\361\377\363\363\363\377"
  "\365\365\365\377\367\367\367\377\371\371\371\377\373\373\373\377\375"
  "\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377\373\373"
  "\373\377\245\245\245\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\202\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\22;\200\256\373;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\253\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256_;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\231\377"
  "\377\377\0;\200\256\227;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256b\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2566"
  ";\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\257\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212$\212\212\212"
  "\361\212\212\212\377\212\212\212\377\217\217\217\377\350\350\350\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\374\374\374\377\372\372\372\377\370\370\370\377\366\366"
  "\366\377\364\364\364\377\362\362\362\377\360\360\360\377\356\356\356"
  "\377\354\354\354\377\352\352\352\377\350\350\350\377\346\346\346\377"
  "\344\344\344\377\342\342\342\377\340\340\340\377\336\336\336\377\335"
  "\335\335\377\333\333\333\377\331\331\331\377\327\327\327\377\326\326"
  "\326\377\324\324\324\377\322\322\322\377\321\321\321\377\317\317\317"
  "\377\315\315\315\377\314\314\314\377\312\312\312\377\311\311\311\377"
  "\310\310\310\377\306\306\306\377\305\305\305\377\303\303\303\377\302"
  "\302\302\377\301\301\301\377\277\277\277\377\276\276\276\377\275\275"
  "\275\377\274\274\274\377\272\272\272\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272"
  "\377\273\273\273\377\274\274\274\377\276\276\276\377\277\277\277\377"
  "\300\300\300\377\302\302\302\377\303\303\303\377\304\304\304\377\306"
  "\306\306\377\307\307\307\377\311\311\311\377\312\312\312\377\314\314"
  "\314\377\315\315\315\377\317\317\317\377\320\320\320\377\322\322\322"
  "\377\324\324\324\377\325\325\325\377\327\327\327\377\331\331\331\377"
  "\332\332\332\377\334\334\334\377\336\336\336\377\340\340\340\377\342"
  "\342\342\377\344\344\344\377\345\345\345\377\347\347\347\377\351\351"
  "\351\377\353\353\353\377\355\355\355\377\357\357\357\377\361\361\361"
  "\377\363\363\363\377\365\365\365\377\367\367\367\377\371\371\371\377"
  "\373\373\373\377\375\375\375\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\367\367\367\377\236\236\236\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212V\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256^;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\263\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256l;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\256\377"
  "\377\377\0;\200\256\177;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\332;\200\256\2\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\234;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\366;\200\256"
  "\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\7\212\212\212\316\212\212"
  "\212\377\212\212\212\377\214\214\214\377\340\340\340\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377"
  "\374\374\374\377\372\372\372\377\370\370\370\377\366\366\366\377\364"
  "\364\364\377\362\362\362\377\360\360\360\377\356\356\356\377\354\354"
  "\354\377\352\352\352\377\350\350\350\377\346\346\346\377\344\344\344"
  "\377\342\342\342\377\340\340\340\377\336\336\336\377\334\334\334\377"
  "\332\332\332\377\331\331\331\377\327\327\327\377\325\325\325\377\323"
  "\323\323\377\322\322\322\377\320\320\320\377\316\316\316\377\315\315"
  "\315\377\313\313\313\377\311\311\311\377\310\310\310\377\306\306\306"
  "\377\305\305\305\377\303\303\303\377\302\302\302\377\301\301\301\377"
  "\277\277\277\377\276\276\276\377\275\275\275\377\273\273\273\377\272"
  "\272\272\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\272\272\272\377\273\273\273\377\274\274\274"
  "\377\276\276\276\377\277\277\277\377\300\300\300\377\302\302\302\377"
  "\303\303\303\377\305\305\305\377\306\306\306\377\310\310\310\377\311"
  "\311\311\377\313\313\313\377\314\314\314\377\316\316\316\377\320\320"
  "\320\377\321\321\321\377\323\323\323\377\325\325\325\377\326\326\326"
  "\377\330\330\330\377\332\332\332\377\334\334\334\377\336\336\336\377"
  "\340\340\340\377\341\341\341\377\343\343\343\377\345\345\345\377\347"
  "\347\347\377\351\351\351\377\353\353\353\377\355\355\355\377\357\357"
  "\357\377\361\361\361\377\363\363\363\377\365\365\365\377\367\367\367"
  "\377\371\371\371\377\374\374\374\377\376\376\376\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\362\362\362\377\230\230\230\377\212"
  "\212\212\377\212\212\212\377\212\212\212\361\212\212\212$\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\256;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\274\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256y;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\303\377\377\377\0;\200\256g;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256W\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\25;\200\256\357;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256T\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\212\226\212\212\212\377\212"
  "\212\212\377\212\212\212\377\317\317\317\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374\374"
  "\377\372\372\372\377\370\370\370\377\366\366\366\377\364\364\364\377"
  "\362\362\362\377\360\360\360\377\356\356\356\377\354\354\354\377\351"
  "\351\351\377\350\350\350\377\345\345\345\377\344\344\344\377\342\342"
  "\342\377\340\340\340\377\336\336\336\377\334\334\334\377\332\332\332"
  "\377\330\330\330\377\326\326\326\377\325\325\325\377\323\323\323\377"
  "\321\321\321\377\317\317\317\377\316\316\316\377\314\314\314\377\312"
  "\312\312\377\311\311\311\377\307\307\307\377\306\306\306\377\304\304"
  "\304\377\302\302\302\377\301\301\301\377\277\277\277\377\276\276\276"
  "\377\275\275\275\377\273\273\273\377\272\272\272\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272"
  "\272\377\273\273\273\377\274\274\274\377\276\276\276\377\277\277\277"
  "\377\301\301\301\377\302\302\302\377\304\304\304\377\305\305\305\377"
  "\307\307\307\377\310\310\310\377\312\312\312\377\314\314\314\377\315"
  "\315\315\377\317\317\317\377\321\321\321\377\322\322\322\377\324\324"
  "\324\377\326\326\326\377\330\330\330\377\332\332\332\377\333\333\333"
  "\377\335\335\335\377\337\337\337\377\341\341\341\377\343\343\343\377"
  "\345\345\345\377\347\347\347\377\351\351\351\377\353\353\353\377\355"
  "\355\355\377\357\357\357\377\361\361\361\377\363\363\363\377\365\365"
  "\365\377\367\367\367\377\372\372\372\377\374\374\374\377\376\376\376"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\350\350\350\377"
  "\215\215\215\377\212\212\212\377\212\212\212\377\212\212\212\316\212"
  "\212\212\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256\365;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\304\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\206;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\327\377\377\377\0;\200\256O;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\320"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256l;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\247\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212V\212\212\212"
  "\377\212\212\212\377\212\212\212\377\262\262\262\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\372\372\372\377\370\370\370\377\366\366\366\377\364\364"
  "\364\377\362\362\362\377\360\360\360\377\356\356\356\377\354\354\354"
  "\377\351\351\351\377\350\350\350\377\345\345\345\377\344\344\344\377"
  "\341\341\341\377\340\340\340\377\336\336\336\377\334\334\334\377\332"
  "\332\332\377\330\330\330\377\326\326\326\377\324\324\324\377\322\322"
  "\322\377\321\321\321\377\317\317\317\377\315\315\315\377\313\313\313"
  "\377\312\312\312\377\310\310\310\377\306\306\306\377\305\305\305\377"
  "\303\303\303\377\302\302\302\377\300\300\300\377\277\277\277\377\275"
  "\275\275\377\274\274\274\377\272\272\272\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377\273"
  "\273\273\377\275\275\275\377\276\276\276\377\300\300\300\377\301\301"
  "\301\377\303\303\303\377\304\304\304\377\306\306\306\377\310\310\310"
  "\377\311\311\311\377\313\313\313\377\315\315\315\377\316\316\316\377"
  "\320\320\320\377\322\322\322\377\324\324\324\377\326\326\326\377\327"
  "\327\327\377\331\331\331\377\333\333\333\377\335\335\335\377\337\337"
  "\337\377\341\341\341\377\343\343\343\377\345\345\345\377\347\347\347"
  "\377\351\351\351\377\353\353\353\377\355\355\355\377\357\357\357\377"
  "\361\361\361\377\363\363\363\377\366\366\366\377\370\370\370\377\372"
  "\372\372\377\374\374\374\377\376\376\376\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\317\317\317\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\226\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256O;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\315"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\223"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\354\377\377\377\0;\200\2568;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256K\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\3"
  ";\200\256\321;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\356;\200\256\1\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212$\212\212\212"
  "\361\212\212\212\377\212\212\212\377\232\232\232\377\371\371\371\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\373\373\373\377\371\371\371\377\366\366\366\377\364\364"
  "\364\377\362\362\362\377\360\360\360\377\356\356\356\377\354\354\354"
  "\377\351\351\351\377\350\350\350\377\345\345\345\377\344\344\344\377"
  "\341\341\341\377\340\340\340\377\335\335\335\377\333\333\333\377\332"
  "\332\332\377\330\330\330\377\326\326\326\377\324\324\324\377\322\322"
  "\322\377\320\320\320\377\316\316\316\377\315\315\315\377\313\313\313"
  "\377\311\311\311\377\307\307\307\377\306\306\306\377\304\304\304\377"
  "\302\302\302\377\301\301\301\377\277\277\277\377\276\276\276\377\274"
  "\274\274\377\273\273\273\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\272\272\272\377\274\274\274\377\275\275"
  "\275\377\277\277\277\377\300\300\300\377\302\302\302\377\303\303\303"
  "\377\305\305\305\377\307\307\307\377\311\311\311\377\312\312\312\377"
  "\314\314\314\377\316\316\316\377\320\320\320\377\321\321\321\377\323"
  "\323\323\377\325\325\325\377\327\327\327\377\331\331\331\377\333\333"
  "\333\377\335\335\335\377\337\337\337\377\341\341\341\377\343\343\343"
  "\377\345\345\345\377\347\347\347\377\351\351\351\377\353\353\353\377"
  "\355\355\355\377\357\357\357\377\362\362\362\377\364\364\364\377\366"
  "\366\366\377\370\370\370\377\372\372\372\377\374\374\374\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\262\262\262"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212V\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\237;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\325\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\237;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256\3;"
  "\200\256\40;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\305\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256,\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\7\212\212"
  "\212\316\212\212\212\377\212\212\212\377\215\215\215\377\350\350\350"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\373\373\373\377\371\371\371\377\367\367\367\377\365"
  "\365\365\377\362\362\362\377\360\360\360\377\356\356\356\377\354\354"
  "\354\377\352\352\352\377\350\350\350\377\345\345\345\377\344\344\344"
  "\377\341\341\341\377\337\337\337\377\335\335\335\377\333\333\333\377"
  "\331\331\331\377\327\327\327\377\326\326\326\377\324\324\324\377\322"
  "\322\322\377\320\320\320\377\316\316\316\377\314\314\314\377\312\312"
  "\312\377\311\311\311\377\307\307\307\377\305\305\305\377\303\303\303"
  "\377\302\302\302\377\300\300\300\377\276\276\276\377\275\275\275\377"
  "\273\273\273\377\272\272\272\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\273\273\273\377\274\274\274\377\276\276\276\377\277\277"
  "\277\377\301\301\301\377\303\303\303\377\305\305\305\377\306\306\306"
  "\377\310\310\310\377\312\312\312\377\314\314\314\377\315\315\315\377"
  "\317\317\317\377\321\321\321\377\323\323\323\377\325\325\325\377\327"
  "\327\327\377\331\331\331\377\333\333\333\377\335\335\335\377\337\337"
  "\337\377\341\341\341\377\343\343\343\377\345\345\345\377\347\347\347"
  "\377\351\351\351\377\353\353\353\377\356\356\356\377\360\360\360\377"
  "\362\362\362\377\364\364\364\377\366\366\366\377\370\370\370\377\372"
  "\372\372\377\375\375\375\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\371\371\371\377\232\232\232\377\212\212\212\377\212\212\212"
  "\377\212\212\212\361\212\212\212$\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\3;\200\256\354;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\336\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\254;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\26;\200\256\10;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\77\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\324"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256h\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\226\212\212\212\377\212\212\212\377\212\212\212\377\317"
  "\317\317\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\376\376\376\377\374\374\374\377\371\371\371\377\367\367\367"
  "\377\365\365\365\377\363\363\363\377\360\360\360\377\356\356\356\377"
  "\354\354\354\377\352\352\352\377\350\350\350\377\346\346\346\377\344"
  "\344\344\377\341\341\341\377\340\340\340\377\335\335\335\377\333\333"
  "\333\377\331\331\331\377\327\327\327\377\325\325\325\377\323\323\323"
  "\377\321\321\321\377\320\320\320\377\316\316\316\377\314\314\314\377"
  "\312\312\312\377\310\310\310\377\306\306\306\377\305\305\305\377\303"
  "\303\303\377\301\301\301\377\277\277\277\377\276\276\276\377\274\274"
  "\274\377\272\272\272\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\274\274\274\377\275\275\275\377\277\277\277\377\301\301\301\377\302"
  "\302\302\377\304\304\304\377\306\306\306\377\310\310\310\377\311\311"
  "\311\377\313\313\313\377\315\315\315\377\317\317\317\377\321\321\321"
  "\377\323\323\323\377\325\325\325\377\327\327\327\377\331\331\331\377"
  "\333\333\333\377\335\335\335\377\337\337\337\377\341\341\341\377\343"
  "\343\343\377\345\345\345\377\347\347\347\377\351\351\351\377\354\354"
  "\354\377\356\356\356\377\360\360\360\377\362\362\362\377\364\364\364"
  "\377\366\366\366\377\371\371\371\377\373\373\373\377\375\375\375\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\350\350\350\377\215"
  "\215\215\377\212\212\212\377\212\212\212\377\212\212\212\316\212\212"
  "\212\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\77;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\346"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\271"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256*\377\377\377\0;\200"
  "\256\360;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\271\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256b;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\244\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212Q\212\212\212\377\212\212\212\377\212"
  "\212\212\377\262\262\262\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\376\376\376\377\374\374\374\377\372\372\372"
  "\377\367\367\367\377\365\365\365\377\363\363\363\377\361\361\361\377"
  "\357\357\357\377\354\354\354\377\352\352\352\377\350\350\350\377\346"
  "\346\346\377\344\344\344\377\342\342\342\377\340\340\340\377\335\335"
  "\335\377\333\333\333\377\331\331\331\377\327\327\327\377\325\325\325"
  "\377\323\323\323\377\321\321\321\377\317\317\317\377\315\315\315\377"
  "\314\314\314\377\312\312\312\377\310\310\310\377\306\306\306\377\304"
  "\304\304\377\302\302\302\377\301\301\301\377\277\277\277\377\275\275"
  "\275\377\273\273\273\377\272\272\272\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\273\273\273\377\274"
  "\274\274\377\276\276\276\377\300\300\300\377\302\302\302\377\303\303"
  "\303\377\305\305\305\377\307\307\307\377\311\311\311\377\313\313\313"
  "\377\315\315\315\377\317\317\317\377\321\321\321\377\323\323\323\377"
  "\325\325\325\377\327\327\327\377\331\331\331\377\333\333\333\377\335"
  "\335\335\377\337\337\337\377\341\341\341\377\343\343\343\377\345\345"
  "\345\377\347\347\347\377\351\351\351\377\354\354\354\377\356\356\356"
  "\377\360\360\360\377\362\362\362\377\365\365\365\377\367\367\367\377"
  "\371\371\371\377\374\374\374\377\376\376\376\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\317\317\317\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\220\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\220;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\357\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\306;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\77\377\377\377\0;\200\256\330;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\2564\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\7"
  ";\200\256\350;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\340\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\14\212\212\212"
  "\343\212\212\212\377\212\212\212\377\232\232\232\377\371\371\371\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\372\372\372\377\370\370\370\377\366\366\366\377\363\363"
  "\363\377\361\361\361\377\357\357\357\377\355\355\355\377\353\353\353"
  "\377\350\350\350\377\346\346\346\377\344\344\344\377\342\342\342\377"
  "\340\340\340\377\336\336\336\377\333\333\333\377\331\331\331\377\327"
  "\327\327\377\325\325\325\377\323\323\323\377\321\321\321\377\317\317"
  "\317\377\315\315\315\377\313\313\313\377\311\311\311\377\307\307\307"
  "\377\305\305\305\377\304\304\304\377\302\302\302\377\300\300\300\377"
  "\276\276\276\377\274\274\274\377\273\273\273\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\272\272\272\377\274\274\274\377"
  "\276\276\276\377\277\277\277\377\301\301\301\377\303\303\303\377\305"
  "\305\305\377\307\307\307\377\311\311\311\377\313\313\313\377\315\315"
  "\315\377\317\317\317\377\321\321\321\377\323\323\323\377\325\325\325"
  "\377\327\327\327\377\331\331\331\377\333\333\333\377\335\335\335\377"
  "\337\337\337\377\341\341\341\377\343\343\343\377\345\345\345\377\350"
  "\350\350\377\352\352\352\377\354\354\354\377\356\356\356\377\360\360"
  "\360\377\363\363\363\377\365\365\365\377\367\367\367\377\372\372\372"
  "\377\374\374\374\377\376\376\376\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\262\262\262\377\212\212\212\377\212\212\212\377\212"
  "\212\212\375\212\212\2122\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\340;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\367\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\323;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256T\377\377\377\0;"
  "\200\256\300;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\255\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256|;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\34\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\212\212\212\212\377\212\212\212\377\212\212\212\377"
  "\346\346\346\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\375\375\375\377\373\373\373\377\371\371\371\377\366\366"
  "\366\377\364\364\364\377\362\362\362\377\357\357\357\377\355\355\355"
  "\377\353\353\353\377\351\351\351\377\347\347\347\377\344\344\344\377"
  "\342\342\342\377\340\340\340\377\336\336\336\377\333\333\333\377\332"
  "\332\332\377\327\327\327\377\325\325\325\377\323\323\323\377\321\321"
  "\321\377\317\317\317\377\315\315\315\377\313\313\313\377\311\311\311"
  "\377\307\307\307\377\305\305\305\377\303\303\303\377\301\301\301\377"
  "\300\300\300\377\276\276\276\377\274\274\274\377\272\272\272\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\272\272\272\377\273\273\273\377\275\275\275\377\277"
  "\277\277\377\301\301\301\377\303\303\303\377\305\305\305\377\307\307"
  "\307\377\311\311\311\377\312\312\312\377\315\315\315\377\317\317\317"
  "\377\321\321\321\377\323\323\323\377\325\325\325\377\327\327\327\377"
  "\331\331\331\377\333\333\333\377\335\335\335\377\337\337\337\377\341"
  "\341\341\377\344\344\344\377\346\346\346\377\350\350\350\377\352\352"
  "\352\377\354\354\354\377\357\357\357\377\361\361\361\377\363\363\363"
  "\377\366\366\366\377\370\370\370\377\372\372\372\377\375\375\375\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\371\371\371\377\226"
  "\226\226\377\212\212\212\377\212\212\212\377\212\212\212\310\212\212"
  "\212\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\2560;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\1\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\340;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256i\377\377\377\0;\200\256\250;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\376;\200\256)\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\23;\200\256\366;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256X\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212*\212\212\212\372\212\212\212\377"
  "\212\212\212\377\272\272\272\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\374\374\374\377\371\371"
  "\371\377\367\367\367\377\365\365\365\377\362\362\362\377\360\360\360"
  "\377\356\356\356\377\353\353\353\377\351\351\351\377\347\347\347\377"
  "\345\345\345\377\342\342\342\377\340\340\340\377\336\336\336\377\334"
  "\334\334\377\332\332\332\377\327\327\327\377\325\325\325\377\323\323"
  "\323\377\321\321\321\377\317\317\317\377\315\315\315\377\313\313\313"
  "\377\311\311\311\377\307\307\307\377\305\305\305\377\303\303\303\377"
  "\301\301\301\377\277\277\277\377\275\275\275\377\273\273\273\377\272"
  "\272\272\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\273\273\273\377\275\275\275\377\277\277\277\377\301\301"
  "\301\377\303\303\303\377\305\305\305\377\306\306\306\377\311\311\311"
  "\377\312\312\312\377\315\315\315\377\317\317\317\377\321\321\321\377"
  "\323\323\323\377\325\325\325\377\327\327\327\377\331\331\331\377\333"
  "\333\333\377\335\335\335\377\340\340\340\377\342\342\342\377\344\344"
  "\344\377\346\346\346\377\350\350\350\377\353\353\353\377\355\355\355"
  "\377\357\357\357\377\362\362\362\377\364\364\364\377\366\366\366\377"
  "\371\371\371\377\373\373\373\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\327\327\327\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212e\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\201;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\10\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\355"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256}\377\377\377\0;\200"
  "\256\220;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\242\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\226;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\202\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\277\212\212\212\377\212\212\212\377\223\223\223\377\367\367"
  "\367\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\374\374\374\377\372\372\372\377\367\367\367\377\365\365\365\377"
  "\363\363\363\377\360\360\360\377\356\356\356\377\354\354\354\377\351"
  "\351\351\377\347\347\347\377\345\345\345\377\343\343\343\377\341\341"
  "\341\377\336\336\336\377\334\334\334\377\332\332\332\377\330\330\330"
  "\377\326\326\326\377\323\323\323\377\321\321\321\377\317\317\317\377"
  "\315\315\315\377\313\313\313\377\311\311\311\377\307\307\307\377\305"
  "\305\305\377\303\303\303\377\301\301\301\377\277\277\277\377\275\275"
  "\275\377\273\273\273\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\273\273\273\377\275\275\275\377\277\277\277\377\301\301\301\377"
  "\302\302\302\377\305\305\305\377\306\306\306\377\311\311\311\377\312"
  "\312\312\377\315\315\315\377\317\317\317\377\321\321\321\377\323\323"
  "\323\377\325\325\325\377\327\327\327\377\331\331\331\377\333\333\333"
  "\377\336\336\336\377\340\340\340\377\342\342\342\377\344\344\344\377"
  "\347\347\347\377\351\351\351\377\353\353\353\377\356\356\356\377\360"
  "\360\360\377\362\362\362\377\365\365\365\377\367\367\367\377\371\371"
  "\371\377\374\374\374\377\376\376\376\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\251\251\251\377\212\212\212\377\212\212\212\377"
  "\212\212\212\354\212\212\212\23\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\321;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\21\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\372;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\222\377\377\377\0;\200\256x;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\373;\200\256\40\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256&;\200\256\376;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\246\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212Z\212\212\212\377\212\212\212\377"
  "\212\212\212\377\322\322\322\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\375\375\375\377\373\373\373\377\370\370"
  "\370\377\366\366\366\377\363\363\363\377\361\361\361\377\357\357\357"
  "\377\354\354\354\377\352\352\352\377\350\350\350\377\345\345\345\377"
  "\343\343\343\377\341\341\341\377\337\337\337\377\335\335\335\377\332"
  "\332\332\377\330\330\330\377\326\326\326\377\324\324\324\377\321\321"
  "\321\377\317\317\317\377\315\315\315\377\313\313\313\377\311\311\311"
  "\377\307\307\307\377\305\305\305\377\303\303\303\377\301\301\301\377"
  "\277\277\277\377\275\275\275\377\273\273\273\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377\273\273"
  "\273\377\274\274\274\377\276\276\276\377\301\301\301\377\302\302\302"
  "\377\305\305\305\377\306\306\306\377\311\311\311\377\313\313\313\377"
  "\315\315\315\377\317\317\317\377\321\321\321\377\323\323\323\377\325"
  "\325\325\377\327\327\327\377\332\332\332\377\334\334\334\377\336\336"
  "\336\377\340\340\340\377\343\343\343\377\345\345\345\377\347\347\347"
  "\377\351\351\351\377\354\354\354\377\356\356\356\377\360\360\360\377"
  "\363\363\363\377\365\365\365\377\367\367\367\377\372\372\372\377\374"
  "\374\374\377\377\377\377\377\377\377\377\377\377\377\377\377\355\355"
  "\355\377\214\214\214\377\212\212\212\377\212\212\212\377\212\212\212"
  "\232\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\32;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\27\377\377\377\0\377\377\377\0;\200"
  "\256\6;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\247"
  "\377\377\377\0;\200\256`;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\226\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\261;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\312\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\16\212\212"
  "\212\347\212\212\212\377\212\212\212\377\244\244\244\377\376\376\376"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377"
  "\374\374\374\377\371\371\371\377\367\367\367\377\364\364\364\377\362"
  "\362\362\377\357\357\357\377\355\355\355\377\353\353\353\377\350\350"
  "\350\377\346\346\346\377\344\344\344\377\341\341\341\377\337\337\337"
  "\377\335\335\335\377\333\333\333\377\330\330\330\377\326\326\326\377"
  "\324\324\324\377\322\322\322\377\320\320\320\377\315\315\315\377\313"
  "\313\313\377\311\311\311\377\307\307\307\377\305\305\305\377\303\303"
  "\303\377\301\301\301\377\277\277\277\377\275\275\275\377\273\273\273"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377\274"
  "\274\274\377\276\276\276\377\300\300\300\377\302\302\302\377\305\305"
  "\305\377\306\306\306\377\311\311\311\377\313\313\313\377\315\315\315"
  "\377\317\317\317\377\321\321\321\377\323\323\323\377\326\326\326\377"
  "\330\330\330\377\332\332\332\377\334\334\334\377\337\337\337\377\341"
  "\341\341\377\343\343\343\377\345\345\345\377\350\350\350\377\352\352"
  "\352\377\354\354\354\377\357\357\357\377\361\361\361\377\364\364\364"
  "\377\366\366\366\377\370\370\370\377\373\373\373\377\375\375\375\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\301\301\301\377\212"
  "\212\212\377\212\212\212\377\212\212\212\376\212\212\2127\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256P;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\27\377\377\377\0\377\377\377\0;\200\256\23;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\274\377\377\377\0;\200\256H;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\364;\200\256\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2563;\200\256\376;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\351\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\220\212\212\212\377\212\212\212\377"
  "\213\213\213\377\351\351\351\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\374\374\374\377\372\372\372\377\367\367"
  "\367\377\365\365\365\377\363\363\363\377\360\360\360\377\356\356\356"
  "\377\353\353\353\377\351\351\351\377\347\347\347\377\344\344\344\377"
  "\342\342\342\377\340\340\340\377\336\336\336\377\333\333\333\377\331"
  "\331\331\377\327\327\327\377\324\324\324\377\322\322\322\377\320\320"
  "\320\377\316\316\316\377\314\314\314\377\311\311\311\377\307\307\307"
  "\377\305\305\305\377\303\303\303\377\301\301\301\377\277\277\277\377"
  "\275\275\275\377\273\273\273\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\272\272\272\377\274\274\274"
  "\377\276\276\276\377\301\301\301\377\302\302\302\377\305\305\305\377"
  "\307\307\307\377\311\311\311\377\313\313\313\377\315\315\315\377\317"
  "\317\317\377\322\322\322\377\324\324\324\377\326\326\326\377\330\330"
  "\330\377\333\333\333\377\335\335\335\377\337\337\337\377\342\342\342"
  "\377\344\344\344\377\346\346\346\377\350\350\350\377\353\353\353\377"
  "\355\355\355\377\360\360\360\377\362\362\362\377\365\365\365\377\367"
  "\367\367\377\371\371\371\377\374\374\374\377\376\376\376\377\377\377"
  "\377\377\377\377\377\377\372\372\372\377\227\227\227\377\212\212\212"
  "\377\212\212\212\377\212\212\212\315\212\212\212\2\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\205;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\26\377\377\377\0"
  "\377\377\377\0;\200\256\40;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\332\377\377\377\0;\200\2560;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256^\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\247;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\347\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212+\212"
  "\212\212\374\212\212\212\377\212\212\212\377\274\274\274\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375"
  "\377\373\373\373\377\370\370\370\377\366\366\366\377\363\363\363\377"
  "\361\361\361\377\357\357\357\377\354\354\354\377\352\352\352\377\350"
  "\350\350\377\345\345\345\377\343\343\343\377\340\340\340\377\336\336"
  "\336\377\334\334\334\377\332\332\332\377\327\327\327\377\325\325\325"
  "\377\323\323\323\377\320\320\320\377\316\316\316\377\314\314\314\377"
  "\312\312\312\377\310\310\310\377\305\305\305\377\303\303\303\377\301"
  "\301\301\377\277\277\277\377\275\275\275\377\273\273\273\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\272\272\272\377\274\274\274\377\276"
  "\276\276\377\301\301\301\377\303\303\303\377\305\305\305\377\307\307"
  "\307\377\311\311\311\377\313\313\313\377\316\316\316\377\320\320\320"
  "\377\322\322\322\377\324\324\324\377\327\327\327\377\331\331\331\377"
  "\333\333\333\377\336\336\336\377\340\340\340\377\342\342\342\377\345"
  "\345\345\377\347\347\347\377\351\351\351\377\354\354\354\377\356\356"
  "\356\377\360\360\360\377\363\363\363\377\365\365\365\377\370\370\370"
  "\377\372\372\372\377\375\375\375\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\331\331\331\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212g\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\272;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\26\377\377\377\0\377\377\377\0;\200\256-;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\371;\200"
  "\256\2;\200\256\30;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\275\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\";\200\256\371;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\335\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\247\212\212\212\377\212\212"
  "\212\377\225\225\225\377\370\370\370\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\374\374\374\377\371\371\371\377"
  "\367\367\367\377\364\364\364\377\362\362\362\377\357\357\357\377\355"
  "\355\355\377\353\353\353\377\350\350\350\377\346\346\346\377\344\344"
  "\344\377\341\341\341\377\337\337\337\377\335\335\335\377\332\332\332"
  "\377\330\330\330\377\326\326\326\377\323\323\323\377\321\321\321\377"
  "\317\317\317\377\314\314\314\377\312\312\312\377\310\310\310\377\306"
  "\306\306\377\303\303\303\377\301\301\301\377\277\277\277\377\275\275"
  "\275\377\273\273\273\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\272\272\272\377\274\274\274\377\277\277"
  "\277\377\301\301\301\377\303\303\303\377\305\305\305\377\307\307\307"
  "\377\312\312\312\377\314\314\314\377\316\316\316\377\320\320\320\377"
  "\323\323\323\377\325\325\325\377\327\327\327\377\332\332\332\377\334"
  "\334\334\377\336\336\336\377\341\341\341\377\343\343\343\377\345\345"
  "\345\377\350\350\350\377\352\352\352\377\354\354\354\377\357\357\357"
  "\377\361\361\361\377\364\364\364\377\366\366\366\377\371\371\371\377"
  "\373\373\373\377\376\376\376\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\253\253\253\377\212\212\212\377\212\212\212\377\212\212"
  "\212\342\212\212\212\5\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\356;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\25\377\377\377\0\377\377\377\0;\200\256:;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\33;\200"
  "\256\3;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\376;\200\256\36\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\221;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\324"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212&\212\212\212\375\212\212\212\377\212\212\212\377\316\316"
  "\316\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\375\375\375\377\372\372\372\377\370\370\370\377\365\365\365\377"
  "\363\363\363\377\360\360\360\377\356\356\356\377\354\354\354\377\351"
  "\351\351\377\347\347\347\377\344\344\344\377\342\342\342\377\340\340"
  "\340\377\335\335\335\377\333\333\333\377\330\330\330\377\326\326\326"
  "\377\324\324\324\377\321\321\321\377\317\317\317\377\315\315\315\377"
  "\312\312\312\377\310\310\310\377\306\306\306\377\304\304\304\377\302"
  "\302\302\377\277\277\277\377\275\275\275\377\273\273\273\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257\377"
  "\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377"
  "\257\257\257\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\273\273\273\377\275\275\275\377\277\277"
  "\277\377\301\301\301\377\303\303\303\377\306\306\306\377\310\310\310"
  "\377\312\312\312\377\314\314\314\377\317\317\317\377\321\321\321\377"
  "\323\323\323\377\326\326\326\377\330\330\330\377\332\332\332\377\335"
  "\335\335\377\337\337\337\377\341\341\341\377\344\344\344\377\346\346"
  "\346\377\350\350\350\377\353\353\353\377\355\355\355\377\360\360\360"
  "\377\362\362\362\377\365\365\365\377\367\367\367\377\372\372\372\377"
  "\374\374\374\377\377\377\377\377\377\377\377\377\377\377\377\377\353"
  "\353\353\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212c\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "$;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\25\377\377\377"
  "\0\377\377\377\0;\200\256E;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256<\377\377\377\0;\200\256\350;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256{\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\24;\200\256"
  "\357;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\312\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212\237\212\212\212\377"
  "\212\212\212\377\225\225\225\377\373\373\373\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\373\373\373\377\371\371"
  "\371\377\366\366\366\377\364\364\364\377\361\361\361\377\357\357\357"
  "\377\354\354\354\377\352\352\352\377\350\350\350\377\345\345\345\377"
  "\343\343\343\377\340\340\340\377\336\336\336\377\333\333\333\377\331"
  "\331\331\377\327\327\327\377\324\324\324\377\322\322\322\377\320\320"
  "\320\377\315\315\315\377\313\313\313\377\311\311\311\377\306\306\306"
  "\377\304\304\304\377\302\302\302\377\300\300\300\377\276\276\276\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\313\313\313\377\370\370"
  "\370\377\361\361\361\377\370\370\370\377\370\370\370\377\370\370\370"
  "\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377"
  "\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370"
  "\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370"
  "\370\377\370\370\370\377\367\367\367\377\367\367\367\377\367\367\367"
  "\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377"
  "\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367"
  "\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367"
  "\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367"
  "\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377"
  "\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367"
  "\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367"
  "\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367"
  "\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377"
  "\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367"
  "\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367"
  "\367\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370"
  "\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377"
  "\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370"
  "\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370"
  "\370\377\370\370\370\377\333\333\333\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\273\273\273\377\275\275\275\377\277\277\277\377\302"
  "\302\302\377\304\304\304\377\306\306\306\377\310\310\310\377\312\312"
  "\312\377\315\315\315\377\317\317\317\377\321\321\321\377\324\324\324"
  "\377\326\326\326\377\330\330\330\377\333\333\333\377\335\335\335\377"
  "\340\340\340\377\342\342\342\377\345\345\345\377\347\347\347\377\351"
  "\351\351\377\354\354\354\377\356\356\356\377\361\361\361\377\363\363"
  "\363\377\366\366\366\377\370\370\370\377\373\373\373\377\375\375\375"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\260\260\260\377"
  "\212\212\212\377\212\212\212\377\212\212\212\333\212\212\212\3\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256X;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\24\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256]\377\377\377\0;\200\256\305;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\331\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256M;\200\256\376;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\213\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\40\212\212\212\373\212\212\212\377\212\212\212\377\313"
  "\313\313\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\375\375\375\377\372\372\372\377\367\367\367\377\365\365\365"
  "\377\362\362\362\377\360\360\360\377\356\356\356\377\353\353\353\377"
  "\350\350\350\377\346\346\346\377\344\344\344\377\341\341\341\377\337"
  "\337\337\377\334\334\334\377\332\332\332\377\327\327\327\377\325\325"
  "\325\377\323\323\323\377\320\320\320\377\316\316\316\377\314\314\314"
  "\377\311\311\311\377\307\307\307\377\305\305\305\377\302\302\302\377"
  "\300\300\300\377\276\276\276\377\274\274\274\377\272\272\272\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\315\315\315\377\377\377\377\377\334\334\334"
  "\377\334\334\334\377\334\334\334\377\334\334\334\377\334\334\334\377"
  "\334\334\334\377\334\334\334\377\334\334\334\377\334\334\334\377\334"
  "\334\334\377\333\333\333\377\333\333\333\377\333\333\333\377\333\333"
  "\333\377\333\333\333\377\333\333\333\377\333\333\333\377\332\332\332"
  "\377\332\332\332\377\332\332\332\377\332\332\332\377\332\332\332\377"
  "\332\332\332\377\332\332\332\377\332\332\332\377\332\332\332\377\331"
  "\331\331\377\341\341\341\377\351\351\351\377\331\331\331\377\331\331"
  "\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331"
  "\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377"
  "\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331"
  "\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331"
  "\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331"
  "\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377"
  "\345\345\345\377\346\346\346\377\331\331\331\377\331\331\331\377\332"
  "\332\332\377\332\332\332\377\332\332\332\377\332\332\332\377\332\332"
  "\332\377\332\332\332\377\332\332\332\377\332\332\332\377\332\332\332"
  "\377\333\333\333\377\333\333\333\377\333\333\333\377\333\333\333\377"
  "\333\333\333\377\333\333\333\377\333\333\333\377\333\333\333\377\334"
  "\334\334\377\334\334\334\377\334\334\334\377\334\334\334\377\334\334"
  "\334\377\334\334\334\377\334\334\334\377\334\334\334\377\352\352\352"
  "\377\331\331\331\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\273\273\273\377\276\276\276\377\300\300\300\377\302\302"
  "\302\377\304\304\304\377\306\306\306\377\311\311\311\377\313\313\313"
  "\377\315\315\315\377\320\320\320\377\322\322\322\377\324\324\324\377"
  "\327\327\327\377\331\331\331\377\334\334\334\377\336\336\336\377\341"
  "\341\341\377\343\343\343\377\345\345\345\377\350\350\350\377\352\352"
  "\352\377\355\355\355\377\357\357\357\377\362\362\362\377\364\364\364"
  "\377\367\367\367\377\371\371\371\377\374\374\374\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\350\350\350\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212[\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\215;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\24\377\377\377\0\377\377\377\0;\200\256H;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256}\377\377"
  "\377\0;\200\256\232;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\2568\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256q;\200\256\375;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\370;\200\256+\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\227\212"
  "\212\212\377\212\212\212\377\224\224\224\377\372\372\372\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373\373\373"
  "\377\371\371\371\377\366\366\366\377\363\363\363\377\361\361\361\377"
  "\357\357\357\377\354\354\354\377\351\351\351\377\347\347\347\377\345"
  "\345\345\377\342\342\342\377\340\340\340\377\335\335\335\377\333\333"
  "\333\377\330\330\330\377\326\326\326\377\324\324\324\377\321\321\321"
  "\377\317\317\317\377\314\314\314\377\312\312\312\377\310\310\310\377"
  "\305\305\305\377\303\303\303\377\301\301\301\377\276\276\276\377\274"
  "\274\274\377\272\272\272\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267"
  "\377\315\315\315\377\377\377\377\377\277\277\277\377\266\266\266\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\257\257\257\377\257\257\257\377\257\257\257\377\327\327"
  "\327\377\372\372\372\377\257\257\257\377\256\256\256\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256"
  "\256\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\256\256\256\377\256\256\256\377\345\345\345\377\353"
  "\353\353\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\266\266\266\377\366\366\366\377\337\337\337\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272"
  "\272\377\274\274\274\377\276\276\276\377\300\300\300\377\302\302\302"
  "\377\305\305\305\377\307\307\307\377\311\311\311\377\314\314\314\377"
  "\316\316\316\377\320\320\320\377\323\323\323\377\325\325\325\377\330"
  "\330\330\377\332\332\332\377\335\335\335\377\337\337\337\377\341\341"
  "\341\377\344\344\344\377\347\347\347\377\351\351\351\377\353\353\353"
  "\377\356\356\356\377\360\360\360\377\363\363\363\377\365\365\365\377"
  "\370\370\370\377\372\372\372\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\254\254\254\377\212\212\212\377\212\212"
  "\212\377\212\212\212\325\212\212\212\1\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\302;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\23"
  "\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\236\377\377\377\0;\200\256"
  "p;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\225\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256@;\200\256\250;\200\256\353"
  ";\200\256\377;\200\256\334;\200\256L\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\32\212\212\212\370\212\212\212\377"
  "\212\212\212\377\310\310\310\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\374\374\374\377\372\372\372\377\367\367"
  "\367\377\365\365\365\377\362\362\362\377\360\360\360\377\355\355\355"
  "\377\353\353\353\377\350\350\350\377\346\346\346\377\343\343\343\377"
  "\341\341\341\377\336\336\336\377\334\334\334\377\331\331\331\377\327"
  "\327\327\377\324\324\324\377\322\322\322\377\320\320\320\377\315\315"
  "\315\377\313\313\313\377\310\310\310\377\306\306\306\377\304\304\304"
  "\377\301\301\301\377\277\277\277\377\275\275\275\377\272\272\272\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377\314\314"
  "\314\377\377\377\377\377\277\277\277\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377"
  "\257\257\257\377\257\257\257\377\257\257\257\377\326\326\326\377\372"
  "\372\372\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256"
  "\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\256\256\256\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\345\345\345\377\352\352\352\377"
  "\256\256\256\377\256\256\256\377\257\257\257\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\260\260\260\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\366\366\366\377\337\337\337\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272"
  "\272\272\377\274\274\274\377\276\276\276\377\301\301\301\377\303\303"
  "\303\377\305\305\305\377\310\310\310\377\312\312\312\377\315\315\315"
  "\377\317\317\317\377\321\321\321\377\324\324\324\377\326\326\326\377"
  "\331\331\331\377\333\333\333\377\336\336\336\377\340\340\340\377\342"
  "\342\342\377\345\345\345\377\350\350\350\377\352\352\352\377\354\354"
  "\354\377\357\357\357\377\362\362\362\377\364\364\364\377\367\367\367"
  "\377\371\371\371\377\374\374\374\377\376\376\376\377\377\377\377\377"
  "\377\377\377\377\345\345\345\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212R\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\364;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\23\377\377\377\0\377"
  "\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\276\377\377\377\0;\200\256E;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\344;\200\256\1\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256"
  "\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\216\212\212\212\377\212\212\212\377\222"
  "\222\222\377\371\371\371\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\376\376\376\377\373\373\373\377\371\371\371\377\366\366\366"
  "\377\363\363\363\377\361\361\361\377\356\356\356\377\354\354\354\377"
  "\351\351\351\377\347\347\347\377\344\344\344\377\342\342\342\377\337"
  "\337\337\377\335\335\335\377\332\332\332\377\330\330\330\377\325\325"
  "\325\377\323\323\323\377\320\320\320\377\316\316\316\377\314\314\314"
  "\377\311\311\311\377\307\307\307\377\304\304\304\377\302\302\302\377"
  "\300\300\300\377\275\275\275\377\273\273\273\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\266\266\266\377\314\314\314"
  "\377\377\377\377\377\276\276\276\377\265\265\265\377\265\265\265\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\326\326\326\377\372\372"
  "\372\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\345\345\345\377\352\352\352\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265\265"
  "\377\265\265\265\377\366\366\366\377\337\337\337\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\272\272\272\377\275\275\275\377\277\277\277\377\301\301\301"
  "\377\304\304\304\377\306\306\306\377\311\311\311\377\313\313\313\377"
  "\315\315\315\377\320\320\320\377\322\322\322\377\325\325\325\377\327"
  "\327\327\377\332\332\332\377\334\334\334\377\337\337\337\377\341\341"
  "\341\377\344\344\344\377\346\346\346\377\351\351\351\377\353\353\353"
  "\377\356\356\356\377\360\360\360\377\363\363\363\377\365\365\365\377"
  "\370\370\370\377\372\372\372\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\251\251\251\377\212\212\212\377\212\212"
  "\212\377\212\212\212\315\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256,;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\22\377\377\377\0\377"
  "\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\337\377\377\377\0;\200\256\32;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\2563\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\25\212\212\212\365\212\212\212\377\212\212\212\377\305"
  "\305\305\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\374\374\374\377\372\372\372\377\367\367\367\377\365\365\365"
  "\377\362\362\362\377\357\357\357\377\355\355\355\377\352\352\352\377"
  "\350\350\350\377\345\345\345\377\343\343\343\377\340\340\340\377\336"
  "\336\336\377\333\333\333\377\331\331\331\377\326\326\326\377\324\324"
  "\324\377\321\321\321\377\317\317\317\377\314\314\314\377\312\312\312"
  "\377\310\310\310\377\305\305\305\377\303\303\303\377\301\301\301\377"
  "\276\276\276\377\274\274\274\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267"
  "\267\377\267\267\267\377\266\266\266\377\266\266\266\377\314\314\314"
  "\377\377\377\377\377\276\276\276\377\265\265\265\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377"
  "\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\326\326\326\377\372\372"
  "\372\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\257\257\257\377\301\301\301\377\321\321\321\377\342"
  "\342\342\377\360\360\360\377\346\346\346\377\325\325\325\377\305\305"
  "\305\377\263\263\263\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\345\345\345\377\352\352\352\377\255"
  "\255\255\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256"
  "\256\377\256\256\256\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\264\264\264\377\306\306\306\377\326\326\326\377\346\346\346\377"
  "\361\361\361\377\344\344\344\377\325\325\325\377\305\305\305\377\265"
  "\265\265\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\265\265\265\377\366\366\366\377\336\336\336\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\273\273\273\377\276\276\276\377\300\300\300"
  "\377\302\302\302\377\305\305\305\377\307\307\307\377\311\311\311\377"
  "\314\314\314\377\316\316\316\377\321\321\321\377\323\323\323\377\326"
  "\326\326\377\330\330\330\377\333\333\333\377\335\335\335\377\340\340"
  "\340\377\342\342\342\377\345\345\345\377\347\347\347\377\352\352\352"
  "\377\354\354\354\377\357\357\357\377\362\362\362\377\364\364\364\377"
  "\367\367\367\377\371\371\371\377\374\374\374\377\376\376\376\377\377"
  "\377\377\377\377\377\377\377\343\343\343\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212J\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256a;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\22\377\377\377\0\377"
  "\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\374;\200\256\10\377\377\377\0;\200\256\357"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\200\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212y\212\212\212\377\212\212\212\377\220\220\220\377\367"
  "\367\367\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376"
  "\376\377\373\373\373\377\371\371\371\377\366\366\366\377\363\363\363"
  "\377\361\361\361\377\356\356\356\377\354\354\354\377\351\351\351\377"
  "\347\347\347\377\344\344\344\377\341\341\341\377\337\337\337\377\334"
  "\334\334\377\332\332\332\377\327\327\327\377\325\325\325\377\322\322"
  "\322\377\320\320\320\377\315\315\315\377\313\313\313\377\311\311\311"
  "\377\306\306\306\377\304\304\304\377\301\301\301\377\277\277\277\377"
  "\274\274\274\377\272\272\272\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267"
  "\267\377\266\266\266\377\266\266\266\377\266\266\266\377\314\314\314"
  "\377\377\377\377\377\276\276\276\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257\377"
  "\257\257\257\377\256\256\256\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\326\326\326\377\372\372"
  "\372\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\303\303\303\377\366\366\366\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\374\374\374\377\321\321\321\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\255\255\255\377\345\345\345\377\352\352\352\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\256\256\256\377\256\256"
  "\256\377\256\256\256\377\256\256\256\377\256\256\256\377\317\317\317"
  "\377\373\373\373\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\367"
  "\367\367\377\311\311\311\377\262\262\262\377\262\262\262\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\366\366\366\377\336\336\336\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271"
  "\271\377\271\271\271\377\272\272\272\377\274\274\274\377\276\276\276"
  "\377\301\301\301\377\303\303\303\377\305\305\305\377\310\310\310\377"
  "\312\312\312\377\315\315\315\377\317\317\317\377\322\322\322\377\324"
  "\324\324\377\327\327\327\377\331\331\331\377\334\334\334\377\336\336"
  "\336\377\341\341\341\377\343\343\343\377\346\346\346\377\350\350\350"
  "\377\353\353\353\377\356\356\356\377\360\360\360\377\363\363\363\377"
  "\365\365\365\377\370\370\370\377\372\372\372\377\375\375\375\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\246\246\246\377\212\212"
  "\212\377\212\212\212\377\212\212\212\271\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\226;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\21\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\2563\377\377\377\0;\200\256\305"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\315\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\326\212\212\212\377\212\212\212\377\276\276\276\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\372\372\372\377\367\367\367\377\365\365\365\377\362\362"
  "\362\377\360\360\360\377\355\355\355\377\352\352\352\377\350\350\350"
  "\377\345\345\345\377\343\343\343\377\340\340\340\377\336\336\336\377"
  "\333\333\333\377\330\330\330\377\326\326\326\377\323\323\323\377\321"
  "\321\321\377\317\317\317\377\314\314\314\377\311\311\311\377\307\307"
  "\307\377\305\305\305\377\302\302\302\377\300\300\300\377\275\275\275"
  "\377\273\273\273\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377\314\314"
  "\314\377\377\377\377\377\275\275\275\377\264\264\264\377\264\264\264"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\260\260\260\377\260\260\260\377\260\260\260\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\326\326\326\377\372"
  "\372\372\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\254\254\254\377\257\257\257\377\334\334\334"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\352\352\352\377\265\265"
  "\265\377\253\253\253\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\345\345\345\377\352\352\352\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\256\256\256\377\266\266\266\377\350\350\350\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\342\342\342\377\266\266\266\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377\264\264"
  "\264\377\264\264\264\377\365\365\365\377\336\336\336\377\265\265\265"
  "\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\272\272\272\377\275\275"
  "\275\377\277\277\277\377\302\302\302\377\304\304\304\377\306\306\306"
  "\377\311\311\311\377\313\313\313\377\316\316\316\377\320\320\320\377"
  "\323\323\323\377\325\325\325\377\330\330\330\377\332\332\332\377\335"
  "\335\335\377\340\340\340\377\342\342\342\377\345\345\345\377\347\347"
  "\347\377\352\352\352\377\354\354\354\377\357\357\357\377\362\362\362"
  "\377\364\364\364\377\367\367\367\377\371\371\371\377\374\374\374\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\334\334\334\377\212"
  "\212\212\377\212\212\212\377\212\212\212\374\212\212\212\32\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\313;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\21\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256c\377\377\377\0;\200\256\232"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\33\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212"
  "\2125\212\212\212\377\212\212\212\377\212\212\212\377\352\352\352\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374"
  "\374\374\377\371\371\371\377\366\366\366\377\363\363\363\377\361\361"
  "\361\377\356\356\356\377\354\354\354\377\351\351\351\377\347\347\347"
  "\377\344\344\344\377\341\341\341\377\337\337\337\377\334\334\334\377"
  "\332\332\332\377\327\327\327\377\325\325\325\377\322\322\322\377\320"
  "\320\320\377\315\315\315\377\312\312\312\377\310\310\310\377\306\306"
  "\306\377\303\303\303\377\301\301\301\377\276\276\276\377\274\274\274"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377"
  "\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\314\314"
  "\314\377\377\377\377\377\275\275\275\377\264\264\264\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256"
  "\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\254\254\254\377\325\325\325\377\372"
  "\372\372\377\254\254\254\377\254\254\254\377\254\254\254\377\253\253"
  "\253\377\253\253\253\377\253\253\253\377\353\353\353\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\370\370"
  "\370\377\262\262\262\377\253\253\253\377\253\253\253\377\253\253\253"
  "\377\253\253\253\377\254\254\254\377\345\345\345\377\352\352\352\377"
  "\254\254\254\377\254\254\254\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\262\262\262\377\366\366\366\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\360\360\360\377\263"
  "\263\263\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\264\264\264\377\365\365\365\377\336\336\336\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377\273\273"
  "\273\377\276\276\276\377\300\300\300\377\302\302\302\377\305\305\305"
  "\377\310\310\310\377\312\312\312\377\314\314\314\377\317\317\317\377"
  "\321\321\321\377\324\324\324\377\327\327\327\377\331\331\331\377\334"
  "\334\334\377\336\336\336\377\341\341\341\377\343\343\343\377\346\346"
  "\346\377\350\350\350\377\353\353\353\377\356\356\356\377\360\360\360"
  "\377\363\363\363\377\366\366\366\377\370\370\370\377\373\373\373\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\375\375\375\377\224"
  "\224\224\377\212\212\212\377\212\212\212\377\212\212\212u\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256\371;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\20\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\223\377\377\377\0;\200\256"
  "p;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256g\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\223\212\212\212\377\212\212\212\377\240\240\240\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372"
  "\372\372\377\370\370\370\377\365\365\365\377\362\362\362\377\360\360"
  "\360\377\355\355\355\377\353\353\353\377\350\350\350\377\345\345\345"
  "\377\343\343\343\377\340\340\340\377\336\336\336\377\333\333\333\377"
  "\330\330\330\377\326\326\326\377\323\323\323\377\321\321\321\377\316"
  "\316\316\377\314\314\314\377\311\311\311\377\307\307\307\377\304\304"
  "\304\377\302\302\302\377\277\277\277\377\275\275\275\377\272\272\272"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\313\313"
  "\313\377\377\377\377\377\275\275\275\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256"
  "\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\325\325\325\377\372"
  "\372\372\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\320\320\320\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\345\345\345\377\253\253\253\377\253\253\253\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\344\344\344\377\352\352\352\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377\255"
  "\255\255\377\341\341\341\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\331"
  "\331\331\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\365\365\365\377\336\336\336\377\264\264\264"
  "\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272"
  "\272\377\274\274\274\377\277\277\277\377\301\301\301\377\303\303\303"
  "\377\306\306\306\377\311\311\311\377\313\313\313\377\315\315\315\377"
  "\320\320\320\377\323\323\323\377\325\325\325\377\330\330\330\377\332"
  "\332\332\377\335\335\335\377\340\340\340\377\342\342\342\377\345\345"
  "\345\377\347\347\347\377\352\352\352\377\354\354\354\377\357\357\357"
  "\377\362\362\362\377\364\364\364\377\367\367\367\377\372\372\372\377"
  "\374\374\374\377\377\377\377\377\377\377\377\377\377\377\377\377\275"
  "\275\275\377\212\212\212\377\212\212\212\377\212\212\212\323\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\2560;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\17\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\303\377\377\377\0;\200\256"
  "E;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\265\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\5\212\212"
  "\212\353\212\212\212\377\212\212\212\377\313\313\313\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374\374\377"
  "\371\371\371\377\366\366\366\377\364\364\364\377\361\361\361\377\357"
  "\357\357\377\354\354\354\377\351\351\351\377\347\347\347\377\344\344"
  "\344\377\341\341\341\377\337\337\337\377\334\334\334\377\332\332\332"
  "\377\327\327\327\377\324\324\324\377\322\322\322\377\317\317\317\377"
  "\315\315\315\377\312\312\312\377\310\310\310\377\305\305\305\377\303"
  "\303\303\377\300\300\300\377\276\276\276\377\273\273\273\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377\313"
  "\313\313\377\377\377\377\377\274\274\274\377\263\263\263\377\263\263"
  "\263\377\262\262\262\377\262\262\262\377\262\262\262\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\325\325\325\377"
  "\372\372\372\377\253\253\253\377\253\253\253\377\253\253\253\377\252"
  "\252\252\377\267\267\267\377\374\374\374\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\312\312\312\377\252\252\252\377\252\252"
  "\252\377\253\253\253\377\253\253\253\377\344\344\344\377\352\352\352"
  "\377\253\253\253\377\253\253\253\377\254\254\254\377\254\254\254\377"
  "\306\306\306\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\301\301\301\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\365\365\365\377\336\336\336\377\264\264"
  "\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271"
  "\271\271\377\273\273\273\377\275\275\275\377\277\277\277\377\302\302"
  "\302\377\305\305\305\377\307\307\307\377\312\312\312\377\314\314\314"
  "\377\317\317\317\377\321\321\321\377\324\324\324\377\326\326\326\377"
  "\331\331\331\377\334\334\334\377\336\336\336\377\341\341\341\377\344"
  "\344\344\377\346\346\346\377\351\351\351\377\353\353\353\377\356\356"
  "\356\377\360\360\360\377\363\363\363\377\366\366\366\377\371\371\371"
  "\377\373\373\373\377\376\376\376\377\377\377\377\377\377\377\377\377"
  "\350\350\350\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\2121\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256P;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\15\377"
  "\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\362;\200\256\1;"
  "\200\256\32;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\367;\200\256"
  "\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "O\212\212\212\377\212\212\212\377\213\213\213\377\364\364\364\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\373\373"
  "\373\377\370\370\370\377\365\365\365\377\363\363\363\377\360\360\360"
  "\377\356\356\356\377\353\353\353\377\350\350\350\377\345\345\345\377"
  "\343\343\343\377\340\340\340\377\336\336\336\377\333\333\333\377\330"
  "\330\330\377\326\326\326\377\323\323\323\377\321\321\321\377\316\316"
  "\316\377\314\314\314\377\311\311\311\377\306\306\306\377\304\304\304"
  "\377\301\301\301\377\277\277\277\377\274\274\274\377\272\272\272\377"
  "\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\313\313\313\377\377\377\377\377\274\274\274\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\257\257\257\377\257\257\257\377\257\257\257\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\254\254\254\377\253\253\253\377\253\253\253\377\325\325"
  "\325\377\372\372\372\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\252\252\252\377\344\344\344\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\370\370\370\377\252\252\252\377"
  "\252\252\252\377\252\252\252\377\252\252\252\377\344\344\344\377\352"
  "\352\352\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253"
  "\253\377\364\364\364\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\353\353\353\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\263\263\263\377\365\365\365\377\335\335\335\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\274\274\274\377\276\276\276\377"
  "\301\301\301\377\303\303\303\377\306\306\306\377\310\310\310\377\313"
  "\313\313\377\315\315\315\377\320\320\320\377\323\323\323\377\325\325"
  "\325\377\330\330\330\377\332\332\332\377\335\335\335\377\340\340\340"
  "\377\342\342\342\377\345\345\345\377\350\350\350\377\352\352\352\377"
  "\355\355\355\377\357\357\357\377\362\362\362\377\365\365\365\377\367"
  "\367\367\377\372\372\372\377\375\375\375\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\236\236\236\377\212\212\212\377\212\212\212"
  "\377\212\212\212\217\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256o;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\12\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256#\377\377\377\0;\200\256\357;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256>\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212"
  "\212\255\212\212\212\377\212\212\212\377\253\253\253\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374\374\377"
  "\372\372\372\377\367\367\367\377\364\364\364\377\362\362\362\377\357"
  "\357\357\377\354\354\354\377\352\352\352\377\347\347\347\377\344\344"
  "\344\377\342\342\342\377\337\337\337\377\335\335\335\377\332\332\332"
  "\377\327\327\327\377\325\325\325\377\322\322\322\377\317\317\317\377"
  "\315\315\315\377\312\312\312\377\310\310\310\377\305\305\305\377\303"
  "\303\303\377\300\300\300\377\276\276\276\377\273\273\273\377\271\271"
  "\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264"
  "\264\264\377\313\313\313\377\377\377\377\377\274\274\274\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\257\257\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256"
  "\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377"
  "\324\324\324\377\372\372\372\377\252\252\252\377\252\252\252\377\252"
  "\252\252\377\252\252\252\377\367\367\367\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\266\266"
  "\266\377\251\251\251\377\252\252\252\377\252\252\252\377\344\344\344"
  "\377\352\352\352\377\252\252\252\377\253\253\253\377\253\253\253\377"
  "\262\262\262\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\373\373\373\377\261\261\261\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\365\365\365\377\335\335"
  "\335\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265\265"
  "\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\272\272\272\377\275\275"
  "\275\377\277\277\277\377\302\302\302\377\305\305\305\377\307\307\307"
  "\377\312\312\312\377\314\314\314\377\317\317\317\377\321\321\321\377"
  "\324\324\324\377\327\327\327\377\331\331\331\377\334\334\334\377\336"
  "\336\336\377\341\341\341\377\344\344\344\377\347\347\347\377\351\351"
  "\351\377\354\354\354\377\356\356\356\377\361\361\361\377\364\364\364"
  "\377\366\366\366\377\371\371\371\377\374\374\374\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\311\311\311\377\212\212\212\377\212"
  "\212\212\377\212\212\212\350\212\212\212\4\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\215"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\10\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256S\377\377\377\0;\200\256\305;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256z\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212"
  "\212\21\212\212\212\371\212\212\212\377\212\212\212\377\327\327\327\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374"
  "\374\374\377\371\371\371\377\366\366\366\377\363\363\363\377\361\361"
  "\361\377\356\356\356\377\353\353\353\377\351\351\351\377\346\346\346"
  "\377\343\343\343\377\341\341\341\377\336\336\336\377\333\333\333\377"
  "\331\331\331\377\326\326\326\377\323\323\323\377\321\321\321\377\316"
  "\316\316\377\314\314\314\377\311\311\311\377\306\306\306\377\304\304"
  "\304\377\301\301\301\377\277\277\277\377\274\274\274\377\272\272\272"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\312\312\312\377\377\377\377\377\274\274\274"
  "\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256"
  "\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\253\253\253\377\253\253\253\377\253\253\253\377\252\252\252\377\252"
  "\252\252\377\324\324\324\377\372\372\372\377\252\252\252\377\251\251"
  "\251\377\251\251\251\377\262\262\262\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\310\310\310\377\251\251\251\377\251\251\251\377\251\251\251\377"
  "\344\344\344\377\352\352\352\377\252\252\252\377\252\252\252\377\252"
  "\252\252\377\304\304\304\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\275\275"
  "\275\377\261\261\261\377\262\262\262\377\262\262\262\377\365\365\365"
  "\377\335\335\335\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\273\273\273\377\276\276\276\377\301\301\301\377\303\303\303\377"
  "\306\306\306\377\310\310\310\377\313\313\313\377\315\315\315\377\320"
  "\320\320\377\323\323\323\377\326\326\326\377\330\330\330\377\333\333"
  "\333\377\335\335\335\377\340\340\340\377\343\343\343\377\345\345\345"
  "\377\350\350\350\377\353\353\353\377\355\355\355\377\360\360\360\377"
  "\363\363\363\377\365\365\365\377\370\370\370\377\373\373\373\377\375"
  "\375\375\377\377\377\377\377\377\377\377\377\363\363\363\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212K\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\253;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\5\377\377\377\0\377\377\377\0;\200\256H;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\216\377\377\377\0;\200\256\231;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\266\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212i\212\212\212\377\212\212\212\377\220\220\220\377\373\373"
  "\373\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375"
  "\377\372\372\372\377\370\370\370\377\365\365\365\377\362\362\362\377"
  "\360\360\360\377\355\355\355\377\352\352\352\377\350\350\350\377\345"
  "\345\345\377\342\342\342\377\340\340\340\377\335\335\335\377\332\332"
  "\332\377\330\330\330\377\325\325\325\377\322\322\322\377\320\320\320"
  "\377\315\315\315\377\312\312\312\377\310\310\310\377\305\305\305\377"
  "\303\303\303\377\300\300\300\377\275\275\275\377\273\273\273\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\312\312\312\377\377\377\377\377\273"
  "\273\273\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261"
  "\261\377\260\260\260\377\260\260\260\377\260\260\260\377\257\257\257"
  "\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\253\253\253\377\252\252\252\377\252\252\252"
  "\377\252\252\252\377\324\324\324\377\371\371\371\377\251\251\251\377"
  "\251\251\251\377\251\251\251\377\304\304\304\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\331\331\331\377\251\251\251\377\251\251\251\377\251\251"
  "\251\377\344\344\344\377\351\351\351\377\252\252\252\377\252\252\252"
  "\377\252\252\252\377\325\325\325\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\314\314\314\377\261\261\261\377\261\261\261\377\262\262\262\377\365"
  "\365\365\377\335\335\335\377\263\263\263\377\263\263\263\377\264\264"
  "\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271"
  "\271\271\377\272\272\272\377\275\275\275\377\277\277\277\377\302\302"
  "\302\377\305\305\305\377\307\307\307\377\312\312\312\377\314\314\314"
  "\377\317\317\317\377\322\322\322\377\324\324\324\377\327\327\327\377"
  "\332\332\332\377\334\334\334\377\337\337\337\377\342\342\342\377\344"
  "\344\344\377\347\347\347\377\351\351\351\377\354\354\354\377\357\357"
  "\357\377\362\362\362\377\364\364\364\377\367\367\367\377\372\372\372"
  "\377\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\252\252\252\377\212\212\212\377\212\212\212\377\212\212\212\251\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\311;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\3\377\377\377\0\377\377\377\0;\200"
  "\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\327\377\377\377\0;\200\256T;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\360;\200\256\2\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\270\212\212\212\377\212\212\212\377\267"
  "\267\267\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\374\374\374\377\371\371\371\377\367\367\367\377\364\364\364"
  "\377\361\361\361\377\357\357\357\377\354\354\354\377\351\351\351\377"
  "\347\347\347\377\344\344\344\377\341\341\341\377\336\336\336\377\334"
  "\334\334\377\331\331\331\377\327\327\327\377\324\324\324\377\321\321"
  "\321\377\317\317\317\377\314\314\314\377\311\311\311\377\307\307\307"
  "\377\304\304\304\377\301\301\301\377\277\277\277\377\274\274\274\377"
  "\272\272\272\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\263\263\263\377\312\312\312\377"
  "\377\377\377\377\273\273\273\377\262\262\262\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256"
  "\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253"
  "\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252"
  "\252\377\252\252\252\377\251\251\251\377\324\324\324\377\371\371\371"
  "\377\251\251\251\377\251\251\251\377\250\250\250\377\312\312\312\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\340\340\340\377\250\250\250\377\250"
  "\250\250\377\251\251\251\377\344\344\344\377\351\351\351\377\251\251"
  "\251\377\251\251\251\377\252\252\252\377\334\334\334\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\322\322\322\377\261\261\261\377\261\261\261\377"
  "\262\262\262\377\365\365\365\377\335\335\335\377\263\263\263\377\263"
  "\263\263\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\273\273\273\377\276"
  "\276\276\377\301\301\301\377\303\303\303\377\306\306\306\377\311\311"
  "\311\377\313\313\313\377\316\316\316\377\320\320\320\377\323\323\323"
  "\377\326\326\326\377\330\330\330\377\333\333\333\377\336\336\336\377"
  "\341\341\341\377\343\343\343\377\346\346\346\377\351\351\351\377\353"
  "\353\353\377\356\356\356\377\361\361\361\377\363\363\363\377\366\366"
  "\366\377\371\371\371\377\374\374\374\377\376\376\376\377\377\377\377"
  "\377\377\377\377\377\324\324\324\377\212\212\212\377\212\212\212\377"
  "\212\212\212\363\212\212\212\5\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\347;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256!;\200\256\15;\200\256\370;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256/\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\5\212\212\212\365\212\212\212\377\212"
  "\212\212\377\333\333\333\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\376\376\376\377\373\373\373\377\371\371\371\377\366\366\366"
  "\377\363\363\363\377\360\360\360\377\356\356\356\377\353\353\353\377"
  "\350\350\350\377\346\346\346\377\343\343\343\377\340\340\340\377\336"
  "\336\336\377\333\333\333\377\330\330\330\377\326\326\326\377\323\323"
  "\323\377\320\320\320\377\315\315\315\377\313\313\313\377\310\310\310"
  "\377\305\305\305\377\303\303\303\377\300\300\300\377\276\276\276\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377"
  "\312\312\312\377\377\377\377\377\273\273\273\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256"
  "\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253"
  "\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252"
  "\252\377\251\251\251\377\251\251\251\377\251\251\251\377\324\324\324"
  "\377\371\371\371\377\250\250\250\377\250\250\250\377\250\250\250\377"
  "\271\271\271\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\317\317\317\377\250"
  "\250\250\377\250\250\250\377\250\250\250\377\344\344\344\377\351\351"
  "\351\377\251\251\251\377\251\251\251\377\251\251\251\377\312\312\312"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\303\303\303\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\365\365\365\377\335\335\335\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272"
  "\272\272\377\275\275\275\377\277\277\277\377\302\302\302\377\305\305"
  "\305\377\310\310\310\377\312\312\312\377\315\315\315\377\317\317\317"
  "\377\322\322\322\377\325\325\325\377\327\327\327\377\332\332\332\377"
  "\335\335\335\377\340\340\340\377\342\342\342\377\345\345\345\377\350"
  "\350\350\377\352\352\352\377\355\355\355\377\360\360\360\377\362\362"
  "\362\377\365\365\365\377\370\370\370\377\373\373\373\377\375\375\375"
  "\377\377\377\377\377\377\377\377\377\367\367\367\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212:\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\7;\200\256\376;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256k\377\377\377\0;\200\256\267;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256k\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\212<\212\212\212\377\212\212"
  "\212\377\213\213\213\377\370\370\370\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\375\375\375\377\372\372\372\377\370\370\370\377"
  "\365\365\365\377\362\362\362\377\357\357\357\377\355\355\355\377\352"
  "\352\352\377\347\347\347\377\345\345\345\377\342\342\342\377\337\337"
  "\337\377\335\335\335\377\332\332\332\377\327\327\327\377\324\324\324"
  "\377\322\322\322\377\317\317\317\377\314\314\314\377\312\312\312\377"
  "\307\307\307\377\304\304\304\377\302\302\302\377\277\277\277\377\274"
  "\274\274\377\272\272\272\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263"
  "\263\263\377\312\312\312\377\377\377\377\377\273\273\273\377\261\261"
  "\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251\377"
  "\323\323\323\377\371\371\371\377\250\250\250\377\250\250\250\377\247"
  "\247\247\377\250\250\250\377\374\374\374\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\274\274"
  "\274\377\247\247\247\377\247\247\247\377\250\250\250\377\344\344\344"
  "\377\351\351\351\377\250\250\250\377\251\251\251\377\251\251\251\377"
  "\270\270\270\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\376\376\376\377\264\264\264\377\260"
  "\260\260\377\261\261\261\377\261\261\261\377\365\365\365\377\335\335"
  "\335\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\274\274\274\377\276\276\276\377\301\301\301"
  "\377\304\304\304\377\306\306\306\377\311\311\311\377\314\314\314\377"
  "\316\316\316\377\321\321\321\377\324\324\324\377\326\326\326\377\331"
  "\331\331\377\334\334\334\377\336\336\336\377\341\341\341\377\344\344"
  "\344\377\347\347\347\377\351\351\351\377\354\354\354\377\357\357\357"
  "\377\362\362\362\377\364\364\364\377\367\367\367\377\372\372\372\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377\241"
  "\241\241\377\212\212\212\377\212\212\212\377\212\212\212|\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\373\377\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\265\377\377\377\0;\200\256h;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\247\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212~\212\212"
  "\212\377\212\212\212\377\242\242\242\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\374\374\374\377\372\372\372\377"
  "\367\367\367\377\364\364\364\377\361\361\361\377\357\357\357\377\354"
  "\354\354\377\351\351\351\377\347\347\347\377\344\344\344\377\341\341"
  "\341\377\336\336\336\377\333\333\333\377\331\331\331\377\326\326\326"
  "\377\323\323\323\377\321\321\321\377\316\316\316\377\313\313\313\377"
  "\311\311\311\377\306\306\306\377\303\303\303\377\301\301\301\377\276"
  "\276\276\377\273\273\273\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267"
  "\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\264\264\264\377\264\264\264\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\312\312\312\377\377\377\377\377\272\272"
  "\272\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\250\250\250\377"
  "\250\250\250\377\323\323\323\377\371\371\371\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\354\354\354\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376"
  "\376\377\253\253\253\377\247\247\247\377\247\247\247\377\247\247\247"
  "\377\343\343\343\377\351\351\351\377\250\250\250\377\250\250\250\377"
  "\250\250\250\377\252\252\252\377\373\373\373\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\362\362\362\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\261\261\261\377\365\365"
  "\365\377\335\335\335\377\262\262\262\377\262\262\262\377\263\263\263"
  "\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\273\273\273\377\275\275\275"
  "\377\300\300\300\377\303\303\303\377\305\305\305\377\310\310\310\377"
  "\313\313\313\377\315\315\315\377\320\320\320\377\323\323\323\377\326"
  "\326\326\377\330\330\330\377\333\333\333\377\336\336\336\377\340\340"
  "\340\377\343\343\343\377\346\346\346\377\350\350\350\377\353\353\353"
  "\377\356\356\356\377\361\361\361\377\363\363\363\377\366\366\366\377"
  "\371\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\277\277\277\377\212\212\212\377\212\212\212\377\212\212"
  "\212\276\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256B;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\370\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\366;\200\256\11;\200"
  "\256\25;\200\256\362;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\341\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\300\212\212\212\377\212\212\212\377\300\300\300\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374\374"
  "\374\377\371\371\371\377\366\366\366\377\363\363\363\377\360\360\360"
  "\377\356\356\356\377\353\353\353\377\350\350\350\377\345\345\345\377"
  "\343\343\343\377\340\340\340\377\335\335\335\377\333\333\333\377\330"
  "\330\330\377\325\325\325\377\323\323\323\377\320\320\320\377\315\315"
  "\315\377\312\312\312\377\310\310\310\377\305\305\305\377\302\302\302"
  "\377\277\277\277\377\275\275\275\377\272\272\272\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\265\265"
  "\265\377\265\265\265\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\263\263\263\377\263\263\263\377\262\262\262\377\312\312\312\377"
  "\377\377\377\377\272\272\272\377\261\261\261\377\260\260\260\377\260"
  "\260\260\377\257\257\257\377\257\257\257\377\257\257\257\377\256\256"
  "\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377"
  "\253\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252"
  "\252\252\377\251\251\251\377\251\251\251\377\251\251\251\377\250\250"
  "\250\377\250\250\250\377\250\250\250\377\323\323\323\377\371\371\371"
  "\377\247\247\247\377\247\247\247\377\247\247\247\377\246\246\246\377"
  "\311\311\311\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\337\337\337\377\246\246\246\377\246\246\246\377\247"
  "\247\247\377\247\247\247\377\343\343\343\377\351\351\351\377\247\247"
  "\247\377\250\250\250\377\250\250\250\377\250\250\250\377\333\333\333"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\324\324\324\377\257\257\257\377\260\260\260\377\260\260\260\377"
  "\261\261\261\377\365\365\365\377\335\335\335\377\262\262\262\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377\264\264"
  "\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272"
  "\272\272\377\274\274\274\377\277\277\277\377\302\302\302\377\304\304"
  "\304\377\307\307\307\377\312\312\312\377\314\314\314\377\317\317\317"
  "\377\322\322\322\377\324\324\324\377\327\327\327\377\332\332\332\377"
  "\335\335\335\377\340\340\340\377\342\342\342\377\345\345\345\377\350"
  "\350\350\377\352\352\352\377\355\355\355\377\360\360\360\377\363\363"
  "\363\377\365\365\365\377\370\370\370\377\373\373\373\377\376\376\376"
  "\377\377\377\377\377\377\377\377\377\335\335\335\377\212\212\212\377"
  "\212\212\212\377\212\212\212\370\212\212\212\10\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256`;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\366\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256r\377\377\377\0;\200\256u;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\11\212\212\212\371\212\212\212\377\212\212\212\377"
  "\336\336\336\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\373\373\373\377\370\370\370\377\365\365\365\377\362\362"
  "\362\377\360\360\360\377\355\355\355\377\352\352\352\377\347\347\347"
  "\377\345\345\345\377\342\342\342\377\337\337\337\377\335\335\335\377"
  "\332\332\332\377\327\327\327\377\324\324\324\377\321\321\321\377\317"
  "\317\317\377\314\314\314\377\311\311\311\377\307\307\307\377\304\304"
  "\304\377\301\301\301\377\277\277\277\377\274\274\274\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262"
  "\377\312\312\312\377\377\377\377\377\272\272\272\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255"
  "\255\377\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377"
  "\252\252\252\377\251\251\251\377\251\251\251\377\251\251\251\377\250"
  "\250\250\377\250\250\250\377\250\250\250\377\247\247\247\377\323\323"
  "\323\377\371\371\371\377\247\247\247\377\246\246\246\377\246\246\246"
  "\377\246\246\246\377\246\246\246\377\347\347\347\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\366\366\366\377\254\254\254\377\246\246\246\377"
  "\246\246\246\377\246\246\246\377\246\246\246\377\343\343\343\377\351"
  "\351\351\377\247\247\247\377\247\247\247\377\250\250\250\377\250\250"
  "\250\377\254\254\254\377\364\364\364\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\355\355\355\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\260\260\260\377\260\260\260\377\365\365\365\377\335\335\335\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377\263"
  "\263\263\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\266\266\266\377\266\266\266\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\273\273\273\377\276\276\276\377\301"
  "\301\301\377\303\303\303\377\306\306\306\377\311\311\311\377\313\313"
  "\313\377\316\316\316\377\321\321\321\377\324\324\324\377\326\326\326"
  "\377\331\331\331\377\334\334\334\377\336\336\336\377\341\341\341\377"
  "\344\344\344\377\347\347\347\377\351\351\351\377\354\354\354\377\357"
  "\357\357\377\362\362\362\377\365\365\365\377\367\367\367\377\372\372"
  "\372\377\375\375\375\377\377\377\377\377\377\377\377\377\371\371\371"
  "\377\214\214\214\377\212\212\212\377\212\212\212\377\212\212\212B\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256~;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\363\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\360;\200\256\24;\200\256\6;\200\256"
  "\331;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256;\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212D\212\212\212\377\212\212\212\377"
  "\214\214\214\377\371\371\371\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\375\375\375\377\372\372\372\377\367\367\367\377\365\365"
  "\365\377\362\362\362\377\357\357\357\377\354\354\354\377\351\351\351"
  "\377\347\347\347\377\344\344\344\377\341\341\341\377\336\336\336\377"
  "\333\333\333\377\331\331\331\377\326\326\326\377\323\323\323\377\321"
  "\321\321\377\316\316\316\377\313\313\313\377\310\310\310\377\306\306"
  "\306\377\303\303\303\377\300\300\300\377\276\276\276\377\273\273\273"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262"
  "\377\262\262\262\377\311\311\311\377\377\377\377\377\272\272\272\377"
  "\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255"
  "\255\377\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377"
  "\252\252\252\377\251\251\251\377\251\251\251\377\251\251\251\377\250"
  "\250\250\377\250\250\250\377\250\250\250\377\247\247\247\377\247\247"
  "\247\377\323\323\323\377\371\371\371\377\246\246\246\377\246\246\246"
  "\377\246\246\246\377\246\246\246\377\245\245\245\377\257\257\257\377"
  "\372\372\372\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\301\301\301\377\245\245\245\377"
  "\245\245\245\377\246\246\246\377\246\246\246\377\246\246\246\377\343"
  "\343\343\377\351\351\351\377\247\247\247\377\247\247\247\377\247\247"
  "\247\377\250\250\250\377\250\250\250\377\276\276\276\377\376\376\376"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\374\374\374\377\272\272\272\377\256\256\256\377\257\257\257"
  "\377\257\257\257\377\260\260\260\377\260\260\260\377\365\365\365\377"
  "\335\335\335\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272\377\275"
  "\275\275\377\300\300\300\377\302\302\302\377\305\305\305\377\310\310"
  "\310\377\312\312\312\377\315\315\315\377\320\320\320\377\323\323\323"
  "\377\326\326\326\377\330\330\330\377\333\333\333\377\336\336\336\377"
  "\340\340\340\377\343\343\343\377\346\346\346\377\351\351\351\377\353"
  "\353\353\377\356\356\356\377\361\361\361\377\364\364\364\377\366\366"
  "\366\377\371\371\371\377\374\374\374\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\244\244\244\377\212\212\212\377\212\212\212\377"
  "\212\212\212\204\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\234"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\361\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\227\377\377\377\0;\200\256-;\200\256\354;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256h\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\206\212"
  "\212\212\377\212\212\212\377\245\245\245\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\374\374\374\377\371\371\371"
  "\377\366\366\366\377\364\364\364\377\361\361\361\377\356\356\356\377"
  "\353\353\353\377\351\351\351\377\346\346\346\377\343\343\343\377\340"
  "\340\340\377\336\336\336\377\333\333\333\377\330\330\330\377\325\325"
  "\325\377\323\323\323\377\320\320\320\377\315\315\315\377\312\312\312"
  "\377\310\310\310\377\305\305\305\377\302\302\302\377\277\277\277\377"
  "\275\275\275\377\272\272\272\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\311\311\311\377\377"
  "\377\377\377\271\271\271\377\260\260\260\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\256\256\256\377\256\256\256\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377"
  "\253\253\253\377\253\253\253\377\253\253\253\377\252\252\252\377\252"
  "\252\252\377\252\252\252\377\251\251\251\377\251\251\251\377\251\251"
  "\251\377\250\250\250\377\250\250\250\377\250\250\250\377\247\247\247"
  "\377\247\247\247\377\247\247\247\377\322\322\322\377\371\371\371\377"
  "\246\246\246\377\246\246\246\377\245\245\245\377\245\245\245\377\245"
  "\245\245\377\245\245\245\377\277\277\277\377\370\370\370\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\375\375\375\377\320\320\320\377\245"
  "\245\245\377\245\245\245\377\245\245\245\377\245\245\245\377\245\245"
  "\245\377\246\246\246\377\343\343\343\377\351\351\351\377\246\246\246"
  "\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247\377"
  "\250\250\250\377\315\315\315\377\374\374\374\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\372\372\372\377\310\310\310\377\256\256\256\377"
  "\256\256\256\377\257\257\257\377\257\257\257\377\257\257\257\377\260"
  "\260\260\377\365\365\365\377\335\335\335\377\261\261\261\377\261\261"
  "\261\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\274\274\274\377\277\277\277\377\301\301\301"
  "\377\304\304\304\377\307\307\307\377\312\312\312\377\314\314\314\377"
  "\317\317\317\377\322\322\322\377\324\324\324\377\327\327\327\377\332"
  "\332\332\377\335\335\335\377\340\340\340\377\342\342\342\377\345\345"
  "\345\377\350\350\350\377\353\353\353\377\356\356\356\377\360\360\360"
  "\377\363\363\363\377\366\366\366\377\371\371\371\377\373\373\373\377"
  "\376\376\376\377\377\377\377\377\377\377\377\377\302\302\302\377\212"
  "\212\212\377\212\212\212\377\212\212\212\306\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\272;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\356\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\374;\200\256B\377\377\377\0;\200\256/"
  ";\200\256\355;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\224\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\310\212\212\212\377\212\212\212\377\303\303\303\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373"
  "\373\373\377\371\371\371\377\366\366\366\377\363\363\363\377\360\360"
  "\360\377\356\356\356\377\353\353\353\377\350\350\350\377\345\345\345"
  "\377\342\342\342\377\340\340\340\377\335\335\335\377\332\332\332\377"
  "\327\327\327\377\324\324\324\377\322\322\322\377\317\317\317\377\314"
  "\314\314\377\311\311\311\377\307\307\307\377\304\304\304\377\301\301"
  "\301\377\276\276\276\377\274\274\274\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263"
  "\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261"
  "\377\311\311\311\377\377\377\377\377\271\271\271\377\260\260\260\377"
  "\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\253\253\253\377\253\253\253\377\252\252\252"
  "\377\252\252\252\377\252\252\252\377\251\251\251\377\251\251\251\377"
  "\251\251\251\377\250\250\250\377\250\250\250\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\246\246\246\377\322\322"
  "\322\377\371\371\371\377\245\245\245\377\245\245\245\377\245\245\245"
  "\377\245\245\245\377\244\244\244\377\244\244\244\377\244\244\244\377"
  "\254\254\254\377\343\343\343\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\360\360\360\377\266\266\266"
  "\377\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377"
  "\245\245\245\377\245\245\245\377\245\245\245\377\343\343\343\377\351"
  "\351\351\377\246\246\246\377\246\246\246\377\246\246\246\377\247\247"
  "\247\377\247\247\247\377\247\247\247\377\250\250\250\377\267\267\267"
  "\377\355\355\355\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\350\350\350\377\266\266\266\377\255\255"
  "\255\377\255\255\255\377\256\256\256\377\256\256\256\377\257\257\257"
  "\377\257\257\257\377\260\260\260\377\365\365\365\377\334\334\334\377"
  "\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276"
  "\276\276\377\301\301\301\377\303\303\303\377\306\306\306\377\311\311"
  "\311\377\314\314\314\377\316\316\316\377\321\321\321\377\324\324\324"
  "\377\327\327\327\377\331\331\331\377\334\334\334\377\337\337\337\377"
  "\342\342\342\377\344\344\344\377\347\347\347\377\352\352\352\377\355"
  "\355\355\377\357\357\357\377\362\362\362\377\365\365\365\377\370\370"
  "\370\377\373\373\373\377\375\375\375\377\377\377\377\377\377\377\377"
  "\377\340\340\340\377\212\212\212\377\212\212\212\377\212\212\212\373"
  "\212\212\212\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\330;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\354\377\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\365;\200\256\77\377\377\377\0;\200\2562;\200\256\356;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\301\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\10\212\212\212\374\212\212\212\377\212"
  "\212\212\377\341\341\341\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\375\375\375\377\373\373\373\377\370\370\370\377\365\365\365"
  "\377\362\362\362\377\357\357\357\377\355\355\355\377\352\352\352\377"
  "\347\347\347\377\344\344\344\377\342\342\342\377\337\337\337\377\334"
  "\334\334\377\331\331\331\377\326\326\326\377\324\324\324\377\321\321"
  "\321\377\316\316\316\377\313\313\313\377\311\311\311\377\306\306\306"
  "\377\303\303\303\377\300\300\300\377\276\276\276\377\273\273\273\377"
  "\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\311\311\311\377\377\377\377\377\271"
  "\271\271\377\257\257\257\377\257\257\257\377\257\257\257\377\256\256"
  "\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253\253\377"
  "\253\253\253\377\252\252\252\377\252\252\252\377\251\251\251\377\251"
  "\251\251\377\251\251\251\377\250\250\250\377\250\250\250\377\250\250"
  "\250\377\247\247\247\377\247\247\247\377\247\247\247\377\246\246\246"
  "\377\246\246\246\377\322\322\322\377\371\371\371\377\245\245\245\377"
  "\245\245\245\377\244\244\244\377\244\244\244\377\244\244\244\377\244"
  "\244\244\377\244\244\244\377\244\244\244\377\243\243\243\377\303\303"
  "\303\377\337\337\337\377\362\362\362\377\376\376\376\377\377\377\377"
  "\377\377\377\377\377\366\366\366\377\344\344\344\377\315\315\315\377"
  "\245\245\245\377\243\243\243\377\243\243\243\377\244\244\244\377\244"
  "\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377\245\245"
  "\245\377\343\343\343\377\350\350\350\377\246\246\246\377\246\246\246"
  "\377\246\246\246\377\246\246\246\377\247\247\247\377\247\247\247\377"
  "\247\247\247\377\250\250\250\377\251\251\251\377\316\316\316\377\345"
  "\345\345\377\366\366\366\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\364\364\364\377\343\343\343\377\312\312\312\377\254\254\254"
  "\377\254\254\254\377\255\255\255\377\255\255\255\377\256\256\256\377"
  "\256\256\256\377\256\256\256\377\257\257\257\377\257\257\257\377\365"
  "\365\365\377\334\334\334\377\261\261\261\377\261\261\261\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\272\272\272\377\275\275\275\377\300\300\300\377\302\302\302"
  "\377\305\305\305\377\310\310\310\377\313\313\313\377\315\315\315\377"
  "\320\320\320\377\323\323\323\377\326\326\326\377\330\330\330\377\333"
  "\333\333\377\336\336\336\377\341\341\341\377\344\344\344\377\347\347"
  "\347\377\351\351\351\377\354\354\354\377\357\357\357\377\362\362\362"
  "\377\365\365\365\377\367\367\367\377\372\372\372\377\375\375\375\377"
  "\377\377\377\377\377\377\377\377\373\373\373\377\215\215\215\377\212"
  "\212\212\377\212\212\212\377\212\212\212D\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\366;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\351\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\364;\200\256<\377\377\377"
  "\0;\200\2564;\200\256\360;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\355\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212-\212"
  "\212\212\377\212\212\212\377\212\212\212\377\371\371\371\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372"
  "\377\367\367\367\377\365\365\365\377\362\362\362\377\357\357\357\377"
  "\354\354\354\377\351\351\351\377\347\347\347\377\344\344\344\377\341"
  "\341\341\377\336\336\336\377\333\333\333\377\330\330\330\377\326\326"
  "\326\377\323\323\323\377\320\320\320\377\315\315\315\377\312\312\312"
  "\377\310\310\310\377\305\305\305\377\302\302\302\377\277\277\277\377"
  "\275\275\275\377\272\272\272\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377\311"
  "\311\311\377\377\377\377\377\271\271\271\377\257\257\257\377\257\257"
  "\257\377\256\256\256\377\256\256\256\377\256\256\256\377\255\255\255"
  "\377\255\255\255\377\254\254\254\377\254\254\254\377\253\253\253\377"
  "\253\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377\251"
  "\251\251\377\251\251\251\377\251\251\251\377\250\250\250\377\250\250"
  "\250\377\250\250\250\377\247\247\247\377\247\247\247\377\247\247\247"
  "\377\246\246\246\377\246\246\246\377\246\246\246\377\322\322\322\377"
  "\371\371\371\377\245\245\245\377\244\244\244\377\244\244\244\377\244"
  "\244\244\377\244\244\244\377\243\243\243\377\243\243\243\377\243\243"
  "\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243"
  "\377\250\250\250\377\267\267\267\377\254\254\254\377\243\243\243\377"
  "\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243"
  "\243\243\377\243\243\243\377\243\243\243\377\244\244\244\377\244\244"
  "\244\377\244\244\244\377\244\244\244\377\343\343\343\377\350\350\350"
  "\377\245\245\245\377\245\245\245\377\246\246\246\377\246\246\246\377"
  "\246\246\246\377\247\247\247\377\247\247\247\377\247\247\247\377\250"
  "\250\250\377\250\250\250\377\251\251\251\377\251\251\251\377\261\261"
  "\261\377\275\275\275\377\260\260\260\377\253\253\253\377\253\253\253"
  "\377\253\253\253\377\254\254\254\377\254\254\254\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\256\256\256\377\256\256\256\377\257"
  "\257\257\377\257\257\257\377\365\365\365\377\334\334\334\377\260\260"
  "\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\271\271\271\377\274\274\274"
  "\377\277\277\277\377\302\302\302\377\304\304\304\377\307\307\307\377"
  "\312\312\312\377\315\315\315\377\317\317\317\377\322\322\322\377\325"
  "\325\325\377\330\330\330\377\333\333\333\377\335\335\335\377\340\340"
  "\340\377\343\343\343\377\346\346\346\377\351\351\351\377\353\353\353"
  "\377\356\356\356\377\361\361\361\377\364\364\364\377\367\367\367\377"
  "\371\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\241\241\241\377\212\212\212\377\212\212\212\377\212\212"
  "\212m\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\25;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\347\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\363;\200\256:\377\377\377\0;\200\2566;\200\256\361;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\32\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212U\212\212\212\377\212\212\212\377\225\225\225\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374"
  "\374\377\371\371\371\377\367\367\367\377\364\364\364\377\361\361\361"
  "\377\356\356\356\377\353\353\353\377\351\351\351\377\346\346\346\377"
  "\343\343\343\377\340\340\340\377\335\335\335\377\333\333\333\377\330"
  "\330\330\377\325\325\325\377\322\322\322\377\317\317\317\377\315\315"
  "\315\377\312\312\312\377\307\307\307\377\304\304\304\377\302\302\302"
  "\377\277\277\277\377\274\274\274\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267"
  "\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265"
  "\265\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263"
  "\377\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261\377"
  "\261\261\261\377\310\310\310\377\377\377\377\377\271\271\271\377\257"
  "\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377\255\255"
  "\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\253\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377"
  "\252\252\252\377\251\251\251\377\251\251\251\377\250\250\250\377\250"
  "\250\250\377\250\250\250\377\247\247\247\377\247\247\247\377\247\247"
  "\247\377\246\246\246\377\246\246\246\377\245\245\245\377\245\245\245"
  "\377\322\322\322\377\371\371\371\377\244\244\244\377\244\244\244\377"
  "\244\244\244\377\243\243\243\377\243\243\243\377\243\243\243\377\243"
  "\243\243\377\243\243\243\377\242\242\242\377\242\242\242\377\242\242"
  "\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242"
  "\377\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377"
  "\242\242\242\377\243\243\243\377\243\243\243\377\243\243\243\377\243"
  "\243\243\377\243\243\243\377\244\244\244\377\244\244\244\377\342\342"
  "\342\377\350\350\350\377\245\245\245\377\245\245\245\377\245\245\245"
  "\377\246\246\246\377\246\246\246\377\246\246\246\377\247\247\247\377"
  "\247\247\247\377\250\250\250\377\250\250\250\377\250\250\250\377\251"
  "\251\251\377\251\251\251\377\251\251\251\377\252\252\252\377\252\252"
  "\252\377\253\253\253\377\253\253\253\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\255\255\255\377\255\255\255\377\256\256\256\377"
  "\256\256\256\377\257\257\257\377\257\257\257\377\365\365\365\377\334"
  "\334\334\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262"
  "\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\273\273\273\377\276\276\276\377\301\301\301\377\304\304\304"
  "\377\306\306\306\377\311\311\311\377\314\314\314\377\317\317\317\377"
  "\321\321\321\377\324\324\324\377\327\327\327\377\332\332\332\377\335"
  "\335\335\377\340\340\340\377\342\342\342\377\345\345\345\377\350\350"
  "\350\377\353\353\353\377\356\356\356\377\360\360\360\377\363\363\363"
  "\377\366\366\366\377\371\371\371\377\374\374\374\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\263\263\263\377\212\212\212\377\212"
  "\212\212\377\212\212\212\225\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256+;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\344\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\362;\200\2568\377"
  "\377\377\0;\200\2569;\200\256\362;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "D\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212}\212\212\212\377\212\212\212"
  "\377\250\250\250\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\374\374\374\377\371\371\371\377\366\366\366\377\363"
  "\363\363\377\360\360\360\377\356\356\356\377\353\353\353\377\350\350"
  "\350\377\345\345\345\377\342\342\342\377\340\340\340\377\335\335\335"
  "\377\332\332\332\377\327\327\327\377\324\324\324\377\321\321\321\377"
  "\317\317\317\377\314\314\314\377\311\311\311\377\306\306\306\377\303"
  "\303\303\377\301\301\301\377\276\276\276\377\273\273\273\377\271\271"
  "\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\263"
  "\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\261\261\261\377\261\261\261\377\310\310\310\377\377\377\377"
  "\377\271\271\271\377\257\257\257\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254"
  "\254\254\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252"
  "\252\377\252\252\252\377\251\251\251\377\251\251\251\377\251\251\251"
  "\377\250\250\250\377\250\250\250\377\247\247\247\377\247\247\247\377"
  "\247\247\247\377\246\246\246\377\246\246\246\377\245\245\245\377\245"
  "\245\245\377\245\245\245\377\321\321\321\377\371\371\371\377\244\244"
  "\244\377\244\244\244\377\243\243\243\377\243\243\243\377\243\243\243"
  "\377\243\243\243\377\242\242\242\377\242\242\242\377\242\242\242\377"
  "\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242"
  "\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242\242"
  "\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242"
  "\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377"
  "\244\244\244\377\342\342\342\377\350\350\350\377\244\244\244\377\245"
  "\245\245\377\245\245\245\377\245\245\245\377\246\246\246\377\246\246"
  "\246\377\247\247\247\377\247\247\247\377\247\247\247\377\250\250\250"
  "\377\250\250\250\377\250\250\250\377\251\251\251\377\251\251\251\377"
  "\252\252\252\377\252\252\252\377\252\252\252\377\253\253\253\377\253"
  "\253\253\377\254\254\254\377\254\254\254\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\256\256\256\377\256\256\256\377\257\257\257"
  "\377\365\365\365\377\334\334\334\377\260\260\260\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\273\273\273\377\275\275\275\377\300"
  "\300\300\377\303\303\303\377\306\306\306\377\311\311\311\377\313\313"
  "\313\377\316\316\316\377\321\321\321\377\324\324\324\377\326\326\326"
  "\377\331\331\331\377\334\334\334\377\337\337\337\377\342\342\342\377"
  "\345\345\345\377\347\347\347\377\352\352\352\377\355\355\355\377\360"
  "\360\360\377\363\363\363\377\365\365\365\377\370\370\370\377\373\373"
  "\373\377\376\376\376\377\377\377\377\377\377\377\377\377\305\305\305"
  "\377\212\212\212\377\212\212\212\377\212\212\212\275\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\2565;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\342\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\360;\200\2566\377\377\377\0;\200\256;;\200\256\363;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256a\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\244\212"
  "\212\212\377\212\212\212\377\272\272\272\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\376\376\376\377\373\373\373\377\370\370\370"
  "\377\366\366\366\377\363\363\363\377\360\360\360\377\355\355\355\377"
  "\352\352\352\377\350\350\350\377\345\345\345\377\342\342\342\377\337"
  "\337\337\377\334\334\334\377\331\331\331\377\327\327\327\377\324\324"
  "\324\377\321\321\321\377\316\316\316\377\313\313\313\377\311\311\311"
  "\377\306\306\306\377\303\303\303\377\300\300\300\377\275\275\275\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261\377\310"
  "\310\310\377\377\377\377\377\300\300\300\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263"
  "\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\260\260\260\377\260\260\260\377\257\257\257\377\322\322\322\377"
  "\360\360\360\377\257\257\257\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\256\256"
  "\256\377\256\256\256\377\256\256\256\377\336\336\336\377\343\343\343"
  "\377\257\257\257\377\257\257\257\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264"
  "\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\365\365\365\377\334\334\334\377\260\260"
  "\260\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262"
  "\377\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266"
  "\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272"
  "\377\275\275\275\377\277\277\277\377\302\302\302\377\305\305\305\377"
  "\310\310\310\377\313\313\313\377\315\315\315\377\320\320\320\377\323"
  "\323\323\377\326\326\326\377\331\331\331\377\333\333\333\377\336\336"
  "\336\377\341\341\341\377\344\344\344\377\347\347\347\377\351\351\351"
  "\377\354\354\354\377\357\357\357\377\362\362\362\377\365\365\365\377"
  "\370\370\370\377\372\372\372\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\327\327\327\377\212\212\212\377\212\212\212\377\212\212"
  "\212\344\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\77;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\337\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357;\200\256"
  "3\377\377\377\0;\200\256>;\200\256\364;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\363;\200\256\262;\200\256\277;\200\256\324;\200"
  "\256\351;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256{\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\314\212\212\212\377\212\212\212\377\314\314\314\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373"
  "\373\373\377\370\370\370\377\365\365\365\377\362\362\362\377\357\357"
  "\357\377\355\355\355\377\352\352\352\377\347\347\347\377\344\344\344"
  "\377\341\341\341\377\336\336\336\377\334\334\334\377\331\331\331\377"
  "\326\326\326\377\323\323\323\377\320\320\320\377\315\315\315\377\313"
  "\313\313\377\310\310\310\377\305\305\305\377\302\302\302\377\277\277"
  "\277\377\275\275\275\377\272\272\272\377\271\271\271\377\271\271\271"
  "\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377"
  "\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263"
  "\263\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261"
  "\377\260\260\260\377\310\310\310\377\377\377\377\377\366\366\366\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\366\366\366\377"
  "\334\334\334\377\260\260\260\377\260\260\260\377\261\261\261\377\261"
  "\261\261\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265\265"
  "\377\265\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377"
  "\267\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\274\274\274\377\277\277\277\377\302\302"
  "\302\377\304\304\304\377\307\307\307\377\312\312\312\377\315\315\315"
  "\377\320\320\320\377\323\323\323\377\325\325\325\377\330\330\330\377"
  "\333\333\333\377\336\336\336\377\341\341\341\377\343\343\343\377\346"
  "\346\346\377\351\351\351\377\354\354\354\377\357\357\357\377\362\362"
  "\362\377\364\364\364\377\367\367\367\377\372\372\372\377\375\375\375"
  "\377\377\377\377\377\377\377\377\377\351\351\351\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\15\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256I;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\334\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\356;\200\2561\377\377\377\0;\200\256@;\200\256"
  "\365;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\326;\200\256l;\200\256\16\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256\22;\200\256';\200"
  "\256<;\200\256Q;\200\256e;\200\256z;\200\256\217;\200\256\244;\200\256"
  "\270;\200\256\315;\200\256\342;\200\256\367;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\226\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\363\212\212\212\377\212\212\212\377\335"
  "\335\335\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375"
  "\375\377\372\372\372\377\367\367\367\377\365\365\365\377\362\362\362"
  "\377\357\357\357\377\354\354\354\377\351\351\351\377\347\347\347\377"
  "\344\344\344\377\341\341\341\377\336\336\336\377\333\333\333\377\330"
  "\330\330\377\326\326\326\377\323\323\323\377\320\320\320\377\315\315"
  "\315\377\312\312\312\377\307\307\307\377\305\305\305\377\302\302\302"
  "\377\277\277\277\377\274\274\274\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267"
  "\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265"
  "\265\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261\377"
  "\261\261\261\377\260\260\260\377\310\310\310\377\377\377\377\377\314"
  "\314\314\377\307\307\307\377\307\307\307\377\307\307\307\377\306\306"
  "\306\377\306\306\306\377\306\306\306\377\306\306\306\377\305\305\305"
  "\377\305\305\305\377\304\304\304\377\304\304\304\377\304\304\304\377"
  "\303\303\303\377\303\303\303\377\303\303\303\377\303\303\303\377\302"
  "\302\302\377\302\302\302\377\302\302\302\377\301\301\301\377\301\301"
  "\301\377\301\301\301\377\301\301\301\377\301\301\301\377\300\300\300"
  "\377\300\300\300\377\325\325\325\377\350\350\350\377\277\277\277\377"
  "\277\277\277\377\277\277\277\377\277\277\277\377\277\277\277\377\276"
  "\276\276\377\276\276\276\377\276\276\276\377\276\276\276\377\276\276"
  "\276\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275"
  "\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377"
  "\275\275\275\377\276\276\276\377\276\276\276\377\276\276\276\377\276"
  "\276\276\377\276\276\276\377\277\277\277\377\277\277\277\377\277\277"
  "\277\377\335\335\335\377\340\340\340\377\277\277\277\377\300\300\300"
  "\377\300\300\300\377\300\300\300\377\301\301\301\377\301\301\301\377"
  "\301\301\301\377\301\301\301\377\301\301\301\377\302\302\302\377\302"
  "\302\302\377\303\303\303\377\303\303\303\377\303\303\303\377\303\303"
  "\303\377\303\303\303\377\304\304\304\377\304\304\304\377\305\305\305"
  "\377\305\305\305\377\306\306\306\377\306\306\306\377\306\306\306\377"
  "\306\306\306\377\306\306\306\377\307\307\307\377\307\307\307\377\365"
  "\365\365\377\334\334\334\377\260\260\260\377\260\260\260\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276\276\276"
  "\377\301\301\301\377\304\304\304\377\307\307\307\377\311\311\311\377"
  "\314\314\314\377\317\317\317\377\322\322\322\377\325\325\325\377\330"
  "\330\330\377\332\332\332\377\335\335\335\377\340\340\340\377\343\343"
  "\343\377\346\346\346\377\351\351\351\377\353\353\353\377\356\356\356"
  "\377\361\361\361\377\364\364\364\377\367\367\367\377\372\372\372\377"
  "\374\374\374\377\377\377\377\377\377\377\377\377\372\372\372\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\2124\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256S"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\332\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\355;\200\256/\377\377"
  "\377\0;\200\256C;\200\256\366;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373;\200"
  "\256\254;\200\256A\377\377\377\0\377\377\377\0;\200\256\5;\200\256O;"
  "\200\256V;\200\256A;\200\256,;\200\256\30;\200\256\4\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\13;\200\256\40;\200\2565;\200\256J;\200\256^;\200\256s;\200\256"
  "\210;\200\256\235;\200\256\261;\200\256\306;\200\256\333;\200\256\360"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\260\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212\33\212\212\212\377\212\212\212\377\212\212\212"
  "\377\360\360\360\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\372\372\372\377\367\367\367\377\364\364\364\377\361"
  "\361\361\377\357\357\357\377\354\354\354\377\351\351\351\377\346\346"
  "\346\377\343\343\343\377\340\340\340\377\335\335\335\377\333\333\333"
  "\377\330\330\330\377\325\325\325\377\322\322\322\377\317\317\317\377"
  "\314\314\314\377\312\312\312\377\307\307\307\377\304\304\304\377\301"
  "\301\301\377\276\276\276\377\273\273\273\377\271\271\271\377\271\271"
  "\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377"
  "\265\265\265\377\264\264\264\377\264\264\264\377\263\263\263\377\263"
  "\263\263\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\260\260\260\377\310\310\310\377\377\377\377"
  "\377\271\271\271\377\256\256\256\377\256\256\256\377\255\255\255\377"
  "\255\255\255\377\254\254\254\377\254\254\254\377\254\254\254\377\253"
  "\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377\251\251"
  "\251\377\251\251\251\377\250\250\250\377\250\250\250\377\250\250\250"
  "\377\247\247\247\377\247\247\247\377\246\246\246\377\246\246\246\377"
  "\246\246\246\377\245\245\245\377\245\245\245\377\244\244\244\377\244"
  "\244\244\377\244\244\244\377\321\321\321\377\371\371\371\377\242\242"
  "\242\377\242\242\242\377\242\242\242\377\241\241\241\377\241\241\241"
  "\377\241\241\241\377\241\241\241\377\240\240\240\377\240\240\240\377"
  "\240\240\240\377\240\240\240\377\240\240\240\377\240\240\240\377\240"
  "\240\240\377\240\240\240\377\240\240\240\377\240\240\240\377\240\240"
  "\240\377\240\240\240\377\240\240\240\377\240\240\240\377\241\241\241"
  "\377\241\241\241\377\241\241\241\377\241\241\241\377\242\242\242\377"
  "\242\242\242\377\342\342\342\377\350\350\350\377\243\243\243\377\243"
  "\243\243\377\244\244\244\377\244\244\244\377\245\245\245\377\245\245"
  "\245\377\245\245\245\377\246\246\246\377\246\246\246\377\247\247\247"
  "\377\247\247\247\377\247\247\247\377\250\250\250\377\250\250\250\377"
  "\251\251\251\377\251\251\251\377\252\252\252\377\252\252\252\377\253"
  "\253\253\377\253\253\253\377\253\253\253\377\254\254\254\377\254\254"
  "\254\377\255\255\255\377\255\255\255\377\256\256\256\377\256\256\256"
  "\377\365\365\365\377\334\334\334\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276"
  "\276\276\377\301\301\301\377\303\303\303\377\306\306\306\377\311\311"
  "\311\377\314\314\314\377\317\317\317\377\321\321\321\377\324\324\324"
  "\377\327\327\327\377\332\332\332\377\335\335\335\377\340\340\340\377"
  "\342\342\342\377\345\345\345\377\350\350\350\377\353\353\353\377\356"
  "\356\356\377\360\360\360\377\363\363\363\377\366\366\366\377\371\371"
  "\371\377\374\374\374\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\230\230\230\377\212\212\212\377\212\212\212\377\212\212\212[\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\\;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\327\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\353"
  ";\200\256-\377\377\377\0;\200\256F;\200\256\367;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\346;\200\256\201;\200\256\33"
  "\377\377\377\0\377\377\377\0;\200\256\33;\200\256\202;\200\256\347;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\376;\200\256\356;\200\256\331;\200\256\305;\200\256\260;\200\256\233"
  ";\200\256\206;\200\256q;\200\256];\200\256H;\200\2563;\200\256\36;\200"
  "\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\5;\200\256\31;\200\256.;\200\256C;\200"
  "\256W;\200\256l;\200\256\201;\200\256\226;\200\256\252;\200\256\277;"
  "\200\256\324;\200\256\351;\200\256\374;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\312\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212C\212\212\212\377\212\212\212\377\215"
  "\215\215\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\374\374\374\377\371\371\371\377\367\367\367\377\364\364\364"
  "\377\361\361\361\377\356\356\356\377\353\353\353\377\350\350\350\377"
  "\345\345\345\377\343\343\343\377\340\340\340\377\335\335\335\377\332"
  "\332\332\377\327\327\327\377\324\324\324\377\322\322\322\377\317\317"
  "\317\377\314\314\314\377\311\311\311\377\306\306\306\377\303\303\303"
  "\377\301\301\301\377\276\276\276\377\273\273\273\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267"
  "\267\267\377\266\266\266\377\266\266\266\377\266\266\266\377\265\265"
  "\265\377\265\265\265\377\264\264\264\377\264\264\264\377\263\263\263"
  "\377\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261\377"
  "\261\261\261\377\260\260\260\377\260\260\260\377\310\310\310\377\377"
  "\377\377\377\271\271\271\377\256\256\256\377\256\256\256\377\255\255"
  "\255\377\255\255\255\377\254\254\254\377\254\254\254\377\253\253\253"
  "\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252\377"
  "\251\251\251\377\251\251\251\377\250\250\250\377\250\250\250\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\246\246\246\377\246\246"
  "\246\377\245\245\245\377\245\245\245\377\244\244\244\377\244\244\244"
  "\377\244\244\244\377\243\243\243\377\321\321\321\377\371\371\371\377"
  "\242\242\242\377\242\242\242\377\241\241\241\377\241\241\241\377\241"
  "\241\241\377\241\241\241\377\240\240\240\377\240\240\240\377\240\240"
  "\240\377\240\240\240\377\237\237\237\377\237\237\237\377\237\237\237"
  "\377\237\237\237\377\237\237\237\377\237\237\237\377\237\237\237\377"
  "\237\237\237\377\240\240\240\377\240\240\240\377\240\240\240\377\240"
  "\240\240\377\240\240\240\377\241\241\241\377\241\241\241\377\241\241"
  "\241\377\242\242\242\377\342\342\342\377\350\350\350\377\243\243\243"
  "\377\243\243\243\377\244\244\244\377\244\244\244\377\244\244\244\377"
  "\245\245\245\377\245\245\245\377\246\246\246\377\246\246\246\377\246"
  "\246\246\377\247\247\247\377\247\247\247\377\250\250\250\377\250\250"
  "\250\377\251\251\251\377\251\251\251\377\251\251\251\377\252\252\252"
  "\377\252\252\252\377\253\253\253\377\253\253\253\377\254\254\254\377"
  "\254\254\254\377\255\255\255\377\255\255\255\377\256\256\256\377\256"
  "\256\256\377\365\365\365\377\334\334\334\377\257\257\257\377\260\260"
  "\260\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262"
  "\377\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266"
  "\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272"
  "\377\275\275\275\377\300\300\300\377\303\303\303\377\306\306\306\377"
  "\310\310\310\377\313\313\313\377\316\316\316\377\321\321\321\377\324"
  "\324\324\377\327\327\327\377\331\331\331\377\334\334\334\377\337\337"
  "\337\377\342\342\342\377\345\345\345\377\350\350\350\377\353\353\353"
  "\377\355\355\355\377\360\360\360\377\363\363\363\377\366\366\366\377"
  "\371\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\252\252\252\377\212\212\212\377\212\212\212\377\212\212"
  "\212\203\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256f;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\325\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\352;\200\256+\377\377\377\0;\200\256I;\200"
  "\256\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\300;\200\256V;\200\256\5\377\377\377\0"
  "\377\377\377\0;\200\256B;\200\256\254;\200\256\373;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256\340;\200\256"
  "\313;\200\256\267;\200\256\242;\200\256\215;\200\256x;\200\256c;\200"
  "\256O;\200\256:;\200\256%;\200\256\20;\200\256\1\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256"
  "\22;\200\256';\200\256<;\200\256P;\200\256e;\200\256z;\200\256\217;\200"
  "\256\243;\200\256\270;\200\256\315;\200\256\342;\200\256\366;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\344\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212j\212\212\212\377\212\212\212\377"
  "\236\236\236\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\374\374\374\377\371\371\371\377\366\366\366\377\363\363"
  "\363\377\360\360\360\377\356\356\356\377\353\353\353\377\350\350\350"
  "\377\345\345\345\377\342\342\342\377\340\340\340\377\335\335\335\377"
  "\332\332\332\377\327\327\327\377\324\324\324\377\321\321\321\377\316"
  "\316\316\377\314\314\314\377\311\311\311\377\306\306\306\377\303\303"
  "\303\377\300\300\300\377\275\275\275\377\273\273\273\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263"
  "\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261"
  "\377\261\261\261\377\260\260\260\377\260\260\260\377\310\310\310\377"
  "\377\377\377\377\270\270\270\377\256\256\256\377\256\256\256\377\255"
  "\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377\253\253"
  "\253\377\253\253\253\377\252\252\252\377\252\252\252\377\251\251\251"
  "\377\251\251\251\377\253\253\253\377\250\250\250\377\250\250\250\377"
  "\247\247\247\377\247\247\247\377\246\246\246\377\246\246\246\377\245"
  "\245\245\377\245\245\245\377\245\245\245\377\244\244\244\377\244\244"
  "\244\377\243\243\243\377\243\243\243\377\321\321\321\377\371\371\371"
  "\377\242\242\242\377\241\241\241\377\241\241\241\377\241\241\241\377"
  "\240\240\240\377\240\240\240\377\240\240\240\377\240\240\240\377\237"
  "\237\237\377\237\237\237\377\237\237\237\377\237\237\237\377\237\237"
  "\237\377\237\237\237\377\237\237\237\377\237\237\237\377\237\237\237"
  "\377\237\237\237\377\237\237\237\377\237\237\237\377\240\240\240\377"
  "\240\240\240\377\240\240\240\377\240\240\240\377\241\241\241\377\241"
  "\241\241\377\241\241\241\377\342\342\342\377\350\350\350\377\242\242"
  "\242\377\243\243\243\377\243\243\243\377\244\244\244\377\244\244\244"
  "\377\244\244\244\377\245\245\245\377\245\245\245\377\246\246\246\377"
  "\246\246\246\377\247\247\247\377\247\247\247\377\250\250\250\377\253"
  "\253\253\377\250\250\250\377\251\251\251\377\251\251\251\377\252\252"
  "\252\377\252\252\252\377\253\253\253\377\253\253\253\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\255\255\255\377\255\255\255\377"
  "\256\256\256\377\365\365\365\377\334\334\334\377\257\257\257\377\260"
  "\260\260\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262"
  "\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272"
  "\272\377\274\274\274\377\277\277\277\377\302\302\302\377\305\305\305"
  "\377\310\310\310\377\313\313\313\377\316\316\316\377\320\320\320\377"
  "\323\323\323\377\326\326\326\377\331\331\331\377\334\334\334\377\337"
  "\337\337\377\342\342\342\377\344\344\344\377\347\347\347\377\352\352"
  "\352\377\355\355\355\377\360\360\360\377\363\363\363\377\366\366\366"
  "\377\370\370\370\377\373\373\373\377\376\376\376\377\377\377\377\377"
  "\377\377\377\377\274\274\274\377\212\212\212\377\212\212\212\377\212"
  "\212\212\252\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256p;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\322\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\351;\200\256)\377\377\377"
  "\0;\200\256K;\200\256\371;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\362"
  ";\200\256\225;\200\256+\377\377\377\0\377\377\377\0;\200\256\16;\200"
  "\256m;\200\256\326;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373"
  ";\200\256\347;\200\256\322;\200\256\275;\200\256\251;\200\256\224;\200"
  "\256\177;\200\256j;\200\256U;\200\256A;\200\256,;\200\256\27;\200\256"
  "\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\13;\200\256\40;\200\2565;\200\256I;\200\256"
  "^;\200\256s;\200\256\210;\200\256\234;\200\256\261;\200\256\306;\200"
  "\256\333;\200\256\357;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\374;\200\256\2\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\212\206\212\212\212\377\212"
  "\212\212\377\256\256\256\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\374\374\374\377\371\371\371\377\366\366\366"
  "\377\363\363\363\377\360\360\360\377\355\355\355\377\353\353\353\377"
  "\350\350\350\377\345\345\345\377\342\342\342\377\337\337\337\377\334"
  "\334\334\377\331\331\331\377\327\327\327\377\324\324\324\377\321\321"
  "\321\377\316\316\316\377\313\313\313\377\310\310\310\377\305\305\305"
  "\377\303\303\303\377\300\300\300\377\275\275\275\377\272\272\272\377"
  "\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267"
  "\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\265\265"
  "\265\377\265\265\265\377\264\264\264\377\264\264\264\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377"
  "\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\310"
  "\310\310\377\377\377\377\377\270\270\270\377\256\256\256\377\255\255"
  "\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\253\253\253\377\253\253\253\377\261\261\261\377\314\314\314\377"
  "\335\335\335\377\357\357\357\377\375\375\375\377\372\372\372\377\350"
  "\350\350\377\326\326\326\377\302\302\302\377\246\246\246\377\246\246"
  "\246\377\245\245\245\377\245\245\245\377\244\244\244\377\244\244\244"
  "\377\244\244\244\377\243\243\243\377\243\243\243\377\320\320\320\377"
  "\371\371\371\377\242\242\242\377\241\241\241\377\241\241\241\377\240"
  "\240\240\377\240\240\240\377\240\240\240\377\237\237\237\377\237\237"
  "\237\377\237\237\237\377\237\237\237\377\237\237\237\377\236\236\236"
  "\377\236\236\236\377\236\236\236\377\236\236\236\377\236\236\236\377"
  "\236\236\236\377\237\237\237\377\237\237\237\377\237\237\237\377\237"
  "\237\237\377\237\237\237\377\240\240\240\377\240\240\240\377\240\240"
  "\240\377\241\241\241\377\241\241\241\377\341\341\341\377\350\350\350"
  "\377\242\242\242\377\243\243\243\377\243\243\243\377\243\243\243\377"
  "\244\244\244\377\244\244\244\377\245\245\245\377\245\245\245\377\246"
  "\246\246\377\271\271\271\377\321\321\321\377\344\344\344\377\366\366"
  "\366\377\377\377\377\377\364\364\364\377\342\342\342\377\320\320\320"
  "\377\270\270\270\377\252\252\252\377\253\253\253\377\253\253\253\377"
  "\253\253\253\377\254\254\254\377\254\254\254\377\255\255\255\377\255"
  "\255\255\377\256\256\256\377\365\365\365\377\334\334\334\377\257\257"
  "\257\377\260\260\260\377\260\260\260\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\264\264\264\377\264\264\264\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\274\274\274\377\277\277\277\377\302\302\302\377"
  "\305\305\305\377\310\310\310\377\312\312\312\377\315\315\315\377\320"
  "\320\320\377\323\323\323\377\326\326\326\377\330\330\330\377\333\333"
  "\333\377\336\336\336\377\341\341\341\377\344\344\344\377\347\347\347"
  "\377\352\352\352\377\355\355\355\377\357\357\357\377\362\362\362\377"
  "\365\365\365\377\370\370\370\377\373\373\373\377\376\376\376\377\377"
  "\377\377\377\377\377\377\377\313\313\313\377\212\212\212\377\212\212"
  "\212\377\212\212\212\306\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256z;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\320\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\347"
  ";\200\256'\377\377\377\0;\200\256N;\200\256\372;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\325;\200\256k;\200\256"
  "\15\377\377\377\0\377\377\377\0;\200\256-;\200\256\227;\200\256\363;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\376;\200\256\356;\200\256\331;\200\256\304;\200"
  "\256\257;\200\256\233;\200\256\206;\200\256q;\200\256\\;\200\256G;\200"
  "\2563;\200\256\36;\200\256\11\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\31;"
  "\200\256.;\200\256B;\200\256W;\200\256l;\200\256\201;\200\256\225;\200"
  "\256\252;\200\256\277;\200\256\324;\200\256\350;\200\256\374;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\30\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\222\212\212"
  "\212\377\212\212\212\377\265\265\265\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\373\373\373\377\370\370\370\377"
  "\366\366\366\377\363\363\363\377\360\360\360\377\355\355\355\377\352"
  "\352\352\377\347\347\347\377\344\344\344\377\342\342\342\377\337\337"
  "\337\377\334\334\334\377\331\331\331\377\326\326\326\377\323\323\323"
  "\377\320\320\320\377\315\315\315\377\313\313\313\377\310\310\310\377"
  "\305\305\305\377\302\302\302\377\277\277\277\377\274\274\274\377\272"
  "\272\272\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266"
  "\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260"
  "\260\377\310\310\310\377\377\377\377\377\270\270\270\377\256\256\256"
  "\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377"
  "\253\253\253\377\253\253\253\377\307\307\307\377\370\370\370\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\352\352\352"
  "\377\262\262\262\377\245\245\245\377\245\245\245\377\244\244\244\377"
  "\244\244\244\377\243\243\243\377\243\243\243\377\242\242\242\377\320"
  "\320\320\377\371\371\371\377\241\241\241\377\241\241\241\377\240\240"
  "\240\377\240\240\240\377\240\240\240\377\237\237\237\377\237\237\237"
  "\377\237\237\237\377\237\237\237\377\236\236\236\377\236\236\236\377"
  "\236\236\236\377\236\236\236\377\236\236\236\377\236\236\236\377\236"
  "\236\236\377\236\236\236\377\236\236\236\377\236\236\236\377\236\236"
  "\236\377\237\237\237\377\237\237\237\377\237\237\237\377\240\240\240"
  "\377\240\240\240\377\240\240\240\377\241\241\241\377\341\341\341\377"
  "\350\350\350\377\242\242\242\377\242\242\242\377\243\243\243\377\243"
  "\243\243\377\244\244\244\377\244\244\244\377\245\245\245\377\251\251"
  "\251\377\333\333\333\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\375\375\375\377\325\325\325\377\253\253\253\377\253"
  "\253\253\377\253\253\253\377\254\254\254\377\254\254\254\377\255\255"
  "\255\377\255\255\255\377\256\256\256\377\365\365\365\377\334\334\334"
  "\377\257\257\257\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\266\266\266\377\266\266\266\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\274\274\274\377\277\277\277\377\302"
  "\302\302\377\304\304\304\377\307\307\307\377\312\312\312\377\315\315"
  "\315\377\320\320\320\377\323\323\323\377\326\326\326\377\330\330\330"
  "\377\333\333\333\377\336\336\336\377\341\341\341\377\344\344\344\377"
  "\347\347\347\377\351\351\351\377\354\354\354\377\357\357\357\377\362"
  "\362\362\377\365\365\365\377\370\370\370\377\372\372\372\377\375\375"
  "\375\377\377\377\377\377\377\377\377\377\322\322\322\377\212\212\212"
  "\377\212\212\212\377\212\212\212\322\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\204;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\315\377\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\346;\200\256&\377\377\377\0;\200\256Q;\200"
  "\256\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\373;\200\256\252;\200\256@\377\377\377\0\377"
  "\377\377\0;\200\256\5;\200\256X;\200\256\302;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\364"
  ";\200\256\340;\200\256\313;\200\256\266;\200\256\241;\200\256\214;\200"
  "\256x;\200\256c;\200\256N;\200\2569;\200\256%;\200\256\20\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256\22;\200\256';\200\256;;\200\256P;\200\256e;\200"
  "\256z;\200\256\216;\200\256\243;\200\256\270;\200\256\315;\200\256\341"
  ";\200\256\366;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256'\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\237\212\212"
  "\212\377\212\212\212\377\273\273\273\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\373\373\373\377\370\370\370\377"
  "\365\365\365\377\362\362\362\377\360\360\360\377\355\355\355\377\352"
  "\352\352\377\347\347\347\377\344\344\344\377\341\341\341\377\336\336"
  "\336\377\333\333\333\377\331\331\331\377\326\326\326\377\323\323\323"
  "\377\320\320\320\377\315\315\315\377\312\312\312\377\310\310\310\377"
  "\305\305\305\377\302\302\302\377\277\277\277\377\274\274\274\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266"
  "\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\310\310\310\377\377\377\377\377\270\270\270\377\256\256\256"
  "\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377"
  "\261\261\261\377\343\343\343\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\373\373\373\377\312\312\312\377\244\244\244\377\244\244\244\377"
  "\244\244\244\377\243\243\243\377\243\243\243\377\242\242\242\377\320"
  "\320\320\377\371\371\371\377\241\241\241\377\241\241\241\377\240\240"
  "\240\377\240\240\240\377\237\237\237\377\237\237\237\377\237\237\237"
  "\377\236\236\236\377\236\236\236\377\236\236\236\377\236\236\236\377"
  "\235\235\235\377\235\235\235\377\235\235\235\377\235\235\235\377\235"
  "\235\235\377\235\235\235\377\236\236\236\377\236\236\236\377\236\236"
  "\236\377\236\236\236\377\237\237\237\377\237\237\237\377\237\237\237"
  "\377\240\240\240\377\240\240\240\377\241\241\241\377\341\341\341\377"
  "\347\347\347\377\242\242\242\377\242\242\242\377\243\243\243\377\243"
  "\243\243\377\243\243\243\377\244\244\244\377\272\272\272\377\364\364"
  "\364\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\357\357\357\377\272"
  "\272\272\377\253\253\253\377\254\254\254\377\254\254\254\377\255\255"
  "\255\377\255\255\255\377\256\256\256\377\365\365\365\377\333\333\333"
  "\377\257\257\257\377\257\257\257\377\260\260\260\377\260\260\260\377"
  "\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\273\273\273\377\276\276\276\377\301"
  "\301\301\377\304\304\304\377\307\307\307\377\312\312\312\377\315\315"
  "\315\377\317\317\317\377\322\322\322\377\325\325\325\377\330\330\330"
  "\377\333\333\333\377\336\336\336\377\341\341\341\377\343\343\343\377"
  "\346\346\346\377\351\351\351\377\354\354\354\377\357\357\357\377\362"
  "\362\362\377\365\365\365\377\367\367\367\377\372\372\372\377\375\375"
  "\375\377\377\377\377\377\377\377\377\377\330\330\330\377\212\212\212"
  "\377\212\212\212\377\212\212\212\337\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\215;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\313\377\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\344;\200\256$\377\377\377\0;"
  "\200\256T;\200\256\373;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\345;\200\256\177;\200\256\32\377\377\377\0\377\377\377\0;\200\256\34"
  ";\200\256\202;\200\256\347;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\372;\200\256\346;\200\256\322;\200\256\275;\200"
  "\256\250;\200\256\223;\200\256~;\200\256j;\200\256U;\200\256@;\200\256"
  "+;\200\256\27;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\13;\200\256\40;\200\256"
  "4;\200\256I;\200\256^;\200\256s;\200\256\207;\200\256\234;\200\256\261"
  ";\200\256\306;\200\256\332;\200\256\357;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\2562\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\254"
  "\212\212\212\377\212\212\212\377\301\301\301\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\373\373\373\377\370\370"
  "\370\377\365\365\365\377\362\362\362\377\357\357\357\377\354\354\354"
  "\377\351\351\351\377\347\347\347\377\344\344\344\377\341\341\341\377"
  "\336\336\336\377\333\333\333\377\330\330\330\377\326\326\326\377\323"
  "\323\323\377\320\320\320\377\315\315\315\377\312\312\312\377\307\307"
  "\307\377\304\304\304\377\302\302\302\377\277\277\277\377\274\274\274"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262"
  "\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377"
  "\257\257\257\377\310\310\310\377\377\377\377\377\270\270\270\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\350\350\350\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\304\304\304\377\244\244"
  "\244\377\243\243\243\377\243\243\243\377\243\243\243\377\242\242\242"
  "\377\320\320\320\377\371\371\371\377\241\241\241\377\240\240\240\377"
  "\240\240\240\377\240\240\240\377\237\237\237\377\237\237\237\377\236"
  "\236\236\377\236\236\236\377\236\236\236\377\235\235\235\377\235\235"
  "\235\377\235\235\235\377\235\235\235\377\235\235\235\377\235\235\235"
  "\377\235\235\235\377\235\235\235\377\235\235\235\377\235\235\235\377"
  "\236\236\236\377\236\236\236\377\236\236\236\377\237\237\237\377\237"
  "\237\237\377\237\237\237\377\240\240\240\377\240\240\240\377\341\341"
  "\341\377\347\347\347\377\242\242\242\377\242\242\242\377\242\242\242"
  "\377\243\243\243\377\243\243\243\377\261\261\261\377\373\373\373\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\367\367\367\377\261\261\261\377\254\254\254\377\254\254\254\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\365\365\365\377\333"
  "\333\333\377\257\257\257\377\257\257\257\377\260\260\260\377\260\260"
  "\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276\276\276"
  "\377\301\301\301\377\304\304\304\377\306\306\306\377\311\311\311\377"
  "\314\314\314\377\317\317\317\377\322\322\322\377\325\325\325\377\330"
  "\330\330\377\333\333\333\377\335\335\335\377\340\340\340\377\343\343"
  "\343\377\346\346\346\377\351\351\351\377\354\354\354\377\357\357\357"
  "\377\362\362\362\377\364\364\364\377\367\367\367\377\372\372\372\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\336\336\336\377\212"
  "\212\212\377\212\212\212\377\212\212\212\354\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\227;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\310\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\343;\200\256"
  "\"\377\377\377\0;\200\256W;\200\256\374;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\277;\200\256T;\200\256"
  "\4\377\377\377\0\377\377\377\0;\200\256C;\200\256\255;\200\256\374;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\376;\200\256\355;\200\256\330;\200"
  "\256\304;\200\256\257;\200\256\232;\200\256\205;\200\256p;\200\256\\"
  ";\200\256G;\200\2562;\200\256\35;\200\256\11\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\5"
  ";\200\256\31;\200\256-;\200\256B;\200\256W;\200\256l;\200\256\200;\200"
  "\256\225;\200\256\252;\200\256\277;\200\256\323;\200\256\350;\200\256"
  "\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256=\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\271\212\212\212\377\212\212\212\377\307\307\307\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372\377\370"
  "\370\370\377\365\365\365\377\362\362\362\377\357\357\357\377\354\354"
  "\354\377\351\351\351\377\347\347\347\377\344\344\344\377\341\341\341"
  "\377\336\336\336\377\333\333\333\377\330\330\330\377\325\325\325\377"
  "\322\322\322\377\320\320\320\377\315\315\315\377\312\312\312\377\307"
  "\307\307\377\304\304\304\377\301\301\301\377\276\276\276\377\273\273"
  "\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264"
  "\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262"
  "\262\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260"
  "\377\257\257\257\377\310\310\310\377\377\377\377\377\270\270\270\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\316"
  "\316\316\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\370\370\370\377\255"
  "\255\255\377\243\243\243\377\243\243\243\377\242\242\242\377\242\242"
  "\242\377\320\320\320\377\371\371\371\377\241\241\241\377\240\240\240"
  "\377\240\240\240\377\237\237\237\377\237\237\237\377\237\237\237\377"
  "\236\236\236\377\236\236\236\377\235\235\235\377\235\235\235\377\235"
  "\235\235\377\235\235\235\377\234\234\234\377\234\234\234\377\234\234"
  "\234\377\234\234\234\377\235\235\235\377\235\235\235\377\235\235\235"
  "\377\235\235\235\377\236\236\236\377\236\236\236\377\236\236\236\377"
  "\237\237\237\377\237\237\237\377\240\240\240\377\240\240\240\377\341"
  "\341\341\377\347\347\347\377\241\241\241\377\242\242\242\377\242\242"
  "\242\377\243\243\243\377\243\243\243\377\352\352\352\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\342\342\342\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\255\255\255\377\255\255\255\377\365\365\365\377"
  "\333\333\333\377\257\257\257\377\257\257\257\377\260\260\260\377\260"
  "\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262"
  "\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276\276"
  "\276\377\301\301\301\377\303\303\303\377\306\306\306\377\311\311\311"
  "\377\314\314\314\377\317\317\317\377\322\322\322\377\324\324\324\377"
  "\327\327\327\377\332\332\332\377\335\335\335\377\340\340\340\377\343"
  "\343\343\377\346\346\346\377\351\351\351\377\354\354\354\377\356\356"
  "\356\377\361\361\361\377\364\364\364\377\367\367\367\377\372\372\372"
  "\377\375\375\375\377\377\377\377\377\377\377\377\377\344\344\344\377"
  "\212\212\212\377\212\212\212\377\212\212\212\371\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\241;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\306\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\341;\200\256\40\377\377\377\0;\200\256Z;\200\256\375;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\362;\200\256\224;\200\256*\377\377\377\0\377\377\377\0"
  ";\200\256\16;\200\256m;\200\256\327;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\364;\200\256\337;\200\256\312;\200\256\265;\200\256\241;\200\256"
  "\214;\200\256w;\200\256b;\200\256N;\200\2569;\200\256$;\200\256\17\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\1;\200\256\22;\200\256&;\200\256;;\200\256P;\200"
  "\256e;\200\256y;\200\256\216;\200\256\243;\200\256\270;\200\256\314;"
  "\200\256\341;\200\256\366;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256G\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212"
  "\212\306\212\212\212\377\212\212\212\377\315\315\315\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372\377"
  "\367\367\367\377\365\365\365\377\362\362\362\377\357\357\357\377\354"
  "\354\354\377\351\351\351\377\346\346\346\377\344\344\344\377\341\341"
  "\341\377\336\336\336\377\333\333\333\377\330\330\330\377\325\325\325"
  "\377\322\322\322\377\317\317\317\377\314\314\314\377\312\312\312\377"
  "\307\307\307\377\304\304\304\377\301\301\301\377\276\276\276\377\273"
  "\273\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377\262"
  "\262\262\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260"
  "\260\377\257\257\257\377\310\310\310\377\377\377\377\377\270\270\270"
  "\377\255\255\255\377\255\255\255\377\254\254\254\377\267\267\267\377"
  "\373\373\373\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\344\344\344\377\243\243\243\377\243\243\243\377\242\242\242\377\242"
  "\242\242\377\320\320\320\377\371\371\371\377\240\240\240\377\240\240"
  "\240\377\237\237\237\377\237\237\237\377\237\237\237\377\236\236\236"
  "\377\236\236\236\377\235\235\235\377\235\235\235\377\235\235\235\377"
  "\234\234\234\377\234\234\234\377\234\234\234\377\234\234\234\377\234"
  "\234\234\377\234\234\234\377\234\234\234\377\234\234\234\377\235\235"
  "\235\377\235\235\235\377\235\235\235\377\236\236\236\377\236\236\236"
  "\377\237\237\237\377\237\237\237\377\237\237\237\377\240\240\240\377"
  "\341\341\341\377\347\347\347\377\241\241\241\377\242\242\242\377\242"
  "\242\242\377\243\243\243\377\315\315\315\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\307\307\307\377\254\254"
  "\254\377\254\254\254\377\255\255\255\377\255\255\255\377\365\365\365"
  "\377\333\333\333\377\257\257\257\377\257\257\257\377\260\260\260\377"
  "\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276"
  "\276\276\377\300\300\300\377\303\303\303\377\306\306\306\377\311\311"
  "\311\377\314\314\314\377\317\317\317\377\321\321\321\377\324\324\324"
  "\377\327\327\327\377\332\332\332\377\335\335\335\377\340\340\340\377"
  "\343\343\343\377\346\346\346\377\350\350\350\377\353\353\353\377\356"
  "\356\356\377\361\361\361\377\364\364\364\377\367\367\367\377\372\372"
  "\372\377\375\375\375\377\377\377\377\377\377\377\377\377\353\353\353"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\6\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\253;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\303\377\377\377\0\377\377\377\0\377\377\377\0"
  ";\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\337;\200\256\37\377\377\377\0;\200\256];\200\256"
  "\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\323;\200"
  "\256i;\200\256\14\377\377\377\0\377\377\377\0;\200\256.;\200\256\230"
  ";\200\256\364;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\372;\200\256\346;\200\256\321;\200\256\274"
  ";\200\256\247;\200\256\223;\200\256~;\200\256i;\200\256T;\200\256@;\200"
  "\256+;\200\256\26;\200\256\3\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\13;\200\256\37"
  ";\200\2564;\200\256I;\200\256^;\200\256r;\200\256\207;\200\256\234;\200"
  "\256\261;\200\256\305;\200\256\332;\200\256\357;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256R\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\323\212\212\212\377\212\212\212\377\323\323\323\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372"
  "\377\367\367\367\377\365\365\365\377\362\362\362\377\357\357\357\377"
  "\354\354\354\377\351\351\351\377\346\346\346\377\343\343\343\377\340"
  "\340\340\377\336\336\336\377\333\333\333\377\330\330\330\377\325\325"
  "\325\377\322\322\322\377\317\317\317\377\314\314\314\377\311\311\311"
  "\377\306\306\306\377\304\304\304\377\301\301\301\377\276\276\276\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\261\261\261\377\260\260\260\377\260"
  "\260\260\377\257\257\257\377\310\310\310\377\377\377\377\377\270\270"
  "\270\377\255\255\255\377\255\255\255\377\254\254\254\377\331\331\331"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\263\263\263\377\243\243\243\377\242\242\242\377"
  "\242\242\242\377\320\320\320\377\371\371\371\377\240\240\240\377\240"
  "\240\240\377\237\237\237\377\237\237\237\377\236\236\236\377\236\236"
  "\236\377\236\236\236\377\235\235\235\377\235\235\235\377\234\234\234"
  "\377\234\234\234\377\234\234\234\377\234\234\234\377\233\233\233\377"
  "\233\233\233\377\234\234\234\377\234\234\234\377\234\234\234\377\234"
  "\234\234\377\235\235\235\377\235\235\235\377\235\235\235\377\236\236"
  "\236\377\236\236\236\377\237\237\237\377\237\237\237\377\240\240\240"
  "\377\341\341\341\377\347\347\347\377\241\241\241\377\241\241\241\377"
  "\242\242\242\377\242\242\242\377\370\370\370\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\356\356\356\377\254"
  "\254\254\377\254\254\254\377\255\255\255\377\255\255\255\377\365\365"
  "\365\377\333\333\333\377\257\257\257\377\257\257\257\377\260\260\260"
  "\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377\264"
  "\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\275\275\275\377\300\300\300\377\303\303\303\377\306\306\306\377\311"
  "\311\311\377\314\314\314\377\317\317\317\377\321\321\321\377\324\324"
  "\324\377\327\327\327\377\332\332\332\377\335\335\335\377\340\340\340"
  "\377\342\342\342\377\345\345\345\377\350\350\350\377\353\353\353\377"
  "\356\356\356\377\361\361\361\377\364\364\364\377\367\367\367\377\372"
  "\372\372\377\374\374\374\377\377\377\377\377\377\377\377\377\361\361"
  "\361\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\23\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\265"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\300\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\336;\200\256\35\377\377\377\0"
  ";\200\256a;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\372;\200\256\251;\200\256>\377\377\377\0\377"
  "\377\377\0;\200\256\5;\200\256X;\200\256\303;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256\355;\200\256"
  "\330;\200\256\303;\200\256\256;\200\256\231;\200\256\205;\200\256p;\200"
  "\256[;\200\256F;\200\2562;\200\256\35;\200\256\10\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\5;\200\256\30;\200\256-;\200\256B;\200\256W;\200\256k;\200\256\200;"
  "\200\256\225;\200\256\252;\200\256\276;\200\256\323;\200\256\350;\200"
  "\256\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\\\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\337\212\212\212\377\212\212\212\377\331\331\331\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372"
  "\377\367\367\367\377\364\364\364\377\362\362\362\377\357\357\357\377"
  "\354\354\354\377\351\351\351\377\346\346\346\377\343\343\343\377\340"
  "\340\340\377\335\335\335\377\333\333\333\377\330\330\330\377\325\325"
  "\325\377\322\322\322\377\317\317\317\377\314\314\314\377\311\311\311"
  "\377\306\306\306\377\303\303\303\377\301\301\301\377\276\276\276\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\261\261\261\377\260\260\260\377\260"
  "\260\260\377\257\257\257\377\310\310\310\377\377\377\377\377\270\270"
  "\270\377\255\255\255\377\255\255\255\377\254\254\254\377\352\352\352"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\306\306\306\377\242\242\242\377\242\242\242\377"
  "\242\242\242\377\320\320\320\377\371\371\371\377\240\240\240\377\240"
  "\240\240\377\237\237\237\377\237\237\237\377\236\236\236\377\236\236"
  "\236\377\235\235\235\377\235\235\235\377\234\234\234\377\234\234\234"
  "\377\234\234\234\377\233\233\233\377\233\233\233\377\233\233\233\377"
  "\233\233\233\377\233\233\233\377\233\233\233\377\234\234\234\377\234"
  "\234\234\377\234\234\234\377\235\235\235\377\235\235\235\377\236\236"
  "\236\377\236\236\236\377\237\237\237\377\237\237\237\377\240\240\240"
  "\377\341\341\341\377\347\347\347\377\241\241\241\377\241\241\241\377"
  "\242\242\242\377\256\256\256\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\255"
  "\255\255\377\254\254\254\377\255\255\255\377\255\255\255\377\365\365"
  "\365\377\333\333\333\377\257\257\257\377\257\257\257\377\260\260\260"
  "\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263\377\264"
  "\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\275\275\275\377\300\300\300\377\303\303\303\377\306\306\306\377\311"
  "\311\311\377\314\314\314\377\316\316\316\377\321\321\321\377\324\324"
  "\324\377\327\327\327\377\332\332\332\377\335\335\335\377\340\340\340"
  "\377\342\342\342\377\345\345\345\377\350\350\350\377\353\353\353\377"
  "\356\356\356\377\361\361\361\377\364\364\364\377\366\366\366\377\371"
  "\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377\367\367"
  "\367\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\37\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\277"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\276\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\334;\200\256\33"
  "\377\377\377\0;\200\256d;\200\256\376;\200\256\377;\200\256\377;\200"
  "\256\344;\200\256~;\200\256\31\377\377\377\0\377\377\377\0;\200\256\34"
  ";\200\256\203;\200\256\350;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\363;\200\256\337;\200\256\312;\200\256\265;\200\256\240"
  ";\200\256\213;\200\256w;\200\256b;\200\256M;\200\2568;\200\256$;\200"
  "\256\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\1;\200\256\21;\200\256&;\200\256;;\200"
  "\256P;\200\256d;\200\256y;\200\256\216;\200\256\243;\200\256\267;\200"
  "\256\314;\200\256\341;\200\256\366;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256g\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\354\212\212\212\377\212\212\212\377\340\340\340\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372"
  "\372\372\377\367\367\367\377\364\364\364\377\362\362\362\377\357\357"
  "\357\377\354\354\354\377\351\351\351\377\346\346\346\377\343\343\343"
  "\377\340\340\340\377\335\335\335\377\332\332\332\377\330\330\330\377"
  "\325\325\325\377\322\322\322\377\317\317\317\377\314\314\314\377\311"
  "\311\311\377\306\306\306\377\303\303\303\377\301\301\301\377\276\276"
  "\276\377\273\273\273\377\271\271\271\377\271\271\271\377\270\270\270"
  "\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262"
  "\262\377\262\262\262\377\261\261\261\377\261\261\261\377\260\260\260"
  "\377\260\260\260\377\257\257\257\377\310\310\310\377\377\377\377\377"
  "\270\270\270\377\255\255\255\377\255\255\255\377\254\254\254\377\372"
  "\372\372\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\331\331\331\377\242\242\242\377\242\242"
  "\242\377\241\241\241\377\320\320\320\377\371\371\371\377\240\240\240"
  "\377\240\240\240\377\237\237\237\377\237\237\237\377\236\236\236\377"
  "\236\236\236\377\235\235\235\377\235\235\235\377\234\234\234\377\234"
  "\234\234\377\233\233\233\377\233\233\233\377\233\233\233\377\232\232"
  "\232\377\232\232\232\377\233\233\233\377\233\233\233\377\233\233\233"
  "\377\234\234\234\377\234\234\234\377\235\235\235\377\235\235\235\377"
  "\236\236\236\377\236\236\236\377\237\237\237\377\237\237\237\377\237"
  "\237\237\377\341\341\341\377\347\347\347\377\241\241\241\377\241\241"
  "\241\377\242\242\242\377\302\302\302\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\274\274\274\377\254\254\254\377\255\255\255\377\255\255\255\377"
  "\365\365\365\377\333\333\333\377\257\257\257\377\257\257\257\377\260"
  "\260\260\377\260\260\260\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272"
  "\272\377\275\275\275\377\300\300\300\377\303\303\303\377\306\306\306"
  "\377\311\311\311\377\313\313\313\377\316\316\316\377\321\321\321\377"
  "\324\324\324\377\327\327\327\377\332\332\332\377\335\335\335\377\340"
  "\340\340\377\342\342\342\377\345\345\345\377\350\350\350\377\353\353"
  "\353\377\356\356\356\377\361\361\361\377\364\364\364\377\366\366\366"
  "\377\371\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212,\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\310;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\273\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\332;\200\256\32\377\377\377\0;\200\256g;\200\256\275;\200\256S;"
  "\200\256\4\377\377\377\0\377\377\377\0;\200\256C;\200\256\256;\200\256"
  "\374;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\371;\200\256\345;\200\256\320;\200"
  "\256\274;\200\256\247;\200\256\222;\200\256};\200\256i;\200\256T;\200"
  "\256\77;\200\256*;\200\256\26;\200\256\3\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\12"
  ";\200\256\37;\200\2564;\200\256I;\200\256];\200\256r;\200\256\207;\200"
  "\256\234;\200\256\260;\200\256\305;\200\256\332;\200\256\357;\200\256"
  "\376;\200\256q\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\371\212\212\212\377\212\212\212\377\346"
  "\346\346\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375"
  "\375\377\372\372\372\377\367\367\367\377\364\364\364\377\361\361\361"
  "\377\357\357\357\377\354\354\354\377\351\351\351\377\346\346\346\377"
  "\343\343\343\377\340\340\340\377\335\335\335\377\332\332\332\377\327"
  "\327\327\377\325\325\325\377\322\322\322\377\317\317\317\377\314\314"
  "\314\377\311\311\311\377\306\306\306\377\303\303\303\377\301\301\301"
  "\377\276\276\276\377\273\273\273\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263"
  "\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377"
  "\260\260\260\377\260\260\260\377\257\257\257\377\310\310\310\377\377"
  "\377\377\377\270\270\270\377\255\255\255\377\255\255\255\377\270\270"
  "\270\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\354\354\354\377\242\242\242"
  "\377\242\242\242\377\241\241\241\377\320\320\320\377\371\371\371\377"
  "\240\240\240\377\240\240\240\377\237\237\237\377\237\237\237\377\236"
  "\236\236\377\236\236\236\377\235\235\235\377\235\235\235\377\234\234"
  "\234\377\234\234\234\377\233\233\233\377\233\233\233\377\232\232\232"
  "\377\232\232\232\377\232\232\232\377\232\232\232\377\233\233\233\377"
  "\233\233\233\377\234\234\234\377\234\234\234\377\235\235\235\377\235"
  "\235\235\377\235\235\235\377\236\236\236\377\236\236\236\377\237\237"
  "\237\377\237\237\237\377\341\341\341\377\347\347\347\377\241\241\241"
  "\377\241\241\241\377\242\242\242\377\325\325\325\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\315\315\315\377\254\254\254\377\255\255\255\377\255"
  "\255\255\377\365\365\365\377\333\333\333\377\257\257\257\377\257\257"
  "\257\377\260\260\260\377\260\260\260\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\264\264\264\377\264\264\264\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\272\272\272\377\275\275\275\377\300\300\300\377\303\303\303\377"
  "\306\306\306\377\310\310\310\377\313\313\313\377\316\316\316\377\321"
  "\321\321\377\324\324\324\377\327\327\327\377\332\332\332\377\335\335"
  "\335\377\340\340\340\377\342\342\342\377\345\345\345\377\350\350\350"
  "\377\353\353\353\377\356\356\356\377\361\361\361\377\363\363\363\377"
  "\366\366\366\377\371\371\371\377\374\374\374\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\216\216\216\377\212\212\212\377\212\212"
  "\212\377\212\212\2129\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\322;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\271\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\330;\200\256\30\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\17;\200\256n;\200\256\330;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\375;\200\256\354;\200\256\327;\200\256\302;\200\256\256;\200\256\231"
  ";\200\256\204;\200\256o;\200\256[;\200\256F;\200\2561;\200\256\34;\200"
  "\256\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\4;\200\256\10\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\371\212\212"
  "\212\377\212\212\212\377\346\346\346\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\375\375\375\377\372\372\372\377\367\367\367\377"
  "\364\364\364\377\361\361\361\377\357\357\357\377\354\354\354\377\351"
  "\351\351\377\346\346\346\377\343\343\343\377\340\340\340\377\335\335"
  "\335\377\332\332\332\377\327\327\327\377\325\325\325\377\322\322\322"
  "\377\317\317\317\377\314\314\314\377\311\311\311\377\306\306\306\377"
  "\303\303\303\377\301\301\301\377\276\276\276\377\273\273\273\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267"
  "\267\377\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265"
  "\377\265\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\257\257"
  "\257\377\310\310\310\377\377\377\377\377\270\270\270\377\255\255\255"
  "\377\255\255\255\377\270\270\270\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\354\354\354\377\242\242\242\377\242\242\242\377\241\241\241\377\320"
  "\320\320\377\371\371\371\377\240\240\240\377\237\237\237\377\237\237"
  "\237\377\237\237\237\377\236\236\236\377\236\236\236\377\235\235\235"
  "\377\235\235\235\377\234\234\234\377\234\234\234\377\233\233\233\377"
  "\233\233\233\377\232\232\232\377\232\232\232\377\232\232\232\377\232"
  "\232\232\377\233\233\233\377\233\233\233\377\234\234\234\377\234\234"
  "\234\377\234\234\234\377\235\235\235\377\235\235\235\377\236\236\236"
  "\377\236\236\236\377\237\237\237\377\237\237\237\377\341\341\341\377"
  "\347\347\347\377\241\241\241\377\241\241\241\377\242\242\242\377\325"
  "\325\325\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\315\315\315\377\254\254"
  "\254\377\255\255\255\377\255\255\255\377\365\365\365\377\333\333\333"
  "\377\257\257\257\377\257\257\257\377\260\260\260\377\260\260\260\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\272\272\272\377\275\275\275\377\300"
  "\300\300\377\303\303\303\377\306\306\306\377\310\310\310\377\313\313"
  "\313\377\316\316\316\377\321\321\321\377\324\324\324\377\327\327\327"
  "\377\332\332\332\377\335\335\335\377\340\340\340\377\342\342\342\377"
  "\345\345\345\377\350\350\350\377\353\353\353\377\356\356\356\377\361"
  "\361\361\377\363\363\363\377\366\366\366\377\371\371\371\377\374\374"
  "\374\377\377\377\377\377\377\377\377\377\377\377\377\377\216\216\216"
  "\377\212\212\212\377\212\212\212\377\212\212\2129\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\323;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\271\377\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350;\200\256"
  "'\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\";\200\256\216;"
  "\200\256\356;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\367;\200\256"
  "\342;\200\256\315;\200\256\271;\200\256\244;\200\256\217;\200\256z;\200"
  "\256f;\200\256Q;\200\256<;\200\256';\200\256\10\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\354\212\212\212\377\212\212\212\377\340\340\340\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372"
  "\372\372\377\367\367\367\377\364\364\364\377\361\361\361\377\357\357"
  "\357\377\354\354\354\377\351\351\351\377\346\346\346\377\343\343\343"
  "\377\340\340\340\377\335\335\335\377\332\332\332\377\327\327\327\377"
  "\325\325\325\377\322\322\322\377\317\317\317\377\314\314\314\377\311"
  "\311\311\377\306\306\306\377\303\303\303\377\301\301\301\377\276\276"
  "\276\377\273\273\273\377\271\271\271\377\271\271\271\377\270\270\270"
  "\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262"
  "\262\377\262\262\262\377\261\261\261\377\261\261\261\377\260\260\260"
  "\377\260\260\260\377\257\257\257\377\310\310\310\377\377\377\377\377"
  "\270\270\270\377\255\255\255\377\255\255\255\377\254\254\254\377\372"
  "\372\372\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\331\331\331\377\242\242\242\377\242\242"
  "\242\377\241\241\241\377\320\320\320\377\371\371\371\377\240\240\240"
  "\377\240\240\240\377\237\237\237\377\237\237\237\377\236\236\236\377"
  "\236\236\236\377\235\235\235\377\235\235\235\377\234\234\234\377\234"
  "\234\234\377\233\233\233\377\233\233\233\377\232\232\232\377\232\232"
  "\232\377\232\232\232\377\232\232\232\377\233\233\233\377\233\233\233"
  "\377\234\234\234\377\234\234\234\377\235\235\235\377\235\235\235\377"
  "\235\235\235\377\236\236\236\377\236\236\236\377\237\237\237\377\237"
  "\237\237\377\341\341\341\377\347\347\347\377\241\241\241\377\241\241"
  "\241\377\242\242\242\377\302\302\302\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\274\274\274\377\254\254\254\377\255\255\255\377\255\255\255\377"
  "\365\365\365\377\333\333\333\377\257\257\257\377\257\257\257\377\260"
  "\260\260\377\260\260\260\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272"
  "\272\377\275\275\275\377\300\300\300\377\303\303\303\377\306\306\306"
  "\377\310\310\310\377\313\313\313\377\316\316\316\377\321\321\321\377"
  "\324\324\324\377\327\327\327\377\332\332\332\377\335\335\335\377\340"
  "\340\340\377\342\342\342\377\345\345\345\377\350\350\350\377\353\353"
  "\353\377\356\356\356\377\361\361\361\377\363\363\363\377\366\366\366"
  "\377\371\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212,\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\311;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\275\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\351;\200\256*\377\377\377\0;\200\256M;\200\256\236;\200\2564\377"
  "\377\377\0\377\377\377\0;\200\256\11;\200\256c;\200\256\315;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357;\200"
  "\256\333;\200\256\306;\200\256\261;\200\256\234;\200\256\210;\200\256"
  "s;\200\256^;\200\256J;\200\2565;\200\256\40;\200\256\13\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\7;\200\256\34;\200\2561;\200\256E;\200\256Z;\200\256o;\200"
  "\256\204;\200\256\230;\200\256\255;\200\256\302;\200\256\327;\200\256"
  "\353;\200\256p\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\337\212\212\212\377\212\212\212\377\331"
  "\331\331\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375"
  "\375\377\372\372\372\377\367\367\367\377\364\364\364\377\362\362\362"
  "\377\357\357\357\377\354\354\354\377\351\351\351\377\346\346\346\377"
  "\343\343\343\377\340\340\340\377\335\335\335\377\332\332\332\377\330"
  "\330\330\377\325\325\325\377\322\322\322\377\317\317\317\377\314\314"
  "\314\377\311\311\311\377\306\306\306\377\303\303\303\377\301\301\301"
  "\377\276\276\276\377\273\273\273\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263"
  "\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377"
  "\260\260\260\377\260\260\260\377\257\257\257\377\310\310\310\377\377"
  "\377\377\377\270\270\270\377\255\255\255\377\255\255\255\377\254\254"
  "\254\377\352\352\352\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\306\306\306\377\242\242\242"
  "\377\242\242\242\377\241\241\241\377\320\320\320\377\371\371\371\377"
  "\240\240\240\377\240\240\240\377\237\237\237\377\237\237\237\377\236"
  "\236\236\377\236\236\236\377\235\235\235\377\235\235\235\377\234\234"
  "\234\377\234\234\234\377\233\233\233\377\233\233\233\377\233\233\233"
  "\377\232\232\232\377\232\232\232\377\233\233\233\377\233\233\233\377"
  "\233\233\233\377\234\234\234\377\234\234\234\377\235\235\235\377\235"
  "\235\235\377\236\236\236\377\236\236\236\377\237\237\237\377\237\237"
  "\237\377\237\237\237\377\341\341\341\377\347\347\347\377\241\241\241"
  "\377\241\241\241\377\242\242\242\377\256\256\256\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\255\255\255\377\254\254\254\377\255\255\255\377\255"
  "\255\255\377\365\365\365\377\333\333\333\377\257\257\257\377\257\257"
  "\257\377\260\260\260\377\260\260\260\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\264\264\264\377\264\264\264\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\272\272\272\377\275\275\275\377\300\300\300\377\303\303\303\377"
  "\306\306\306\377\311\311\311\377\313\313\313\377\316\316\316\377\321"
  "\321\321\377\324\324\324\377\327\327\327\377\332\332\332\377\335\335"
  "\335\377\340\340\340\377\342\342\342\377\345\345\345\377\350\350\350"
  "\377\353\353\353\377\356\356\356\377\361\361\361\377\364\364\364\377"
  "\366\366\366\377\371\371\371\377\374\374\374\377\377\377\377\377\377"
  "\377\377\377\367\367\367\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\37\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\277;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\300\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\352;\200\256,\377\377\377\0;\200\256J;\200\256\371;\200\256\377"
  ";\200\256\377;\200\256\311;\200\256_;\200\256\10\377\377\377\0\377\377"
  "\377\0;\200\2567;\200\256\242;\200\256\370;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\373;\200\256\350;\200\256"
  "\323;\200\256\277;\200\256\252;\200\256\225;\200\256\200;\200\256l;\200"
  "\256W;\200\256B;\200\256.;\200\256\31;\200\256\5\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\16;\200\256#;\200\2568;\200\256L;\200\256a;\200\256v;\200\256\213;\200"
  "\256\237;\200\256\264;\200\256\311;\200\256\336;\200\256\362;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256h\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\323\212\212\212\377\212\212\212\377"
  "\323\323\323\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\372\372\372\377\367\367\367\377\364\364\364\377\362\362"
  "\362\377\357\357\357\377\354\354\354\377\351\351\351\377\346\346\346"
  "\377\343\343\343\377\340\340\340\377\335\335\335\377\333\333\333\377"
  "\330\330\330\377\325\325\325\377\322\322\322\377\317\317\317\377\314"
  "\314\314\377\311\311\311\377\306\306\306\377\303\303\303\377\301\301"
  "\301\377\276\276\276\377\273\273\273\377\271\271\271\377\271\271\271"
  "\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377"
  "\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263"
  "\263\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261"
  "\377\260\260\260\377\260\260\260\377\257\257\257\377\310\310\310\377"
  "\377\377\377\377\270\270\270\377\255\255\255\377\255\255\255\377\254"
  "\254\254\377\331\331\331\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\263\263\263\377\242\242"
  "\242\377\242\242\242\377\242\242\242\377\320\320\320\377\371\371\371"
  "\377\240\240\240\377\240\240\240\377\237\237\237\377\237\237\237\377"
  "\236\236\236\377\236\236\236\377\235\235\235\377\235\235\235\377\234"
  "\234\234\377\234\234\234\377\234\234\234\377\233\233\233\377\233\233"
  "\233\377\233\233\233\377\233\233\233\377\233\233\233\377\233\233\233"
  "\377\234\234\234\377\234\234\234\377\234\234\234\377\235\235\235\377"
  "\235\235\235\377\236\236\236\377\236\236\236\377\237\237\237\377\237"
  "\237\237\377\240\240\240\377\341\341\341\377\347\347\347\377\241\241"
  "\241\377\241\241\241\377\242\242\242\377\242\242\242\377\370\370\370"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\356\356\356\377\254\254\254\377\254\254\254\377\255\255\255\377"
  "\255\255\255\377\365\365\365\377\333\333\333\377\257\257\257\377\257"
  "\257\257\377\260\260\260\377\260\260\260\377\261\261\261\377\261\261"
  "\261\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263"
  "\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265\265\377"
  "\265\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\272\272\272\377\275\275\275\377\300\300\300\377\303\303\303"
  "\377\306\306\306\377\311\311\311\377\314\314\314\377\316\316\316\377"
  "\321\321\321\377\324\324\324\377\327\327\327\377\332\332\332\377\335"
  "\335\335\377\340\340\340\377\342\342\342\377\345\345\345\377\350\350"
  "\350\377\353\353\353\377\356\356\356\377\361\361\361\377\364\364\364"
  "\377\366\366\366\377\371\371\371\377\374\374\374\377\377\377\377\377"
  "\377\377\377\377\361\361\361\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\23\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\265;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\304\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\354;\200\256.\377\377\377\0;\200\256G;\200\256\370;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\354;\200\256"
  "\213;\200\256\"\377\377\377\0\377\377\377\0;\200\256\24;\200\256v;\200"
  "\256\336;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\365;\200\256\341;\200\256\314;\200"
  "\256\267;\200\256\243;\200\256\216;\200\256y;\200\256d;\200\256P;\200"
  "\256;;\200\256&;\200\256\21;\200\256\1\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\25;\200\256"
  "*;\200\256\77;\200\256S;\200\256h;\200\256};\200\256\222;\200\256\246"
  ";\200\256\273;\200\256\320;\200\256\345;\200\256\371;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256]\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\306\212\212\212\377\212\212"
  "\212\377\315\315\315\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\375\375\375\377\372\372\372\377\367\367\367\377\365\365\365\377"
  "\362\362\362\377\357\357\357\377\354\354\354\377\351\351\351\377\346"
  "\346\346\377\343\343\343\377\340\340\340\377\336\336\336\377\333\333"
  "\333\377\330\330\330\377\325\325\325\377\322\322\322\377\317\317\317"
  "\377\314\314\314\377\311\311\311\377\306\306\306\377\304\304\304\377"
  "\301\301\301\377\276\276\276\377\273\273\273\377\271\271\271\377\271"
  "\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267"
  "\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\264\264\264\377\264\264\264\377\263\263\263\377"
  "\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261\377\261"
  "\261\261\377\260\260\260\377\260\260\260\377\257\257\257\377\310\310"
  "\310\377\377\377\377\377\270\270\270\377\255\255\255\377\255\255\255"
  "\377\254\254\254\377\266\266\266\377\372\372\372\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\343\343\343\377\243\243\243\377"
  "\243\243\243\377\242\242\242\377\242\242\242\377\320\320\320\377\371"
  "\371\371\377\240\240\240\377\240\240\240\377\237\237\237\377\237\237"
  "\237\377\236\236\236\377\236\236\236\377\236\236\236\377\235\235\235"
  "\377\235\235\235\377\234\234\234\377\234\234\234\377\234\234\234\377"
  "\234\234\234\377\233\233\233\377\233\233\233\377\234\234\234\377\234"
  "\234\234\377\234\234\234\377\234\234\234\377\235\235\235\377\235\235"
  "\235\377\235\235\235\377\236\236\236\377\236\236\236\377\237\237\237"
  "\377\237\237\237\377\240\240\240\377\341\341\341\377\347\347\347\377"
  "\241\241\241\377\241\241\241\377\242\242\242\377\242\242\242\377\314"
  "\314\314\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\306\306\306\377\254\254\254\377\254\254\254\377\255\255"
  "\255\377\255\255\255\377\365\365\365\377\333\333\333\377\257\257\257"
  "\377\257\257\257\377\260\260\260\377\260\260\260\377\261\261\261\377"
  "\261\261\261\377\262\262\262\377\262\262\262\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\266\266\266\377\266\266\266\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377"
  "\271\271\271\377\272\272\272\377\275\275\275\377\300\300\300\377\303"
  "\303\303\377\306\306\306\377\311\311\311\377\314\314\314\377\317\317"
  "\317\377\321\321\321\377\324\324\324\377\327\327\327\377\332\332\332"
  "\377\335\335\335\377\340\340\340\377\342\342\342\377\345\345\345\377"
  "\350\350\350\377\353\353\353\377\356\356\356\377\361\361\361\377\364"
  "\364\364\377\367\367\367\377\372\372\372\377\374\374\374\377\377\377"
  "\377\377\377\377\377\377\353\353\353\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\6\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\254;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\307\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\355;\200"
  "\256/\377\377\377\0;\200\256E;\200\256\367;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\376;\200\256\266;\200\256L;\200\256\2\377\377\377\0"
  ";\200\256\2;\200\256K;\200\256\265;\200\256\375;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\376;\200\256\356;\200\256\331;\200\256\305;\200\256\260;\200\256"
  "\233;\200\256\206;\200\256r;\200\256];\200\256H;\200\2564;\200\256\37"
  ";\200\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\10;\200\256\34;\200\2561;\200"
  "\256F;\200\256Z;\200\256o;\200\256\204;\200\256\231;\200\256\255;\200"
  "\256\302;\200\256\327;\200\256\354;\200\256\375;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256S\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\271\212\212"
  "\212\377\212\212\212\377\307\307\307\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\375\375\375\377\372\372\372\377\367\367\367\377"
  "\365\365\365\377\362\362\362\377\357\357\357\377\354\354\354\377\351"
  "\351\351\377\346\346\346\377\344\344\344\377\341\341\341\377\336\336"
  "\336\377\333\333\333\377\330\330\330\377\325\325\325\377\322\322\322"
  "\377\317\317\317\377\314\314\314\377\312\312\312\377\307\307\307\377"
  "\304\304\304\377\301\301\301\377\276\276\276\377\273\273\273\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267"
  "\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\257\257"
  "\257\377\310\310\310\377\377\377\377\377\270\270\270\377\255\255\255"
  "\377\255\255\255\377\254\254\254\377\254\254\254\377\315\315\315\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\370\370\370\377\254\254\254\377"
  "\243\243\243\377\243\243\243\377\242\242\242\377\242\242\242\377\320"
  "\320\320\377\371\371\371\377\240\240\240\377\240\240\240\377\237\237"
  "\237\377\237\237\237\377\237\237\237\377\236\236\236\377\236\236\236"
  "\377\235\235\235\377\235\235\235\377\235\235\235\377\234\234\234\377"
  "\234\234\234\377\234\234\234\377\234\234\234\377\234\234\234\377\234"
  "\234\234\377\234\234\234\377\234\234\234\377\235\235\235\377\235\235"
  "\235\377\235\235\235\377\236\236\236\377\236\236\236\377\237\237\237"
  "\377\237\237\237\377\237\237\237\377\240\240\240\377\341\341\341\377"
  "\347\347\347\377\241\241\241\377\242\242\242\377\242\242\242\377\243"
  "\243\243\377\243\243\243\377\351\351\351\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\341\341\341\377\253\253\253\377\254\254\254\377\254\254"
  "\254\377\255\255\255\377\255\255\255\377\365\365\365\377\333\333\333"
  "\377\257\257\257\377\257\257\257\377\260\260\260\377\260\260\260\377"
  "\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\273\273\273\377\276\276\276\377\300"
  "\300\300\377\303\303\303\377\306\306\306\377\311\311\311\377\314\314"
  "\314\377\317\317\317\377\321\321\321\377\324\324\324\377\327\327\327"
  "\377\332\332\332\377\335\335\335\377\340\340\340\377\343\343\343\377"
  "\346\346\346\377\350\350\350\377\353\353\353\377\356\356\356\377\361"
  "\361\361\377\364\364\364\377\367\367\367\377\372\372\372\377\375\375"
  "\375\377\377\377\377\377\377\377\377\377\344\344\344\377\212\212\212"
  "\377\212\212\212\377\212\212\212\371\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\242;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\312\377\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\356"
  ";\200\2561\377\377\377\0;\200\256C;\200\256\366;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\337;\200\256x;\200\256\25\377\377\377\0\377\377\377\0;\200\256\""
  ";\200\256\212;\200\256\354;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\373;\200\256\347;\200\256\322;\200\256\275;\200\256\251;\200"
  "\256\224;\200\256\177;\200\256j;\200\256V;\200\256A;\200\256,;\200\256"
  "\30;\200\256\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\16;\200\256#;\200\2568;\200\256"
  "M;\200\256a;\200\256v;\200\256\213;\200\256\240;\200\256\264;\200\256"
  "\311;\200\256\336;\200\256\363;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256H\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\254"
  "\212\212\212\377\212\212\212\377\301\301\301\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\375\375\375\377\372\372\372\377\370\370"
  "\370\377\365\365\365\377\362\362\362\377\357\357\357\377\354\354\354"
  "\377\351\351\351\377\347\347\347\377\344\344\344\377\341\341\341\377"
  "\336\336\336\377\333\333\333\377\330\330\330\377\325\325\325\377\322"
  "\322\322\377\320\320\320\377\315\315\315\377\312\312\312\377\307\307"
  "\307\377\304\304\304\377\301\301\301\377\276\276\276\377\273\273\273"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262"
  "\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377"
  "\257\257\257\377\310\310\310\377\377\377\377\377\270\270\270\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\350\350\350\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\304\304\304\377\244\244"
  "\244\377\243\243\243\377\243\243\243\377\242\242\242\377\242\242\242"
  "\377\320\320\320\377\371\371\371\377\241\241\241\377\240\240\240\377"
  "\240\240\240\377\237\237\237\377\237\237\237\377\237\237\237\377\236"
  "\236\236\377\236\236\236\377\235\235\235\377\235\235\235\377\235\235"
  "\235\377\235\235\235\377\234\234\234\377\234\234\234\377\234\234\234"
  "\377\234\234\234\377\235\235\235\377\235\235\235\377\235\235\235\377"
  "\235\235\235\377\236\236\236\377\236\236\236\377\236\236\236\377\237"
  "\237\237\377\237\237\237\377\240\240\240\377\240\240\240\377\341\341"
  "\341\377\347\347\347\377\241\241\241\377\242\242\242\377\242\242\242"
  "\377\243\243\243\377\243\243\243\377\261\261\261\377\373\373\373\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\367\367\367\377\261\261\261\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\255\255\255\377\255\255\255\377\365\365\365\377\333"
  "\333\333\377\257\257\257\377\257\257\257\377\260\260\260\377\260\260"
  "\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276\276\276"
  "\377\301\301\301\377\303\303\303\377\306\306\306\377\311\311\311\377"
  "\314\314\314\377\317\317\317\377\322\322\322\377\324\324\324\377\327"
  "\327\327\377\332\332\332\377\335\335\335\377\340\340\340\377\343\343"
  "\343\377\346\346\346\377\351\351\351\377\354\354\354\377\356\356\356"
  "\377\361\361\361\377\364\364\364\377\367\367\367\377\372\372\372\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\336\336\336\377\212"
  "\212\212\377\212\212\212\377\212\212\212\354\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\230;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\316\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357;\200\256"
  "3\377\377\377\0;\200\256@;\200\256\365;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\370;\200\256\243;\200\2569\377\377"
  "\377\0\377\377\377\0;\200\256\10;\200\256_;\200\256\311;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\364"
  ";\200\256\337;\200\256\313;\200\256\266;\200\256\241;\200\256\215;\200"
  "\256x;\200\256c;\200\256N;\200\256:;\200\256%;\200\256\20\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\3;\200\256\25;\200\256*;\200\256\77;\200\256T;\200\256h;"
  "\200\256};\200\256\222;\200\256\247;\200\256\273;\200\256\320;\200\256"
  "\345;\200\256\371;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256=\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\237\212\212\212\377\212\212\212\377\273\273\273\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\376\376\376\377\373\373\373\377\370"
  "\370\370\377\365\365\365\377\362\362\362\377\357\357\357\377\354\354"
  "\354\377\351\351\351\377\347\347\347\377\344\344\344\377\341\341\341"
  "\377\336\336\336\377\333\333\333\377\330\330\330\377\326\326\326\377"
  "\323\323\323\377\320\320\320\377\315\315\315\377\312\312\312\377\307"
  "\307\307\377\304\304\304\377\302\302\302\377\277\277\277\377\274\274"
  "\274\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264"
  "\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262"
  "\262\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260"
  "\377\257\257\257\377\310\310\310\377\377\377\377\377\270\270\270\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254"
  "\254\254\377\261\261\261\377\343\343\343\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\373\373\373\377\312\312\312\377\244\244\244\377\244"
  "\244\244\377\243\243\243\377\243\243\243\377\243\243\243\377\242\242"
  "\242\377\320\320\320\377\371\371\371\377\241\241\241\377\240\240\240"
  "\377\240\240\240\377\240\240\240\377\237\237\237\377\237\237\237\377"
  "\236\236\236\377\236\236\236\377\236\236\236\377\235\235\235\377\235"
  "\235\235\377\235\235\235\377\235\235\235\377\235\235\235\377\235\235"
  "\235\377\235\235\235\377\235\235\235\377\235\235\235\377\235\235\235"
  "\377\236\236\236\377\236\236\236\377\236\236\236\377\237\237\237\377"
  "\237\237\237\377\237\237\237\377\240\240\240\377\240\240\240\377\341"
  "\341\341\377\347\347\347\377\242\242\242\377\242\242\242\377\242\242"
  "\242\377\243\243\243\377\243\243\243\377\244\244\244\377\272\272\272"
  "\377\364\364\364\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\357\357"
  "\357\377\272\272\272\377\253\253\253\377\254\254\254\377\254\254\254"
  "\377\255\255\255\377\255\255\255\377\255\255\255\377\365\365\365\377"
  "\333\333\333\377\257\257\257\377\257\257\257\377\260\260\260\377\260"
  "\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262"
  "\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276\276"
  "\276\377\301\301\301\377\304\304\304\377\306\306\306\377\311\311\311"
  "\377\314\314\314\377\317\317\317\377\322\322\322\377\325\325\325\377"
  "\330\330\330\377\333\333\333\377\335\335\335\377\340\340\340\377\343"
  "\343\343\377\346\346\346\377\351\351\351\377\354\354\354\377\357\357"
  "\357\377\362\362\362\377\364\364\364\377\367\367\367\377\372\372\372"
  "\377\375\375\375\377\377\377\377\377\377\377\377\377\330\330\330\377"
  "\212\212\212\377\212\212\212\377\212\212\212\337\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\216;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\321\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\360;\200\2565\377\377"
  "\377\0;\200\256>;\200\256\364;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\317;\200\256e;\200\256\12\377\377\377\0\377\377\377\0;\200"
  "\2564;\200\256\236;\200\256\366;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\376;\200\256\355;\200\256\330"
  ";\200\256\303;\200\256\257;\200\256\232;\200\256\205;\200\256q;\200\256"
  "\\;\200\256G;\200\2562;\200\256\36;\200\256\11\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\10;\200\256\34;\200\2561;\200\256F;\200\256[;\200\256o;\200\256\204"
  ";\200\256\231;\200\256\256;\200\256\302;\200\256\327;\200\256\354;\200"
  "\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2563\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\222\212\212\212\377\212\212\212\377\265\265\265\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373\373\373"
  "\377\370\370\370\377\365\365\365\377\362\362\362\377\360\360\360\377"
  "\355\355\355\377\352\352\352\377\347\347\347\377\344\344\344\377\341"
  "\341\341\377\336\336\336\377\333\333\333\377\331\331\331\377\326\326"
  "\326\377\323\323\323\377\320\320\320\377\315\315\315\377\312\312\312"
  "\377\310\310\310\377\305\305\305\377\302\302\302\377\277\277\277\377"
  "\274\274\274\377\271\271\271\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\261\261\261\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\310\310\310\377\377\377\377\377\270\270"
  "\270\377\256\256\256\377\255\255\255\377\255\255\255\377\254\254\254"
  "\377\254\254\254\377\253\253\253\377\253\253\253\377\306\306\306\377"
  "\370\370\370\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\352\352\352\377\261\261\261\377\245\245\245\377\244\244\244"
  "\377\244\244\244\377\244\244\244\377\243\243\243\377\243\243\243\377"
  "\242\242\242\377\320\320\320\377\371\371\371\377\241\241\241\377\241"
  "\241\241\377\240\240\240\377\240\240\240\377\237\237\237\377\237\237"
  "\237\377\237\237\237\377\236\236\236\377\236\236\236\377\236\236\236"
  "\377\236\236\236\377\235\235\235\377\235\235\235\377\235\235\235\377"
  "\235\235\235\377\235\235\235\377\235\235\235\377\236\236\236\377\236"
  "\236\236\377\236\236\236\377\236\236\236\377\237\237\237\377\237\237"
  "\237\377\237\237\237\377\240\240\240\377\240\240\240\377\241\241\241"
  "\377\341\341\341\377\347\347\347\377\242\242\242\377\242\242\242\377"
  "\243\243\243\377\243\243\243\377\243\243\243\377\244\244\244\377\244"
  "\244\244\377\251\251\251\377\333\333\333\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\375\375\375\377\325\325\325\377"
  "\253\253\253\377\253\253\253\377\253\253\253\377\254\254\254\377\254"
  "\254\254\377\255\255\255\377\255\255\255\377\256\256\256\377\365\365"
  "\365\377\333\333\333\377\257\257\257\377\257\257\257\377\260\260\260"
  "\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377"
  "\276\276\276\377\301\301\301\377\304\304\304\377\307\307\307\377\312"
  "\312\312\377\315\315\315\377\317\317\317\377\322\322\322\377\325\325"
  "\325\377\330\330\330\377\333\333\333\377\336\336\336\377\341\341\341"
  "\377\343\343\343\377\346\346\346\377\351\351\351\377\354\354\354\377"
  "\357\357\357\377\362\362\362\377\365\365\365\377\367\367\367\377\372"
  "\372\372\377\375\375\375\377\377\377\377\377\377\377\377\377\322\322"
  "\322\377\212\212\212\377\212\212\212\377\212\212\212\322\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\204"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\325\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\361;\200\2567\377\377\377"
  "\0;\200\256<;\200\256\363;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\360;\200\256\220;\200\256"
  "'\377\377\377\0\377\377\377\0;\200\256\22;\200\256s;\200\256\333;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\372;\200\256\346;\200\256\321;\200\256"
  "\274;\200\256\247;\200\256\223;\200\256~;\200\256i;\200\256T;\200\256"
  "@;\200\256+;\200\256\26;\200\256\3\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\17;\200\256"
  "#;\200\2568;\200\256M;\200\256b;\200\256v;\200\256\213;\200\256\240;"
  "\200\256\265;\200\256\311;\200\256\336;\200\256\363;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "(\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\206\212\212\212\377\212\212\212\377\256\256\256\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373\373"
  "\373\377\370\370\370\377\366\366\366\377\363\363\363\377\360\360\360"
  "\377\355\355\355\377\352\352\352\377\347\347\347\377\344\344\344\377"
  "\342\342\342\377\337\337\337\377\334\334\334\377\331\331\331\377\326"
  "\326\326\377\323\323\323\377\320\320\320\377\315\315\315\377\313\313"
  "\313\377\310\310\310\377\305\305\305\377\302\302\302\377\277\277\277"
  "\377\274\274\274\377\272\272\272\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262"
  "\377\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\260\260\260\377\260\260\260\377\310\310\310\377\377\377\377\377\270"
  "\270\270\377\256\256\256\377\255\255\255\377\255\255\255\377\254\254"
  "\254\377\254\254\254\377\253\253\253\377\253\253\253\377\253\253\253"
  "\377\261\261\261\377\314\314\314\377\334\334\334\377\355\355\355\377"
  "\374\374\374\377\370\370\370\377\347\347\347\377\325\325\325\377\301"
  "\301\301\377\246\246\246\377\246\246\246\377\245\245\245\377\245\245"
  "\245\377\244\244\244\377\244\244\244\377\243\243\243\377\243\243\243"
  "\377\242\242\242\377\320\320\320\377\371\371\371\377\241\241\241\377"
  "\241\241\241\377\240\240\240\377\240\240\240\377\240\240\240\377\237"
  "\237\237\377\237\237\237\377\237\237\237\377\237\237\237\377\236\236"
  "\236\377\236\236\236\377\236\236\236\377\236\236\236\377\236\236\236"
  "\377\236\236\236\377\236\236\236\377\236\236\236\377\236\236\236\377"
  "\236\236\236\377\236\236\236\377\237\237\237\377\237\237\237\377\237"
  "\237\237\377\240\240\240\377\240\240\240\377\240\240\240\377\241\241"
  "\241\377\341\341\341\377\350\350\350\377\242\242\242\377\242\242\242"
  "\377\243\243\243\377\243\243\243\377\244\244\244\377\244\244\244\377"
  "\245\245\245\377\245\245\245\377\245\245\245\377\271\271\271\377\320"
  "\320\320\377\342\342\342\377\364\364\364\377\376\376\376\377\362\362"
  "\362\377\340\340\340\377\317\317\317\377\267\267\267\377\252\252\252"
  "\377\252\252\252\377\253\253\253\377\253\253\253\377\254\254\254\377"
  "\254\254\254\377\255\255\255\377\255\255\255\377\256\256\256\377\365"
  "\365\365\377\334\334\334\377\257\257\257\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262"
  "\377\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377"
  "\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\274\274\274"
  "\377\277\277\277\377\302\302\302\377\304\304\304\377\307\307\307\377"
  "\312\312\312\377\315\315\315\377\320\320\320\377\323\323\323\377\326"
  "\326\326\377\330\330\330\377\333\333\333\377\336\336\336\377\341\341"
  "\341\377\344\344\344\377\347\347\347\377\351\351\351\377\354\354\354"
  "\377\357\357\357\377\362\362\362\377\365\365\365\377\370\370\370\377"
  "\372\372\372\377\375\375\375\377\377\377\377\377\377\377\377\377\313"
  "\313\313\377\212\212\212\377\212\212\212\377\212\212\212\306\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "{;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\330\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\362;\200\2569\377\377\377\0;\200\2569"
  ";\200\256\362;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\274;\200\256R;\200\256\4\377\377\377\0;\200\256\1;\200"
  "\256G;\200\256\262;\200\256\375;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\363;\200\256\336;\200\256\311;\200\256\265;\200\256\240;\200"
  "\256\213;\200\256w;\200\256b;\200\256M;\200\2568;\200\256$;\200\256\17"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\3;\200\256\26;\200\256*;\200\256\77;\200\256"
  "T;\200\256i;\200\256};\200\256\222;\200\256\247;\200\256\274;\200\256"
  "\320;\200\256\345;\200\256\371;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\32"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212j\212\212\212\377\212\212\212\377\236\236\236\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374\374"
  "\377\371\371\371\377\366\366\366\377\363\363\363\377\360\360\360\377"
  "\355\355\355\377\353\353\353\377\350\350\350\377\345\345\345\377\342"
  "\342\342\377\337\337\337\377\334\334\334\377\331\331\331\377\327\327"
  "\327\377\324\324\324\377\321\321\321\377\316\316\316\377\313\313\313"
  "\377\310\310\310\377\305\305\305\377\303\303\303\377\300\300\300\377"
  "\275\275\275\377\272\272\272\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377\260"
  "\260\260\377\260\260\260\377\310\310\310\377\377\377\377\377\270\270"
  "\270\377\256\256\256\377\255\255\255\377\255\255\255\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253\253\377"
  "\252\252\252\377\252\252\252\377\251\251\251\377\251\251\251\377\251"
  "\251\251\377\250\250\250\377\247\247\247\377\247\247\247\377\247\247"
  "\247\377\246\246\246\377\246\246\246\377\245\245\245\377\245\245\245"
  "\377\244\244\244\377\244\244\244\377\244\244\244\377\243\243\243\377"
  "\243\243\243\377\320\320\320\377\371\371\371\377\242\242\242\377\241"
  "\241\241\377\241\241\241\377\240\240\240\377\240\240\240\377\240\240"
  "\240\377\237\237\237\377\237\237\237\377\237\237\237\377\237\237\237"
  "\377\237\237\237\377\236\236\236\377\236\236\236\377\236\236\236\377"
  "\236\236\236\377\236\236\236\377\236\236\236\377\237\237\237\377\237"
  "\237\237\377\237\237\237\377\237\237\237\377\237\237\237\377\240\240"
  "\240\377\240\240\240\377\240\240\240\377\241\241\241\377\241\241\241"
  "\377\341\341\341\377\350\350\350\377\242\242\242\377\243\243\243\377"
  "\243\243\243\377\243\243\243\377\244\244\244\377\244\244\244\377\245"
  "\245\245\377\245\245\245\377\246\246\246\377\246\246\246\377\246\246"
  "\246\377\247\247\247\377\247\247\247\377\251\251\251\377\250\250\250"
  "\377\251\251\251\377\251\251\251\377\252\252\252\377\252\252\252\377"
  "\253\253\253\377\253\253\253\377\253\253\253\377\254\254\254\377\254"
  "\254\254\377\255\255\255\377\255\255\255\377\256\256\256\377\365\365"
  "\365\377\334\334\334\377\257\257\257\377\260\260\260\377\260\260\260"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\274\274\274\377"
  "\277\277\277\377\302\302\302\377\305\305\305\377\310\310\310\377\312"
  "\312\312\377\315\315\315\377\320\320\320\377\323\323\323\377\326\326"
  "\326\377\330\330\330\377\333\333\333\377\336\336\336\377\341\341\341"
  "\377\344\344\344\377\347\347\347\377\352\352\352\377\355\355\355\377"
  "\357\357\357\377\362\362\362\377\365\365\365\377\370\370\370\377\373"
  "\373\373\377\376\376\376\377\377\377\377\377\377\377\377\377\274\274"
  "\274\377\212\212\212\377\212\212\212\377\212\212\212\252\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256q"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\334\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\363;\200\256;\377\377\377\0;\200\2567;\200\256\361"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\344;\200\256};\200\256\30\377"
  "\377\377\0\377\377\377\0;\200\256\37;\200\256\206;\200\256\352;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256\354"
  ";\200\256\327;\200\256\302;\200\256\255;\200\256\231;\200\256\204;\200"
  "\256o;\200\256[;\200\256F;\200\2561;\200\256\34;\200\256\10\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\10;\200\256\35;\200\2561;\200\256F;\200\256[;\200\256p;\200"
  "\256\204;\200\256\231;\200\256\256;\200\256\303;\200\256\327;\200\256"
  "\354;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256"
  "\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212C\212\212\212\377\212\212\212\377\215\215\215\377\376\376"
  "\376\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374\374"
  "\377\371\371\371\377\366\366\366\377\363\363\363\377\360\360\360\377"
  "\356\356\356\377\353\353\353\377\350\350\350\377\345\345\345\377\342"
  "\342\342\377\340\340\340\377\335\335\335\377\332\332\332\377\327\327"
  "\327\377\324\324\324\377\321\321\321\377\316\316\316\377\314\314\314"
  "\377\311\311\311\377\306\306\306\377\303\303\303\377\300\300\300\377"
  "\275\275\275\377\273\273\273\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377\260"
  "\260\260\377\260\260\260\377\310\310\310\377\377\377\377\377\270\270"
  "\270\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255"
  "\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253\253\377"
  "\252\252\252\377\252\252\252\377\251\251\251\377\251\251\251\377\251"
  "\251\251\377\250\250\250\377\250\250\250\377\247\247\247\377\247\247"
  "\247\377\246\246\246\377\246\246\246\377\245\245\245\377\245\245\245"
  "\377\245\245\245\377\244\244\244\377\244\244\244\377\243\243\243\377"
  "\243\243\243\377\321\321\321\377\371\371\371\377\242\242\242\377\241"
  "\241\241\377\241\241\241\377\241\241\241\377\240\240\240\377\240\240"
  "\240\377\240\240\240\377\240\240\240\377\237\237\237\377\237\237\237"
  "\377\237\237\237\377\237\237\237\377\237\237\237\377\237\237\237\377"
  "\237\237\237\377\237\237\237\377\237\237\237\377\237\237\237\377\237"
  "\237\237\377\237\237\237\377\240\240\240\377\240\240\240\377\240\240"
  "\240\377\240\240\240\377\241\241\241\377\241\241\241\377\241\241\241"
  "\377\342\342\342\377\350\350\350\377\242\242\242\377\243\243\243\377"
  "\243\243\243\377\244\244\244\377\244\244\244\377\244\244\244\377\245"
  "\245\245\377\245\245\245\377\246\246\246\377\246\246\246\377\247\247"
  "\247\377\247\247\247\377\250\250\250\377\250\250\250\377\250\250\250"
  "\377\251\251\251\377\251\251\251\377\252\252\252\377\252\252\252\377"
  "\253\253\253\377\253\253\253\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\255\255\255\377\255\255\255\377\256\256\256\377\365\365"
  "\365\377\334\334\334\377\257\257\257\377\260\260\260\377\260\260\260"
  "\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270"
  "\377\271\271\271\377\271\271\271\377\272\272\272\377\274\274\274\377"
  "\277\277\277\377\302\302\302\377\305\305\305\377\310\310\310\377\313"
  "\313\313\377\316\316\316\377\320\320\320\377\323\323\323\377\326\326"
  "\326\377\331\331\331\377\334\334\334\377\337\337\337\377\342\342\342"
  "\377\344\344\344\377\347\347\347\377\352\352\352\377\355\355\355\377"
  "\360\360\360\377\363\363\363\377\366\366\366\377\370\370\370\377\373"
  "\373\373\377\376\376\376\377\377\377\377\377\377\377\377\377\252\252"
  "\252\377\212\212\212\377\212\212\212\377\212\212\212\203\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256g"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\337\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\364;\200\256=\377\377\377\0;\200\2565;\200\256\360;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\372"
  ";\200\256\251;\200\256\77\377\377\377\0\377\377\377\0;\200\256\6;\200"
  "\256[;\200\256\305;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\371;\200\256\344;\200\256\320;\200"
  "\256\273;\200\256\246;\200\256\221;\200\256};\200\256h;\200\256S;\200"
  "\256>;\200\256*;\200\256\25;\200\256\3\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\17;\200"
  "\256$;\200\2568;\200\256M;\200\256b;\200\256w;\200\256\213;\200\256\240"
  ";\200\256\265;\200\256\312;\200\256\336;\200\256\363;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\347\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\33\212\212\212\377\212\212\212\377\212\212\212\377\360"
  "\360\360\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374"
  "\374\377\371\371\371\377\367\367\367\377\364\364\364\377\361\361\361"
  "\377\356\356\356\377\353\353\353\377\350\350\350\377\345\345\345\377"
  "\343\343\343\377\340\340\340\377\335\335\335\377\332\332\332\377\327"
  "\327\327\377\324\324\324\377\322\322\322\377\317\317\317\377\314\314"
  "\314\377\311\311\311\377\306\306\306\377\303\303\303\377\301\301\301"
  "\377\276\276\276\377\273\273\273\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265"
  "\265\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263"
  "\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377"
  "\260\260\260\377\260\260\260\377\310\310\310\377\377\377\377\377\271"
  "\271\271\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255"
  "\255\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253\253"
  "\377\252\252\252\377\252\252\252\377\252\252\252\377\251\251\251\377"
  "\251\251\251\377\250\250\250\377\250\250\250\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\246\246\246\377\246\246\246\377\245\245"
  "\245\377\245\245\245\377\244\244\244\377\244\244\244\377\244\244\244"
  "\377\243\243\243\377\321\321\321\377\371\371\371\377\242\242\242\377"
  "\242\242\242\377\241\241\241\377\241\241\241\377\241\241\241\377\241"
  "\241\241\377\240\240\240\377\240\240\240\377\240\240\240\377\240\240"
  "\240\377\237\237\237\377\237\237\237\377\237\237\237\377\237\237\237"
  "\377\237\237\237\377\237\237\237\377\237\237\237\377\237\237\237\377"
  "\240\240\240\377\240\240\240\377\240\240\240\377\240\240\240\377\240"
  "\240\240\377\241\241\241\377\241\241\241\377\241\241\241\377\242\242"
  "\242\377\342\342\342\377\350\350\350\377\243\243\243\377\243\243\243"
  "\377\244\244\244\377\244\244\244\377\244\244\244\377\245\245\245\377"
  "\245\245\245\377\246\246\246\377\246\246\246\377\246\246\246\377\247"
  "\247\247\377\247\247\247\377\250\250\250\377\250\250\250\377\251\251"
  "\251\377\251\251\251\377\251\251\251\377\252\252\252\377\252\252\252"
  "\377\253\253\253\377\253\253\253\377\254\254\254\377\254\254\254\377"
  "\255\255\255\377\255\255\255\377\256\256\256\377\256\256\256\377\365"
  "\365\365\377\334\334\334\377\257\257\257\377\260\260\260\377\260\260"
  "\260\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\272\272\272\377\275\275\275"
  "\377\300\300\300\377\303\303\303\377\306\306\306\377\310\310\310\377"
  "\313\313\313\377\316\316\316\377\321\321\321\377\324\324\324\377\327"
  "\327\327\377\331\331\331\377\334\334\334\377\337\337\337\377\342\342"
  "\342\377\345\345\345\377\350\350\350\377\353\353\353\377\355\355\355"
  "\377\360\360\360\377\363\363\363\377\366\366\366\377\371\371\371\377"
  "\374\374\374\377\377\377\377\377\377\377\377\377\377\377\377\377\230"
  "\230\230\377\212\212\212\377\212\212\212\377\212\212\212[\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256]"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\343\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200"
  "\256\77\377\377\377\0;\200\2563;\200\256\357;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\324;\200\256j;\200\256\15\377\377"
  "\377\0\377\377\377\0;\200\2560;\200\256\232;\200\256\365;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\362;\200\256\335;\200\256\310;\200\256\264;\200\256"
  "\237;\200\256\212;\200\256u;\200\256a;\200\256L;\200\2567;\200\256\""
  ";\200\256\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\26;\200\256+;\200"
  "\256\77;\200\256T;\200\256i;\200\256~;\200\256\222;\200\256\247;\200"
  "\256\274;\200\256\321;\200\256\345;\200\256\372;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\315"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\363\212\212\212\377\212\212"
  "\212\377\335\335\335\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\375\375\375\377\372\372\372\377\367\367\367\377\364\364\364\377"
  "\361\361\361\377\357\357\357\377\354\354\354\377\351\351\351\377\346"
  "\346\346\377\343\343\343\377\340\340\340\377\335\335\335\377\333\333"
  "\333\377\330\330\330\377\325\325\325\377\322\322\322\377\317\317\317"
  "\377\314\314\314\377\312\312\312\377\307\307\307\377\304\304\304\377"
  "\301\301\301\377\276\276\276\377\273\273\273\377\271\271\271\377\271"
  "\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265"
  "\377\265\265\265\377\264\264\264\377\264\264\264\377\263\263\263\377"
  "\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\310\310\310\377\377\377"
  "\377\377\314\314\314\377\307\307\307\377\307\307\307\377\306\306\306"
  "\377\306\306\306\377\306\306\306\377\306\306\306\377\306\306\306\377"
  "\305\305\305\377\305\305\305\377\304\304\304\377\304\304\304\377\303"
  "\303\303\377\303\303\303\377\303\303\303\377\303\303\303\377\303\303"
  "\303\377\302\302\302\377\302\302\302\377\301\301\301\377\301\301\301"
  "\377\301\301\301\377\301\301\301\377\301\301\301\377\300\300\300\377"
  "\300\300\300\377\300\300\300\377\325\325\325\377\350\350\350\377\277"
  "\277\277\377\277\277\277\377\277\277\277\377\276\276\276\377\276\276"
  "\276\377\276\276\276\377\276\276\276\377\275\275\275\377\275\275\275"
  "\377\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377"
  "\275\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\275"
  "\275\275\377\275\275\275\377\275\275\275\377\275\275\275\377\276\276"
  "\276\377\276\276\276\377\276\276\276\377\276\276\276\377\277\277\277"
  "\377\277\277\277\377\335\335\335\377\340\340\340\377\277\277\277\377"
  "\277\277\277\377\300\300\300\377\300\300\300\377\301\301\301\377\301"
  "\301\301\377\301\301\301\377\301\301\301\377\301\301\301\377\302\302"
  "\302\377\302\302\302\377\302\302\302\377\303\303\303\377\303\303\303"
  "\377\303\303\303\377\303\303\303\377\304\304\304\377\304\304\304\377"
  "\305\305\305\377\305\305\305\377\305\305\305\377\306\306\306\377\306"
  "\306\306\377\306\306\306\377\306\306\306\377\307\307\307\377\307\307"
  "\307\377\365\365\365\377\334\334\334\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377"
  "\276\276\276\377\301\301\301\377\303\303\303\377\306\306\306\377\311"
  "\311\311\377\314\314\314\377\317\317\317\377\321\321\321\377\324\324"
  "\324\377\327\327\327\377\332\332\332\377\335\335\335\377\340\340\340"
  "\377\342\342\342\377\345\345\345\377\350\350\350\377\353\353\353\377"
  "\356\356\356\377\360\360\360\377\363\363\363\377\366\366\366\377\371"
  "\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377\372\372"
  "\372\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256S;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\346\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\366;\200"
  "\256A\377\377\377\0;\200\2561;\200\256\356;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\363;\200\256\226;\200\256,\377\377\377\0\377\377\377\0;\200\256"
  "\17;\200\256g;\200\256n;\200\256Y;\200\256E;\200\2560;\200\256\33;\200"
  "\256\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\10;\200\256\35;\200\2562;\200\256F;\200"
  "\256[;\200\256p;\200\256\205;\200\256\231;\200\256\256;\200\256\303;"
  "\200\256\330;\200\256\354;\200\256\376;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\262\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212\314\212\212\212\377"
  "\212\212\212\377\314\314\314\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\375\375\375\377\372\372\372\377\367\367\367\377\365\365"
  "\365\377\362\362\362\377\357\357\357\377\354\354\354\377\351\351\351"
  "\377\347\347\347\377\344\344\344\377\341\341\341\377\336\336\336\377"
  "\333\333\333\377\330\330\330\377\326\326\326\377\323\323\323\377\320"
  "\320\320\377\315\315\315\377\312\312\312\377\307\307\307\377\305\305"
  "\305\377\302\302\302\377\277\277\277\377\274\274\274\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\265"
  "\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262"
  "\377\261\261\261\377\261\261\261\377\260\260\260\377\310\310\310\377"
  "\377\377\377\377\366\366\366\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\366\366\366\377\334\334\334\377\260\260\260\377\260"
  "\260\260\377\261\261\261\377\261\261\261\377\261\261\261\377\262\262"
  "\262\377\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264"
  "\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\273\273"
  "\273\377\276\276\276\377\301\301\301\377\304\304\304\377\307\307\307"
  "\377\311\311\311\377\314\314\314\377\317\317\317\377\322\322\322\377"
  "\325\325\325\377\330\330\330\377\332\332\332\377\335\335\335\377\340"
  "\340\340\377\343\343\343\377\346\346\346\377\351\351\351\377\353\353"
  "\353\377\356\356\356\377\361\361\361\377\364\364\364\377\367\367\367"
  "\377\372\372\372\377\374\374\374\377\377\377\377\377\377\377\377\377"
  "\351\351\351\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\15\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256J;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\352\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\366;\200\256"
  "C\377\377\377\0;\200\256/;\200\256\354;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\302;\200\256W;\200"
  "\256\5\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\17;\200\256$;\200\2569;\200\256M;\200\256"
  "b;\200\256w;\200\256\214;\200\256\240;\200\256\265;\200\256\312;\200"
  "\256\337;\200\256\363;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\230\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\244\212"
  "\212\212\377\212\212\212\377\272\272\272\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\376\376\376\377\373\373\373\377\370\370\370"
  "\377\365\365\365\377\362\362\362\377\357\357\357\377\355\355\355\377"
  "\352\352\352\377\347\347\347\377\344\344\344\377\341\341\341\377\336"
  "\336\336\377\334\334\334\377\331\331\331\377\326\326\326\377\323\323"
  "\323\377\320\320\320\377\315\315\315\377\313\313\313\377\310\310\310"
  "\377\305\305\305\377\302\302\302\377\277\277\277\377\275\275\275\377"
  "\272\272\272\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377"
  "\262\262\262\377\261\261\261\377\261\261\261\377\260\260\260\377\310"
  "\310\310\377\377\377\377\377\300\300\300\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\261\261\261\377\261\261\261\377\261\261\261\377\260\260\260"
  "\377\260\260\260\377\257\257\257\377\257\257\257\377\322\322\322\377"
  "\360\360\360\377\256\256\256\377\256\256\256\377\256\256\256\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\254\254\254\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\256\256\256\377\336\336\336\377\343\343\343"
  "\377\257\257\257\377\257\257\257\377\257\257\257\377\260\260\260\377"
  "\260\260\260\377\261\261\261\377\261\261\261\377\261\261\261\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\365\365\365\377\334\334\334\377\260\260"
  "\260\377\260\260\260\377\261\261\261\377\261\261\261\377\262\262\262"
  "\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266"
  "\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\274\274\274\377\277\277\277\377\302\302\302\377\304\304\304\377"
  "\307\307\307\377\312\312\312\377\315\315\315\377\320\320\320\377\323"
  "\323\323\377\325\325\325\377\330\330\330\377\333\333\333\377\336\336"
  "\336\377\341\341\341\377\343\343\343\377\346\346\346\377\351\351\351"
  "\377\354\354\354\377\357\357\357\377\362\362\362\377\364\364\364\377"
  "\367\367\367\377\372\372\372\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\327\327\327\377\212\212\212\377\212\212\212\377\212\212"
  "\212\344\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256@;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\355\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\367;\200\256"
  "E\377\377\377\0;\200\256-;\200\256\353;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\347;\200\256\233;\200\256\247;\200\256\274;\200"
  "\256\321;\200\256\346;\200\256\372;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256~\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212}\212\212\212\377\212\212\212\377\250\250\250\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373\373"
  "\373\377\370\370\370\377\366\366\366\377\363\363\363\377\360\360\360"
  "\377\355\355\355\377\352\352\352\377\350\350\350\377\345\345\345\377"
  "\342\342\342\377\337\337\337\377\334\334\334\377\331\331\331\377\327"
  "\327\327\377\324\324\324\377\321\321\321\377\316\316\316\377\313\313"
  "\313\377\311\311\311\377\306\306\306\377\303\303\303\377\300\300\300"
  "\377\275\275\275\377\273\273\273\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265"
  "\265\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263"
  "\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\310\310\310\377\377\377\377\377\271\271\271\377\257"
  "\257\257\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\254\254\254\377\254\254\254\377\253\253\253"
  "\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252\377"
  "\251\251\251\377\251\251\251\377\250\250\250\377\250\250\250\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\246\246\246\377\246\246"
  "\246\377\246\246\246\377\245\245\245\377\245\245\245\377\244\244\244"
  "\377\321\321\321\377\371\371\371\377\244\244\244\377\243\243\243\377"
  "\243\243\243\377\243\243\243\377\242\242\242\377\242\242\242\377\242"
  "\242\242\377\242\242\242\377\242\242\242\377\241\241\241\377\241\241"
  "\241\377\241\241\241\377\241\241\241\377\241\241\241\377\241\241\241"
  "\377\241\241\241\377\241\241\241\377\241\241\241\377\241\241\241\377"
  "\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242"
  "\242\242\377\243\243\243\377\243\243\243\377\243\243\243\377\342\342"
  "\342\377\350\350\350\377\244\244\244\377\244\244\244\377\245\245\245"
  "\377\245\245\245\377\245\245\245\377\246\246\246\377\246\246\246\377"
  "\247\247\247\377\247\247\247\377\247\247\247\377\250\250\250\377\250"
  "\250\250\377\251\251\251\377\251\251\251\377\251\251\251\377\252\252"
  "\252\377\252\252\252\377\253\253\253\377\253\253\253\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\255\255\255\377\255\255\255\377"
  "\256\256\256\377\256\256\256\377\257\257\257\377\365\365\365\377\334"
  "\334\334\377\260\260\260\377\260\260\260\377\261\261\261\377\261\261"
  "\261\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377"
  "\265\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\272\272\272\377\275\275\275\377\277\277\277\377\302\302\302"
  "\377\305\305\305\377\310\310\310\377\313\313\313\377\315\315\315\377"
  "\320\320\320\377\323\323\323\377\326\326\326\377\331\331\331\377\333"
  "\333\333\377\336\336\336\377\341\341\341\377\344\344\344\377\347\347"
  "\347\377\351\351\351\377\354\354\354\377\357\357\357\377\362\362\362"
  "\377\365\365\365\377\370\370\370\377\372\372\372\377\375\375\375\377"
  "\377\377\377\377\377\377\377\377\305\305\305\377\212\212\212\377\212"
  "\212\212\377\212\212\212\275\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2566;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\361\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\370"
  ";\200\256H\377\377\377\0;\200\256+;\200\256\352;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "c\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212U\212\212\212\377\212\212\212"
  "\377\225\225\225\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\374\374\374\377\371\371\371\377\366\366\366\377\363"
  "\363\363\377\360\360\360\377\356\356\356\377\353\353\353\377\350\350"
  "\350\377\345\345\345\377\342\342\342\377\340\340\340\377\335\335\335"
  "\377\332\332\332\377\327\327\327\377\324\324\324\377\321\321\321\377"
  "\317\317\317\377\314\314\314\377\311\311\311\377\306\306\306\377\303"
  "\303\303\377\301\301\301\377\276\276\276\377\273\273\273\377\271\271"
  "\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\263"
  "\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\261\261\261\377\261\261\261\377\310\310\310\377\377\377\377"
  "\377\271\271\271\377\257\257\257\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254"
  "\254\254\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252"
  "\252\377\252\252\252\377\251\251\251\377\251\251\251\377\251\251\251"
  "\377\250\250\250\377\250\250\250\377\247\247\247\377\247\247\247\377"
  "\247\247\247\377\246\246\246\377\246\246\246\377\245\245\245\377\245"
  "\245\245\377\245\245\245\377\321\321\321\377\371\371\371\377\244\244"
  "\244\377\244\244\244\377\243\243\243\377\243\243\243\377\243\243\243"
  "\377\243\243\243\377\242\242\242\377\242\242\242\377\242\242\242\377"
  "\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242"
  "\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242\242"
  "\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242"
  "\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377"
  "\244\244\244\377\342\342\342\377\350\350\350\377\244\244\244\377\245"
  "\245\245\377\245\245\245\377\245\245\245\377\246\246\246\377\246\246"
  "\246\377\247\247\247\377\247\247\247\377\247\247\247\377\250\250\250"
  "\377\250\250\250\377\250\250\250\377\251\251\251\377\251\251\251\377"
  "\252\252\252\377\252\252\252\377\252\252\252\377\253\253\253\377\253"
  "\253\253\377\254\254\254\377\254\254\254\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\256\256\256\377\256\256\256\377\257\257\257"
  "\377\365\365\365\377\334\334\334\377\260\260\260\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\273\273\273\377\275\275\275\377\300"
  "\300\300\377\303\303\303\377\306\306\306\377\311\311\311\377\313\313"
  "\313\377\316\316\316\377\321\321\321\377\324\324\324\377\326\326\326"
  "\377\331\331\331\377\334\334\334\377\337\337\337\377\342\342\342\377"
  "\345\345\345\377\347\347\347\377\352\352\352\377\355\355\355\377\360"
  "\360\360\377\363\363\363\377\365\365\365\377\370\370\370\377\373\373"
  "\373\377\376\376\376\377\377\377\377\377\377\377\377\377\263\263\263"
  "\377\212\212\212\377\212\212\212\377\212\212\212\225\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256,;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\364\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\371;\200\256J\377\377\377\0;\200\256);\200\256\350;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256G\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212-\212\212"
  "\212\377\212\212\212\377\212\212\212\377\371\371\371\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\374\374\374\377\371\371\371\377"
  "\367\367\367\377\364\364\364\377\361\361\361\377\356\356\356\377\353"
  "\353\353\377\351\351\351\377\346\346\346\377\343\343\343\377\340\340"
  "\340\377\335\335\335\377\333\333\333\377\330\330\330\377\325\325\325"
  "\377\322\322\322\377\317\317\317\377\315\315\315\377\312\312\312\377"
  "\307\307\307\377\304\304\304\377\302\302\302\377\277\277\277\377\274"
  "\274\274\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\262"
  "\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377\310\310"
  "\310\377\377\377\377\377\271\271\271\377\257\257\257\377\257\257\257"
  "\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253"
  "\253\253\377\252\252\252\377\252\252\252\377\252\252\252\377\251\251"
  "\251\377\251\251\251\377\250\250\250\377\250\250\250\377\250\250\250"
  "\377\247\247\247\377\247\247\247\377\247\247\247\377\246\246\246\377"
  "\246\246\246\377\245\245\245\377\245\245\245\377\322\322\322\377\371"
  "\371\371\377\244\244\244\377\244\244\244\377\244\244\244\377\243\243"
  "\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243"
  "\377\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377"
  "\242\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377\242"
  "\242\242\377\242\242\242\377\242\242\242\377\242\242\242\377\243\243"
  "\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243"
  "\377\244\244\244\377\244\244\244\377\342\342\342\377\350\350\350\377"
  "\245\245\245\377\245\245\245\377\245\245\245\377\246\246\246\377\246"
  "\246\246\377\246\246\246\377\247\247\247\377\247\247\247\377\250\250"
  "\250\377\250\250\250\377\250\250\250\377\251\251\251\377\261\261\261"
  "\377\274\274\274\377\260\260\260\377\252\252\252\377\253\253\253\377"
  "\253\253\253\377\254\254\254\377\254\254\254\377\254\254\254\377\255"
  "\255\255\377\255\255\255\377\256\256\256\377\256\256\256\377\257\257"
  "\257\377\257\257\257\377\365\365\365\377\334\334\334\377\260\260\260"
  "\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377"
  "\276\276\276\377\301\301\301\377\304\304\304\377\306\306\306\377\311"
  "\311\311\377\314\314\314\377\317\317\317\377\321\321\321\377\324\324"
  "\324\377\327\327\327\377\332\332\332\377\335\335\335\377\340\340\340"
  "\377\342\342\342\377\345\345\345\377\350\350\350\377\353\353\353\377"
  "\356\356\356\377\360\360\360\377\363\363\363\377\366\366\366\377\371"
  "\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\241\241\241\377\212\212\212\377\212\212\212\377\212\212\212"
  "m\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\27;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\367\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\371;\200\256L\377\377\377\0;\200\256';\200\256\347;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\37\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\10\212\212\212\374\212\212\212\377\212\212\212\377"
  "\341\341\341\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\372\372\372\377\367\367\367\377\365\365\365\377\362\362"
  "\362\377\357\357\357\377\354\354\354\377\351\351\351\377\347\347\347"
  "\377\344\344\344\377\341\341\341\377\336\336\336\377\333\333\333\377"
  "\330\330\330\377\326\326\326\377\323\323\323\377\320\320\320\377\315"
  "\315\315\377\312\312\312\377\310\310\310\377\305\305\305\377\302\302"
  "\302\377\277\277\277\377\275\275\275\377\272\272\272\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\263\263"
  "\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261"
  "\377\261\261\261\377\311\311\311\377\377\377\377\377\271\271\271\377"
  "\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252\252"
  "\377\252\252\252\377\251\251\251\377\251\251\251\377\251\251\251\377"
  "\250\250\250\377\250\250\250\377\250\250\250\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\246\246\246\377\246\246\246\377\246\246"
  "\246\377\322\322\322\377\371\371\371\377\245\245\245\377\244\244\244"
  "\377\244\244\244\377\244\244\244\377\244\244\244\377\243\243\243\377"
  "\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243"
  "\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243"
  "\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243"
  "\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377"
  "\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377\343"
  "\343\343\377\350\350\350\377\245\245\245\377\245\245\245\377\246\246"
  "\246\377\246\246\246\377\246\246\246\377\247\247\247\377\247\247\247"
  "\377\247\247\247\377\251\251\251\377\316\316\316\377\345\345\345\377"
  "\366\366\366\377\377\377\377\377\377\377\377\377\377\377\377\377\364"
  "\364\364\377\343\343\343\377\311\311\311\377\254\254\254\377\254\254"
  "\254\377\255\255\255\377\255\255\255\377\255\255\255\377\256\256\256"
  "\377\256\256\256\377\257\257\257\377\257\257\257\377\365\365\365\377"
  "\334\334\334\377\260\260\260\377\261\261\261\377\261\261\261\377\262"
  "\262\262\377\262\262\262\377\263\263\263\377\263\263\263\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265"
  "\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\274\274\274\377\277\277\277\377\302\302\302\377\304\304"
  "\304\377\307\307\307\377\312\312\312\377\315\315\315\377\317\317\317"
  "\377\322\322\322\377\325\325\325\377\330\330\330\377\333\333\333\377"
  "\335\335\335\377\340\340\340\377\343\343\343\377\346\346\346\377\351"
  "\351\351\377\353\353\353\377\356\356\356\377\361\361\361\377\364\364"
  "\364\377\367\367\367\377\371\371\371\377\374\374\374\377\377\377\377"
  "\377\377\377\377\377\373\373\373\377\215\215\215\377\212\212\212\377"
  "\212\212\212\377\212\212\212D\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256\370"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\373\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\372;\200\256O\377\377\377\0;\200\256%;\200"
  "\256\346;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\362;\200\256"
  "\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\310\212\212"
  "\212\377\212\212\212\377\303\303\303\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\375\375\375\377\373\373\373\377\370\370\370\377"
  "\365\365\365\377\362\362\362\377\357\357\357\377\355\355\355\377\352"
  "\352\352\377\347\347\347\377\344\344\344\377\342\342\342\377\337\337"
  "\337\377\334\334\334\377\331\331\331\377\326\326\326\377\324\324\324"
  "\377\321\321\321\377\316\316\316\377\313\313\313\377\311\311\311\377"
  "\306\306\306\377\303\303\303\377\300\300\300\377\276\276\276\377\273"
  "\273\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377\262"
  "\262\262\377\262\262\262\377\261\261\261\377\311\311\311\377\377\377"
  "\377\377\271\271\271\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\254\254\254\377\254\254\254\377\253\253\253\377\253"
  "\253\253\377\253\253\253\377\252\252\252\377\252\252\252\377\251\251"
  "\251\377\251\251\251\377\251\251\251\377\250\250\250\377\250\250\250"
  "\377\250\250\250\377\247\247\247\377\247\247\247\377\247\247\247\377"
  "\246\246\246\377\246\246\246\377\322\322\322\377\371\371\371\377\245"
  "\245\245\377\245\245\245\377\244\244\244\377\244\244\244\377\244\244"
  "\244\377\244\244\244\377\244\244\244\377\244\244\244\377\243\243\243"
  "\377\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377"
  "\243\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377\243"
  "\243\243\377\243\243\243\377\243\243\243\377\243\243\243\377\244\244"
  "\244\377\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244"
  "\377\245\245\245\377\343\343\343\377\350\350\350\377\246\246\246\377"
  "\246\246\246\377\246\246\246\377\246\246\246\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\267\267\267\377\355\355\355\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\350\350\350\377\265\265\265\377\255\255\255\377\255\255\255\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\257\257\257\377\257\257"
  "\257\377\365\365\365\377\334\334\334\377\261\261\261\377\261\261\261"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\264\264\264\377\264\264\264\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377\267\267"
  "\267\377\267\267\267\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\272\272\272\377\275\275\275\377\300\300\300\377"
  "\302\302\302\377\305\305\305\377\310\310\310\377\313\313\313\377\315"
  "\315\315\377\320\320\320\377\323\323\323\377\326\326\326\377\330\330"
  "\330\377\333\333\333\377\336\336\336\377\341\341\341\377\344\344\344"
  "\377\347\347\347\377\351\351\351\377\354\354\354\377\357\357\357\377"
  "\362\362\362\377\365\365\365\377\367\367\367\377\372\372\372\377\375"
  "\375\375\377\377\377\377\377\377\377\377\377\340\340\340\377\212\212"
  "\212\377\212\212\212\377\212\212\212\373\212\212\212\14\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\333;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\376\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\373;\200\256Q\377\377\377"
  "\0;\200\256#;\200\256\344;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\310\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\206\212\212\212\377\212\212\212\377\245\245\245\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373"
  "\373\373\377\371\371\371\377\366\366\366\377\363\363\363\377\360\360"
  "\360\377\356\356\356\377\353\353\353\377\350\350\350\377\345\345\345"
  "\377\342\342\342\377\340\340\340\377\335\335\335\377\332\332\332\377"
  "\327\327\327\377\324\324\324\377\322\322\322\377\317\317\317\377\314"
  "\314\314\377\311\311\311\377\307\307\307\377\304\304\304\377\301\301"
  "\301\377\276\276\276\377\274\274\274\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263"
  "\263\377\263\263\263\377\262\262\262\377\262\262\262\377\261\261\261"
  "\377\311\311\311\377\377\377\377\377\271\271\271\377\260\260\260\377"
  "\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\253\253\253\377\253\253\253\377\252\252\252"
  "\377\252\252\252\377\252\252\252\377\251\251\251\377\251\251\251\377"
  "\251\251\251\377\250\250\250\377\250\250\250\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\246\246\246\377\322\322"
  "\322\377\371\371\371\377\245\245\245\377\245\245\245\377\245\245\245"
  "\377\245\245\245\377\244\244\244\377\244\244\244\377\244\244\244\377"
  "\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377\244"
  "\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377\244\244"
  "\244\377\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244"
  "\377\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377"
  "\245\245\245\377\245\245\245\377\245\245\245\377\343\343\343\377\351"
  "\351\351\377\246\246\246\377\246\246\246\377\246\246\246\377\247\247"
  "\247\377\247\247\247\377\247\247\247\377\315\315\315\377\374\374\374"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\372\372\372\377\310\310"
  "\310\377\255\255\255\377\256\256\256\377\256\256\256\377\257\257\257"
  "\377\257\257\257\377\260\260\260\377\365\365\365\377\334\334\334\377"
  "\261\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\273\273\273\377\276"
  "\276\276\377\301\301\301\377\303\303\303\377\306\306\306\377\311\311"
  "\311\377\314\314\314\377\316\316\316\377\321\321\321\377\324\324\324"
  "\377\327\327\327\377\331\331\331\377\334\334\334\377\337\337\337\377"
  "\342\342\342\377\344\344\344\377\347\347\347\377\352\352\352\377\355"
  "\355\355\377\357\357\357\377\362\362\362\377\365\365\365\377\370\370"
  "\370\377\373\373\373\377\375\375\375\377\377\377\377\377\377\377\377"
  "\377\302\302\302\377\212\212\212\377\212\212\212\377\212\212\212\306"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\275;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\2\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256T\377"
  "\377\377\0;\200\256\";\200\256\342;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\234\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212D\212\212\212\377\212\212\212"
  "\377\214\214\214\377\371\371\371\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\374\374\374\377\371\371\371\377\366\366\366\377\364"
  "\364\364\377\361\361\361\377\356\356\356\377\353\353\353\377\351\351"
  "\351\377\346\346\346\377\343\343\343\377\340\340\340\377\336\336\336"
  "\377\333\333\333\377\330\330\330\377\325\325\325\377\323\323\323\377"
  "\320\320\320\377\315\315\315\377\312\312\312\377\310\310\310\377\305"
  "\305\305\377\302\302\302\377\277\277\277\377\275\275\275\377\272\272"
  "\272\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377\264"
  "\264\264\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\311\311\311\377\377\377\377\377\271\271\271"
  "\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257\377"
  "\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\250\250\250\377"
  "\250\250\250\377\250\250\250\377\247\247\247\377\247\247\247\377\247"
  "\247\247\377\322\322\322\377\371\371\371\377\246\246\246\377\246\246"
  "\246\377\245\245\245\377\245\245\245\377\245\245\245\377\245\245\245"
  "\377\245\245\245\377\244\244\244\377\244\244\244\377\244\244\244\377"
  "\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377\244"
  "\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377\244\244"
  "\244\377\244\244\244\377\244\244\244\377\245\245\245\377\245\245\245"
  "\377\245\245\245\377\245\245\245\377\245\245\245\377\246\246\246\377"
  "\343\343\343\377\351\351\351\377\246\246\246\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\276\276\276\377\376\376"
  "\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\374\374\374\377\272\272\272\377\256\256\256\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\260\260\260\377\365\365\365"
  "\377\335\335\335\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\263\263\263\377\263\263\263\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\274\274\274\377\277\277\277\377\301\301\301\377\304\304\304\377\307"
  "\307\307\377\312\312\312\377\314\314\314\377\317\317\317\377\322\322"
  "\322\377\324\324\324\377\327\327\327\377\332\332\332\377\335\335\335"
  "\377\340\340\340\377\342\342\342\377\345\345\345\377\350\350\350\377"
  "\353\353\353\377\356\356\356\377\360\360\360\377\363\363\363\377\366"
  "\366\366\377\371\371\371\377\373\373\373\377\376\376\376\377\377\377"
  "\377\377\377\377\377\377\244\244\244\377\212\212\212\377\212\212\212"
  "\377\212\212\212\204\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\237;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\5\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\245\377\377\377\0;\200\256\40;\200\256\341;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256q\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\11\212\212"
  "\212\371\212\212\212\377\212\212\212\377\336\336\336\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372\377"
  "\367\367\367\377\365\365\365\377\362\362\362\377\357\357\357\377\354"
  "\354\354\377\351\351\351\377\347\347\347\377\344\344\344\377\341\341"
  "\341\377\336\336\336\377\333\333\333\377\331\331\331\377\326\326\326"
  "\377\323\323\323\377\321\321\321\377\316\316\316\377\313\313\313\377"
  "\310\310\310\377\306\306\306\377\303\303\303\377\300\300\300\377\276"
  "\276\276\377\273\273\273\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263"
  "\263\263\377\262\262\262\377\262\262\262\377\311\311\311\377\377\377"
  "\377\377\272\272\272\377\260\260\260\377\260\260\260\377\257\257\257"
  "\377\257\257\257\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252"
  "\252\377\252\252\252\377\252\252\252\377\251\251\251\377\251\251\251"
  "\377\251\251\251\377\250\250\250\377\250\250\250\377\250\250\250\377"
  "\247\247\247\377\247\247\247\377\323\323\323\377\371\371\371\377\246"
  "\246\246\377\246\246\246\377\246\246\246\377\246\246\246\377\245\245"
  "\245\377\245\245\245\377\245\245\245\377\245\245\245\377\245\245\245"
  "\377\245\245\245\377\245\245\245\377\244\244\244\377\244\244\244\377"
  "\244\244\244\377\244\244\244\377\244\244\244\377\244\244\244\377\245"
  "\245\245\377\245\245\245\377\245\245\245\377\245\245\245\377\245\245"
  "\245\377\245\245\245\377\245\245\245\377\246\246\246\377\246\246\246"
  "\377\246\246\246\377\343\343\343\377\351\351\351\377\247\247\247\377"
  "\247\247\247\377\247\247\247\377\250\250\250\377\254\254\254\377\364"
  "\364\364\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\355\355\355\377\256"
  "\256\256\377\257\257\257\377\257\257\257\377\260\260\260\377\260\260"
  "\260\377\365\365\365\377\335\335\335\377\261\261\261\377\262\262\262"
  "\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\272\272\272\377\275\275\275\377\300\300\300\377\302\302\302\377"
  "\305\305\305\377\310\310\310\377\312\312\312\377\315\315\315\377\320"
  "\320\320\377\323\323\323\377\326\326\326\377\330\330\330\377\333\333"
  "\333\377\336\336\336\377\340\340\340\377\343\343\343\377\346\346\346"
  "\377\351\351\351\377\353\353\353\377\356\356\356\377\361\361\361\377"
  "\364\364\364\377\366\366\366\377\371\371\371\377\374\374\374\377\377"
  "\377\377\377\377\377\377\377\371\371\371\377\214\214\214\377\212\212"
  "\212\377\212\212\212\377\212\212\212B\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\201;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\11\377\377\377\0\377"
  "\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\365;\200\256\34;\200\256\2;\200\256\316;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256E\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212\300\212\212\212\377\212\212\212\377\300\300\300"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377"
  "\373\373\373\377\370\370\370\377\365\365\365\377\362\362\362\377\360"
  "\360\360\377\355\355\355\377\352\352\352\377\347\347\347\377\345\345"
  "\345\377\342\342\342\377\337\337\337\377\335\335\335\377\332\332\332"
  "\377\327\327\327\377\324\324\324\377\321\321\321\377\317\317\317\377"
  "\314\314\314\377\311\311\311\377\307\307\307\377\304\304\304\377\301"
  "\301\301\377\277\277\277\377\274\274\274\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267"
  "\377\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\263"
  "\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\312\312"
  "\312\377\377\377\377\377\272\272\272\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\257\257\257\377\257\257\257\377\256\256\256\377"
  "\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\250\250\250\377"
  "\250\250\250\377\250\250\250\377\247\247\247\377\323\323\323\377\371"
  "\371\371\377\247\247\247\377\246\246\246\377\246\246\246\377\246\246"
  "\246\377\246\246\246\377\246\246\246\377\245\245\245\377\245\245\245"
  "\377\245\245\245\377\245\245\245\377\245\245\245\377\245\245\245\377"
  "\245\245\245\377\245\245\245\377\245\245\245\377\245\245\245\377\245"
  "\245\245\377\245\245\245\377\245\245\245\377\245\245\245\377\245\245"
  "\245\377\245\245\245\377\246\246\246\377\246\246\246\377\246\246\246"
  "\377\246\246\246\377\246\246\246\377\343\343\343\377\351\351\351\377"
  "\247\247\247\377\247\247\247\377\250\250\250\377\250\250\250\377\333"
  "\333\333\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\324\324\324\377\257\257\257\377\257\257\257\377\260\260"
  "\260\377\260\260\260\377\365\365\365\377\335\335\335\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267"
  "\267\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\273\273\273\377\276\276\276\377\301\301\301\377"
  "\303\303\303\377\306\306\306\377\311\311\311\377\313\313\313\377\316"
  "\316\316\377\321\321\321\377\324\324\324\377\326\326\326\377\331\331"
  "\331\377\334\334\334\377\336\336\336\377\341\341\341\377\344\344\344"
  "\377\347\347\347\377\351\351\351\377\354\354\354\377\357\357\357\377"
  "\362\362\362\377\365\365\365\377\367\367\367\377\372\372\372\377\375"
  "\375\375\377\377\377\377\377\377\377\377\377\335\335\335\377\212\212"
  "\212\377\212\212\212\377\212\212\212\370\212\212\212\10\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256c;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\14"
  "\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\200\377\377\377\0;\200\256g;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\32\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\212~\212\212\212\377\212\212"
  "\212\377\242\242\242\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\376\376\376\377\374\374\374\377\371\371\371\377\366\366\366\377"
  "\363\363\363\377\360\360\360\377\356\356\356\377\353\353\353\377\350"
  "\350\350\377\345\345\345\377\343\343\343\377\340\340\340\377\335\335"
  "\335\377\333\333\333\377\330\330\330\377\325\325\325\377\323\323\323"
  "\377\320\320\320\377\315\315\315\377\312\312\312\377\310\310\310\377"
  "\305\305\305\377\302\302\302\377\277\277\277\377\275\275\275\377\272"
  "\272\272\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263\377\262"
  "\262\262\377\312\312\312\377\377\377\377\377\272\272\272\377\261\261"
  "\261\377\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257"
  "\377\257\257\257\377\256\256\256\377\256\256\256\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252"
  "\252\377\252\252\252\377\252\252\252\377\251\251\251\377\251\251\251"
  "\377\251\251\251\377\250\250\250\377\250\250\250\377\250\250\250\377"
  "\323\323\323\377\371\371\371\377\247\247\247\377\247\247\247\377\247"
  "\247\247\377\246\246\246\377\246\246\246\377\246\246\246\377\246\246"
  "\246\377\246\246\246\377\246\246\246\377\246\246\246\377\246\246\246"
  "\377\245\245\245\377\245\245\245\377\245\245\245\377\245\245\245\377"
  "\245\245\245\377\245\245\245\377\246\246\246\377\246\246\246\377\246"
  "\246\246\377\246\246\246\377\246\246\246\377\246\246\246\377\246\246"
  "\246\377\246\246\246\377\247\247\247\377\247\247\247\377\343\343\343"
  "\377\351\351\351\377\247\247\247\377\250\250\250\377\250\250\250\377"
  "\251\251\251\377\373\373\373\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\362\362\362\377\257\257\257\377\260"
  "\260\260\377\260\260\260\377\261\261\261\377\365\365\365\377\335\335"
  "\335\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\264\264\264\377\264\264\264\377\265\265\265\377"
  "\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377\267"
  "\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377\271\271"
  "\271\377\271\271\271\377\272\272\272\377\274\274\274\377\277\277\277"
  "\377\302\302\302\377\304\304\304\377\307\307\307\377\312\312\312\377"
  "\314\314\314\377\317\317\317\377\322\322\322\377\324\324\324\377\327"
  "\327\327\377\332\332\332\377\335\335\335\377\340\340\340\377\342\342"
  "\342\377\345\345\345\377\350\350\350\377\352\352\352\377\355\355\355"
  "\377\360\360\360\377\363\363\363\377\365\365\365\377\370\370\370\377"
  "\373\373\373\377\376\376\376\377\377\377\377\377\377\377\377\377\277"
  "\277\277\377\212\212\212\377\212\212\212\377\212\212\212\276\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256D;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\20\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\371;\200\256\15;\200\256\17;\200\256\354"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\355\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212<\212\212"
  "\212\377\212\212\212\377\213\213\213\377\370\370\370\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\374\374\374\377\372\372\372\377"
  "\367\367\367\377\364\364\364\377\361\361\361\377\357\357\357\377\354"
  "\354\354\377\351\351\351\377\347\347\347\377\344\344\344\377\341\341"
  "\341\377\336\336\336\377\333\333\333\377\331\331\331\377\326\326\326"
  "\377\323\323\323\377\321\321\321\377\316\316\316\377\313\313\313\377"
  "\311\311\311\377\306\306\306\377\303\303\303\377\301\301\301\377\276"
  "\276\276\377\273\273\273\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267"
  "\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\264\264\264\377\264\264\264\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\312\312\312\377\377\377\377\377\272\272"
  "\272\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\250\250\250\377"
  "\250\250\250\377\323\323\323\377\371\371\371\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247"
  "\247\377\246\246\246\377\246\246\246\377\246\246\246\377\246\246\246"
  "\377\246\246\246\377\246\246\246\377\246\246\246\377\246\246\246\377"
  "\246\246\246\377\246\246\246\377\246\246\246\377\246\246\246\377\246"
  "\246\246\377\246\246\246\377\246\246\246\377\246\246\246\377\247\247"
  "\247\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247"
  "\377\343\343\343\377\351\351\351\377\250\250\250\377\250\250\250\377"
  "\250\250\250\377\270\270\270\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\264"
  "\264\264\377\260\260\260\377\260\260\260\377\261\261\261\377\365\365"
  "\365\377\335\335\335\377\262\262\262\377\262\262\262\377\263\263\263"
  "\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\273\273\273\377\275\275\275"
  "\377\300\300\300\377\303\303\303\377\305\305\305\377\310\310\310\377"
  "\313\313\313\377\315\315\315\377\320\320\320\377\323\323\323\377\326"
  "\326\326\377\330\330\330\377\333\333\333\377\336\336\336\377\340\340"
  "\340\377\343\343\343\377\346\346\346\377\350\350\350\377\353\353\353"
  "\377\356\356\356\377\361\361\361\377\363\363\363\377\366\366\366\377"
  "\371\371\371\377\374\374\374\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\241\241\241\377\212\212\212\377\212\212\212\377\212\212"
  "\212|\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "&;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\23\377\377\377\0\377\377\377\0;\200\256H;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\274\377\377\377\0;\200\256"
  "`;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\264\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212"
  "\212\5\212\212\212\365\212\212\212\377\212\212\212\377\333\333\333\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372"
  "\372\372\377\370\370\370\377\365\365\365\377\362\362\362\377\357\357"
  "\357\377\355\355\355\377\352\352\352\377\347\347\347\377\345\345\345"
  "\377\342\342\342\377\337\337\337\377\335\335\335\377\332\332\332\377"
  "\327\327\327\377\324\324\324\377\322\322\322\377\317\317\317\377\314"
  "\314\314\377\312\312\312\377\307\307\307\377\304\304\304\377\302\302"
  "\302\377\277\277\277\377\274\274\274\377\272\272\272\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\266\266\266\377\266\266\266\377\266\266\266\377\265"
  "\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\263\263\263\377\263\263\263\377\312\312\312\377\377\377\377"
  "\377\273\273\273\377\261\261\261\377\261\261\261\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252\252\377"
  "\252\252\252\377\252\252\252\377\251\251\251\377\251\251\251\377\251"
  "\251\251\377\251\251\251\377\323\323\323\377\371\371\371\377\250\250"
  "\250\377\250\250\250\377\247\247\247\377\247\247\247\377\247\247\247"
  "\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247\377"
  "\247\247\247\377\246\246\246\377\246\246\246\377\246\246\246\377\246"
  "\246\246\377\246\246\246\377\246\246\246\377\246\246\246\377\246\246"
  "\246\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247"
  "\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247\377"
  "\250\250\250\377\344\344\344\377\351\351\351\377\250\250\250\377\251"
  "\251\251\377\251\251\251\377\312\312\312\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\303\303\303\377\260\260\260\377\261\261\261\377\261\261\261"
  "\377\365\365\365\377\335\335\335\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265"
  "\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\274\274\274\377"
  "\276\276\276\377\301\301\301\377\304\304\304\377\306\306\306\377\311"
  "\311\311\377\314\314\314\377\316\316\316\377\321\321\321\377\324\324"
  "\324\377\326\326\326\377\331\331\331\377\334\334\334\377\336\336\336"
  "\377\341\341\341\377\344\344\344\377\347\347\347\377\351\351\351\377"
  "\354\354\354\377\357\357\357\377\362\362\362\377\364\364\364\377\367"
  "\367\367\377\372\372\372\377\375\375\375\377\377\377\377\377\377\377"
  "\377\377\367\367\367\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212:\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\11;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\27\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256r\377\377\377"
  "\0;\200\256\257;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256w\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\270\212\212\212\377\212\212\212\377"
  "\267\267\267\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\373\373\373\377\371\371\371\377\366\366\366\377\363\363"
  "\363\377\360\360\360\377\356\356\356\377\353\353\353\377\350\350\350"
  "\377\346\346\346\377\343\343\343\377\340\340\340\377\336\336\336\377"
  "\333\333\333\377\330\330\330\377\326\326\326\377\323\323\323\377\320"
  "\320\320\377\315\315\315\377\313\313\313\377\310\310\310\377\305\305"
  "\305\377\303\303\303\377\300\300\300\377\276\276\276\377\273\273\273"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\263\263\263\377\263\263\263\377\312\312\312"
  "\377\377\377\377\377\273\273\273\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\260\260\260\377\260\260\260\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377\256\256"
  "\256\377\255\255\255\377\255\255\255\377\255\255\255\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\253\253\253\377\253\253\253\377"
  "\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252\377\251"
  "\251\251\377\251\251\251\377\251\251\251\377\324\324\324\377\371\371"
  "\371\377\250\250\250\377\250\250\250\377\250\250\250\377\250\250\250"
  "\377\250\250\250\377\247\247\247\377\247\247\247\377\247\247\247\377"
  "\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247\377\247"
  "\247\247\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247"
  "\247\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247"
  "\377\247\247\247\377\247\247\247\377\250\250\250\377\250\250\250\377"
  "\250\250\250\377\250\250\250\377\344\344\344\377\351\351\351\377\251"
  "\251\251\377\251\251\251\377\251\251\251\377\333\333\333\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\322\322\322\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\365\365\365\377\335\335\335\377\262\262\262\377"
  "\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\275\275\275\377\277\277\277\377\302\302\302\377\305\305\305\377\310"
  "\310\310\377\312\312\312\377\315\315\315\377\317\317\317\377\322\322"
  "\322\377\325\325\325\377\327\327\327\377\332\332\332\377\335\335\335"
  "\377\340\340\340\377\342\342\342\377\345\345\345\377\350\350\350\377"
  "\352\352\352\377\355\355\355\377\360\360\360\377\362\362\362\377\365"
  "\365\365\377\370\370\370\377\373\373\373\377\375\375\375\377\377\377"
  "\377\377\377\377\377\377\324\324\324\377\212\212\212\377\212\212\212"
  "\377\212\212\212\363\212\212\212\5\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\352;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\32\377"
  "\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256(;\200\256\11;\200\256\365;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\2569\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212i\212\212\212\377\212"
  "\212\212\377\220\220\220\377\373\373\373\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\374\374\374\377\371\371\371\377\367\367\367"
  "\377\364\364\364\377\361\361\361\377\357\357\357\377\354\354\354\377"
  "\351\351\351\377\347\347\347\377\344\344\344\377\341\341\341\377\336"
  "\336\336\377\334\334\334\377\331\331\331\377\327\327\327\377\324\324"
  "\324\377\321\321\321\377\317\317\317\377\314\314\314\377\311\311\311"
  "\377\307\307\307\377\304\304\304\377\301\301\301\377\277\277\277\377"
  "\274\274\274\377\272\272\272\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377"
  "\312\312\312\377\377\377\377\377\273\273\273\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260"
  "\260\377\257\257\257\377\257\257\257\377\257\257\257\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\254\254\254\377\254\254\254\377\254\254\254\377\253"
  "\253\253\377\253\253\253\377\253\253\253\377\252\252\252\377\252\252"
  "\252\377\252\252\252\377\252\252\252\377\251\251\251\377\324\324\324"
  "\377\371\371\371\377\251\251\251\377\251\251\251\377\250\250\250\377"
  "\250\250\250\377\250\250\250\377\250\250\250\377\250\250\250\377\250"
  "\250\250\377\250\250\250\377\247\247\247\377\247\247\247\377\247\247"
  "\247\377\247\247\247\377\247\247\247\377\247\247\247\377\247\247\247"
  "\377\247\247\247\377\247\247\247\377\247\247\247\377\250\250\250\377"
  "\250\250\250\377\250\250\250\377\250\250\250\377\250\250\250\377\250"
  "\250\250\377\250\250\250\377\251\251\251\377\344\344\344\377\351\351"
  "\351\377\251\251\251\377\251\251\251\377\252\252\252\377\325\325\325"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\314\314\314\377\261\261\261\377"
  "\261\261\261\377\262\262\262\377\365\365\365\377\335\335\335\377\263"
  "\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377\273"
  "\273\273\377\276\276\276\377\301\301\301\377\303\303\303\377\306\306"
  "\306\377\311\311\311\377\313\313\313\377\316\316\316\377\320\320\320"
  "\377\323\323\323\377\326\326\326\377\330\330\330\377\333\333\333\377"
  "\336\336\336\377\341\341\341\377\343\343\343\377\346\346\346\377\351"
  "\351\351\377\353\353\353\377\356\356\356\377\361\361\361\377\363\363"
  "\363\377\366\366\366\377\371\371\371\377\374\374\374\377\376\376\376"
  "\377\377\377\377\377\377\377\377\377\252\252\252\377\212\212\212\377"
  "\212\212\212\377\212\212\212\251\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\314;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\36\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\336\377\377\377\0;\200\256M;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\366;\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\21\212\212"
  "\212\371\212\212\212\377\212\212\212\377\327\327\327\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372\377"
  "\370\370\370\377\365\365\365\377\362\362\362\377\360\360\360\377\355"
  "\355\355\377\352\352\352\377\350\350\350\377\345\345\345\377\342\342"
  "\342\377\340\340\340\377\335\335\335\377\332\332\332\377\330\330\330"
  "\377\325\325\325\377\322\322\322\377\320\320\320\377\315\315\315\377"
  "\312\312\312\377\310\310\310\377\305\305\305\377\303\303\303\377\300"
  "\300\300\377\275\275\275\377\273\273\273\377\271\271\271\377\271\271"
  "\271\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267"
  "\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\312\312\312\377\377\377\377\377\273\273\273\377\262\262"
  "\262\377\262\262\262\377\261\261\261\377\261\261\261\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377"
  "\257\257\257\377\256\256\256\377\256\256\256\377\256\256\256\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\253\253\253\377\253\253\253\377\253\253\253"
  "\377\253\253\253\377\252\252\252\377\252\252\252\377\252\252\252\377"
  "\324\324\324\377\371\371\371\377\251\251\251\377\251\251\251\377\251"
  "\251\251\377\251\251\251\377\251\251\251\377\250\250\250\377\250\250"
  "\250\377\250\250\250\377\250\250\250\377\250\250\250\377\250\250\250"
  "\377\250\250\250\377\250\250\250\377\250\250\250\377\250\250\250\377"
  "\250\250\250\377\250\250\250\377\250\250\250\377\250\250\250\377\250"
  "\250\250\377\250\250\250\377\250\250\250\377\250\250\250\377\250\250"
  "\250\377\251\251\251\377\251\251\251\377\251\251\251\377\344\344\344"
  "\377\351\351\351\377\252\252\252\377\252\252\252\377\252\252\252\377"
  "\303\303\303\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\275\275\275\377\261"
  "\261\261\377\261\261\261\377\262\262\262\377\365\365\365\377\335\335"
  "\335\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272"
  "\272\377\275\275\275\377\277\277\277\377\302\302\302\377\305\305\305"
  "\377\307\307\307\377\312\312\312\377\314\314\314\377\317\317\317\377"
  "\322\322\322\377\324\324\324\377\327\327\327\377\332\332\332\377\334"
  "\334\334\377\337\337\337\377\342\342\342\377\344\344\344\377\347\347"
  "\347\377\351\351\351\377\354\354\354\377\357\357\357\377\362\362\362"
  "\377\364\364\364\377\367\367\367\377\372\372\372\377\375\375\375\377"
  "\377\377\377\377\377\377\377\377\363\363\363\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212K\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\256"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256!\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\224\377\377\377\0;\200\256\224;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\277\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\255\212\212\212\377\212\212\212\377\253\253\253\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374"
  "\374\374\377\371\371\371\377\366\366\366\377\363\363\363\377\361\361"
  "\361\377\356\356\356\377\353\353\353\377\351\351\351\377\346\346\346"
  "\377\343\343\343\377\341\341\341\377\336\336\336\377\333\333\333\377"
  "\331\331\331\377\326\326\326\377\323\323\323\377\321\321\321\377\316"
  "\316\316\377\314\314\314\377\311\311\311\377\306\306\306\377\304\304"
  "\304\377\301\301\301\377\277\277\277\377\274\274\274\377\272\272\272"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\312\312\312\377\377\377\377\377\274\274\274"
  "\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256"
  "\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\253\253\253\377\253\253\253\377\253\253\253\377\252\252\252\377\252"
  "\252\252\377\324\324\324\377\372\372\372\377\252\252\252\377\251\251"
  "\251\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\250\250\250\377"
  "\250\250\250\377\250\250\250\377\250\250\250\377\250\250\250\377\250"
  "\250\250\377\250\250\250\377\250\250\250\377\250\250\250\377\250\250"
  "\250\377\250\250\250\377\251\251\251\377\251\251\251\377\251\251\251"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251\377"
  "\344\344\344\377\352\352\352\377\252\252\252\377\252\252\252\377\252"
  "\252\252\377\262\262\262\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\373\373\373\377\261\261"
  "\261\377\261\261\261\377\262\262\262\377\262\262\262\377\365\365\365"
  "\377\335\335\335\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\273\273\273\377\276\276\276\377\301\301\301\377\303\303\303\377"
  "\306\306\306\377\310\310\310\377\313\313\313\377\315\315\315\377\320"
  "\320\320\377\323\323\323\377\326\326\326\377\330\330\330\377\333\333"
  "\333\377\335\335\335\377\340\340\340\377\343\343\343\377\345\345\345"
  "\377\350\350\350\377\353\353\353\377\355\355\355\377\360\360\360\377"
  "\363\363\363\377\365\365\365\377\370\370\370\377\373\373\373\377\375"
  "\375\375\377\377\377\377\377\377\377\377\377\311\311\311\377\212\212"
  "\212\377\212\212\212\377\212\212\212\350\212\212\212\4\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\220;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256$\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256X\377\377\377\0;\200\256\301;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\202\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212O\212\212\212\377\212\212\212\377\213"
  "\213\213\377\364\364\364\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\374\374\374\377\372\372\372\377\367\367\367\377\364\364\364"
  "\377\362\362\362\377\357\357\357\377\354\354\354\377\352\352\352\377"
  "\347\347\347\377\344\344\344\377\342\342\342\377\337\337\337\377\335"
  "\335\335\377\332\332\332\377\327\327\327\377\325\325\325\377\322\322"
  "\322\377\317\317\317\377\315\315\315\377\312\312\312\377\310\310\310"
  "\377\305\305\305\377\303\303\303\377\300\300\300\377\276\276\276\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\313\313\313\377\377\377\377\377"
  "\274\274\274\377\262\262\262\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\254\254\254\377\253\253\253\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\324\324\324\377\372\372\372\377\252\252\252"
  "\377\252\252\252\377\252\252\252\377\252\252\252\377\251\251\251\377"
  "\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251\377\251"
  "\251\251\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251"
  "\251\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251\377"
  "\251\251\251\377\251\251\251\377\251\251\251\377\252\252\252\377\252"
  "\252\252\377\344\344\344\377\352\352\352\377\252\252\252\377\253\253"
  "\253\377\253\253\253\377\253\253\253\377\364\364\364\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\353\353\353"
  "\377\261\261\261\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\365\365\365\377\335\335\335\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377"
  "\272\272\272\377\275\275\275\377\277\277\277\377\302\302\302\377\305"
  "\305\305\377\307\307\307\377\312\312\312\377\314\314\314\377\317\317"
  "\317\377\321\321\321\377\324\324\324\377\327\327\327\377\331\331\331"
  "\377\334\334\334\377\336\336\336\377\341\341\341\377\344\344\344\377"
  "\347\347\347\377\351\351\351\377\354\354\354\377\356\356\356\377\361"
  "\361\361\377\364\364\364\377\366\366\366\377\371\371\371\377\374\374"
  "\374\377\377\377\377\377\377\377\377\377\377\377\377\377\236\236\236"
  "\377\212\212\212\377\212\212\212\377\212\212\212\217\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256q;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256(\377\377\377\0\377\377\377\0;\200"
  "\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256(\377\377\377\0;\200\256\353;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256D\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\5\212\212\212\353\212\212"
  "\212\377\212\212\212\377\313\313\313\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\375\375\375\377\373\373\373\377\370\370\370\377"
  "\365\365\365\377\363\363\363\377\360\360\360\377\356\356\356\377\353"
  "\353\353\377\350\350\350\377\345\345\345\377\343\343\343\377\340\340"
  "\340\377\336\336\336\377\333\333\333\377\330\330\330\377\326\326\326"
  "\377\323\323\323\377\321\321\321\377\316\316\316\377\314\314\314\377"
  "\311\311\311\377\306\306\306\377\304\304\304\377\301\301\301\377\277"
  "\277\277\377\274\274\274\377\272\272\272\377\271\271\271\377\271\271"
  "\271\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\266\266\266\377\266\266\266\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\264\264\264\377\313\313\313\377\377"
  "\377\377\377\274\274\274\377\263\263\263\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\257\257\257\377"
  "\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\253\253\253\377\253\253\253\377\325\325\325\377\372\372\372\377"
  "\252\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252"
  "\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\251\251"
  "\251\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251"
  "\377\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251\377"
  "\251\251\251\377\251\251\251\377\251\251\251\377\251\251\251\377\252"
  "\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252\252"
  "\252\377\252\252\252\377\344\344\344\377\352\352\352\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\306\306\306\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377"
  "\300\300\300\377\262\262\262\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\365\365\365\377\335\335\335\377\264\264\264\377\264\264"
  "\264\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\274\274\274\377\276\276\276\377\301\301\301\377\303\303"
  "\303\377\306\306\306\377\310\310\310\377\313\313\313\377\315\315\315"
  "\377\320\320\320\377\323\323\323\377\325\325\325\377\330\330\330\377"
  "\332\332\332\377\335\335\335\377\340\340\340\377\342\342\342\377\345"
  "\345\345\377\350\350\350\377\352\352\352\377\355\355\355\377\357\357"
  "\357\377\362\362\362\377\365\365\365\377\367\367\367\377\372\372\372"
  "\377\375\375\375\377\377\377\377\377\377\377\377\377\350\350\350\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\2121\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256S;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256+\377\377\377\0\377\377\377"
  "\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\365;\200\256\2;\200\256\26;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\372;\200\256\13\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\223\212"
  "\212\212\377\212\212\212\377\240\240\240\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\374\374\374\377\371\371\371"
  "\377\366\366\366\377\364\364\364\377\361\361\361\377\357\357\357\377"
  "\354\354\354\377\351\351\351\377\347\347\347\377\344\344\344\377\341"
  "\341\341\377\337\337\337\377\334\334\334\377\332\332\332\377\327\327"
  "\327\377\324\324\324\377\322\322\322\377\317\317\317\377\315\315\315"
  "\377\312\312\312\377\310\310\310\377\305\305\305\377\303\303\303\377"
  "\300\300\300\377\276\276\276\377\273\273\273\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\313\313\313\377"
  "\377\377\377\377\274\274\274\377\263\263\263\377\263\263\263\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\257\257\257\377\257\257\257\377\257\257\257\377\256\256\256\377"
  "\256\256\256\377\256\256\256\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\254\254\254\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\254\254\254\377\325\325\325\377\372\372\372"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252\252\377"
  "\252\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252"
  "\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252\252"
  "\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\252\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377"
  "\252\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\253"
  "\253\253\377\253\253\253\377\344\344\344\377\352\352\352\377\253\253"
  "\253\377\253\253\253\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\341\341\341\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\331\331\331"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\365\365\365\377\336\336\336\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377"
  "\273\273\273\377\275\275\275\377\277\277\277\377\302\302\302\377\305"
  "\305\305\377\307\307\307\377\312\312\312\377\314\314\314\377\317\317"
  "\317\377\321\321\321\377\324\324\324\377\326\326\326\377\331\331\331"
  "\377\334\334\334\377\336\336\336\377\341\341\341\377\344\344\344\377"
  "\346\346\346\377\351\351\351\377\353\353\353\377\356\356\356\377\360"
  "\360\360\377\363\363\363\377\366\366\366\377\371\371\371\377\373\373"
  "\373\377\376\376\376\377\377\377\377\377\377\377\377\377\275\275\275"
  "\377\212\212\212\377\212\212\212\377\212\212\212\323\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\2564;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256/\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\310\377\377\377\0;\200\256A;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\274\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "5\212\212\212\377\212\212\212\377\212\212\212\377\352\352\352\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372"
  "\372\377\370\370\370\377\365\365\365\377\362\362\362\377\360\360\360"
  "\377\355\355\355\377\353\353\353\377\350\350\350\377\345\345\345\377"
  "\343\343\343\377\340\340\340\377\336\336\336\377\333\333\333\377\330"
  "\330\330\377\326\326\326\377\323\323\323\377\321\321\321\377\316\316"
  "\316\377\314\314\314\377\311\311\311\377\307\307\307\377\304\304\304"
  "\377\302\302\302\377\277\277\277\377\275\275\275\377\272\272\272\377"
  "\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\313\313\313"
  "\377\377\377\377\377\275\275\275\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\325\325\325\377\372\372"
  "\372\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\252\252\252\377"
  "\252\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252"
  "\252\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252\252"
  "\252\377\252\252\252\377\252\252\252\377\252\252\252\377\252\252\252"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377"
  "\253\253\253\377\253\253\253\377\344\344\344\377\352\352\352\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377\255\255"
  "\255\377\262\262\262\377\366\366\366\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\360\360\360\377\263\263"
  "\263\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\365\365\365\377\336\336\336\377\264\264\264\377"
  "\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272"
  "\377\274\274\274\377\277\277\277\377\301\301\301\377\303\303\303\377"
  "\306\306\306\377\311\311\311\377\313\313\313\377\315\315\315\377\320"
  "\320\320\377\323\323\323\377\325\325\325\377\330\330\330\377\332\332"
  "\332\377\335\335\335\377\340\340\340\377\342\342\342\377\345\345\345"
  "\377\347\347\347\377\352\352\352\377\354\354\354\377\357\357\357\377"
  "\362\362\362\377\364\364\364\377\367\367\367\377\372\372\372\377\374"
  "\374\374\377\377\377\377\377\377\377\377\377\375\375\375\377\224\224"
  "\224\377\212\212\212\377\212\212\212\377\212\212\212u\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\11;\200\256\373;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\2561\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\230\377\377\377\0;\200\256l;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256n\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\326\212\212\212\377\212\212\212\377\276\276\276\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374\374"
  "\374\377\371\371\371\377\366\366\366\377\363\363\363\377\361\361\361"
  "\377\356\356\356\377\354\354\354\377\351\351\351\377\347\347\347\377"
  "\344\344\344\377\341\341\341\377\337\337\337\377\334\334\334\377\332"
  "\332\332\377\327\327\327\377\325\325\325\377\322\322\322\377\320\320"
  "\320\377\315\315\315\377\312\312\312\377\310\310\310\377\306\306\306"
  "\377\303\303\303\377\301\301\301\377\276\276\276\377\274\274\274\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\265\265\265\377\314\314\314"
  "\377\377\377\377\377\275\275\275\377\264\264\264\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\261\261\261\377\261\261\261\377\261\261\261\377\260\260"
  "\260\377\260\260\260\377\260\260\260\377\257\257\257\377\257\257\257"
  "\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\254\254\254\377\325\325\325\377\372\372"
  "\372\377\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377"
  "\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377\253"
  "\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377"
  "\253\253\253\377\254\254\254\377\345\345\345\377\352\352\352\377\254"
  "\254\254\377\254\254\254\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\265\265\265\377\350\350\350\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\341\341\341\377\266\266\266\377\262\262"
  "\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\365\365\365\377\336\336\336\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\271\271\271\377\273\273\273"
  "\377\276\276\276\377\300\300\300\377\302\302\302\377\305\305\305\377"
  "\310\310\310\377\312\312\312\377\314\314\314\377\317\317\317\377\321"
  "\321\321\377\324\324\324\377\327\327\327\377\331\331\331\377\334\334"
  "\334\377\336\336\336\377\341\341\341\377\343\343\343\377\346\346\346"
  "\377\350\350\350\377\353\353\353\377\356\356\356\377\360\360\360\377"
  "\363\363\363\377\366\366\366\377\370\370\370\377\373\373\373\377\375"
  "\375\375\377\377\377\377\377\377\377\377\377\334\334\334\377\212\212"
  "\212\377\212\212\212\377\212\212\212\374\212\212\212\32\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\320;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2563\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256h\377\377\377\0;\200\256\226"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256!\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212y\212\212\212\377\212\212\212\377\220\220\220\377\367\367"
  "\367\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375"
  "\377\372\372\372\377\367\367\367\377\365\365\365\377\362\362\362\377"
  "\360\360\360\377\355\355\355\377\352\352\352\377\350\350\350\377\345"
  "\345\345\377\343\343\343\377\340\340\340\377\336\336\336\377\333\333"
  "\333\377\330\330\330\377\326\326\326\377\323\323\323\377\321\321\321"
  "\377\317\317\317\377\314\314\314\377\311\311\311\377\307\307\307\377"
  "\305\305\305\377\302\302\302\377\300\300\300\377\275\275\275\377\273"
  "\273\273\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270"
  "\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\266\266\266\377\266\266\266\377\265\265\265\377\314\314\314\377"
  "\377\377\377\377\275\275\275\377\264\264\264\377\264\264\264\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\257\257\257\377"
  "\257\257\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\326\326\326\377\372\372\372"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\253\253\253\377\253"
  "\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253"
  "\253\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253"
  "\377\253\253\253\377\253\253\253\377\253\253\253\377\253\253\253\377"
  "\253\253\253\377\254\254\254\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\254\254\254\377\345\345\345\377\352\352\352\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\317\317\317\377"
  "\373\373\373\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\367\367"
  "\367\377\311\311\311\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377"
  "\264\264\264\377\365\365\365\377\336\336\336\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377\267\267"
  "\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\271\271\271\377\271\271\271\377\272\272\272\377\275\275\275\377"
  "\277\277\277\377\302\302\302\377\304\304\304\377\306\306\306\377\311"
  "\311\311\377\313\313\313\377\316\316\316\377\320\320\320\377\323\323"
  "\323\377\325\325\325\377\330\330\330\377\332\332\332\377\335\335\335"
  "\377\340\340\340\377\342\342\342\377\345\345\345\377\347\347\347\377"
  "\352\352\352\377\354\354\354\377\357\357\357\377\362\362\362\377\364"
  "\364\364\377\367\367\367\377\371\371\371\377\374\374\374\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\246\246\246\377\212\212\212"
  "\377\212\212\212\377\212\212\212\271\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\233;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\2565\377\377\377\0\377"
  "\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\2568\377\377\377\0;\200\256\301;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\323\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212\25\212\212\212\365\212\212\212\377\212\212\212\377"
  "\305\305\305\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\373\373\373\377\371\371\371\377\366\366\366\377\363\363"
  "\363\377\361\361\361\377\356\356\356\377\354\354\354\377\351\351\351"
  "\377\347\347\347\377\344\344\344\377\341\341\341\377\337\337\337\377"
  "\334\334\334\377\332\332\332\377\327\327\327\377\325\325\325\377\322"
  "\322\322\377\320\320\320\377\315\315\315\377\313\313\313\377\311\311"
  "\311\377\306\306\306\377\304\304\304\377\301\301\301\377\277\277\277"
  "\377\274\274\274\377\272\272\272\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267"
  "\267\267\377\266\266\266\377\266\266\266\377\266\266\266\377\314\314"
  "\314\377\377\377\377\377\276\276\276\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\257\257\257\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\326\326\326\377\372"
  "\372\372\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\255\255\255\377\345\345\345\377\352\352\352\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\256\256\256\377\256"
  "\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377\257\257"
  "\257\377\264\264\264\377\306\306\306\377\326\326\326\377\346\346\346"
  "\377\361\361\361\377\344\344\344\377\325\325\325\377\305\305\305\377"
  "\264\264\264\377\262\262\262\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\366\366\366\377\336\336\336\377\265\265\265"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377"
  "\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\271"
  "\271\271\377\271\271\271\377\272\272\272\377\274\274\274\377\276\276"
  "\276\377\301\301\301\377\303\303\303\377\305\305\305\377\310\310\310"
  "\377\312\312\312\377\315\315\315\377\317\317\317\377\322\322\322\377"
  "\324\324\324\377\327\327\327\377\331\331\331\377\334\334\334\377\336"
  "\336\336\377\341\341\341\377\343\343\343\377\346\346\346\377\350\350"
  "\350\377\353\353\353\377\356\356\356\377\360\360\360\377\363\363\363"
  "\377\365\365\365\377\370\370\370\377\372\372\372\377\375\375\375\377"
  "\377\377\377\377\377\377\377\377\343\343\343\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212J\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256f;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2568\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\375;\200\256\12\377\377\377\0;\200\256"
  "\353;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\206\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\216\212\212\212\377\212\212\212"
  "\377\222\222\222\377\371\371\371\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\374\374\374\377\372\372\372\377\367\367\367\377\365"
  "\365\365\377\362\362\362\377\357\357\357\377\355\355\355\377\353\353"
  "\353\377\350\350\350\377\345\345\345\377\343\343\343\377\340\340\340"
  "\377\336\336\336\377\333\333\333\377\331\331\331\377\326\326\326\377"
  "\324\324\324\377\321\321\321\377\317\317\317\377\314\314\314\377\312"
  "\312\312\377\310\310\310\377\305\305\305\377\303\303\303\377\301\301"
  "\301\377\276\276\276\377\274\274\274\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\314"
  "\314\314\377\377\377\377\377\276\276\276\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\256\256\256\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\326\326\326\377"
  "\372\372\372\377\255\255\255\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\254\254\254\377\254\254"
  "\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254"
  "\377\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377"
  "\254\254\254\377\254\254\254\377\254\254\254\377\254\254\254\377\254"
  "\254\254\377\254\254\254\377\254\254\254\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\345\345\345\377\352\352\352"
  "\377\255\255\255\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\256\256\256\377\257\257\257\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\366\366\366\377\336\336\336\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\273\273\273\377\276\276\276\377\300"
  "\300\300\377\302\302\302\377\305\305\305\377\307\307\307\377\311\311"
  "\311\377\314\314\314\377\316\316\316\377\321\321\321\377\323\323\323"
  "\377\326\326\326\377\330\330\330\377\333\333\333\377\335\335\335\377"
  "\340\340\340\377\342\342\342\377\345\345\345\377\347\347\347\377\352"
  "\352\352\377\354\354\354\377\357\357\357\377\362\362\362\377\364\364"
  "\364\377\367\367\367\377\371\371\371\377\374\374\374\377\376\376\376"
  "\377\377\377\377\377\377\377\377\377\251\251\251\377\212\212\212\377"
  "\212\212\212\377\212\212\212\315\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2561;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256:\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\342\377\377\377\0;\200\256\26;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\2568\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\32\212\212\212\370\212\212\212\377"
  "\212\212\212\377\310\310\310\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\376\376\376\377\373\373\373\377\371\371\371\377\366\366"
  "\366\377\363\363\363\377\361\361\361\377\356\356\356\377\354\354\354"
  "\377\351\351\351\377\347\347\347\377\344\344\344\377\342\342\342\377"
  "\337\337\337\377\335\335\335\377\332\332\332\377\330\330\330\377\325"
  "\325\325\377\323\323\323\377\320\320\320\377\316\316\316\377\314\314"
  "\314\377\311\311\311\377\307\307\307\377\304\304\304\377\302\302\302"
  "\377\300\300\300\377\275\275\275\377\273\273\273\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\314\314"
  "\314\377\377\377\377\377\276\276\276\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377"
  "\256\256\256\377\256\256\256\377\256\256\256\377\326\326\326\377\372"
  "\372\372\377\256\256\256\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\345\345\345\377\352\352\352\377"
  "\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\260\260"
  "\260\377\260\260\260\377\260\260\260\377\260\260\260\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\264\264\264\377\264\264\264\377\264\264\264\377\265\265"
  "\265\377\265\265\265\377\366\366\366\377\337\337\337\377\266\266\266"
  "\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\272\272\272\377\275\275\275\377\277\277\277\377\301\301"
  "\301\377\304\304\304\377\306\306\306\377\311\311\311\377\313\313\313"
  "\377\315\315\315\377\320\320\320\377\322\322\322\377\325\325\325\377"
  "\327\327\327\377\332\332\332\377\334\334\334\377\337\337\337\377\341"
  "\341\341\377\344\344\344\377\346\346\346\377\351\351\351\377\353\353"
  "\353\377\356\356\356\377\360\360\360\377\363\363\363\377\365\365\365"
  "\377\370\370\370\377\372\372\372\377\375\375\375\377\377\377\377\377"
  "\377\377\377\377\345\345\345\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212R\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\367;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256<\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\301\377\377\377\0;\200\256A;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\351;\200\256\2\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\227\212\212\212\377\212\212"
  "\212\377\224\224\224\377\372\372\372\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\374\374\374\377\372\372\372\377\367\367\367\377"
  "\365\365\365\377\362\362\362\377\360\360\360\377\355\355\355\377\353"
  "\353\353\377\350\350\350\377\346\346\346\377\343\343\343\377\341\341"
  "\341\377\336\336\336\377\334\334\334\377\331\331\331\377\327\327\327"
  "\377\324\324\324\377\322\322\322\377\320\320\320\377\315\315\315\377"
  "\313\313\313\377\310\310\310\377\306\306\306\377\304\304\304\377\301"
  "\301\301\377\277\277\277\377\275\275\275\377\272\272\272\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\314\314\314\377"
  "\377\377\377\377\277\277\277\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\326\326\326\377\372\372\372"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\255\255\255\377\255\255\255\377\255\255\255\377\255"
  "\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255"
  "\255\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255"
  "\377\255\255\255\377\255\255\255\377\255\255\255\377\255\255\255\377"
  "\255\255\255\377\255\255\255\377\256\256\256\377\256\256\256\377\256"
  "\256\256\377\256\256\256\377\345\345\345\377\352\352\352\377\256\256"
  "\256\377\256\256\256\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\257\257\257\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\263\263\263\377\263\263\263\377\263\263\263\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\366\366\366\377\337\337\337\377\266\266\266\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\272\272\272"
  "\377\274\274\274\377\276\276\276\377\301\301\301\377\303\303\303\377"
  "\305\305\305\377\310\310\310\377\312\312\312\377\315\315\315\377\317"
  "\317\317\377\321\321\321\377\324\324\324\377\326\326\326\377\331\331"
  "\331\377\333\333\333\377\336\336\336\377\340\340\340\377\342\342\342"
  "\377\345\345\345\377\350\350\350\377\352\352\352\377\354\354\354\377"
  "\357\357\357\377\362\362\362\377\364\364\364\377\367\367\367\377\371"
  "\371\371\377\374\374\374\377\376\376\376\377\377\377\377\377\377\377"
  "\377\377\254\254\254\377\212\212\212\377\212\212\212\377\212\212\212"
  "\325\212\212\212\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\307;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256>\377\377\377\0\377\377"
  "\377\0;\200\256H;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\241\377\377\377\0;\200\256l;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\233\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256;;\200\256\240;\200\256\344;\200\256\376;\200"
  "\256\332;\200\256J\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\40\212\212\212\373\212\212\212\377\212"
  "\212\212\377\313\313\313\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\376\376\376\377\373\373\373\377\371\371\371\377\366\366\366"
  "\377\363\363\363\377\361\361\361\377\357\357\357\377\354\354\354\377"
  "\351\351\351\377\347\347\347\377\345\345\345\377\342\342\342\377\340"
  "\340\340\377\335\335\335\377\333\333\333\377\330\330\330\377\326\326"
  "\326\377\324\324\324\377\321\321\321\377\317\317\317\377\314\314\314"
  "\377\312\312\312\377\310\310\310\377\305\305\305\377\303\303\303\377"
  "\301\301\301\377\276\276\276\377\274\274\274\377\272\272\272\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\313\313\313\377\354\354\354"
  "\377\336\336\336\377\334\334\334\377\334\334\334\377\334\334\334\377"
  "\334\334\334\377\334\334\334\377\334\334\334\377\334\334\334\377\333"
  "\333\333\377\333\333\333\377\333\333\333\377\333\333\333\377\333\333"
  "\333\377\333\333\333\377\333\333\333\377\332\332\332\377\332\332\332"
  "\377\332\332\332\377\332\332\332\377\332\332\332\377\332\332\332\377"
  "\332\332\332\377\332\332\332\377\332\332\332\377\331\331\331\377\331"
  "\331\331\377\331\331\331\377\341\341\341\377\351\351\351\377\331\331"
  "\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331"
  "\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377"
  "\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331"
  "\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331"
  "\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331"
  "\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377"
  "\331\331\331\377\345\345\345\377\346\346\346\377\331\331\331\377\331"
  "\331\331\377\331\331\331\377\331\331\331\377\332\332\332\377\332\332"
  "\332\377\332\332\332\377\332\332\332\377\332\332\332\377\332\332\332"
  "\377\332\332\332\377\332\332\332\377\332\332\332\377\333\333\333\377"
  "\333\333\333\377\333\333\333\377\333\333\333\377\333\333\333\377\333"
  "\333\333\377\333\333\333\377\334\334\334\377\334\334\334\377\334\334"
  "\334\377\334\334\334\377\334\334\334\377\334\334\334\377\334\334\334"
  "\377\366\366\366\377\337\337\337\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\271"
  "\271\271\377\271\271\271\377\272\272\272\377\274\274\274\377\276\276"
  "\276\377\300\300\300\377\302\302\302\377\305\305\305\377\307\307\307"
  "\377\311\311\311\377\314\314\314\377\316\316\316\377\321\321\321\377"
  "\323\323\323\377\325\325\325\377\330\330\330\377\332\332\332\377\335"
  "\335\335\377\337\337\337\377\341\341\341\377\344\344\344\377\347\347"
  "\347\377\351\351\351\377\353\353\353\377\356\356\356\377\360\360\360"
  "\377\363\363\363\377\365\365\365\377\370\370\370\377\372\372\372\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\350\350\350\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212[\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\222;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256@\377\377\377\0\377\377\377\0;\200\256"
  "H;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\200\377\377\377\0;\200\256\226;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256>\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256o;\200\256"
  "\374;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\366"
  ";\200\256(\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212\237\212\212\212\377\212\212\212\377\225\225\225"
  "\377\373\373\373\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\372\372\372\377\367\367\367\377\365\365\365\377\362"
  "\362\362\377\360\360\360\377\356\356\356\377\353\353\353\377\350\350"
  "\350\377\346\346\346\377\344\344\344\377\341\341\341\377\337\337\337"
  "\377\334\334\334\377\332\332\332\377\327\327\327\377\325\325\325\377"
  "\323\323\323\377\320\320\320\377\316\316\316\377\314\314\314\377\311"
  "\311\311\377\307\307\307\377\305\305\305\377\302\302\302\377\300\300"
  "\300\377\276\276\276\377\274\274\274\377\272\272\272\377\271\271\271"
  "\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\267\267\267\377\313\313\313\377\370\370\370\377\370\370\370\377\370"
  "\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370"
  "\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370"
  "\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377"
  "\370\370\370\377\370\370\370\377\370\370\370\377\367\367\367\377\367"
  "\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367"
  "\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367"
  "\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377"
  "\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367"
  "\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367"
  "\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367"
  "\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377"
  "\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367"
  "\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367"
  "\367\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367"
  "\377\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377"
  "\367\367\367\377\367\367\367\377\367\367\367\377\367\367\367\377\370"
  "\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370"
  "\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370"
  "\377\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377"
  "\370\370\370\377\370\370\370\377\370\370\370\377\361\361\361\377\333"
  "\333\333\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\273\273\273\377\276\276\276\377\300\300\300\377\302\302\302\377"
  "\304\304\304\377\306\306\306\377\311\311\311\377\313\313\313\377\315"
  "\315\315\377\320\320\320\377\322\322\322\377\324\324\324\377\327\327"
  "\327\377\331\331\331\377\334\334\334\377\336\336\336\377\341\341\341"
  "\377\343\343\343\377\345\345\345\377\350\350\350\377\352\352\352\377"
  "\355\355\355\377\357\357\357\377\362\362\362\377\364\364\364\377\367"
  "\367\367\377\371\371\371\377\374\374\374\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\260\260\260\377\212\212\212\377\212\212\212"
  "\377\212\212\212\333\212\212\212\3\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256];\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256B\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256`\377\377\377\0;\200"
  "\256\301;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\337;\200\256\1\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256J;\200\256\376;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\212\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212"
  "\212&\212\212\212\375\212\212\212\377\212\212\212\377\316\316\316\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\373"
  "\373\373\377\371\371\371\377\366\366\366\377\364\364\364\377\361\361"
  "\361\377\357\357\357\377\354\354\354\377\352\352\352\377\350\350\350"
  "\377\345\345\345\377\343\343\343\377\340\340\340\377\336\336\336\377"
  "\333\333\333\377\331\331\331\377\327\327\327\377\324\324\324\377\322"
  "\322\322\377\320\320\320\377\315\315\315\377\313\313\313\377\311\311"
  "\311\377\306\306\306\377\304\304\304\377\302\302\302\377\300\300\300"
  "\377\276\276\276\377\273\273\273\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\257\257\257\377\257\257\257\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\256\256\256"
  "\377\256\256\256\377\256\256\256\377\256\256\256\377\256\256\256\377"
  "\256\256\256\377\256\256\256\377\257\257\257\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\273\273\273\377\275\275\275\377"
  "\277\277\277\377\302\302\302\377\304\304\304\377\306\306\306\377\310"
  "\310\310\377\312\312\312\377\315\315\315\377\317\317\317\377\321\321"
  "\321\377\324\324\324\377\326\326\326\377\330\330\330\377\333\333\333"
  "\377\335\335\335\377\340\340\340\377\342\342\342\377\345\345\345\377"
  "\347\347\347\377\351\351\351\377\354\354\354\377\356\356\356\377\361"
  "\361\361\377\363\363\363\377\366\366\366\377\370\370\370\377\373\373"
  "\373\377\375\375\375\377\377\377\377\377\377\377\377\377\353\353\353"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212c\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256(;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256D\377\377\377\0\377\377"
  "\377\0;\200\256E;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\77\377\377\377\0;\200\256\346;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\202\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\22;\200\256"
  "\354;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\312\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\247"
  "\212\212\212\377\212\212\212\377\225\225\225\377\370\370\370\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\372\372"
  "\372\377\370\370\370\377\365\365\365\377\363\363\363\377\360\360\360"
  "\377\356\356\356\377\354\354\354\377\351\351\351\377\347\347\347\377"
  "\344\344\344\377\342\342\342\377\340\340\340\377\335\335\335\377\333"
  "\333\333\377\330\330\330\377\326\326\326\377\324\324\324\377\321\321"
  "\321\377\317\317\317\377\315\315\315\377\312\312\312\377\310\310\310"
  "\377\306\306\306\377\304\304\304\377\302\302\302\377\277\277\277\377"
  "\275\275\275\377\273\273\273\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377"
  "\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257"
  "\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\273\273\273\377\275\275\275\377\277\277\277\377\301\301\301\377\303"
  "\303\303\377\306\306\306\377\310\310\310\377\312\312\312\377\314\314"
  "\314\377\317\317\317\377\321\321\321\377\323\323\323\377\326\326\326"
  "\377\330\330\330\377\332\332\332\377\335\335\335\377\337\337\337\377"
  "\341\341\341\377\344\344\344\377\346\346\346\377\350\350\350\377\353"
  "\353\353\377\355\355\355\377\360\360\360\377\362\362\362\377\365\365"
  "\365\377\367\367\367\377\372\372\372\377\374\374\374\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\253\253\253\377\212\212\212\377"
  "\212\212\212\377\212\212\212\342\212\212\212\5\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256\362;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256F\377\377\377\0\377\377\377\0;\200\256"
  "9;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\36;\200\256\2;\200\256\374;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256$\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\215;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\324\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212+\212\212\212\374\212\212\212"
  "\377\212\212\212\377\274\274\274\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\376\376\376\377\374\374\374\377\371\371\371\377\367"
  "\367\367\377\364\364\364\377\362\362\362\377\357\357\357\377\355\355"
  "\355\377\353\353\353\377\350\350\350\377\346\346\346\377\344\344\344"
  "\377\341\341\341\377\337\337\337\377\335\335\335\377\332\332\332\377"
  "\330\330\330\377\326\326\326\377\323\323\323\377\321\321\321\377\317"
  "\317\317\377\314\314\314\377\312\312\312\377\310\310\310\377\306\306"
  "\306\377\303\303\303\377\301\301\301\377\277\277\277\377\275\275\275"
  "\377\273\273\273\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\257\257"
  "\257\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257"
  "\377\257\257\257\377\257\257\257\377\257\257\257\377\257\257\257\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\272\272\272\377\274\274\274\377\277\277\277"
  "\377\301\301\301\377\303\303\303\377\305\305\305\377\307\307\307\377"
  "\312\312\312\377\314\314\314\377\316\316\316\377\320\320\320\377\323"
  "\323\323\377\325\325\325\377\327\327\327\377\332\332\332\377\334\334"
  "\334\377\336\336\336\377\341\341\341\377\343\343\343\377\345\345\345"
  "\377\350\350\350\377\352\352\352\377\354\354\354\377\357\357\357\377"
  "\361\361\361\377\364\364\364\377\366\366\366\377\371\371\371\377\373"
  "\373\373\377\376\376\376\377\377\377\377\377\377\377\377\377\331\331"
  "\331\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "g\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\277;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256H\377\377\377\0\377\377\377\0;\200\256,;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\372;\200\256\3;\200\256\26;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\305\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\37"
  ";\200\256\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\335\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\220\212\212\212\377\212\212\212\377"
  "\213\213\213\377\351\351\351\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\375\375\375\377\373\373\373\377\370\370\370\377\366\366"
  "\366\377\363\363\363\377\361\361\361\377\357\357\357\377\354\354\354"
  "\377\352\352\352\377\350\350\350\377\345\345\345\377\343\343\343\377"
  "\340\340\340\377\336\336\336\377\334\334\334\377\332\332\332\377\327"
  "\327\327\377\325\325\325\377\323\323\323\377\320\320\320\377\316\316"
  "\316\377\314\314\314\377\312\312\312\377\310\310\310\377\305\305\305"
  "\377\303\303\303\377\301\301\301\377\277\277\277\377\275\275\275\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377"
  "\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272"
  "\377\274\274\274\377\276\276\276\377\301\301\301\377\303\303\303\377"
  "\305\305\305\377\307\307\307\377\311\311\311\377\313\313\313\377\316"
  "\316\316\377\320\320\320\377\322\322\322\377\324\324\324\377\327\327"
  "\327\377\331\331\331\377\333\333\333\377\336\336\336\377\340\340\340"
  "\377\342\342\342\377\345\345\345\377\347\347\347\377\351\351\351\377"
  "\354\354\354\377\356\356\356\377\360\360\360\377\363\363\363\377\365"
  "\365\365\377\370\370\370\377\372\372\372\377\375\375\375\377\377\377"
  "\377\377\377\377\377\377\372\372\372\377\227\227\227\377\212\212\212"
  "\377\212\212\212\377\212\212\212\315\212\212\212\2\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\212;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256K\377\377\377\0\377"
  "\377\377\0;\200\256\37;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\335\377\377\377\0;\200\256.;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256g\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\243;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\347\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\16\212\212\212\347\212\212\212\377\212\212\212\377\244\244\244"
  "\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\374\374\374\377\372\372\372\377\367\367\367\377\365\365\365\377\363"
  "\363\363\377\360\360\360\377\356\356\356\377\353\353\353\377\351\351"
  "\351\377\347\347\347\377\344\344\344\377\342\342\342\377\340\340\340"
  "\377\336\336\336\377\333\333\333\377\331\331\331\377\327\327\327\377"
  "\324\324\324\377\322\322\322\377\320\320\320\377\316\316\316\377\314"
  "\314\314\377\311\311\311\377\307\307\307\377\305\305\305\377\303\303"
  "\303\377\301\301\301\377\277\277\277\377\275\275\275\377\273\273\273"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\260"
  "\260\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260"
  "\260\377\260\260\260\377\260\260\260\377\260\260\260\377\260\260\260"
  "\377\260\260\260\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\272\272\272\377\274\274\274\377\276\276\276\377\301\301"
  "\301\377\302\302\302\377\305\305\305\377\307\307\307\377\311\311\311"
  "\377\313\313\313\377\315\315\315\377\317\317\317\377\322\322\322\377"
  "\324\324\324\377\326\326\326\377\330\330\330\377\333\333\333\377\335"
  "\335\335\377\337\337\337\377\342\342\342\377\344\344\344\377\346\346"
  "\346\377\351\351\351\377\353\353\353\377\355\355\355\377\360\360\360"
  "\377\362\362\362\377\365\365\365\377\367\367\367\377\371\371\371\377"
  "\374\374\374\377\376\376\376\377\377\377\377\377\377\377\377\377\301"
  "\301\301\377\212\212\212\377\212\212\212\377\212\212\212\376\212\212"
  "\2127\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256U;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256M\377\377\377\0\377\377\377\0;\200\256\23;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\277\377\377\377\0;\200"
  "\256F;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\370;\200\256\20\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2560;\200\256"
  "\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\351\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212Z\212\212\212\377\212"
  "\212\212\377\212\212\212\377\322\322\322\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\376\376\376\377\374\374\374\377\371\371\371"
  "\377\367\367\367\377\364\364\364\377\362\362\362\377\357\357\357\377"
  "\355\355\355\377\353\353\353\377\350\350\350\377\346\346\346\377\344"
  "\344\344\377\341\341\341\377\337\337\337\377\335\335\335\377\333\333"
  "\333\377\330\330\330\377\326\326\326\377\324\324\324\377\322\322\322"
  "\377\320\320\320\377\315\315\315\377\313\313\313\377\311\311\311\377"
  "\307\307\307\377\305\305\305\377\303\303\303\377\301\301\301\377\277"
  "\277\277\377\275\275\275\377\273\273\273\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261"
  "\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\272\272\272\377\274\274\274\377\276\276\276\377"
  "\300\300\300\377\302\302\302\377\305\305\305\377\306\306\306\377\311"
  "\311\311\377\313\313\313\377\315\315\315\377\317\317\317\377\321\321"
  "\321\377\323\323\323\377\326\326\326\377\330\330\330\377\332\332\332"
  "\377\334\334\334\377\337\337\337\377\341\341\341\377\343\343\343\377"
  "\345\345\345\377\350\350\350\377\352\352\352\377\354\354\354\377\357"
  "\357\357\377\361\361\361\377\364\364\364\377\366\366\366\377\370\370"
  "\370\377\373\373\373\377\375\375\375\377\377\377\377\377\377\377\377"
  "\377\355\355\355\377\214\214\214\377\212\212\212\377\212\212\212\377"
  "\212\212\212\232\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\40"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256O\377\377\377\0\377\377\377"
  "\0;\200\256\6;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\251\377\377\377\0;\200\256^;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\241\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\255;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\312\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\277\212\212\212\377\212\212\212\377\223"
  "\223\223\377\367\367\367\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\375\375\375\377\373\373\373\377\370\370\370\377\366\366\366"
  "\377\363\363\363\377\361\361\361\377\357\357\357\377\354\354\354\377"
  "\352\352\352\377\350\350\350\377\345\345\345\377\343\343\343\377\341"
  "\341\341\377\337\337\337\377\335\335\335\377\332\332\332\377\330\330"
  "\330\377\326\326\326\377\324\324\324\377\321\321\321\377\317\317\317"
  "\377\315\315\315\377\313\313\313\377\311\311\311\377\307\307\307\377"
  "\305\305\305\377\303\303\303\377\301\301\301\377\277\277\277\377\275"
  "\275\275\377\273\273\273\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\261\261\261\377\261\261\261"
  "\377\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377"
  "\261\261\261\377\261\261\261\377\261\261\261\377\261\261\261\377\261"
  "\261\261\377\261\261\261\377\261\261\261\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\273\273\273\377\274\274\274"
  "\377\276\276\276\377\301\301\301\377\302\302\302\377\305\305\305\377"
  "\306\306\306\377\311\311\311\377\313\313\313\377\315\315\315\377\317"
  "\317\317\377\321\321\321\377\323\323\323\377\325\325\325\377\327\327"
  "\327\377\332\332\332\377\334\334\334\377\336\336\336\377\340\340\340"
  "\377\343\343\343\377\345\345\345\377\347\347\347\377\351\351\351\377"
  "\354\354\354\377\356\356\356\377\360\360\360\377\363\363\363\377\365"
  "\365\365\377\367\367\367\377\372\372\372\377\374\374\374\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\251\251\251\377\212\212\212"
  "\377\212\212\212\377\212\212\212\354\212\212\212\23\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\330;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256K\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\371"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\224\377\377\377\0;\200"
  "\256v;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376"
  ";\200\256)\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256\375;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\247\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212*\212"
  "\212\212\372\212\212\212\377\212\212\212\377\272\272\272\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\374\374\374"
  "\377\372\372\372\377\367\367\367\377\365\365\365\377\363\363\363\377"
  "\360\360\360\377\356\356\356\377\354\354\354\377\351\351\351\377\347"
  "\347\347\377\345\345\345\377\343\343\343\377\341\341\341\377\336\336"
  "\336\377\334\334\334\377\332\332\332\377\330\330\330\377\326\326\326"
  "\377\323\323\323\377\321\321\321\377\317\317\317\377\315\315\315\377"
  "\313\313\313\377\311\311\311\377\307\307\307\377\305\305\305\377\303"
  "\303\303\377\301\301\301\377\277\277\277\377\275\275\275\377\273\273"
  "\273\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262"
  "\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\271\271\271\377\273\273\273"
  "\377\275\275\275\377\277\277\277\377\301\301\301\377\302\302\302\377"
  "\305\305\305\377\306\306\306\377\311\311\311\377\312\312\312\377\315"
  "\315\315\377\317\317\317\377\321\321\321\377\323\323\323\377\325\325"
  "\325\377\327\327\327\377\331\331\331\377\333\333\333\377\336\336\336"
  "\377\340\340\340\377\342\342\342\377\344\344\344\377\347\347\347\377"
  "\351\351\351\377\353\353\353\377\356\356\356\377\360\360\360\377\362"
  "\362\362\377\365\365\365\377\367\367\367\377\371\371\371\377\374\374"
  "\374\377\376\376\376\377\377\377\377\377\377\377\377\377\327\327\327"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212e\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\210;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256D\377\377\377\0\377\377\377\0"
  "\377\377\377\0;\200\256\354;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\177\377\377\377\0;\200\256\216;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\255\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\224;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\203\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\212\212\212\212\212\377\212"
  "\212\212\377\212\212\212\377\346\346\346\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\376\376\376\377\374\374\374\377\371\371\371"
  "\377\367\367\367\377\365\365\365\377\362\362\362\377\360\360\360\377"
  "\356\356\356\377\353\353\353\377\351\351\351\377\347\347\347\377\345"
  "\345\345\377\342\342\342\377\340\340\340\377\336\336\336\377\334\334"
  "\334\377\332\332\332\377\327\327\327\377\325\325\325\377\323\323\323"
  "\377\321\321\321\377\317\317\317\377\315\315\315\377\313\313\313\377"
  "\311\311\311\377\307\307\307\377\305\305\305\377\303\303\303\377\301"
  "\301\301\377\277\277\277\377\275\275\275\377\274\274\274\377\272\272"
  "\272\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\262\262\262\377\262\262\262\377\262\262\262"
  "\377\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377"
  "\262\262\262\377\262\262\262\377\262\262\262\377\262\262\262\377\262"
  "\262\262\377\262\262\262\377\262\262\262\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\273\273\273\377\275\275\275\377\277\277\277\377\301\301\301"
  "\377\303\303\303\377\305\305\305\377\306\306\306\377\311\311\311\377"
  "\312\312\312\377\315\315\315\377\317\317\317\377\321\321\321\377\323"
  "\323\323\377\325\325\325\377\327\327\327\377\331\331\331\377\333\333"
  "\333\377\335\335\335\377\340\340\340\377\342\342\342\377\344\344\344"
  "\377\346\346\346\377\350\350\350\377\353\353\353\377\355\355\355\377"
  "\357\357\357\377\362\362\362\377\364\364\364\377\366\366\366\377\371"
  "\371\371\377\373\373\373\377\375\375\375\377\377\377\377\377\377\377"
  "\377\377\371\371\371\377\226\226\226\377\212\212\212\377\212\212\212"
  "\377\212\212\212\310\212\212\212\1\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\2568;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256>\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\337;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256k\377\377\377\0;\200\256\246;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2563\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\22;\200\256\365;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256Y\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\14\212\212\212\343\212\212\212\377\212\212\212\377\232\232\232\377\371"
  "\371\371\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375"
  "\375\377\373\373\373\377\371\371\371\377\366\366\366\377\364\364\364"
  "\377\362\362\362\377\357\357\357\377\355\355\355\377\353\353\353\377"
  "\351\351\351\377\347\347\347\377\344\344\344\377\342\342\342\377\340"
  "\340\340\377\336\336\336\377\333\333\333\377\332\332\332\377\327\327"
  "\327\377\325\325\325\377\323\323\323\377\321\321\321\377\317\317\317"
  "\377\315\315\315\377\313\313\313\377\311\311\311\377\307\307\307\377"
  "\305\305\305\377\303\303\303\377\301\301\301\377\300\300\300\377\276"
  "\276\276\377\274\274\274\377\272\272\272\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377\272"
  "\272\272\377\273\273\273\377\275\275\275\377\277\277\277\377\301\301"
  "\301\377\303\303\303\377\305\305\305\377\307\307\307\377\311\311\311"
  "\377\312\312\312\377\315\315\315\377\317\317\317\377\321\321\321\377"
  "\323\323\323\377\325\325\325\377\327\327\327\377\331\331\331\377\333"
  "\333\333\377\335\335\335\377\337\337\337\377\341\341\341\377\344\344"
  "\344\377\346\346\346\377\350\350\350\377\352\352\352\377\354\354\354"
  "\377\357\357\357\377\361\361\361\377\363\363\363\377\366\366\366\377"
  "\370\370\370\377\372\372\372\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\262\262\262\377\212\212\212\377\212\212"
  "\212\377\212\212\212\375\212\212\2122\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200"
  "\256\346;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\2567\377\377\377\0\377\377\377\0\377\377\377\0"
  ";\200\256\323;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256V\377\377"
  "\377\0;\200\256\276;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\271"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256z;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\36\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212Q\212\212\212\377\212\212\212"
  "\377\212\212\212\377\262\262\262\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\375\375\375\377\372\372\372\377\370"
  "\370\370\377\366\366\366\377\363\363\363\377\361\361\361\377\357\357"
  "\357\377\355\355\355\377\353\353\353\377\350\350\350\377\346\346\346"
  "\377\344\344\344\377\342\342\342\377\340\340\340\377\336\336\336\377"
  "\333\333\333\377\331\331\331\377\327\327\327\377\325\325\325\377\323"
  "\323\323\377\321\321\321\377\317\317\317\377\315\315\315\377\313\313"
  "\313\377\311\311\311\377\307\307\307\377\305\305\305\377\304\304\304"
  "\377\302\302\302\377\300\300\300\377\276\276\276\377\274\274\274\377"
  "\273\273\273\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\263\263\263\377"
  "\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263"
  "\263\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263"
  "\263\377\263\263\263\377\263\263\263\377\263\263\263\377\263\263\263"
  "\377\263\263\263\377\263\263\263\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\272\272\272\377\274\274\274\377\276\276\276\377\277\277\277\377"
  "\301\301\301\377\303\303\303\377\305\305\305\377\307\307\307\377\311"
  "\311\311\377\313\313\313\377\315\315\315\377\317\317\317\377\321\321"
  "\321\377\323\323\323\377\325\325\325\377\327\327\327\377\331\331\331"
  "\377\333\333\333\377\335\335\335\377\337\337\337\377\341\341\341\377"
  "\343\343\343\377\345\345\345\377\350\350\350\377\352\352\352\377\354"
  "\354\354\377\356\356\356\377\360\360\360\377\363\363\363\377\365\365"
  "\365\377\367\367\367\377\372\372\372\377\374\374\374\377\376\376\376"
  "\377\377\377\377\377\377\377\377\377\317\317\317\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\220\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\227;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\2560\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\306;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256A\377\377\377\0;\200\256\326;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\77\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200"
  "\256\347;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\342\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\226\212\212\212\377\212\212\212\377\212\212\212\377\317"
  "\317\317\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376"
  "\376\377\374\374\374\377\372\372\372\377\367\367\367\377\365\365\365"
  "\377\363\363\363\377\361\361\361\377\357\357\357\377\354\354\354\377"
  "\352\352\352\377\350\350\350\377\346\346\346\377\344\344\344\377\342"
  "\342\342\377\340\340\340\377\335\335\335\377\333\333\333\377\331\331"
  "\331\377\327\327\327\377\325\325\325\377\323\323\323\377\321\321\321"
  "\377\317\317\317\377\315\315\315\377\314\314\314\377\312\312\312\377"
  "\310\310\310\377\306\306\306\377\304\304\304\377\302\302\302\377\301"
  "\301\301\377\277\277\277\377\275\275\275\377\273\273\273\377\272\272"
  "\272\377\271\271\271\377\271\271\271\377\271\271\271\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\273\273\273\377\274\274\274\377\276\276\276\377\300"
  "\300\300\377\302\302\302\377\303\303\303\377\305\305\305\377\307\307"
  "\307\377\311\311\311\377\313\313\313\377\315\315\315\377\317\317\317"
  "\377\321\321\321\377\323\323\323\377\325\325\325\377\327\327\327\377"
  "\331\331\331\377\333\333\333\377\335\335\335\377\337\337\337\377\341"
  "\341\341\377\343\343\343\377\345\345\345\377\347\347\347\377\352\352"
  "\352\377\354\354\354\377\356\356\356\377\360\360\360\377\362\362\362"
  "\377\365\365\365\377\367\367\367\377\371\371\371\377\374\374\374\377"
  "\376\376\376\377\377\377\377\377\377\377\377\377\350\350\350\377\215"
  "\215\215\377\212\212\212\377\212\212\212\377\212\212\212\316\212\212"
  "\212\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256G;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256)\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\271;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256,\377\377\377\0;\200\256\355;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\305\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256a;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\246\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\7\212\212\212\316\212\212\212\377"
  "\212\212\212\377\215\215\215\377\350\350\350\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\374\374\374\377\371\371"
  "\371\377\367\367\367\377\365\365\365\377\363\363\363\377\360\360\360"
  "\377\356\356\356\377\354\354\354\377\352\352\352\377\350\350\350\377"
  "\346\346\346\377\344\344\344\377\341\341\341\377\340\340\340\377\335"
  "\335\335\377\333\333\333\377\331\331\331\377\327\327\327\377\325\325"
  "\325\377\323\323\323\377\321\321\321\377\320\320\320\377\316\316\316"
  "\377\314\314\314\377\312\312\312\377\310\310\310\377\306\306\306\377"
  "\305\305\305\377\303\303\303\377\301\301\301\377\277\277\277\377\276"
  "\276\276\377\274\274\274\377\272\272\272\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\264\264\264\377\264\264\264\377\264\264\264\377\264"
  "\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264"
  "\264\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264"
  "\377\264\264\264\377\264\264\264\377\264\264\264\377\264\264\264\377"
  "\264\264\264\377\264\264\264\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\272\272\272\377\274\274\274\377\275\275\275\377\277\277\277\377"
  "\301\301\301\377\302\302\302\377\304\304\304\377\306\306\306\377\310"
  "\310\310\377\311\311\311\377\313\313\313\377\315\315\315\377\317\317"
  "\317\377\321\321\321\377\323\323\323\377\325\325\325\377\327\327\327"
  "\377\331\331\331\377\333\333\333\377\335\335\335\377\337\337\337\377"
  "\341\341\341\377\343\343\343\377\345\345\345\377\347\347\347\377\351"
  "\351\351\377\354\354\354\377\356\356\356\377\360\360\360\377\362\362"
  "\362\377\364\364\364\377\366\366\366\377\371\371\371\377\373\373\373"
  "\377\375\375\375\377\377\377\377\377\377\377\377\377\371\371\371\377"
  "\232\232\232\377\212\212\212\377\212\212\212\377\212\212\212\361\212"
  "\212\212$\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\6;\200\256\361;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256#\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\254;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\30;\200\256"
  "\6;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256K\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\323;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256j\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212$\212"
  "\212\212\361\212\212\212\377\212\212\212\377\232\232\232\377\371\371"
  "\371\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375"
  "\377\373\373\373\377\371\371\371\377\367\367\367\377\365\365\365\377"
  "\362\362\362\377\360\360\360\377\356\356\356\377\354\354\354\377\352"
  "\352\352\377\350\350\350\377\345\345\345\377\344\344\344\377\341\341"
  "\341\377\337\337\337\377\335\335\335\377\333\333\333\377\331\331\331"
  "\377\327\327\327\377\326\326\326\377\324\324\324\377\322\322\322\377"
  "\320\320\320\377\316\316\316\377\314\314\314\377\312\312\312\377\311"
  "\311\311\377\307\307\307\377\305\305\305\377\303\303\303\377\302\302"
  "\302\377\300\300\300\377\276\276\276\377\275\275\275\377\273\273\273"
  "\377\272\272\272\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\265\265\265\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\273\273\273\377\274\274\274\377\276\276\276\377\277\277\277\377\301"
  "\301\301\377\303\303\303\377\305\305\305\377\306\306\306\377\310\310"
  "\310\377\312\312\312\377\314\314\314\377\315\315\315\377\317\317\317"
  "\377\321\321\321\377\323\323\323\377\325\325\325\377\327\327\327\377"
  "\331\331\331\377\333\333\333\377\335\335\335\377\337\337\337\377\341"
  "\341\341\377\343\343\343\377\345\345\345\377\347\347\347\377\351\351"
  "\351\377\353\353\353\377\356\356\356\377\360\360\360\377\362\362\362"
  "\377\364\364\364\377\366\366\366\377\370\370\370\377\372\372\372\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377\262"
  "\262\262\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212V\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\246;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\34\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\237;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376"
  ";\200\256\4;\200\256\35;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\320\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256H;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256.\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212V\212\212\212\377\212\212\212\377\212\212"
  "\212\377\262\262\262\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\375\375\375\377\373\373\373\377\371\371\371\377"
  "\366\366\366\377\364\364\364\377\362\362\362\377\360\360\360\377\356"
  "\356\356\377\354\354\354\377\351\351\351\377\350\350\350\377\345\345"
  "\345\377\344\344\344\377\341\341\341\377\340\340\340\377\335\335\335"
  "\377\333\333\333\377\332\332\332\377\330\330\330\377\326\326\326\377"
  "\324\324\324\377\322\322\322\377\320\320\320\377\316\316\316\377\315"
  "\315\315\377\313\313\313\377\311\311\311\377\307\307\307\377\306\306"
  "\306\377\304\304\304\377\302\302\302\377\301\301\301\377\277\277\277"
  "\377\276\276\276\377\274\274\274\377\273\273\273\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\265\265\265\377\265\265"
  "\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265"
  "\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377"
  "\265\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265"
  "\265\265\377\265\265\265\377\265\265\265\377\265\265\265\377\265\265"
  "\265\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\274\274\274\377\275\275\275\377\277\277\277\377\300\300\300\377\302"
  "\302\302\377\303\303\303\377\305\305\305\377\307\307\307\377\311\311"
  "\311\377\312\312\312\377\314\314\314\377\316\316\316\377\320\320\320"
  "\377\321\321\321\377\323\323\323\377\325\325\325\377\327\327\327\377"
  "\331\331\331\377\333\333\333\377\335\335\335\377\337\337\337\377\341"
  "\341\341\377\343\343\343\377\345\345\345\377\347\347\347\377\351\351"
  "\351\377\353\353\353\377\355\355\355\377\357\357\357\377\362\362\362"
  "\377\364\364\364\377\366\366\366\377\370\370\370\377\372\372\372\377"
  "\374\374\374\377\377\377\377\377\377\377\377\377\377\377\377\377\317"
  "\317\317\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\226\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256V;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\25\377\377\377\0"
  "\377\377\377\0\377\377\377\0;\200\256\222;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\356\377\377\377\0;\200\2565;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256V\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\321;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\360;\200\256\2\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\226\212\212"
  "\212\377\212\212\212\377\212\212\212\377\317\317\317\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377"
  "\372\372\372\377\370\370\370\377\366\366\366\377\364\364\364\377\362"
  "\362\362\377\360\360\360\377\356\356\356\377\354\354\354\377\351\351"
  "\351\377\350\350\350\377\345\345\345\377\344\344\344\377\341\341\341"
  "\377\340\340\340\377\336\336\336\377\334\334\334\377\332\332\332\377"
  "\330\330\330\377\326\326\326\377\324\324\324\377\322\322\322\377\321"
  "\321\321\377\317\317\317\377\315\315\315\377\313\313\313\377\312\312"
  "\312\377\310\310\310\377\306\306\306\377\305\305\305\377\303\303\303"
  "\377\302\302\302\377\300\300\300\377\277\277\277\377\275\275\275\377"
  "\274\274\274\377\272\272\272\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\272\272\272\377\273\273\273\377"
  "\275\275\275\377\276\276\276\377\300\300\300\377\301\301\301\377\303"
  "\303\303\377\304\304\304\377\306\306\306\377\310\310\310\377\311\311"
  "\311\377\313\313\313\377\315\315\315\377\316\316\316\377\320\320\320"
  "\377\322\322\322\377\324\324\324\377\326\326\326\377\327\327\327\377"
  "\331\331\331\377\333\333\333\377\335\335\335\377\337\337\337\377\341"
  "\341\341\377\343\343\343\377\345\345\345\377\347\347\347\377\351\351"
  "\351\377\353\353\353\377\355\355\355\377\357\357\357\377\361\361\361"
  "\377\363\363\363\377\366\366\366\377\370\370\370\377\372\372\372\377"
  "\374\374\374\377\376\376\376\377\377\377\377\377\377\377\377\377\350"
  "\350\350\377\215\215\215\377\212\212\212\377\212\212\212\377\212\212"
  "\212\316\212\212\212\7\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\15;\200"
  "\256\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\17\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\206;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\331\377\377\377\0;\200\256M;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\332;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256l;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\251\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\7\212\212\212\316\212\212\212\377\212\212\212\377\214\214\214\377\340"
  "\340\340\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\374\374\374\377\372\372\372\377\370\370\370\377\366\366\366"
  "\377\364\364\364\377\362\362\362\377\360\360\360\377\356\356\356\377"
  "\354\354\354\377\351\351\351\377\350\350\350\377\345\345\345\377\344"
  "\344\344\377\342\342\342\377\340\340\340\377\336\336\336\377\334\334"
  "\334\377\332\332\332\377\330\330\330\377\326\326\326\377\325\325\325"
  "\377\323\323\323\377\321\321\321\377\317\317\317\377\316\316\316\377"
  "\314\314\314\377\312\312\312\377\311\311\311\377\307\307\307\377\306"
  "\306\306\377\304\304\304\377\302\302\302\377\301\301\301\377\277\277"
  "\277\377\276\276\276\377\275\275\275\377\273\273\273\377\272\272\272"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266"
  "\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266"
  "\266\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266"
  "\377\266\266\266\377\266\266\266\377\266\266\266\377\266\266\266\377"
  "\266\266\266\377\266\266\266\377\266\266\266\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\272\272\272\377\273\273\273\377\274\274\274\377\276\276"
  "\276\377\277\277\277\377\301\301\301\377\302\302\302\377\304\304\304"
  "\377\305\305\305\377\307\307\307\377\310\310\310\377\312\312\312\377"
  "\314\314\314\377\315\315\315\377\317\317\317\377\321\321\321\377\322"
  "\322\322\377\324\324\324\377\326\326\326\377\330\330\330\377\332\332"
  "\332\377\333\333\333\377\335\335\335\377\337\337\337\377\341\341\341"
  "\377\343\343\343\377\345\345\345\377\347\347\347\377\351\351\351\377"
  "\353\353\353\377\355\355\355\377\357\357\357\377\361\361\361\377\363"
  "\363\363\377\365\365\365\377\367\367\367\377\372\372\372\377\374\374"
  "\374\377\376\376\376\377\377\377\377\377\377\377\377\377\362\362\362"
  "\377\230\230\230\377\212\212\212\377\212\212\212\377\212\212\212\361"
  "\212\212\212$\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\266;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\10\377\377\377\0\377\377\377\0\377\377\377\0;\200\256y;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\305\377\377\377\0;\200\256e;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256b\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\25;\200\256\357;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256W\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212$\212\212\212\361\212\212\212\377\212\212\212\377"
  "\217\217\217\377\350\350\350\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\376\376\376\377\374\374\374\377\372\372\372\377\370\370"
  "\370\377\366\366\366\377\364\364\364\377\362\362\362\377\360\360\360"
  "\377\356\356\356\377\354\354\354\377\352\352\352\377\350\350\350\377"
  "\346\346\346\377\344\344\344\377\342\342\342\377\340\340\340\377\336"
  "\336\336\377\334\334\334\377\332\332\332\377\331\331\331\377\327\327"
  "\327\377\325\325\325\377\323\323\323\377\322\322\322\377\320\320\320"
  "\377\316\316\316\377\315\315\315\377\313\313\313\377\311\311\311\377"
  "\310\310\310\377\306\306\306\377\305\305\305\377\303\303\303\377\302"
  "\302\302\377\301\301\301\377\277\277\277\377\276\276\276\377\275\275"
  "\275\377\273\273\273\377\272\272\272\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\273\273\273\377\274\274\274\377\276\276\276\377\277\277\277\377\300"
  "\300\300\377\302\302\302\377\303\303\303\377\305\305\305\377\306\306"
  "\306\377\310\310\310\377\311\311\311\377\313\313\313\377\314\314\314"
  "\377\316\316\316\377\320\320\320\377\321\321\321\377\323\323\323\377"
  "\325\325\325\377\326\326\326\377\330\330\330\377\332\332\332\377\334"
  "\334\334\377\336\336\336\377\340\340\340\377\341\341\341\377\343\343"
  "\343\377\345\345\345\377\347\347\347\377\351\351\351\377\353\353\353"
  "\377\355\355\355\377\357\357\357\377\361\361\361\377\363\363\363\377"
  "\365\365\365\377\367\367\367\377\371\371\371\377\374\374\374\377\376"
  "\376\376\377\377\377\377\377\377\377\377\377\367\367\367\377\236\236"
  "\236\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "V\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256e;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\1\377\377\377\0\377\377\377\0\377\377\377\0;\200\256l;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\260\377\377\377\0;\200\256};\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\342;\200"
  "\256\5\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\234;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\367;\200\256\14\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212H\212\212\212\372\212\212\212\377\212"
  "\212\212\377\224\224\224\377\356\356\356\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\376\376\376\377\374\374\374\377\372\372\372"
  "\377\370\370\370\377\366\366\366\377\364\364\364\377\362\362\362\377"
  "\360\360\360\377\356\356\356\377\354\354\354\377\352\352\352\377\350"
  "\350\350\377\346\346\346\377\344\344\344\377\342\342\342\377\340\340"
  "\340\377\336\336\336\377\335\335\335\377\333\333\333\377\331\331\331"
  "\377\327\327\327\377\326\326\326\377\324\324\324\377\322\322\322\377"
  "\321\321\321\377\317\317\317\377\315\315\315\377\314\314\314\377\312"
  "\312\312\377\311\311\311\377\310\310\310\377\306\306\306\377\305\305"
  "\305\377\303\303\303\377\302\302\302\377\301\301\301\377\277\277\277"
  "\377\276\276\276\377\275\275\275\377\274\274\274\377\272\272\272\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267"
  "\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267"
  "\267\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267"
  "\377\267\267\267\377\267\267\267\377\267\267\267\377\267\267\267\377"
  "\267\267\267\377\267\267\267\377\267\267\267\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\272\272\272\377\273\273\273\377\274\274\274\377\276"
  "\276\276\377\277\277\277\377\300\300\300\377\302\302\302\377\303\303"
  "\303\377\304\304\304\377\306\306\306\377\307\307\307\377\311\311\311"
  "\377\312\312\312\377\314\314\314\377\315\315\315\377\317\317\317\377"
  "\320\320\320\377\322\322\322\377\324\324\324\377\325\325\325\377\327"
  "\327\327\377\331\331\331\377\332\332\332\377\334\334\334\377\336\336"
  "\336\377\340\340\340\377\342\342\342\377\344\344\344\377\345\345\345"
  "\377\347\347\347\377\351\351\351\377\353\353\353\377\355\355\355\377"
  "\357\357\357\377\361\361\361\377\363\363\363\377\365\365\365\377\367"
  "\367\367\377\371\371\371\377\374\374\374\377\375\375\375\377\377\377"
  "\377\377\377\377\377\377\373\373\373\377\245\245\245\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\202\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\27;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256_;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\233\377\377\377\0;\200\256\225;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256n\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\2566;\200\256\376;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\262\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212[\212\212\212\376\212\212\212"
  "\377\212\212\212\377\231\231\231\377\364\364\364\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\376\376\376\377\374\374\374\377\372"
  "\372\372\377\370\370\370\377\366\366\366\377\364\364\364\377\362\362"
  "\362\377\360\360\360\377\356\356\356\377\354\354\354\377\352\352\352"
  "\377\350\350\350\377\346\346\346\377\344\344\344\377\342\342\342\377"
  "\341\341\341\377\337\337\337\377\335\335\335\377\333\333\333\377\332"
  "\332\332\377\330\330\330\377\326\326\326\377\325\325\325\377\323\323"
  "\323\377\321\321\321\377\320\320\320\377\316\316\316\377\315\315\315"
  "\377\313\313\313\377\312\312\312\377\311\311\311\377\307\307\307\377"
  "\306\306\306\377\304\304\304\377\303\303\303\377\302\302\302\377\301"
  "\301\301\377\277\277\277\377\276\276\276\377\275\275\275\377\274\274"
  "\274\377\273\273\273\377\272\272\272\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\272\272\272\377\273\273\273\377\274\274"
  "\274\377\275\275\275\377\276\276\276\377\277\277\277\377\300\300\300"
  "\377\302\302\302\377\303\303\303\377\304\304\304\377\305\305\305\377"
  "\307\307\307\377\310\310\310\377\312\312\312\377\313\313\313\377\314"
  "\314\314\377\316\316\316\377\320\320\320\377\321\321\321\377\323\323"
  "\323\377\324\324\324\377\326\326\326\377\330\330\330\377\331\331\331"
  "\377\333\333\333\377\335\335\335\377\336\336\336\377\340\340\340\377"
  "\342\342\342\377\344\344\344\377\346\346\346\377\350\350\350\377\351"
  "\351\351\377\353\353\353\377\355\355\355\377\357\357\357\377\361\361"
  "\361\377\363\363\363\377\365\365\365\377\367\367\367\377\371\371\371"
  "\377\373\373\373\377\375\375\375\377\377\377\377\377\377\377\377\377"
  "\375\375\375\377\255\255\255\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\231\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\261;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\352\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256G;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\206\377\377\377\0;\200\256\250;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\352;\200\256\11\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\1;\200\256\312;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256_\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212p\212\212"
  "\212\377\212\212\212\377\212\212\212\377\240\240\240\377\370\370\370"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377"
  "\374\374\374\377\372\372\372\377\370\370\370\377\366\366\366\377\364"
  "\364\364\377\362\362\362\377\360\360\360\377\356\356\356\377\354\354"
  "\354\377\352\352\352\377\350\350\350\377\347\347\347\377\345\345\345"
  "\377\343\343\343\377\341\341\341\377\340\340\340\377\336\336\336\377"
  "\334\334\334\377\332\332\332\377\331\331\331\377\327\327\327\377\326"
  "\326\326\377\324\324\324\377\322\322\322\377\321\321\321\377\317\317"
  "\317\377\316\316\316\377\314\314\314\377\313\313\313\377\312\312\312"
  "\377\310\310\310\377\307\307\307\377\306\306\306\377\304\304\304\377"
  "\303\303\303\377\302\302\302\377\301\301\301\377\300\300\300\377\277"
  "\277\277\377\276\276\276\377\274\274\274\377\274\274\274\377\273\273"
  "\273\377\272\272\272\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270"
  "\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270"
  "\377\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\270"
  "\270\270\377\270\270\270\377\270\270\270\377\270\270\270\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377"
  "\272\272\272\377\273\273\273\377\274\274\274\377\275\275\275\377\276"
  "\276\276\377\277\277\277\377\301\301\301\377\302\302\302\377\303\303"
  "\303\377\304\304\304\377\305\305\305\377\307\307\307\377\310\310\310"
  "\377\311\311\311\377\313\313\313\377\314\314\314\377\315\315\315\377"
  "\317\317\317\377\320\320\320\377\322\322\322\377\323\323\323\377\325"
  "\325\325\377\327\327\327\377\330\330\330\377\332\332\332\377\334\334"
  "\334\377\335\335\335\377\337\337\337\377\341\341\341\377\342\342\342"
  "\377\344\344\344\377\346\346\346\377\350\350\350\377\352\352\352\377"
  "\354\354\354\377\356\356\356\377\357\357\357\377\361\361\361\377\363"
  "\363\363\377\365\365\365\377\367\367\367\377\371\371\371\377\373\373"
  "\373\377\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\267\267\267\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\255\212\212\212\3\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256;;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\320\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\40;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256r\377\377\377\0;\200\256\266;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256k\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256d;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373"
  ";\200\256\22\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\207\212\212\212\377\212\212\212\377\212\212\212\377\250\250\250\377"
  "\373\373\373\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\374\374\374\377\372\372\372\377\370\370\370\377\366\366"
  "\366\377\364\364\364\377\362\362\362\377\360\360\360\377\356\356\356"
  "\377\354\354\354\377\353\353\353\377\351\351\351\377\347\347\347\377"
  "\345\345\345\377\344\344\344\377\342\342\342\377\340\340\340\377\336"
  "\336\336\377\335\335\335\377\333\333\333\377\332\332\332\377\330\330"
  "\330\377\326\326\326\377\325\325\325\377\323\323\323\377\322\322\322"
  "\377\320\320\320\377\317\317\317\377\315\315\315\377\314\314\314\377"
  "\313\313\313\377\311\311\311\377\310\310\310\377\307\307\307\377\306"
  "\306\306\377\305\305\305\377\303\303\303\377\302\302\302\377\301\301"
  "\301\377\300\300\300\377\277\277\277\377\276\276\276\377\275\275\275"
  "\377\274\274\274\377\274\274\274\377\273\273\273\377\272\272\272\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\270\270\270\377\270\270\270\377"
  "\270\270\270\377\270\270\270\377\270\270\270\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\272\272\272\377\273\273\273\377\273\273\273\377\274\274\274\377\275"
  "\275\275\377\276\276\276\377\277\277\277\377\300\300\300\377\301\301"
  "\301\377\302\302\302\377\303\303\303\377\304\304\304\377\305\305\305"
  "\377\307\307\307\377\310\310\310\377\311\311\311\377\312\312\312\377"
  "\314\314\314\377\315\315\315\377\317\317\317\377\320\320\320\377\321"
  "\321\321\377\323\323\323\377\324\324\324\377\326\326\326\377\327\327"
  "\327\377\331\331\331\377\333\333\333\377\334\334\334\377\336\336\336"
  "\377\340\340\340\377\341\341\341\377\343\343\343\377\345\345\345\377"
  "\347\347\347\377\350\350\350\377\352\352\352\377\354\354\354\377\356"
  "\356\356\377\360\360\360\377\362\362\362\377\363\363\363\377\366\366"
  "\366\377\367\367\367\377\371\371\371\377\373\373\373\377\375\375\375"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\301\301\301\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\300\212"
  "\212\212\7\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\306;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\266\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256\366;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256]\377\377\377\0;\200\256\304;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\312;\200\256\2\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\20;\200"
  "\256\352;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\266\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\236\212\212\212\377\212\212\212\377\212\212\212\377\260\260"
  "\260\377\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\376\376\376\377\374\374\374\377\372\372\372\377\370\370\370\377"
  "\366\366\366\377\364\364\364\377\362\362\362\377\360\360\360\377\357"
  "\357\357\377\355\355\355\377\353\353\353\377\351\351\351\377\350\350"
  "\350\377\346\346\346\377\344\344\344\377\342\342\342\377\341\341\341"
  "\377\337\337\337\377\335\335\335\377\334\334\334\377\332\332\332\377"
  "\331\331\331\377\327\327\327\377\326\326\326\377\324\324\324\377\323"
  "\323\323\377\321\321\321\377\320\320\320\377\317\317\317\377\315\315"
  "\315\377\314\314\314\377\313\313\313\377\312\312\312\377\310\310\310"
  "\377\307\307\307\377\306\306\306\377\305\305\305\377\304\304\304\377"
  "\303\303\303\377\302\302\302\377\301\301\301\377\300\300\300\377\277"
  "\277\277\377\276\276\276\377\276\276\276\377\275\275\275\377\274\274"
  "\274\377\273\273\273\377\273\273\273\377\272\272\272\377\272\272\272"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271"
  "\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377"
  "\271\271\271\377\271\271\271\377\271\271\271\377\272\272\272\377\272"
  "\272\272\377\273\273\273\377\273\273\273\377\274\274\274\377\275\275"
  "\275\377\275\275\275\377\276\276\276\377\277\277\277\377\300\300\300"
  "\377\301\301\301\377\302\302\302\377\303\303\303\377\304\304\304\377"
  "\305\305\305\377\306\306\306\377\307\307\307\377\310\310\310\377\311"
  "\311\311\377\312\312\312\377\314\314\314\377\315\315\315\377\316\316"
  "\316\377\320\320\320\377\321\321\321\377\323\323\323\377\324\324\324"
  "\377\325\325\325\377\327\327\327\377\330\330\330\377\332\332\332\377"
  "\333\333\333\377\335\335\335\377\337\337\337\377\340\340\340\377\342"
  "\342\342\377\344\344\344\377\345\345\345\377\347\347\347\377\351\351"
  "\351\377\353\353\353\377\354\354\354\377\356\356\356\377\360\360\360"
  "\377\362\362\362\377\364\364\364\377\366\366\366\377\367\367\367\377"
  "\372\372\372\377\374\374\374\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\314\314\314\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\320\212\212\212\16\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256P;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\235\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\321;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256H\377\377\377\0;\200\256\322;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\374;\200\2561\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\223;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256L\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\3\212"
  "\212\212\262\212\212\212\377\212\212\212\377\212\212\212\377\255\255"
  "\255\377\372\372\372\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\376\376\376\377\374\374\374\377\372\372\372\377\370\370\370\377"
  "\366\366\366\377\365\365\365\377\363\363\363\377\361\361\361\377\357"
  "\357\357\377\355\355\355\377\354\354\354\377\352\352\352\377\350\350"
  "\350\377\347\347\347\377\345\345\345\377\343\343\343\377\341\341\341"
  "\377\340\340\340\377\336\336\336\377\335\335\335\377\333\333\333\377"
  "\332\332\332\377\330\330\330\377\327\327\327\377\325\325\325\377\324"
  "\324\324\377\323\323\323\377\321\321\321\377\320\320\320\377\317\317"
  "\317\377\315\315\315\377\314\314\314\377\313\313\313\377\312\312\312"
  "\377\311\311\311\377\310\310\310\377\307\307\307\377\306\306\306\377"
  "\305\305\305\377\304\304\304\377\303\303\303\377\302\302\302\377\301"
  "\301\301\377\300\300\300\377\300\300\300\377\277\277\277\377\276\276"
  "\276\377\276\276\276\377\275\275\275\377\274\274\274\377\274\274\274"
  "\377\273\273\273\377\273\273\273\377\273\273\273\377\272\272\272\377"
  "\272\272\272\377\272\272\272\377\272\272\272\377\271\271\271\377\271"
  "\271\271\377\271\271\271\377\271\271\271\377\271\271\271\377\271\271"
  "\271\377\271\271\271\377\271\271\271\377\272\272\272\377\272\272\272"
  "\377\272\272\272\377\272\272\272\377\273\273\273\377\273\273\273\377"
  "\273\273\273\377\274\274\274\377\274\274\274\377\275\275\275\377\276"
  "\276\276\377\276\276\276\377\277\277\277\377\277\277\277\377\300\300"
  "\300\377\301\301\301\377\302\302\302\377\303\303\303\377\303\303\303"
  "\377\305\305\305\377\305\305\305\377\306\306\306\377\310\310\310\377"
  "\311\311\311\377\312\312\312\377\313\313\313\377\314\314\314\377\315"
  "\315\315\377\316\316\316\377\320\320\320\377\321\321\321\377\322\322"
  "\322\377\324\324\324\377\325\325\325\377\326\326\326\377\330\330\330"
  "\377\331\331\331\377\333\333\333\377\334\334\334\377\336\336\336\377"
  "\340\340\340\377\341\341\341\377\343\343\343\377\344\344\344\377\346"
  "\346\346\377\350\350\350\377\351\351\351\377\353\353\353\377\355\355"
  "\355\377\357\357\357\377\360\360\360\377\362\362\362\377\364\364\364"
  "\377\366\366\366\377\370\370\370\377\372\372\372\377\374\374\374\377"
  "\376\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377\306"
  "\306\306\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\335\212\212\212\30\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200"
  "\256\330;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\203\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\251;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2563\377\377\377"
  "\0;\200\256\341;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\216\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256/;\200\256\374;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\335;\200\256\2\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\11\212\212\212\303\212\212\212\377\212\212\212\377\212\212\212\377\244"
  "\244\244\377\367\367\367\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\376\376\376\377\374\374\374\377\372\372\372\377\371\371\371"
  "\377\367\367\367\377\365\365\365\377\363\363\363\377\361\361\361\377"
  "\360\360\360\377\356\356\356\377\354\354\354\377\352\352\352\377\351"
  "\351\351\377\347\347\347\377\345\345\345\377\344\344\344\377\342\342"
  "\342\377\341\341\341\377\337\337\337\377\336\336\336\377\334\334\334"
  "\377\333\333\333\377\331\331\331\377\330\330\330\377\326\326\326\377"
  "\325\325\325\377\324\324\324\377\323\323\323\377\321\321\321\377\320"
  "\320\320\377\317\317\317\377\316\316\316\377\315\315\315\377\313\313"
  "\313\377\312\312\312\377\311\311\311\377\310\310\310\377\307\307\307"
  "\377\306\306\306\377\306\306\306\377\305\305\305\377\304\304\304\377"
  "\303\303\303\377\302\302\302\377\302\302\302\377\301\301\301\377\301"
  "\301\301\377\300\300\300\377\277\277\277\377\277\277\277\377\276\276"
  "\276\377\276\276\276\377\276\276\276\377\275\275\275\377\275\275\275"
  "\377\274\274\274\377\274\274\274\377\274\274\274\377\274\274\274\377"
  "\274\274\274\377\274\274\274\377\274\274\274\377\274\274\274\377\274"
  "\274\274\377\274\274\274\377\274\274\274\377\274\274\274\377\275\275"
  "\275\377\275\275\275\377\275\275\275\377\276\276\276\377\276\276\276"
  "\377\277\277\277\377\277\277\277\377\300\300\300\377\300\300\300\377"
  "\301\301\301\377\302\302\302\377\302\302\302\377\303\303\303\377\304"
  "\304\304\377\305\305\305\377\305\305\305\377\306\306\306\377\307\307"
  "\307\377\310\310\310\377\311\311\311\377\312\312\312\377\313\313\313"
  "\377\314\314\314\377\315\315\315\377\317\317\317\377\320\320\320\377"
  "\321\321\321\377\322\322\322\377\323\323\323\377\325\325\325\377\326"
  "\326\326\377\327\327\327\377\331\331\331\377\332\332\332\377\334\334"
  "\334\377\335\335\335\377\337\337\337\377\340\340\340\377\342\342\342"
  "\377\344\344\344\377\345\345\345\377\347\347\347\377\350\350\350\377"
  "\352\352\352\377\354\354\354\377\356\356\356\377\357\357\357\377\361"
  "\361\361\377\363\363\363\377\365\365\365\377\366\366\366\377\370\370"
  "\370\377\372\372\372\377\374\374\374\377\376\376\376\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\273\273\273\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\351\212\212\212$\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256d;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256i\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\201;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\37\377\377\377\0;\200\256\357;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\342;\200\256\14\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\4;\200\256"
  "\315;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "r\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\15\212\212\212"
  "\275\212\212\212\377\212\212\212\377\212\212\212\377\235\235\235\377"
  "\362\362\362\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\375\375\375\377\373\373\373\377\371\371\371\377\367\367"
  "\367\377\365\365\365\377\364\364\364\377\362\362\362\377\360\360\360"
  "\377\356\356\356\377\355\355\355\377\353\353\353\377\351\351\351\377"
  "\350\350\350\377\346\346\346\377\345\345\345\377\343\343\343\377\342"
  "\342\342\377\340\340\340\377\337\337\337\377\335\335\335\377\334\334"
  "\334\377\332\332\332\377\331\331\331\377\330\330\330\377\326\326\326"
  "\377\325\325\325\377\324\324\324\377\323\323\323\377\321\321\321\377"
  "\320\320\320\377\317\317\317\377\316\316\316\377\315\315\315\377\314"
  "\314\314\377\313\313\313\377\312\312\312\377\311\311\311\377\310\310"
  "\310\377\310\310\310\377\307\307\307\377\306\306\306\377\305\305\305"
  "\377\305\305\305\377\304\304\304\377\303\303\303\377\303\303\303\377"
  "\302\302\302\377\302\302\302\377\301\301\301\377\301\301\301\377\300"
  "\300\300\377\300\300\300\377\300\300\300\377\277\277\277\377\277\277"
  "\277\377\277\277\277\377\277\277\277\377\277\277\277\377\277\277\277"
  "\377\277\277\277\377\277\277\277\377\277\277\277\377\277\277\277\377"
  "\277\277\277\377\277\277\277\377\300\300\300\377\300\300\300\377\300"
  "\300\300\377\301\301\301\377\301\301\301\377\302\302\302\377\302\302"
  "\302\377\302\302\302\377\303\303\303\377\304\304\304\377\304\304\304"
  "\377\305\305\305\377\306\306\306\377\306\306\306\377\307\307\307\377"
  "\310\310\310\377\311\311\311\377\312\312\312\377\313\313\313\377\314"
  "\314\314\377\315\315\315\377\316\316\316\377\317\317\317\377\320\320"
  "\320\377\321\321\321\377\322\322\322\377\324\324\324\377\325\325\325"
  "\377\326\326\326\377\327\327\327\377\331\331\331\377\332\332\332\377"
  "\333\333\333\377\335\335\335\377\336\336\336\377\340\340\340\377\341"
  "\341\341\377\343\343\343\377\344\344\344\377\346\346\346\377\347\347"
  "\347\377\351\351\351\377\353\353\353\377\354\354\354\377\356\356\356"
  "\377\360\360\360\377\362\362\362\377\363\363\363\377\365\365\365\377"
  "\367\367\367\377\371\371\371\377\372\372\372\377\374\374\374\377\376"
  "\376\376\377\377\377\377\377\377\377\377\377\374\374\374\377\261\261"
  "\261\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\341\212\212\212(\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\7;\200\256\347;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256O\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256Z;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\12\377\377\377\0;\200\256\374;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256P\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256z;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\364;\200\256\20\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\6\212\212\212\252\212\212\212\377"
  "\212\212\212\377\212\212\212\377\227\227\227\377\354\354\354\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375\375"
  "\375\377\373\373\373\377\371\371\371\377\370\370\370\377\366\366\366"
  "\377\364\364\364\377\362\362\362\377\361\361\361\377\357\357\357\377"
  "\356\356\356\377\354\354\354\377\352\352\352\377\351\351\351\377\347"
  "\347\347\377\345\345\345\377\344\344\344\377\342\342\342\377\341\341"
  "\341\377\340\340\340\377\336\336\336\377\335\335\335\377\333\333\333"
  "\377\332\332\332\377\331\331\331\377\330\330\330\377\326\326\326\377"
  "\325\325\325\377\324\324\324\377\323\323\323\377\322\322\322\377\321"
  "\321\321\377\320\320\320\377\317\317\317\377\316\316\316\377\315\315"
  "\315\377\314\314\314\377\313\313\313\377\312\312\312\377\311\311\311"
  "\377\311\311\311\377\310\310\310\377\307\307\307\377\307\307\307\377"
  "\306\306\306\377\305\305\305\377\305\305\305\377\305\305\305\377\304"
  "\304\304\377\303\303\303\377\303\303\303\377\303\303\303\377\303\303"
  "\303\377\302\302\302\377\302\302\302\377\302\302\302\377\302\302\302"
  "\377\302\302\302\377\302\302\302\377\302\302\302\377\302\302\302\377"
  "\302\302\302\377\302\302\302\377\302\302\302\377\302\302\302\377\302"
  "\302\302\377\303\303\303\377\303\303\303\377\303\303\303\377\304\304"
  "\304\377\304\304\304\377\305\305\305\377\305\305\305\377\306\306\306"
  "\377\306\306\306\377\307\307\307\377\310\310\310\377\311\311\311\377"
  "\311\311\311\377\312\312\312\377\313\313\313\377\314\314\314\377\315"
  "\315\315\377\315\315\315\377\317\317\317\377\317\317\317\377\320\320"
  "\320\377\321\321\321\377\323\323\323\377\324\324\324\377\325\325\325"
  "\377\326\326\326\377\327\327\327\377\330\330\330\377\332\332\332\377"
  "\333\333\333\377\335\335\335\377\336\336\336\377\337\337\337\377\341"
  "\341\341\377\342\342\342\377\344\344\344\377\345\345\345\377\347\347"
  "\347\377\350\350\350\377\352\352\352\377\353\353\353\377\355\355\355"
  "\377\357\357\357\377\360\360\360\377\362\362\362\377\364\364\364\377"
  "\365\365\365\377\367\367\367\377\371\371\371\377\373\373\373\377\375"
  "\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377\371\371"
  "\371\377\250\250\250\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\325\212\212\212\34\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "y;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2566\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\2562;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\365\377\377\377\0;\200\256\14;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\260\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256*;\200\256\370;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\230\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\2\212\212\212\225\212\212\212\377\212\212\212\377\212"
  "\212\212\377\222\222\222\377\345\345\345\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\375\375\375\377\374\374\374"
  "\377\372\372\372\377\370\370\370\377\366\366\366\377\365\365\365\377"
  "\363\363\363\377\362\362\362\377\360\360\360\377\356\356\356\377\355"
  "\355\355\377\353\353\353\377\351\351\351\377\350\350\350\377\347\347"
  "\347\377\345\345\345\377\344\344\344\377\342\342\342\377\341\341\341"
  "\377\340\340\340\377\336\336\336\377\335\335\335\377\333\333\333\377"
  "\332\332\332\377\331\331\331\377\330\330\330\377\327\327\327\377\326"
  "\326\326\377\324\324\324\377\323\323\323\377\322\322\322\377\321\321"
  "\321\377\320\320\320\377\320\320\320\377\317\317\317\377\316\316\316"
  "\377\315\315\315\377\314\314\314\377\314\314\314\377\313\313\313\377"
  "\312\312\312\377\311\311\311\377\311\311\311\377\310\310\310\377\310"
  "\310\310\377\307\307\307\377\307\307\307\377\306\306\306\377\306\306"
  "\306\377\306\306\306\377\305\305\305\377\305\305\305\377\305\305\305"
  "\377\305\305\305\377\305\305\305\377\305\305\305\377\305\305\305\377"
  "\305\305\305\377\305\305\305\377\305\305\305\377\305\305\305\377\305"
  "\305\305\377\305\305\305\377\305\305\305\377\306\306\306\377\306\306"
  "\306\377\306\306\306\377\307\307\307\377\307\307\307\377\310\310\310"
  "\377\310\310\310\377\311\311\311\377\311\311\311\377\312\312\312\377"
  "\312\312\312\377\313\313\313\377\314\314\314\377\315\315\315\377\316"
  "\316\316\377\317\317\317\377\317\317\317\377\320\320\320\377\321\321"
  "\321\377\322\322\322\377\323\323\323\377\324\324\324\377\325\325\325"
  "\377\326\326\326\377\330\330\330\377\331\331\331\377\332\332\332\377"
  "\333\333\333\377\335\335\335\377\336\336\336\377\337\337\337\377\340"
  "\340\340\377\342\342\342\377\343\343\343\377\345\345\345\377\346\346"
  "\346\377\350\350\350\377\351\351\351\377\353\353\353\377\354\354\354"
  "\377\356\356\356\377\357\357\357\377\361\361\361\377\363\363\363\377"
  "\364\364\364\377\366\366\366\377\370\370\370\377\371\371\371\377\373"
  "\373\373\377\375\375\375\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\364\364\364\377\240\240\240\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\305\212\212\212\21\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\20;\200\256\363;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\34\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\13;\200\256\376;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\344\377\377"
  "\377\0;\200\256\32;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\363;\200\256\35\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\3;\200\256\311;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256+\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212~\212\212\212\377\212\212\212\377\212\212\212\377\216\216"
  "\216\377\334\334\334\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\376\376\376\377\374\374\374\377\372\372\372\377"
  "\371\371\371\377\367\367\367\377\365\365\365\377\364\364\364\377\362"
  "\362\362\377\360\360\360\377\357\357\357\377\356\356\356\377\354\354"
  "\354\377\353\353\353\377\351\351\351\377\350\350\350\377\346\346\346"
  "\377\345\345\345\377\343\343\343\377\342\342\342\377\341\341\341\377"
  "\337\337\337\377\336\336\336\377\335\335\335\377\334\334\334\377\332"
  "\332\332\377\331\331\331\377\330\330\330\377\327\327\327\377\326\326"
  "\326\377\325\325\325\377\324\324\324\377\323\323\323\377\322\322\322"
  "\377\321\321\321\377\320\320\320\377\320\320\320\377\317\317\317\377"
  "\316\316\316\377\315\315\315\377\315\315\315\377\314\314\314\377\314"
  "\314\314\377\313\313\313\377\312\312\312\377\312\312\312\377\312\312"
  "\312\377\311\311\311\377\311\311\311\377\311\311\311\377\310\310\310"
  "\377\310\310\310\377\310\310\310\377\310\310\310\377\310\310\310\377"
  "\310\310\310\377\310\310\310\377\310\310\310\377\310\310\310\377\310"
  "\310\310\377\310\310\310\377\310\310\310\377\310\310\310\377\310\310"
  "\310\377\311\311\311\377\311\311\311\377\311\311\311\377\312\312\312"
  "\377\312\312\312\377\312\312\312\377\313\313\313\377\314\314\314\377"
  "\314\314\314\377\315\315\315\377\315\315\315\377\316\316\316\377\317"
  "\317\317\377\320\320\320\377\320\320\320\377\321\321\321\377\322\322"
  "\322\377\323\323\323\377\324\324\324\377\325\325\325\377\326\326\326"
  "\377\327\327\327\377\330\330\330\377\331\331\331\377\332\332\332\377"
  "\333\333\333\377\335\335\335\377\336\336\336\377\337\337\337\377\340"
  "\340\340\377\342\342\342\377\343\343\343\377\344\344\344\377\346\346"
  "\346\377\347\347\347\377\351\351\351\377\352\352\352\377\354\354\354"
  "\377\355\355\355\377\357\357\357\377\360\360\360\377\362\362\362\377"
  "\363\363\363\377\365\365\365\377\367\367\367\377\370\370\370\377\372"
  "\372\372\377\374\374\374\377\375\375\375\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\356\356\356\377\232\232\232\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\264\212\212\212\12\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\216;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256\4\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\343;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\330\377\377\377\0;\200\256(;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256r\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256u;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\276\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212g\212\212\212\375\212"
  "\212\212\377\212\212\212\377\212\212\212\377\303\303\303\377\375\375"
  "\375\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\375\375\375\377\373\373\373\377\371\371\371\377\370\370\370\377"
  "\366\366\366\377\365\365\365\377\363\363\363\377\361\361\361\377\360"
  "\360\360\377\356\356\356\377\355\355\355\377\353\353\353\377\352\352"
  "\352\377\351\351\351\377\347\347\347\377\346\346\346\377\345\345\345"
  "\377\343\343\343\377\342\342\342\377\341\341\341\377\340\340\340\377"
  "\336\336\336\377\335\335\335\377\334\334\334\377\333\333\333\377\332"
  "\332\332\377\331\331\331\377\330\330\330\377\327\327\327\377\326\326"
  "\326\377\325\325\325\377\324\324\324\377\323\323\323\377\323\323\323"
  "\377\322\322\322\377\321\321\321\377\320\320\320\377\320\320\320\377"
  "\317\317\317\377\317\317\317\377\316\316\316\377\315\315\315\377\315"
  "\315\315\377\314\314\314\377\314\314\314\377\314\314\314\377\314\314"
  "\314\377\313\313\313\377\313\313\313\377\313\313\313\377\312\312\312"
  "\377\312\312\312\377\312\312\312\377\312\312\312\377\312\312\312\377"
  "\312\312\312\377\312\312\312\377\312\312\312\377\313\313\313\377\313"
  "\313\313\377\313\313\313\377\313\313\313\377\314\314\314\377\314\314"
  "\314\377\314\314\314\377\315\315\315\377\315\315\315\377\316\316\316"
  "\377\316\316\316\377\317\317\317\377\320\320\320\377\320\320\320\377"
  "\321\321\321\377\321\321\321\377\322\322\322\377\323\323\323\377\324"
  "\324\324\377\325\325\325\377\326\326\326\377\327\327\327\377\330\330"
  "\330\377\330\330\330\377\332\332\332\377\333\333\333\377\334\334\334"
  "\377\335\335\335\377\336\336\336\377\337\337\337\377\340\340\340\377"
  "\342\342\342\377\343\343\343\377\344\344\344\377\345\345\345\377\347"
  "\347\347\377\350\350\350\377\352\352\352\377\353\353\353\377\354\354"
  "\354\377\356\356\356\377\357\357\357\377\361\361\361\377\363\363\363"
  "\377\364\364\364\377\366\366\366\377\367\367\367\377\371\371\371\377"
  "\373\373\373\377\374\374\374\377\376\376\376\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\330\330\330\377\220\220\220\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\240\212\212\212"
  "\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\35;\200\256\372;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\350\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\273;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\314\377\377\377\0;\200\256"
  "7;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\317;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256';\200\256\367;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256Q\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\212\212\212S\212\212\212\370\212\212\212\377\212\212\212\377\212"
  "\212\212\377\246\246\246\377\363\363\363\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\375\375\375\377\374\374\374"
  "\377\372\372\372\377\371\371\371\377\367\367\367\377\365\365\365\377"
  "\364\364\364\377\362\362\362\377\361\361\361\377\357\357\357\377\356"
  "\356\356\377\354\354\354\377\353\353\353\377\352\352\352\377\350\350"
  "\350\377\347\347\347\377\346\346\346\377\345\345\345\377\343\343\343"
  "\377\342\342\342\377\341\341\341\377\340\340\340\377\337\337\337\377"
  "\336\336\336\377\335\335\335\377\333\333\333\377\332\332\332\377\332"
  "\332\332\377\330\330\330\377\330\330\330\377\327\327\327\377\326\326"
  "\326\377\325\325\325\377\324\324\324\377\324\324\324\377\323\323\323"
  "\377\323\323\323\377\322\322\322\377\321\321\321\377\321\321\321\377"
  "\320\320\320\377\320\320\320\377\317\317\317\377\317\317\317\377\317"
  "\317\317\377\316\316\316\377\316\316\316\377\316\316\316\377\316\316"
  "\316\377\315\315\315\377\315\315\315\377\315\315\315\377\315\315\315"
  "\377\315\315\315\377\315\315\315\377\315\315\315\377\315\315\315\377"
  "\315\315\315\377\316\316\316\377\316\316\316\377\316\316\316\377\317"
  "\317\317\377\317\317\317\377\317\317\317\377\320\320\320\377\320\320"
  "\320\377\321\321\321\377\321\321\321\377\322\322\322\377\322\322\322"
  "\377\323\323\323\377\324\324\324\377\324\324\324\377\325\325\325\377"
  "\326\326\326\377\327\327\327\377\327\327\327\377\330\330\330\377\331"
  "\331\331\377\332\332\332\377\333\333\333\377\334\334\334\377\335\335"
  "\335\377\336\336\336\377\340\340\340\377\341\341\341\377\342\342\342"
  "\377\343\343\343\377\344\344\344\377\345\345\345\377\347\347\347\377"
  "\350\350\350\377\351\351\351\377\353\353\353\377\354\354\354\377\356"
  "\356\356\377\357\357\357\377\360\360\360\377\362\362\362\377\363\363"
  "\363\377\365\365\365\377\367\367\367\377\370\370\370\377\372\372\372"
  "\377\373\373\373\377\375\375\375\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\373\373\373\377\273\273\273\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\212\212\212"
  "\212\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\206;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\263\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\224;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\300\377\377"
  "\377\0;\200\256E;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\375;\200\2566\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256\305;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\340"
  ";\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\212\212\212<\212\212\212\345\212"
  "\212\212\377\212\212\212\377\212\212\212\377\223\223\223\377\336\336"
  "\336\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\376\376\376\377\375\375\375\377\373\373\373\377\371\371\371\377"
  "\370\370\370\377\366\366\366\377\365\365\365\377\363\363\363\377\362"
  "\362\362\377\360\360\360\377\357\357\357\377\356\356\356\377\354\354"
  "\354\377\353\353\353\377\352\352\352\377\350\350\350\377\347\347\347"
  "\377\346\346\346\377\345\345\345\377\344\344\344\377\342\342\342\377"
  "\341\341\341\377\340\340\340\377\337\337\337\377\336\336\336\377\335"
  "\335\335\377\334\334\334\377\333\333\333\377\332\332\332\377\332\332"
  "\332\377\331\331\331\377\330\330\330\377\327\327\327\377\327\327\327"
  "\377\326\326\326\377\325\325\325\377\325\325\325\377\324\324\324\377"
  "\324\324\324\377\323\323\323\377\323\323\323\377\322\322\322\377\322"
  "\322\322\377\321\321\321\377\321\321\321\377\321\321\321\377\321\321"
  "\321\377\320\320\320\377\320\320\320\377\320\320\320\377\320\320\320"
  "\377\320\320\320\377\320\320\320\377\320\320\320\377\320\320\320\377"
  "\320\320\320\377\320\320\320\377\321\321\321\377\321\321\321\377\321"
  "\321\321\377\321\321\321\377\322\322\322\377\322\322\322\377\323\323"
  "\323\377\323\323\323\377\323\323\323\377\324\324\324\377\324\324\324"
  "\377\325\325\325\377\326\326\326\377\326\326\326\377\327\327\327\377"
  "\330\330\330\377\330\330\330\377\331\331\331\377\332\332\332\377\333"
  "\333\333\377\334\334\334\377\335\335\335\377\336\336\336\377\337\337"
  "\337\377\340\340\340\377\341\341\341\377\342\342\342\377\343\343\343"
  "\377\344\344\344\377\346\346\346\377\347\347\347\377\350\350\350\377"
  "\351\351\351\377\353\353\353\377\354\354\354\377\355\355\355\377\357"
  "\357\357\377\360\360\360\377\362\362\362\377\363\363\363\377\365\365"
  "\365\377\366\366\366\377\367\367\367\377\371\371\371\377\372\372\372"
  "\377\374\374\374\377\376\376\376\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\356\356\356\377\240\240\240\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\370\212\212\212i\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11"
  ";\200\256\335;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256n\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256l;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\265\377"
  "\377\377\0;\200\256S;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\224\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256p;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256w\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\25\212\212\212\270\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\301\301\301\377\375\375\375\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\375\375\375\377\374"
  "\374\374\377\372\372\372\377\371\371\371\377\367\367\367\377\366\366"
  "\366\377\364\364\364\377\363\363\363\377\362\362\362\377\360\360\360"
  "\377\357\357\357\377\356\356\356\377\354\354\354\377\353\353\353\377"
  "\352\352\352\377\350\350\350\377\347\347\347\377\346\346\346\377\345"
  "\345\345\377\344\344\344\377\343\343\343\377\342\342\342\377\341\341"
  "\341\377\340\340\340\377\337\337\337\377\336\336\336\377\335\335\335"
  "\377\334\334\334\377\333\333\333\377\333\333\333\377\332\332\332\377"
  "\331\331\331\377\331\331\331\377\330\330\330\377\327\327\327\377\327"
  "\327\327\377\326\326\326\377\326\326\326\377\326\326\326\377\325\325"
  "\325\377\325\325\325\377\324\324\324\377\324\324\324\377\324\324\324"
  "\377\324\324\324\377\323\323\323\377\323\323\323\377\323\323\323\377"
  "\323\323\323\377\323\323\323\377\323\323\323\377\323\323\323\377\323"
  "\323\323\377\323\323\323\377\323\323\323\377\323\323\323\377\324\324"
  "\324\377\324\324\324\377\324\324\324\377\324\324\324\377\325\325\325"
  "\377\325\325\325\377\326\326\326\377\326\326\326\377\327\327\327\377"
  "\327\327\327\377\330\330\330\377\330\330\330\377\331\331\331\377\332"
  "\332\332\377\333\333\333\377\333\333\333\377\334\334\334\377\335\335"
  "\335\377\336\336\336\377\337\337\337\377\340\340\340\377\341\341\341"
  "\377\342\342\342\377\343\343\343\377\344\344\344\377\345\345\345\377"
  "\346\346\346\377\347\347\347\377\350\350\350\377\351\351\351\377\353"
  "\353\353\377\354\354\354\377\355\355\355\377\357\357\357\377\360\360"
  "\360\377\361\361\361\377\363\363\363\377\364\364\364\377\365\365\365"
  "\377\367\367\367\377\370\370\370\377\372\372\372\377\373\373\373\377"
  "\375\375\375\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\327\327\327\377\220\220\220\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\333\212\212\2122\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256F;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256*\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256D;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\251\377\377\377\0;\200\256a;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\346;\200\256\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256\365;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\367"
  ";\200\256\23\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\1\212\212\212y\212\212\212\374\212\212\212"
  "\377\212\212\212\377\212\212\212\377\245\245\245\377\362\362\362\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\375\375\375\377\373\373\373\377\372\372\372\377\370\370"
  "\370\377\367\367\367\377\365\365\365\377\364\364\364\377\363\363\363"
  "\377\361\361\361\377\360\360\360\377\357\357\357\377\356\356\356\377"
  "\354\354\354\377\353\353\353\377\352\352\352\377\351\351\351\377\350"
  "\350\350\377\347\347\347\377\346\346\346\377\345\345\345\377\344\344"
  "\344\377\343\343\343\377\342\342\342\377\341\341\341\377\340\340\340"
  "\377\337\337\337\377\336\336\336\377\336\336\336\377\335\335\335\377"
  "\334\334\334\377\333\333\333\377\333\333\333\377\332\332\332\377\332"
  "\332\332\377\331\331\331\377\331\331\331\377\330\330\330\377\330\330"
  "\330\377\327\327\327\377\327\327\327\377\327\327\327\377\327\327\327"
  "\377\326\326\326\377\326\326\326\377\326\326\326\377\326\326\326\377"
  "\326\326\326\377\326\326\326\377\326\326\326\377\326\326\326\377\326"
  "\326\326\377\326\326\326\377\326\326\326\377\326\326\326\377\327\327"
  "\327\377\327\327\327\377\327\327\327\377\327\327\327\377\330\330\330"
  "\377\330\330\330\377\331\331\331\377\331\331\331\377\332\332\332\377"
  "\332\332\332\377\333\333\333\377\333\333\333\377\334\334\334\377\335"
  "\335\335\377\335\335\335\377\336\336\336\377\337\337\337\377\340\340"
  "\340\377\341\341\341\377\341\341\341\377\342\342\342\377\343\343\343"
  "\377\344\344\344\377\345\345\345\377\347\347\347\377\347\347\347\377"
  "\351\351\351\377\352\352\352\377\353\353\353\377\354\354\354\377\355"
  "\355\355\377\357\357\357\377\360\360\360\377\361\361\361\377\362\362"
  "\362\377\364\364\364\377\365\365\365\377\366\366\366\377\370\370\370"
  "\377\371\371\371\377\373\373\373\377\374\374\374\377\376\376\376\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\373\373\373\377\271"
  "\271\271\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\251\212\212\212\16\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\245;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\345\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\35;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\235\377\377\377\0;\200\256p;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256V\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256\302;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\235\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "<\212\212\212\343\212\212\212\377\212\212\212\377\212\212\212\377\222"
  "\222\222\377\323\323\323\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\374\374\374"
  "\377\373\373\373\377\371\371\371\377\370\370\370\377\367\367\367\377"
  "\365\365\365\377\364\364\364\377\363\363\363\377\361\361\361\377\360"
  "\360\360\377\357\357\357\377\356\356\356\377\355\355\355\377\353\353"
  "\353\377\352\352\352\377\351\351\351\377\350\350\350\377\347\347\347"
  "\377\346\346\346\377\345\345\345\377\344\344\344\377\344\344\344\377"
  "\343\343\343\377\342\342\342\377\341\341\341\377\340\340\340\377\340"
  "\340\340\377\337\337\337\377\336\336\336\377\336\336\336\377\335\335"
  "\335\377\335\335\335\377\334\334\334\377\333\333\333\377\333\333\333"
  "\377\333\333\333\377\332\332\332\377\332\332\332\377\332\332\332\377"
  "\332\332\332\377\331\331\331\377\331\331\331\377\331\331\331\377\331"
  "\331\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331"
  "\331\377\331\331\331\377\331\331\331\377\331\331\331\377\331\331\331"
  "\377\331\331\331\377\332\332\332\377\332\332\332\377\332\332\332\377"
  "\333\333\333\377\333\333\333\377\333\333\333\377\334\334\334\377\335"
  "\335\335\377\335\335\335\377\336\336\336\377\336\336\336\377\337\337"
  "\337\377\340\340\340\377\340\340\340\377\341\341\341\377\342\342\342"
  "\377\342\342\342\377\343\343\343\377\344\344\344\377\345\345\345\377"
  "\346\346\346\377\347\347\347\377\350\350\350\377\351\351\351\377\352"
  "\352\352\377\353\353\353\377\354\354\354\377\356\356\356\377\357\357"
  "\357\377\360\360\360\377\361\361\361\377\362\362\362\377\364\364\364"
  "\377\365\365\365\377\366\366\366\377\367\367\367\377\371\371\371\377"
  "\372\372\372\377\374\374\374\377\375\375\375\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\344\344\344\377\236\236"
  "\236\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\367\212\212\212h\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\25;\200\256\344;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\241\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\1;\200\256\364;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\222\377\377\377\0;\200\256~;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\256\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256z;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\375;\200\256)\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\212\212\212\24\212\212\212\265\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\245\245\245\377\352\352\352\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\375\375\375\377\374\374\374\377\372\372\372\377\371\371\371\377"
  "\370\370\370\377\366\366\366\377\365\365\365\377\364\364\364\377\363"
  "\363\363\377\362\362\362\377\360\360\360\377\357\357\357\377\356\356"
  "\356\377\355\355\355\377\354\354\354\377\353\353\353\377\352\352\352"
  "\377\351\351\351\377\350\350\350\377\347\347\347\377\346\346\346\377"
  "\345\345\345\377\345\345\345\377\344\344\344\377\343\343\343\377\342"
  "\342\342\377\342\342\342\377\341\341\341\377\341\341\341\377\340\340"
  "\340\377\340\340\340\377\337\337\337\377\336\336\336\377\336\336\336"
  "\377\336\336\336\377\335\335\335\377\335\335\335\377\335\335\335\377"
  "\334\334\334\377\334\334\334\377\334\334\334\377\334\334\334\377\334"
  "\334\334\377\333\333\333\377\333\333\333\377\333\333\333\377\333\333"
  "\333\377\334\334\334\377\334\334\334\377\334\334\334\377\334\334\334"
  "\377\334\334\334\377\335\335\335\377\335\335\335\377\335\335\335\377"
  "\336\336\336\377\336\336\336\377\336\336\336\377\337\337\337\377\337"
  "\337\337\377\340\340\340\377\340\340\340\377\341\341\341\377\342\342"
  "\342\377\342\342\342\377\343\343\343\377\344\344\344\377\344\344\344"
  "\377\345\345\345\377\346\346\346\377\347\347\347\377\350\350\350\377"
  "\351\351\351\377\352\352\352\377\353\353\353\377\354\354\354\377\355"
  "\355\355\377\356\356\356\377\357\357\357\377\360\360\360\377\361\361"
  "\361\377\362\362\362\377\364\364\364\377\365\365\365\377\366\366\366"
  "\377\367\367\367\377\371\371\371\377\372\372\372\377\374\374\374\377"
  "\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\365\365\365\377\267\267\267\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\332\212\212\212"
  "/\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2567;\200\256\371;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256]\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\315;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\206\377\377\377\0;\200\256\214;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\331;\200"
  "\256\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\2566;\200\256\373;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\244"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\1\212\212\212v\212\212\212\373\212\212\212"
  "\377\212\212\212\377\212\212\212\377\213\213\213\377\276\276\276\377"
  "\371\371\371\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\375\375\375\377\374\374\374\377\372\372"
  "\372\377\371\371\371\377\370\370\370\377\367\367\367\377\365\365\365"
  "\377\364\364\364\377\363\363\363\377\362\362\362\377\361\361\361\377"
  "\360\360\360\377\357\357\357\377\356\356\356\377\355\355\355\377\354"
  "\354\354\377\353\353\353\377\352\352\352\377\351\351\351\377\350\350"
  "\350\377\347\347\347\377\347\347\347\377\346\346\346\377\345\345\345"
  "\377\345\345\345\377\344\344\344\377\343\343\343\377\343\343\343\377"
  "\342\342\342\377\342\342\342\377\341\341\341\377\341\341\341\377\340"
  "\340\340\377\340\340\340\377\340\340\340\377\340\340\340\377\337\337"
  "\337\377\337\337\337\377\337\337\337\377\337\337\337\377\336\336\336"
  "\377\336\336\336\377\336\336\336\377\336\336\336\377\336\336\336\377"
  "\336\336\336\377\337\337\337\377\337\337\337\377\337\337\337\377\337"
  "\337\337\377\340\340\340\377\340\340\340\377\340\340\340\377\340\340"
  "\340\377\341\341\341\377\341\341\341\377\342\342\342\377\342\342\342"
  "\377\343\343\343\377\343\343\343\377\344\344\344\377\344\344\344\377"
  "\345\345\345\377\346\346\346\377\347\347\347\377\347\347\347\377\350"
  "\350\350\377\351\351\351\377\352\352\352\377\353\353\353\377\354\354"
  "\354\377\354\354\354\377\356\356\356\377\356\356\356\377\357\357\357"
  "\377\360\360\360\377\362\362\362\377\363\363\363\377\364\364\364\377"
  "\365\365\365\377\366\366\366\377\367\367\367\377\371\371\371\377\372"
  "\372\372\377\373\373\373\377\375\375\375\377\376\376\376\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\320\320\320"
  "\377\222\222\222\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\245\212\212\212\15\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256f;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\31\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\246;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "z\377\377\377\0;\200\256\233;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\364;\200\256+\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\14;\200\256\333;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\374;\200\256%\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212+\212\212\212\301\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\226\226\226\377\327"
  "\327\327\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\376\376\376\377\375\375\375\377\374\374\374"
  "\377\372\372\372\377\371\371\371\377\370\370\370\377\367\367\367\377"
  "\366\366\366\377\365\365\365\377\363\363\363\377\362\362\362\377\361"
  "\361\361\377\360\360\360\377\357\357\357\377\356\356\356\377\356\356"
  "\356\377\355\355\355\377\354\354\354\377\353\353\353\377\352\352\352"
  "\377\351\351\351\377\351\351\351\377\350\350\350\377\347\347\347\377"
  "\347\347\347\377\346\346\346\377\346\346\346\377\345\345\345\377\345"
  "\345\345\377\344\344\344\377\344\344\344\377\343\343\343\377\343\343"
  "\343\377\343\343\343\377\342\342\342\377\342\342\342\377\342\342\342"
  "\377\342\342\342\377\342\342\342\377\341\341\341\377\341\341\341\377"
  "\341\341\341\377\341\341\341\377\341\341\341\377\341\341\341\377\341"
  "\341\341\377\342\342\342\377\342\342\342\377\342\342\342\377\342\342"
  "\342\377\342\342\342\377\343\343\343\377\343\343\343\377\344\344\344"
  "\377\344\344\344\377\344\344\344\377\345\345\345\377\345\345\345\377"
  "\346\346\346\377\347\347\347\377\347\347\347\377\350\350\350\377\351"
  "\351\351\377\351\351\351\377\352\352\352\377\353\353\353\377\354\354"
  "\354\377\354\354\354\377\355\355\355\377\356\356\356\377\357\357\357"
  "\377\360\360\360\377\361\361\361\377\362\362\362\377\363\363\363\377"
  "\364\364\364\377\365\365\365\377\366\366\366\377\370\370\370\377\371"
  "\371\371\377\372\372\372\377\373\373\373\377\375\375\375\377\376\376"
  "\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\350\350\350\377\242\242\242\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\337\212\212\212M\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\233;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\324\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256r"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256o\377\377\377\0;"
  "\200\256\251;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256X\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\237;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\237\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212]\212\212\212"
  "\351\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\251\251\251\377\355\355\355\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377\375\375"
  "\375\377\374\374\374\377\373\373\373\377\371\371\371\377\370\370\370"
  "\377\367\367\367\377\366\366\366\377\365\365\365\377\364\364\364\377"
  "\363\363\363\377\362\362\362\377\361\361\361\377\360\360\360\377\357"
  "\357\357\377\357\357\357\377\356\356\356\377\355\355\355\377\354\354"
  "\354\377\354\354\354\377\353\353\353\377\352\352\352\377\351\351\351"
  "\377\351\351\351\377\350\350\350\377\350\350\350\377\347\347\347\377"
  "\347\347\347\377\347\347\347\377\346\346\346\377\346\346\346\377\345"
  "\345\345\377\345\345\345\377\345\345\345\377\345\345\345\377\345\345"
  "\345\377\344\344\344\377\344\344\344\377\344\344\344\377\344\344\344"
  "\377\344\344\344\377\344\344\344\377\344\344\344\377\344\344\344\377"
  "\345\345\345\377\345\345\345\377\345\345\345\377\345\345\345\377\345"
  "\345\345\377\346\346\346\377\346\346\346\377\347\347\347\377\347\347"
  "\347\377\347\347\347\377\350\350\350\377\350\350\350\377\351\351\351"
  "\377\351\351\351\377\352\352\352\377\353\353\353\377\353\353\353\377"
  "\354\354\354\377\355\355\355\377\356\356\356\377\356\356\356\377\357"
  "\357\357\377\360\360\360\377\361\361\361\377\362\362\362\377\363\363"
  "\363\377\364\364\364\377\365\365\365\377\366\366\366\377\367\367\367"
  "\377\370\370\370\377\371\371\371\377\372\372\372\377\374\374\374\377"
  "\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\367\367\367\377\273\273\273\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\371\212\212\212\204\212\212\212\11\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\5;\200\256\256;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256q\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256.;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256c\377\377\377\0;\200\256\267;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\217\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256V;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\372;\200\256"
  "\"\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\212\212\212\20\212\212\212\224\212\212"
  "\212\375\212\212\212\377\212\212\212\377\212\212\212\377\213\213\213"
  "\377\266\266\266\377\355\355\355\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\375"
  "\375\375\377\374\374\374\377\373\373\373\377\372\372\372\377\371\371"
  "\371\377\370\370\370\377\367\367\367\377\366\366\366\377\365\365\365"
  "\377\364\364\364\377\363\363\363\377\362\362\362\377\361\361\361\377"
  "\360\360\360\377\360\360\360\377\357\357\357\377\356\356\356\377\356"
  "\356\356\377\355\355\355\377\354\354\354\377\354\354\354\377\353\353"
  "\353\377\353\353\353\377\352\352\352\377\352\352\352\377\351\351\351"
  "\377\351\351\351\377\351\351\351\377\350\350\350\377\350\350\350\377"
  "\350\350\350\377\350\350\350\377\347\347\347\377\347\347\347\377\347"
  "\347\347\377\347\347\347\377\347\347\347\377\347\347\347\377\347\347"
  "\347\377\347\347\347\377\347\347\347\377\347\347\347\377\350\350\350"
  "\377\350\350\350\377\350\350\350\377\350\350\350\377\351\351\351\377"
  "\351\351\351\377\351\351\351\377\352\352\352\377\352\352\352\377\353"
  "\353\353\377\353\353\353\377\354\354\354\377\354\354\354\377\355\355"
  "\355\377\356\356\356\377\356\356\356\377\357\357\357\377\360\360\360"
  "\377\360\360\360\377\361\361\361\377\362\362\362\377\363\363\363\377"
  "\364\364\364\377\365\365\365\377\366\366\366\377\366\366\366\377\367"
  "\367\367\377\371\371\371\377\372\372\372\377\373\373\373\377\374\374"
  "\374\377\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\367\367\367\377\304\304\304\377"
  "\221\221\221\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\273\212\212\212&\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\4;\200\256\247;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\343;\200"
  "\256\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\1;\200\256\351;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "W\377\377\377\0;\200\256\306;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\302;\200\256\4\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\36;\200\256\357;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\232\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\212\212\2122\212\212\212\311\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\262\262\262\377\352\352\352\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\375\375\375\377\374\374\374\377\372\372\372\377\371\371"
  "\371\377\371\371\371\377\367\367\367\377\367\367\367\377\366\366\366"
  "\377\365\365\365\377\364\364\364\377\363\363\363\377\363\363\363\377"
  "\362\362\362\377\361\361\361\377\360\360\360\377\360\360\360\377\357"
  "\357\357\377\357\357\357\377\356\356\356\377\356\356\356\377\355\355"
  "\355\377\355\355\355\377\354\354\354\377\354\354\354\377\354\354\354"
  "\377\353\353\353\377\353\353\353\377\353\353\353\377\353\353\353\377"
  "\352\352\352\377\352\352\352\377\352\352\352\377\352\352\352\377\352"
  "\352\352\377\352\352\352\377\352\352\352\377\352\352\352\377\352\352"
  "\352\377\352\352\352\377\352\352\352\377\353\353\353\377\353\353\353"
  "\377\353\353\353\377\353\353\353\377\354\354\354\377\354\354\354\377"
  "\354\354\354\377\355\355\355\377\356\356\356\377\356\356\356\377\357"
  "\357\357\377\357\357\357\377\360\360\360\377\360\360\360\377\361\361"
  "\361\377\362\362\362\377\362\362\362\377\363\363\363\377\364\364\364"
  "\377\365\365\365\377\366\366\366\377\366\366\366\377\367\367\367\377"
  "\370\370\370\377\371\371\371\377\372\372\372\377\373\373\373\377\374"
  "\374\374\377\375\375\375\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\364\364\364\377\300\300\300"
  "\377\217\217\217\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\345\212\212\212V\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\241"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256f\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\247;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256K\377\377\377\0;\200\256\324;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\346;\200\256\30\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\2;\200\256\301;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\371;\200\256\36"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\212\212\212\2\212\212\212f\212\212\212\353\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\257\257\257\377\347\347\347\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376"
  "\376\377\375\375\375\377\374\374\374\377\373\373\373\377\372\372\372"
  "\377\371\371\371\377\371\371\371\377\370\370\370\377\367\367\367\377"
  "\366\366\366\377\365\365\365\377\365\365\365\377\364\364\364\377\363"
  "\363\363\377\363\363\363\377\362\362\362\377\361\361\361\377\361\361"
  "\361\377\360\360\360\377\360\360\360\377\357\357\357\377\357\357\357"
  "\377\357\357\357\377\356\356\356\377\356\356\356\377\356\356\356\377"
  "\356\356\356\377\355\355\355\377\355\355\355\377\355\355\355\377\355"
  "\355\355\377\355\355\355\377\355\355\355\377\355\355\355\377\355\355"
  "\355\377\355\355\355\377\355\355\355\377\355\355\355\377\355\355\355"
  "\377\356\356\356\377\356\356\356\377\356\356\356\377\356\356\356\377"
  "\357\357\357\377\357\357\357\377\357\357\357\377\360\360\360\377\360"
  "\360\360\377\361\361\361\377\361\361\361\377\362\362\362\377\362\362"
  "\362\377\363\363\363\377\364\364\364\377\365\365\365\377\365\365\365"
  "\377\366\366\366\377\367\367\367\377\367\367\367\377\370\370\370\377"
  "\371\371\371\377\372\372\372\377\373\373\373\377\374\374\374\377\375"
  "\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\363\363\363\377\275\275\275"
  "\377\216\216\216\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\371\212\212\212\215\212\212\212\15\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\1;\200\256n;\200\256\365;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\260;\200\256\3\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256c;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256@\377"
  "\377\377\0;\200\256\335;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\372;\200\256;\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256{;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\225\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\13\212\212\212r\212\212\212\346\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\253\253\253\377"
  "\344\344\344\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376"
  "\376\377\375\375\375\377\374\374\374\377\373\373\373\377\372\372\372"
  "\377\372\372\372\377\371\371\371\377\370\370\370\377\367\367\367\377"
  "\367\367\367\377\366\366\366\377\365\365\365\377\365\365\365\377\364"
  "\364\364\377\364\364\364\377\363\363\363\377\363\363\363\377\362\362"
  "\362\377\362\362\362\377\362\362\362\377\361\361\361\377\361\361\361"
  "\377\361\361\361\377\360\360\360\377\360\360\360\377\360\360\360\377"
  "\360\360\360\377\360\360\360\377\360\360\360\377\360\360\360\377\360"
  "\360\360\377\360\360\360\377\360\360\360\377\360\360\360\377\360\360"
  "\360\377\360\360\360\377\360\360\360\377\360\360\360\377\361\361\361"
  "\377\361\361\361\377\362\362\362\377\362\362\362\377\362\362\362\377"
  "\363\363\363\377\363\363\363\377\364\364\364\377\364\364\364\377\365"
  "\365\365\377\365\365\365\377\366\366\366\377\366\366\366\377\367\367"
  "\367\377\370\370\370\377\371\371\371\377\371\371\371\377\372\372\372"
  "\377\373\373\373\377\374\374\374\377\375\375\375\377\376\376\376\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\360\360\360\377\271\271\271\377\215\215"
  "\215\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\366\212\212\212\221\212\212\212\33\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256$;\200\256\304;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\304;\200\256\11\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\37;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\2564\377\377\377\0;\200\256\344;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256n\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\2567;\200\256\373;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\367;\200\256\33\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\7\212\212\212"
  "i\212\212\212\340\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\237\237\237\377\312\312\312\377\363\363"
  "\363\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\376\376\376\377"
  "\375\375\375\377\374\374\374\377\374\374\374\377\373\373\373\377\372"
  "\372\372\377\371\371\371\377\371\371\371\377\370\370\370\377\367\367"
  "\367\377\367\367\367\377\366\366\366\377\366\366\366\377\366\366\366"
  "\377\365\365\365\377\365\365\365\377\365\365\365\377\364\364\364\377"
  "\364\364\364\377\363\363\363\377\363\363\363\377\363\363\363\377\363"
  "\363\363\377\363\363\363\377\363\363\363\377\363\363\363\377\363\363"
  "\363\377\363\363\363\377\363\363\363\377\363\363\363\377\363\363\363"
  "\377\363\363\363\377\363\363\363\377\363\363\363\377\363\363\363\377"
  "\364\364\364\377\364\364\364\377\364\364\364\377\365\365\365\377\365"
  "\365\365\377\366\366\366\377\366\366\366\377\366\366\366\377\367\367"
  "\367\377\367\367\367\377\370\370\370\377\371\371\371\377\371\371\371"
  "\377\372\372\372\377\373\373\373\377\374\374\374\377\374\374\374\377"
  "\375\375\375\377\376\376\376\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\372\372"
  "\372\377\325\325\325\377\252\252\252\377\213\213\213\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\362"
  "\212\212\212\210\212\212\212\26\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\2;\200\256Z;\200\256\302;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\374;\200\256\227;\200\256\20\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\333"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256(\377\377\377\0;\200\256\353;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\245"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\15;\200\256\334;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\220\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\212\212\212\5\212\212\212a\212\212\212\332\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\213\213\213\377\252\252\252\377\325\325\325\377\372\372\372"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\376"
  "\376\376\377\375\375\375\377\374\374\374\377\374\374\374\377\373\373"
  "\373\377\372\372\372\377\372\372\372\377\371\371\371\377\371\371\371"
  "\377\370\370\370\377\370\370\370\377\367\367\367\377\367\367\367\377"
  "\367\367\367\377\367\367\367\377\366\366\366\377\366\366\366\377\366"
  "\366\366\377\366\366\366\377\366\366\366\377\366\366\366\377\365\365"
  "\365\377\365\365\365\377\365\365\365\377\365\365\365\377\366\366\366"
  "\377\366\366\366\377\366\366\366\377\366\366\366\377\366\366\366\377"
  "\366\366\366\377\367\367\367\377\367\367\367\377\367\367\367\377\367"
  "\367\367\377\370\370\370\377\370\370\370\377\371\371\371\377\371\371"
  "\371\377\372\372\372\377\372\372\372\377\373\373\373\377\374\374\374"
  "\377\374\374\374\377\375\375\375\377\375\375\375\377\376\376\376\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\340\340\340\377\265\265"
  "\265\377\217\217\217\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\356\212\212\212\200"
  "\212\212\212\21\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256);\200\256\207;\200\256\262;\200\256\325;\200\256\366;\200"
  "\256\360;\200\256\306;\200\256\231;\200\256+\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\230;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\35\377\377\377\0;\200\256"
  "\362;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\322;\200\256\12\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\240;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\366;\200\256\30\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212"
  "\212\212\2\212\212\212X\212\212\212\322\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\217"
  "\217\217\377\265\265\265\377\340\340\340\377\376\376\376\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\376\376\376\377\375\375\375\377\375\375\375\377\374\374\374\377\374"
  "\374\374\377\373\373\373\377\373\373\373\377\372\372\372\377\372\372"
  "\372\377\372\372\372\377\371\371\371\377\371\371\371\377\371\371\371"
  "\377\371\371\371\377\371\371\371\377\371\371\371\377\370\370\370\377"
  "\370\370\370\377\370\370\370\377\370\370\370\377\370\370\370\377\370"
  "\370\370\377\371\371\371\377\371\371\371\377\371\371\371\377\371\371"
  "\371\377\371\371\371\377\371\371\371\377\372\372\372\377\372\372\372"
  "\377\372\372\372\377\373\373\373\377\373\373\373\377\374\374\374\377"
  "\374\374\374\377\375\375\375\377\375\375\375\377\376\376\376\377\376"
  "\376\376\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\353\353\353\377\300\300\300\377\226\226\226\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\350\212\212\212w\212\212\212\15\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256T;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\21\377\377\377\0"
  ";\200\256\371;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\360"
  ";\200\256$\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256W;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\213\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\2127\212\212\212"
  "\224\212\212\212\354\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\225\225\225\377\265"
  "\265\265\377\323\323\323\377\361\361\361\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\376\376\376\377\376\376\376\377\375\375\375\377\375"
  "\375\375\377\375\375\375\377\374\374\374\377\374\374\374\377\374\374"
  "\374\377\374\374\374\377\374\374\374\377\373\373\373\377\373\373\373"
  "\377\373\373\373\377\373\373\373\377\373\373\373\377\373\373\373\377"
  "\373\373\373\377\373\373\373\377\374\374\374\377\374\374\374\377\374"
  "\374\374\377\374\374\374\377\374\374\374\377\375\375\375\377\375\375"
  "\375\377\375\375\375\377\376\376\376\377\376\376\376\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\367\367\367\377\332\332\332\377\274\274\274\377\235\235"
  "\235\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\370\212\212\212\254"
  "\212\212\212N\212\212\212\5\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\22;\200\256\375;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\5\377\377\377"
  "\0;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256"
  "N\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\36;\200\256\357;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\364;\200\256\25\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\212\212\212\5\212\212\212P\212\212\212\255\212\212\212\371"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\232\232\232\377\270\270"
  "\270\377\327\327\327\377\365\365\365\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\376\376\376\377\376\376\376"
  "\377\376\376\376\377\376\376\376\377\376\376\376\377\376\376\376\377"
  "\376\376\376\377\376\376\376\377\376\376\376\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\372\372\372\377\336\336\336\377\300\300\300\377\242"
  "\242\242\377\213\213\213\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\305\212\212\212g\212\212\212\21\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\314;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\372\377\377\377\0;\200\256\7;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\204\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\3;\200\256\302;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\206\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\22\212\212\212"
  "h\212\212\212\306\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\236\236\236\377\274\274\274\377\320\320\320"
  "\377\342\342\342\377\364\364\364\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\371\371\371"
  "\377\347\347\347\377\325\325\325\377\302\302\302\377\246\246\246\377"
  "\214\214\214\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\335\212\212\212\200\212\212\212#\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\210;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\356\377\377\377\0;\200\256\16;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\235;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256};\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\361;\200\256\22"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212"
  "\"\212\212\212i\212\212\212\253\212\212\212\353\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\221\221\221\377\243\243\243\377\265\265\265\377\307\307\307\377\331"
  "\331\331\377\353\353\353\377\367\367\367\377\374\374\374\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377\377"
  "\377\377\377\377\377\377\377\376\376\376\377\370\370\370\377\357\357"
  "\357\377\335\335\335\377\314\314\314\377\272\272\272\377\247\247\247"
  "\377\225\225\225\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\366\212\212"
  "\212\274\212\212\212z\212\212\2126\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256E;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\342\377\377\377\0;\200\256\25;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\247;\200\256\2\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "8;\200\256\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\201\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\1\212"
  "\212\212/\212\212\212q\212\212\212\263\212\212\212\361\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\215\215\215\377\222\222\222\377\230\230\230\377\236\236\236\377"
  "\244\244\244\377\251\251\251\377\257\257\257\377\264\264\264\377\261"
  "\261\261\377\253\253\253\377\245\245\245\377\237\237\237\377\232\232"
  "\232\377\224\224\224\377\216\216\216\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\372\212\212\212\303\212\212\212\201\212\212\212\77\212\212\212\7"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256\370;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\327\377\377\377\0;\200\256"
  "\34;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\260;\200\256\4\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\15;\200\256\335;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\357;\200\256\20\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\3\212"
  "\212\2127\212\212\212y\212\212\212\255\212\212\212\324\212\212\212\371"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\375"
  "\212\212\212\336\212\212\212\266\212\212\212\210\212\212\212G\212\212"
  "\212\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\275;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\313\377\377\377\0;\200\256#;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\270"
  ";\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\242;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "}\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\212\212\212\3\212\212\212"
  "#\212\212\212K\212\212\212s\212\212\212\232\212\212\212\302\212\212\212"
  "\352\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212"
  "\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212"
  "\212\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212"
  "\377\212\212\212\377\212\212\212\377\212\212\212\377\212\212\212\377"
  "\212\212\212\363\212\212\212\314\212\212\212\244\212\212\212}\212\212"
  "\212U\212\212\212-\212\212\212\10\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "y;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\300\377\377"
  "\377\0;\200\256*;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\300;\200\256\11\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "V;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\354;\200\256\15\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\212\212\212\20\212\212\212\"\212\212\212/\212\212"
  "\212<\212\212\212I\212\212\212V\212\212\212c\212\212\212o\212\212\212"
  "|\212\212\212\211\212\212\212\224\212\212\212\214\212\212\212\177\212"
  "\212\212s\212\212\212f\212\212\212Y\212\212\212L\212\212\212\77\212\212"
  "\2122\212\212\212&\212\212\212\26\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\2566;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\273\377\377\377\0;\200\2561;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\310;\200\256\14\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\23;\200\256\352;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256x\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200"
  "\256\342;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\266\377\377\377"
  "\0;\200\2568;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\317;\200\256\20\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\244;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\352;\200"
  "\256\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\204;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\262\377\377\377\0;\200\256\77;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\325;\200\256\24\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256K;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256s\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256#;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\255\377\377"
  "\377\0;\200\256F;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\333;\200\256\31\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\16;\200\256\343;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\347;\200\256\11"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\301"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\250\377\377\377\0;\200\256M;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\341;\200\256\36\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\230;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256n\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256_;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\244\377\377\377\0;\200\256T;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\346;\200\256$\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256@;\200\256\376;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\344;\200\256\7\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\13;\200\256\363;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\237\377\377\377\0;\200\256[;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\353;\200\256*\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256"
  "\334;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256o\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\235;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\233\377\377\377\0;\200\256b;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350"
  ";\200\2560\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\214;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350;\200\256"
  "\11\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256;;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\226\377\377"
  "\377\0;\200\256i;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\325;\200\256\40\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2566"
  ";\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256u\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\331;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\221\377\377\377\0;\200\256p;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\274;\200"
  "\256\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\6;\200\256\323;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\354;\200"
  "\256\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "x;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\215\377\377\377\0;\200\256w;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\236;\200\256\5\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\200"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256z\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\32;\200\256\374;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\210\377\377\377\0;\200"
  "\256~;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\376;\200\256{\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256);\200\256\372;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357;\200\256"
  "\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\266;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\204\377\377\377\0;\200\256\204;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\370"
  ";\200\256Y\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\275;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\200\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256T;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\177\377\377\377\0;\200\256\213;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\354;\200\256<\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256X;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\362;\200\256\21\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256"
  "\354;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256{\377\377\377\0;"
  "\200\256\222;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\332;\200\256%\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\15;\200\256\345;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\206\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\222;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256v\377\377\377\0;\200\256\231;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\303;\200\256\23\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\215"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\364;\200\256\24\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\2560;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256q\377\377\377\0;\200\256\240;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\246;\200\256\7\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256,;\200\256\373;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\214\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\276;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256m\377\377\377\0;\200\256\247;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\204;\200\256"
  "\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\301;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\367;\200"
  "\256\30\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256<;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256h\377"
  "\377\377\0;\200\256\256;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\372;\200\256a\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256]"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\222\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\271;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256d\377\377\377"
  "\0;\200\256\265;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\342"
  ";\200\256=\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\17;\200\256\350;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\371;\200\256\33\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\2566;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256_\377\377\377\0;\200"
  "\256\274;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\253;\200\256\21\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\222;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\230\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\263;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256Z\377\377\377\0;\200\256\303"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\364;\200\256d\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\2560;\200\256\374;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\372"
  ";\200\256\40\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\2562;\200\256\376;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256V\377\377\377\0;\200\256\312;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\316;\200"
  "\256'\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\1;\200\256\305;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\235\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\256;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256Q\377\377\377\0;\200\256\321;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\376;\200\256\214;\200\256\6\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "h;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\374;\200\256$\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256-;\200\256\376;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256M\377\377\377\0;\200\256\330;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\347;\200\256F\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256';\200\256\365;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\241\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\250;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256H\377\377\377\0;\200\256\337;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\264"
  ";\200\256\25\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\314;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\365;\200\256\34\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256(;\200\256\375;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256D\377\377\377\0;\200\256\346;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\370;\200\256m\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\207;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256}\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\243;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\77\377\377\377\0;\200\256\355;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\325;\200\256.\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256>;\200\256\375;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\340;\200\256\11\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256$;\200\256\373;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256:\377\377\377\0;\200\256\364;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\226;\200\256\11\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\17;\200\256\341;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256U\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\235;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\2566\377\377\377\0;\200\256\373;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\354;\200"
  "\256O\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\246;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\301\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\40;\200\256\372;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\2561;\200\256\2;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\376;\200\256\233;\200\256\24"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256[;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\375;\200\2560\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\226;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256-;\200\256\11;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\312;\200\2565\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\37;\200\256\361;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\231\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\20;\200\256\345;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256(;\200\256\20;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\353;\200\256d;\200\256\1\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200"
  "\256\303;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\360"
  ";\200\256\25\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256L;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256#;\200\256\27"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\374"
  ";\200\256\225;\200\256\21\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256{;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256q\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\241;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\37;\200"
  "\256\30;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\305;\200"
  "\2560\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "7;\200\256\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\311;\200\256\4\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\21;\200\256\346;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\32;\200\256\31;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\350;\200\256^;\200\256\1"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\""
  ";\200\256\350;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\360;\200\256!\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256M;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\26;\200\256\31;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\373;\200\256\217;\200\256\16\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\26"
  ";\200\256\333;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256U\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\243"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\21;\200\256\32;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\277;\200\256,\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\34;\200\256%\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\14;\200"
  "\256\313;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\227\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\22;\200\256\347;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\14;\200\256\33;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\344;\200\256X\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\12;\200\256\177;\200\256\365"
  ";\200\256\373;\200\256\234;\200\256\36\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200"
  "\256\270;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\321;\200\256\10\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256O;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\10;\200\256\33;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\364;\200\256\207;\200\256\14\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256Z;\200\256\342;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\370;\200\256\221;\200"
  "\256\27\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\256"
  "\242;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\364;\200\256(\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\24;\200\256"
  "V;\200\256u;\200\256\214;\200\256\227;\200\256x;\200\256U;\200\256#\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\245;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\3;\200\256\34;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\362;\200\256\207;\200\256\25\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\2566;\200\256\306;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\364;\200"
  "\256\216;\200\256&\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\5;\200\256\242;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256`\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1;\200\2564;\200"
  "\256~;\200\256\307;\200\256\375;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256\272;\200"
  "\256N;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\22;\200\256\350;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\376\377\377\377\0;\200\256\35;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\360;\200\256"
  "\203;\200\256\22\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\33;\200\256\242;\200\256\376;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\276;\200\256W;\200\256\6\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\14;\200"
  "\256\271;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\243\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\1"
  ";\200\256;;\200\256\224;\200\256\350;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\337;\200\256v;\200\256\10\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256Q;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\372\377"
  "\377\377\0;\200\256\35;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\356;\200\256~;\200\256\20\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\2567;\200\256\331;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\352;\200\256\212;\200\256<;\200\256\4\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\27;\200\256\315;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\313;\200\256"
  "\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256/;\200\256\210;\200\256\340;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\276;\200\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\247;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\366\377\377\377\0;\200\256\36"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\353;\200\256y;\200\256\15\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\11;\200\256\221;\200\256\376;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\362;\200\256\261;\200\256"
  "l;\200\256&\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256%;\200\256"
  "\335;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\304;\200\256\16\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\36;\200\256m;\200\256r;\200"
  "\256\202;\200\256\264;\200\256\351;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\310;\200\256\21"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\23;\200\256\351;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\361\377\377\377\0;\200\256\37;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\351;\200\256u;\200"
  "\256\13\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "@;\200\256\337;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\341;\200"
  "\256\234;\200\256V;\200\256\23\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\2568;\200\256\352;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\274;\200\256\13\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\16;\200\256\364;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\321;\200\256\27\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256@;\200\256\371;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\354\377\377\377\0;\200"
  "\256\37;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\346"
  ";\200\256p;\200\256\11\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\15;\200"
  "\256\227;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\375;\200\256\314;\200\256\206;\200\256M;\200\256\";\200"
  "\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\1;\200\256u;\200\256\372;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\264;\200\256\10\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\233"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\304;\200\256\2\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256^;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\350\377\377\377\0;\200\256\40;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\343;\200\256k;\200\256\10\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256,;\200\256"
  "\266;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256\315;\200"
  "\256\242;\200\256w;\200\256L;\200\256\";\200\256\1\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\26;\200\256\270;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\253;\200\256\5\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\2563;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256t\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\202;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377"
  "\377\0;\200\256!;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\337;\200\256g;\200\256\6\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256D;\200\256\317"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\365;\200\256\314;\200\256\242;\200\256w;\200"
  "\256L;\200\256!;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256O"
  ";\200\256\347;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\242;\200\256\3\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\234;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\370;\200\256*\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\245;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\350\377\377\377\0;\200\256!;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\376;\200\256\273;\200\256U;\200\256\5\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256[;\200\256\311"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\365;\200\256\314;\200\256\241;\200\256v;\200\256L;\200\256"
  "!;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256N;\200\256\314;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\370;\200\256q;\200"
  "\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\254;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\313;\200\256\4\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\7"
  ";\200\256\303;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256\";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\347;\200\256\206;\200\256\"\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\2562;\200\256\232;\200\256"
  "\364;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200\256\315"
  ";\200\256\257;\200\256\224;\200\256y;\200\256_;\200\256_;\200\256\203"
  ";\200\256\246;\200\256\327;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\324"
  ";\200\256.\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\6;\200\256\213;\200\256\363;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256z\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\23;\200\256\333;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\350\377\377\377\0;\200\256#;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\375;\200\256\267;\200\256Q;\200\256\4\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\16;\200\256k;\200\256\323;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\222;\200\256\10\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\21;\200\256x;\200\256\263;\200\256\335;\200\256\375"
  ";\200\256\377;\200\256\372;\200\256\364;\200\256\355;\200\256\346;\200"
  "\256\340;\200\256\340;\200\256\340;\200\256\347;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\366;\200\256\40\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256%;\200\256\355;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377"
  "\377\0;\200\256#;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\344;\200\256\202;\200\256\37\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256<;\200\256\244;"
  "\200\256\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\350;\200\256I\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256"
  "\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\13;\200\2560;\200"
  "\256\212;\200\256\363;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\262\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256>;\200\256\371;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377\0;\200"
  "\256$;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\374;\200\256\262;\200"
  "\256M;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\24"
  ";\200\256j;\200\256\272;\200\256\372;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\260;\200\256\25\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\23;\200\256\204;\200\256\361;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256M\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\\;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377\0;\200\256"
  "$;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\340;\200\256};\200\256\33\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\17;\200\256X;\200\256\250;\200"
  "\256\361;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\301"
  ";\200\256>\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\20;\200\256~;\200\256"
  "\357;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\336;\200\256\11\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\177;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256%;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\246;\200"
  "\256\264;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373;\200"
  "\256\256;\200\256H;\200\256\2\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\6;\200\256G;\200\256\226;\200\256\344;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\307;\200\256"
  "E\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256#;\200\256\333;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\202\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\243;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\350\377\377\377\0;\200\256&;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256o\377"
  "\377\377\0\377\377\377\0;\200\256`;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\375;\200\256\306;\200\256u;\200\256"
  "\30\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256;;\200\256\226;\200\256\354;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\315;\200\256K\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\26;\200\256\313"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\370;\200\256\40\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256\277;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\350\377\377\377\0;\200\256&;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\274"
  ";\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\230;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\367;\200\256\263;\200\256d;\200\256\27\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\5;\200\256N;\200\256\252;\200\256\367;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\306;\200\256Q;\200\256\1"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\14;\200\256\270;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\251\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\13;\200\256\275;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256';\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\376;\200\256(\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\11;\200\256\345;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\354;\200\256\240;\200\256Q;\200\256\13\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\16;\200\256b;\200\256\275;\200\256\375;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\322;\200\256y;\200\256"
  "\40\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\5;\200\256\242;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2569\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\10"
  ";\200\256\266;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\350\377\377\377\0;\200\256(;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\255\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256f;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\334;\200\256\215;\200\256>;\200\256\3\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\33;\200\256k;\200\256\274;\200\256\373"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\336;\200\256\205"
  ";\200\256,\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\1;\200\256\261;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\307\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200"
  "\256\257;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\350\377\377\377\0;\200\256(;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\2563\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\4;"
  "\200\256\331;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\376;\200\256\311;\200\256z;\200\256+\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\21;\200"
  "\256];\200\256\255;\200\256\365;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\351;\200"
  "\256\266;\200\256\202;\200\2568\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\20;\200\256\336;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256X\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\4"
  ";\200\256\250;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377"
  "\377\377\0;\200\256);\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\271\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "T;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\370;\200\256\266;\200\256g;\200\256\32"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\11;\200\256N;\200\256\223;\200\256\263;\200"
  "\256\321;\200\256\356;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\352;\200"
  "\256\267;\200\256\204;\200\256P;\200\256\35\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\2563;\200\256\370;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\340;\200\256\10\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\3;\200\256\240;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377"
  "\377\377\0;\200\256*;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256@\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\312;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256\321"
  ";\200\256\226;\200\256T;\200\256\14\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\14;\200\256*;\200\256H;\200"
  "\256e;\200\256{;\200\256q;\200\256e;\200\256X;\200\256L;\200\256\77;"
  "\200\2562;\200\256&;\200\256\26\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256i;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256x\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256\203;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377\0;\200"
  "\256*;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\306\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "B;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\363;\200\256\274"
  ";\200\256\201;\200\256F;\200\256\16\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\246;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\361;\200\256\26\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256[;\200\256\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\350\377\377\377\0;\200\256+;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256J\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\266;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\342;\200\256\247;\200\256"
  "l;\200\2561;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\14;\200\256\341;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\230\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\15\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "9;\200\256\351;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350"
  "\377\377\377\0;\200\256,;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\315"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256+;\200\256\374;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\374;\200\256\315;\200\256\222;\200\256"
  "W;\200\256\35\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256T;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\374;\200"
  "\256+\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256.;\200\256\350;\200\256\200"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\37"
  ";\200\256\323;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377\377\377"
  "\0;\200\256,;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256Q\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\233;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\360;\200\256\270;\200\256};\200\256"
  "B;\200\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\274;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\260\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\2564;\200\256\355;\200\256\377;\200\256\377;\200\256"
  "\245;\200\256\7\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\15"
  ";\200\256\241;\200\256\336;\200\256\375;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\350\377\377\377\0;\200\256-;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\323;\200\256\1\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\31;\200\256\364;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\350;\200\256\301;\200\256\232;\200\256t;\200\256M;"
  "\200\256&;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256*;\200\256\373;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2562\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256:;\200\256\361"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\305;\200"
  "\256\25\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\7;\200\256+;\200\256Q;\200\256x;\200\256\236;\200\256"
  "\305;\200\256\353;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\350\377\377\377\0;\200\256.;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256X\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\200;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\366;\200\256\321;\200\256\252;\200\256"
  "\203;\200\256\\;\200\2566;\200\256\17\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\216;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\262\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\32;\200\256\352;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\335;\200"
  "\256)\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\22;\200\2568;\200\256_;\200\256\205;\200"
  "\256\253;\200\256\322;\200\256\363;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\350\377\377\377\0;\200\256.;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\320;\200\256\2\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\13"
  ";\200\256\334;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\376;\200\256\340;\200\256\272;\200\256\223;\200\256l;\200\256E;\200"
  "\256\36;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\16;\200\256\350;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\2564\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\3;\200\256\302;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\360;\200"
  "\256D\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\15;\200\256';\200\256@;\200"
  "\256Z;\200\256t;\200\256\216;\200\256\250;\200\256\302;\200\256\334;"
  "\200\256\365;\200\256\377;\200\256\377;\200\256\377;\200\256\350\377"
  "\377\377\0;\200\256/;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\365;\200\256)\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256(;\200\256\357;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256"
  "\355;\200\256\332;\200\256\306;\200\256\262;\200\256\236;\200\256\212"
  ";\200\256v;\200\256b;\200\256N;\200\256.;\200\256\11\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256d;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\265\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\207"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\373;\200\256\214;\200\256Y;\200\2560;\200\256\12\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\17;\200\256);\200\256C;\200\256S\377\377"
  "\377\0;\200\256\37;\200\256\217;\200\256\235;\200\256\253;\200\256\271"
  ";\200\256\307;\200\256\325;\200\256\343;\200\256\360;\200\256\375;\200"
  "\256\327;\200\256G\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\2564;\200\256\263;\200\256\357;\200\256\334;\200\256\310"
  ";\200\256\264;\200\256\240;\200\256\215;\200\256y;\200\256e;\200\256"
  "Q;\200\256=;\200\256);\200\256\25;\200\256\3\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\331;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\2566\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2565;\200\256\376"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256\340"
  ";\200\256\267;\200\256\217;\200\256g;\200\256\40\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\1;\200\256\1\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256W;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\267\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\300;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256A\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256\26;\200\2563;\200\2564\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\1;\200\256\320;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\2568\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256L;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\362;\200\256\5\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\25;\200\2562;\200\256N;\200\256k;\200\256\207;\200\256"
  "\244;\200\256\300;\200\256\335;\200\256\370;\200\256\377;\200\256\377"
  ";\200\256[\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256L;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\271\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\3;\200\256\325;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\257\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256B;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\330;\200\256\2\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\306;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256:\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256d;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256f\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\1;\200\256\314;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256[\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256A;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\274\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\12;\200"
  "\256\346;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\36\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256Y"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\327;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\273;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256D\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256|;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\325\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\6;\200\256\336;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256Z\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\2566;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\314;\200\256\1\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\21;\200\256\361;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\213\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256q;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\327;\200\256\2\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\260;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256W\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\200;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\375;\200\256$\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\34;\200\256\360"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "Y\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256,;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\334;\200\256\5\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\16;\200\256\357;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\252\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\1;\200\256\272;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\326;\200\256\2\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\244;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256k\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256|;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\2563\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256j"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256Y\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256\373;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\350;\200"
  "\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\14;\200\256\354;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\273"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256$;\200\256\365;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\326;\200\256\2\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\222;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256~\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256w;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256C\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\10"
  ";\200\256\313;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256X\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\21;\200\256\354;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\362;\200\256\25\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\12;\200"
  "\256\352;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\315\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\241;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\325;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256j;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\222\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\207;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256b\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256q;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256T\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\3;\200\256\322;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\371;\200\256!\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256,;\200\256\372;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\356;\200\256\11\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256D;\200\256\374;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\314;\200\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\7;\200\256:;\200\256t;\200\256\253;\200"
  "\256\273;\200\256\276;\200\256\302;\200\256\306;\200\256\312;\200\256"
  "\315;\200\256\321;\200\256\320;\200\256\14\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256A;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\267\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\1;\200\256\306;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\215\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256"
  "\355;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256H\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2"
  ";\200\256L;\200\256\213;\200\256\305;\200\256\370;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\264\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\255;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256d\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\203;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200"
  "\256%\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\14;\200\256\323;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\301\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256G;\200\256\320;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256Y\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\31;\200\256\352;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\361;\200\256\35\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256Z;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\271\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\1;\200\256\256;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256K\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\2562;\200\256\273;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\363;\200\256\12\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256I;\200\256\376;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\272\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256;;\200\256\370;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256O\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256q;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256'\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\36;\200\256\245;\200\256\376;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\227"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\214"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256f\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256I;\200\256\364;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\341;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  ",;\200\256\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\20"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256J;\200\256\356;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\364;\200\256\30\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\5;\200\256\313;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\362;\200\256\37\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256`;\200\256\373;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256z\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\6;\200\256\320;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\370\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\2;\200\256\200;\200\256\376;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\200\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256#;\200\256\361;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\274;\200"
  "\256\1\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256y;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\366;\200\256\26\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\212;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\341\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\22;\200\256\266;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\347;\200\256\13\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256H;\200\256\370;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256i\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\225;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256t\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\77;\200\256\375;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\312\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2561;\200\256\336;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256N\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256L;\200\256\371"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\363;\200\256$\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\36;\200\256\307;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\313;\200"
  "\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\17;\200\256\341;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\263\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256a;\200\256\367"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\202\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256P;\200\256\373;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\341;\200\256\"\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256K;\200\256\355;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\372;\200\256.\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\243"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\233\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\23;\200\256\250"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\265;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256T;\200\256\373"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\343;\200\256$\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\5;\200\256\210;\200\256\376"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\204\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256<"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\204\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256M;\200\256\347;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\320"
  ";\200\256\20\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256X;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\345;\200\256&\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256A;\200\256\325;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\327;\200\256\7\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\263;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256m\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\2569;\200\256\260;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\312"
  ";\200\256\21\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\\;\200\256\375;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\347;\200\256H\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\32;\200\256\247;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\371;\200\256:\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256+;\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256M\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\7;\200\256O;\200\256\303;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\303;\200\256"
  "\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256`;\200\256\376;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\246;\200"
  "\256\26\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\4;\200\256s;\200\256\362;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\372"
  ";\200\256O\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\241;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\375;\200\256\20\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\3;\200\2566;\200\256x;\200\256\273;\200\256\366;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\244;\200\256\12\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256d;\200\256"
  "\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\355"
  ";\200\256c;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\77;\200\256\324;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\372;\200\256P\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\32;\200\256\372"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\311\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\4;\200\256/;\200\256n;\200\256\260;\200\256\360;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\354;\200\256T\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256c"
  ";\200\256\373;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\341;\200\256y;\200\256\24\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\31;\200\256\245;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\372;\200\256Q\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256n;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\206\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\11;\200\2566;\200\256h;\200\256\232;\200\256\313;\200\256"
  "\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\264;\200\256\30\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256A"
  ";\200\256\354;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\370;\200\256\240;\200\256G;\200\256\7"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\25;\200\256\206;\200\256\362"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373"
  ";\200\256S\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\301;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\2569\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\4;\200\256B;\200\256\224;\200\256\323;\200\256\374;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\363;\200\256d\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "#;\200\256\325;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\363;\200\256"
  "\255;\200\256`;\200\256\25\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\32"
  ";\200\256\217;\200\256\365;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\370;\200\256R\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\27;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\262\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\10;\200\256M;\200\256\236;\200\256\354;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\302;\200\256!\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\16"
  ";\200\256\265;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\374;\200\256\300;\200\256o;\200\256\37\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\40;\200\256\227;\200\256\370;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\355;\200\256<\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256h;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\372;\200\256%\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\10;\200\256V;\200\256\251;\200\256"
  "\363;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\333"
  ";\200\256a;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256"
  "\214;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\315;\200\256{;\200\256*\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256&;\200\256\237;\200\256\373;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\336;\200\256'\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\273;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\215"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2566;\200\256\227;"
  "\200\256\357;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\324;\200\256Z;\200\256\3\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256`"
  ";\200\256\371;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\331"
  ";\200\256\177;\200\256\20\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256,;\200\256"
  "\247;\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\312"
  ";\200\256\26\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11"
  ";\200\256\372;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\353;\200\256\20\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\31;\200"
  "\256u;\200\256\326;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\315;\200\256R;\200\256\1\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256;;\200\256\351"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357"
  ";\200\256{;\200\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\2564;\200\256\257;\200\256\376;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\262;\200\256\12\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256:;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "T\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\6;\200\256T;\200"
  "\256\265;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\306;\200\256J\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\37;\200\256\315;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\353;\200\256"
  "i\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256;;\200\256\267;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\225;\200\256\3\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256p"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\210\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\27;\200\256];\200"
  "\256\243;\200\256\355;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\351;\200\256\220;\200\2563\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\7;\200\256\227;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\244;\200\256"
  "\11\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256D;\200\256\277;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\374;\200\256"
  "q\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\246;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\272;\200\256\3\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\7;\200\256B;\200\256\211;\200\256\320"
  ";\200\256\376;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\366;\200\256\247;\200\256J;\200\256\4"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256Z;\200\256\364;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\316;\200\256\37\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256L;\200\256\307;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\357;\200\256F\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\334;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\337;\200\256\23\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256);\200\256o;\200\256\265;\200\256\365;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\376;\200\256\276;\200\256a;\200\256\16\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256);\200\256"
  "\324;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\353;\200\256;\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256>;\200\256\314;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\330;\200\256&\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\23;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\372;\200\2562\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\40;\200\256b;\200\256\244;\200\256\346;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\325;\200\256x;\200\256\35\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\12;\200\256\242;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\352;\200\256\34\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256$;\200\256\256"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\266;\200\256"
  "\17\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256H"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\177"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\27"
  ";\200\256Y;\200\256\233;\200\256\335;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\350;\200\256\217;\200\2562\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256d;\200\256\367;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\307;\200\256\6\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\20;\200"
  "\256\215;\200\256\371;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\375"
  ";\200\256\206;\200\256\2\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256k;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\322;\200\256\5\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256/;\200\256\203"
  ";\200\256\323;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\366;\200\256\246;\200\256I;\200\256\3\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\2560;\200\256\333;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\224\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\4;\200\256l;\200\256\354;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\342;\200\256@\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\205"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\374;\200\2563\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\2564;\200\256\210;\200\256"
  "\333;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\364;\200\256\260;\200\256`;\200\256\15\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\16"
  ";\200\256\254;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256I\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256K;\200\256\327;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\250;\200\256\20\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\240;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\207\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\1;\200\2568;\200\256\214;\200"
  "\256\337;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\336;\200\256\222;\200\256G;\200\256\7\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "o;\200\256\372;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\341;\200\256\14"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256.;\200\256\273;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\361;\200\256]\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\272;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\331;\200\256\7\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0;\200\256\17;\200\256\177;\200"
  "\256\343;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\373;\200\256\300;\200\256u;\200\256)\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\2567;\200\256\341"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\220\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\27;\200\256\232"
  ";\200\256\375;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\272;\200\256\40\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\325;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256r\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\15"
  ";\200\256|;\200\256\356;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\353;\200\256\242;\200\256W;\200\256\20\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\23;\200\256\265;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\375;\200\2566\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\10"
  ";\200\256z;\200\256\362;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\340;\200\256R\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\353;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\376;\200\256\36\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\14;\200\256y;\200\256\355;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\320;\200\256\205;\200\2569;\200\256\2\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\1;\200\256z;\200\256\374;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\322"
  ";\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200"
  "\256\1;\200\256Y;\200\256\341;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\370;\200\256\202;\200\256\11\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\346;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\323\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\13;\200\256v;\200\256\353;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\365;\200"
  "\256\262;\200\256g;\200\256\34\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256@;\200\256\347;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\204\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\2569;\200\256\307;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\263"
  ";\200\256#\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\334;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\321\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\12;\200\256t;\200\256\352;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\327;\200\256\216;\200\256E;\200\256\7\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\27;\200\256\277;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\373;\200\2564\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0;\200\256\2;\200\256P;\200\256\300"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\334;\200\256K\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\322;\200\256\377;\200\256\377;\200\256\377;\200\256\377;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\332\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\11;\200\256"
  "q;\200\256\350;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\364;\200"
  "\256\263;\200\256i;\200\256\40\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\4;\200\256\230;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\324;\200\256\7\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\17"
  ";\200\256r;\200\256\336;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\365;\200\256{;\200\256\7\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\310;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\371;\200\256!\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\10;\200\256n;\200\256\346;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\327;\200"
  "\256\216;\200\256E;\200\256\7\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256o;\200\256\374;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\217\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256&;\200\256\224;\200\256\363;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\254"
  ";\200\256\36\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256\263;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\253\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\27;\200\256v;\200\256\344;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\364"
  ";\200\256\262;\200\256i;\200\256\40\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256J;\200\256\362;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\202\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0;\200\256\16;\200\256P;\200\256\265;\200\256\376"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\322;\200\256D\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256~;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256T\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\3;\200\256M;\200\256\260;\200\256\373"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\327"
  ";\200\256\215;\200\256D;\200\256\7\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  ",;\200\256\337;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\205\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\25;\200\256C;\200\256\205;\200\256\310;\200\256\374;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\326;\200\256V;\200\256\1\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256F;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\232;\200\256\14\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256%;\200\256\207;\200\256\346;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\326;\200"
  "\256\177;\200\256)\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\26;\200\256"
  "\305;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\257;\200"
  "\256A\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256"
  "\13;\200\256';\200\256B;\200\256^;\200\256z;\200\256\227;\200\256\266"
  ";\200\256\326;\200\256\365;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\331;\200\256Z;\200\256\2\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0;\200\256\20;\200\256\376;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\335;\200\256[;\200\256(;\200\256\3\377\377\377\0;\200\256"
  "\26;\200\256=;\200\256i;\200\256\301;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\332;\200\256\204;\200\256-\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\7;\200\256\244;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\341;\200\256\255;\200\256};\200\256h;\200"
  "\256h;\200\256h;\200\256h;\200\256h;\200\256j;\200\256\201;\200\256\234"
  ";\200\256\270;\200\256\324;\200\256\357;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\334;\200\256^;\200\256\3\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\311;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\367;\200\256\360;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\336;\200\256\210;\200\2561\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256u;\200\256\374;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\336;\200\256b;\200\256\4\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256W;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\342;\200\256\215;\200\2566\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256F;\200\256\356;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\341;\200\256f;\200\256\5\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256\3;\200\256\335;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\346;\200\256\221;\200\256:;\200\256\1\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256#;\200\256\323;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\344;\200\256j;\200\256\6"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256c;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\351;\200\256\226;\200\256\77;\200\256\2\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\13;\200\256\254;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\333;\200\256e;\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\237;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\357;\200\256\235;\200\256D;\200\256\3\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256z;\200\256\375;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\320;\200\256W;\200\256\3\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\6;\200\256\305;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\364;\200\256\245;\200"
  "\256M;\200\256\6\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256K;\200\256\356;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\303"
  ";\200\256J\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0;\200\256\22;\200\256\260;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\370;\200\256\256;\200\256V;\200\256\12\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\27;\200\256\244"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\266;\200\256<\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256k;\200\256\367;"
  "\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\374;\200\256\315;\200\256\216;\200\256"
  "O;\200\256\16\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256C;\200\256\332;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\375;\200\256\250;\200\256/\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\33;\200\256\200;\200\256\345;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\373;\200"
  "\256\310;\200\256\211;\200\256J;\200\256\16\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\7;\200\256\200"
  ";\200\256\370;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\354;\200\256\224;\200\256$\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\4;\200"
  "\256H;\200\256\202;\200\256\267;\200\256\353;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\357;\200"
  "\256\326;\200\256\274;\200\256\242;\200\256\210;\200\256o;\200\256F;"
  "\200\256\14\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377"
  "\377\377\0\377\377\377\0;\200\256&;\200\256\274;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\367;\200"
  "\256\252;\200\256N;\200\256\5\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0;\200\256\11;\200\256\27;\200\256&;\200\2563;\200\256#;\200\256\11"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256Z;\200\256\323;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\376;\200\256"
  "\277;\200\256c;\200\256\17\377\377\377\0\377\377\377\0\377\377\377\0"
  "\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0;\200\256=;\200\256\247;\200\256\371;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\376;\200\256\321;\200\256w;\200\256\35\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0;\200\256\25;\200\256W;\200"
  "\256\223;\200\256\320;\200\256\375;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377"
  ";\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200"
  "\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256"
  "\377;\200\256\377;\200\256\377;\200\256\377;\200\256\377;\200\256\356"
  ";\200\256\301;\200\256\224;\200\256f;\200\2569;\200\256\14\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377"
  "\0\377\377\377\0;\200\256\16;\200\256/;\200\256E;\200\256[;\200\256r"
  ";\200\256\210;\200\256\236;\200\256\265;\200\256\313;\200\256\341;\200"
  "\256\364;\200\256\357;\200\256\347;\200\256\337;\200\256\327;\200\256"
  "\317;\200\256\307;\200\256\277;\200\256\267;\200\256\257;\200\256\241"
  ";\200\256w;\200\256J;\200\256\34\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377\377\0\377\377"
  "\377\0\377\377\377\0\377\377\377\0"};
